@@ -13,7 +13,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /* drizzledump.cc  - Dump a tables contents and format to an ASCII file
 
@@ -56,52 +56,24 @@ namespace po= boost::program_options;
 
 #define EX_USAGE 1
 #define EX_DRIZZLEERR 2
-#define EX_CONSCHECK 3
-#define EX_EOM 4
 #define EX_EOF 5 /* ferror for output file was got */
-#define EX_ILLEGAL_TABLE 6
-#define EX_TABLE_STATUS 7
-
-/* index into 'show fields from table' */
-
-#define SHOW_FIELDNAME  0
-#define SHOW_TYPE  1
-#define SHOW_NULL  2
-#define SHOW_DEFAULT  4
-#define SHOW_EXTRA  5
-
-/* Size of buffer for dump's select query */
-#define QUERY_LENGTH 1536
-
-/* ignore table flags */
-#define IGNORE_NONE 0x00 /* no ignore */
-#define IGNORE_DATA 0x01 /* don't dump data for this table */
-#define IGNORE_INSERT_DELAYED 0x02 /* table doesn't support INSERT DELAYED */
 
 bool  verbose= false;
 static bool use_drizzle_protocol= false;
-static bool quick= true;
-static bool ignore_errors= false;
+bool ignore_errors= false;
 static bool flush_logs= false;
-static bool opt_keywords= false;
-static bool opt_compress= false;
-static bool opt_delayed= false; 
 static bool create_options= true; 
 static bool opt_quoted= false;
 bool opt_databases= false; 
 bool opt_alldbs= false; 
 static bool opt_lock_all_tables= false;
-static bool opt_set_charset= false; 
 static bool opt_dump_date= true;
-static bool opt_autocommit= false; 
+bool opt_autocommit= false; 
 static bool opt_single_transaction= false; 
 static bool opt_comments;
 static bool opt_compact;
-static bool opt_order_by_primary=false; 
 bool opt_ignore= false;
-static bool opt_complete_insert= false;
-static bool opt_drop_database;
-static bool opt_alltspcs= false;
+bool opt_drop_database;
 bool opt_no_create_info;
 bool opt_no_data= false;
 bool opt_create_db= false;
@@ -109,10 +81,9 @@ bool opt_disable_keys= true;
 bool extended_insert= true;
 bool opt_replace_into= false;
 bool opt_drop= true; 
+bool opt_data_is_mangled= false;
 uint32_t show_progress_size= 0;
-//static uint64_t total_rows= 0;
 static string insert_pat;
-//static char *order_by= NULL;
 static uint32_t opt_drizzle_port= 0;
 static int first_error= 0;
 static string extended_row;
@@ -141,17 +112,12 @@ string password,
   enclosed,
   escaped,
   current_host,
-  opt_enclosed,
-  fields_terminated,
   path,
-  lines_terminated,
   current_user,
   opt_password,
   opt_protocol,
   where;
 
-//static const CHARSET_INFO *charset_info= &my_charset_utf8_general_ci;
-
 boost::unordered_set<string> ignore_table;
 
 void maybe_exit(int error);
@@ -170,7 +136,7 @@ void dump_all_tables(void)
   std::vector<DrizzleDumpDatabase*>::iterator i;
   for (i= database_store.begin(); i != database_store.end(); ++i)
   {
-    if (not (*i)->populateTables())
+    if ((not (*i)->populateTables()) && (not ignore_errors))
       maybe_exit(EX_DRIZZLEERR);
   }
 }
@@ -178,14 +144,16 @@ void dump_all_tables(void)
 void generate_dump(void)
 {
   std::vector<DrizzleDumpDatabase*>::iterator i;
-  if (opt_set_charset)
-    cout << endl << "SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION;" << endl;
 
   if (path.empty())
   {
     cout << endl << "SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;"
       << endl << "SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;" << endl;
   }
+
+  if (opt_autocommit)
+    cout << "SET AUTOCOMMIT=0;" << endl;
+
   for (i= database_store.begin(); i != database_store.end(); ++i)
   {
     DrizzleDumpDatabase *database= *i;
@@ -197,21 +165,26 @@ void generate_dump(void)
     cout << "SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;"
       << endl << "SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;" << endl;
   }
-  if (opt_set_charset)
-    cout << "SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION;" << endl;
 }
 
 void generate_dump_db(void)
 {
   std::vector<DrizzleDumpDatabase*>::iterator i;
   DrizzleStringBuf sbuf(1024);
-  destination_connection= new DrizzleDumpConnection(opt_destination_host,
-    opt_destination_port, opt_destination_user, opt_destination_password,
-    false);
+  try
+  {
+    destination_connection= new DrizzleDumpConnection(opt_destination_host,
+      opt_destination_port, opt_destination_user, opt_destination_password,
+      false);
+  }
+  catch (std::exception&)
+  {
+    cerr << "Could not connect to destination database server" << endl;
+    maybe_exit(EX_DRIZZLEERR);
+  }
   sbuf.setConnection(destination_connection);
   std::ostream sout(&sbuf);
-  if (opt_set_charset)
-    sout << "SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION;" << endl;
+  sout.exceptions(ios_base::badbit);
 
   if (path.empty())
   {
@@ -219,10 +192,22 @@ void generate_dump_db(void)
     sout << "SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;" << endl;
   }
 
+  if (opt_autocommit)
+    cout << "SET AUTOCOMMIT=0;" << endl;
+
   for (i= database_store.begin(); i != database_store.end(); ++i)
   {
-    DrizzleDumpDatabase *database= *i;
-    sout << *database;
+    try
+    {
+      DrizzleDumpDatabase *database= *i;
+      sout << *database;
+    }
+    catch (std::exception&)
+    {
+      std::cout << _("Error inserting into destination database") << std::endl;
+      if (not ignore_errors)
+        maybe_exit(EX_DRIZZLEERR);
+    }
   }
 
   if (path.empty())
@@ -230,8 +215,6 @@ void generate_dump_db(void)
     sout << "SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;" << endl;
     sout << "SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;" << endl;
   }
-  if (opt_set_charset)
-    sout << "SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION;" << endl;
 }
 
 /*
@@ -258,12 +241,13 @@ static void write_header(char *db_name)
     cout << "-- Host: " << current_host << "    Database: " << db_name << endl;
     cout << "-- ------------------------------------------------------" << endl;
     cout << "-- Server version\t" << db_connection->getServerVersion();
-    if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+    if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
       cout << " (MySQL server)";
-    else if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_DRIZZLE_FOUND)
+    else if (db_connection->getServerType() == ServerDetect::SERVER_DRIZZLE_FOUND)
       cout << " (Drizzle server)";
     cout << endl << endl;
   }
+
 } /* write_header */
 
 
@@ -288,26 +272,12 @@ static void write_footer(FILE *sql_file)
 
 static int get_options(void)
 {
-
-  if (path.empty() && (! enclosed.empty() || ! opt_enclosed.empty() || ! escaped.empty() || ! lines_terminated.empty() ||
-                ! fields_terminated.empty()))
-  {
-    fprintf(stderr,
-            _("%s: You must use option --tab with --fields-...\n"), progname.c_str());
-    return(EX_USAGE);
-  }
-
   if (opt_single_transaction && opt_lock_all_tables)
   {
     fprintf(stderr, _("%s: You can't use --single-transaction and "
                       "--lock-all-tables at the same time.\n"), progname.c_str());
     return(EX_USAGE);
   }
-  if (! enclosed.empty() && ! opt_enclosed.empty())
-  {
-    fprintf(stderr, _("%s: You can't use ..enclosed.. and ..optionally-enclosed.. at the same time.\n"), progname.c_str());
-    return(EX_USAGE);
-  }
   if ((opt_databases || opt_alldbs) && ! path.empty())
   {
     fprintf(stderr,
@@ -365,8 +335,7 @@ void maybe_exit(int error)
   if (ignore_errors)
     return;
   delete db_connection;
-  if (destination_connection)
-    delete destination_connection;
+  delete destination_connection;
   free_resources();
   exit(error);
 }
@@ -383,7 +352,7 @@ static int dump_all_databases()
     std::cerr << _("-- Retrieving database structures...") << std::endl;
 
   /* Blocking the MySQL privilege tables too because we can't import them due to bug#646187 */
-  if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+  if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
     query= "SELECT SCHEMA_NAME, DEFAULT_COLLATION_NAME FROM INFORMATION_SCHEMA.SCHEMATA WHERE SCHEMA_NAME NOT IN ('information_schema', 'performance_schema', 'mysql')";
   else
     query= "SELECT SCHEMA_NAME, DEFAULT_COLLATION_NAME FROM DATA_DICTIONARY.SCHEMAS WHERE SCHEMA_NAME NOT IN ('information_schema','data_dictionary')";
@@ -392,7 +361,7 @@ static int dump_all_databases()
   while ((row= drizzle_row_next(tableres)))
   {
     std::string database_name(row[0]);
-    if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+    if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
       database= new DrizzleDumpDatabaseMySQL(database_name, db_connection);
     else
       database= new DrizzleDumpDatabaseDrizzle(database_name, db_connection);
@@ -415,7 +384,7 @@ static int dump_databases(const vector<string> &db_names)
   for (vector<string>::const_iterator it= db_names.begin(); it != db_names.end(); ++it)
   {
     temp= *it;
-    if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+    if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
       database= new DrizzleDumpDatabaseMySQL(temp, db_connection);
     else
       database= new DrizzleDumpDatabaseDrizzle(temp, db_connection);
@@ -428,7 +397,7 @@ static int dump_selected_tables(const string &db, const vector<string> &table_na
 {
   DrizzleDumpDatabase *database;
 
-  if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+  if (db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND)
     database= new DrizzleDumpDatabaseMySQL(db, db_connection);
   else
     database= new DrizzleDumpDatabaseDrizzle(db, db_connection);
@@ -436,7 +405,8 @@ static int dump_selected_tables(const string &db, const vector<string> &table_na
   if (not database->populateTables(table_names))
   {
     delete database;
-    maybe_exit(EX_DRIZZLEERR);
+    if (not ignore_errors)
+      maybe_exit(EX_DRIZZLEERR);
   }
 
   database_store.push_back(database); 
@@ -461,16 +431,24 @@ static int do_flush_tables_read_lock()
   return 0;
 }
 
-static int do_unlock_tables()
-{
-  db_connection->queryNoResult("UNLOCK TABLES");
-  return 0;
-}
-
 static int start_transaction()
 {
   db_connection->queryNoResult("SET SESSION TRANSACTION ISOLATION LEVEL REPEATABLE READ");
   db_connection->queryNoResult("START TRANSACTION WITH CONSISTENT SNAPSHOT");
+
+  if (db_connection->getServerType() == ServerDetect::SERVER_DRIZZLE_FOUND)
+  {
+    drizzle_result_st *result;
+    drizzle_row_t row;
+    std::string query("SELECT COMMIT_ID, ID FROM DATA_DICTIONARY.SYS_REPLICATION_LOG WHERE COMMIT_ID=(SELECT MAX(COMMIT_ID) FROM DATA_DICTIONARY.SYS_REPLICATION_LOG)");
+    result= db_connection->query(query);
+    if ((row= drizzle_row_next(result)))
+    {
+      cout << "-- SYS_REPLICATION_LOG: COMMIT_ID = " << row[0] << ", ID = " << row[1] << endl << endl;
+    }
+    db_connection->freeResult(result);
+  }
+
   return 0;
 }
 
@@ -480,118 +458,107 @@ try
 {
   int exit_code;
 
-  po::options_description commandline_options(N_("Options used only in command line"));
+#if defined(ENABLE_NLS)
+# if defined(HAVE_LOCALE_H)
+  setlocale(LC_ALL, "");
+# endif
+  bindtextdomain("drizzle7", LOCALEDIR);
+  textdomain("drizzle7");
+#endif
+
+  po::options_description commandline_options(_("Options used only in command line"));
   commandline_options.add_options()
   ("all-databases,A", po::value<bool>(&opt_alldbs)->default_value(false)->zero_tokens(),
-  N_("Dump all the databases. This will be same as --databases with all databases selected."))
-  ("all-tablespaces,Y", po::value<bool>(&opt_alltspcs)->default_value(false)->zero_tokens(),
-  N_("Dump all the tablespaces."))
-  ("complete-insert,c", po::value<bool>(&opt_complete_insert)->default_value(false)->zero_tokens(),
-  N_("Use complete insert statements."))
-  ("compress,C", po::value<bool>(&opt_compress)->default_value(false)->zero_tokens(),
-  N_("Use compression in server/client protocol."))
+  _("Dump all the databases. This will be same as --databases with all databases selected."))
   ("flush-logs,F", po::value<bool>(&flush_logs)->default_value(false)->zero_tokens(),
-  N_("Flush logs file in server before starting dump. Note that if you dump many databases at once (using the option --databases= or --all-databases), the logs will be flushed for each database dumped. The exception is when using --lock-all-tables in this case the logs will be flushed only once, corresponding to the moment all tables are locked. So if you want your dump and the log flush to happen at the same exact moment you should use --lock-all-tables or --flush-logs"))
+  _("Flush logs file in server before starting dump. Note that if you dump many databases at once (using the option --databases= or --all-databases), the logs will be flushed for each database dumped. The exception is when using --lock-all-tables in this case the logs will be flushed only once, corresponding to the moment all tables are locked. So if you want your dump and the log flush to happen at the same exact moment you should use --lock-all-tables or --flush-logs"))
   ("force,f", po::value<bool>(&ignore_errors)->default_value(false)->zero_tokens(),
-  N_("Continue even if we get an sql-error."))
-  ("help,?", N_("Display this help message and exit."))
+  _("Continue even if we get an sql-error."))
+  ("help,?", _("Display this help message and exit."))
   ("lock-all-tables,x", po::value<bool>(&opt_lock_all_tables)->default_value(false)->zero_tokens(),
-  N_("Locks all tables across all databases. This is achieved by taking a global read lock for the duration of the whole dump. Automatically turns --single-transaction and --lock-tables off."))
-  ("order-by-primary", po::value<bool>(&opt_order_by_primary)->default_value(false)->zero_tokens(),
-  N_("Sorts each table's rows by primary key, or first unique key, if such a key exists.  Useful when dumping a MyISAM table to be loaded into an InnoDB table, but will make the dump itself take considerably longer."))
+  _("Locks all tables across all databases. This is achieved by taking a global read lock for the duration of the whole dump. Automatically turns --single-transaction off."))
   ("single-transaction", po::value<bool>(&opt_single_transaction)->default_value(false)->zero_tokens(),
-  N_("Creates a consistent snapshot by dumping all tables in a single transaction. Works ONLY for tables stored in storage engines which support multiversioning (currently only InnoDB does); the dump is NOT guaranteed to be consistent for other storage engines. While a --single-transaction dump is in process, to ensure a valid dump file (correct table contents), no other connection should use the following statements: ALTER TABLE, DROP TABLE, RENAME TABLE, TRUNCATE TABLE, as consistent snapshot is not isolated from them. Option automatically turns off --lock-tables."))
-  ("opt", N_("Same as --add-drop-table, --add-locks, --create-options, --quick, --extended-insert, --lock-tables, --set-charset, and --disable-keys. Enabled by default, disable with --skip-opt.")) 
+  _("Creates a consistent snapshot by dumping all tables in a single transaction. Works ONLY for tables stored in storage engines which support multiversioning (currently only InnoDB does); the dump is NOT guaranteed to be consistent for other storage engines. While a --single-transaction dump is in process, to ensure a valid dump file (correct table contents), no other connection should use the following statements: ALTER TABLE, DROP TABLE, RENAME TABLE, TRUNCATE TABLE, as consistent snapshot is not isolated from them."))
   ("skip-opt", 
-  N_("Disable --opt. Disables --add-drop-table, --add-locks, --create-options, --quick, --extended-insert, --lock-tables, --set-charset, and --disable-keys."))    
-  ("tables", N_("Overrides option --databases (-B)."))
+  _("Disable --opt. Disables --add-drop-table, --add-locks, --create-options, ---extended-insert and --disable-keys."))    
+  ("tables", _("Overrides option --databases (-B)."))
   ("show-progress-size", po::value<uint32_t>(&show_progress_size)->default_value(10000),
-  N_("Number of rows before each output progress report (requires --verbose)."))
+  _("Number of rows before each output progress report (requires --verbose)."))
   ("verbose,v", po::value<bool>(&verbose)->default_value(false)->zero_tokens(),
-  N_("Print info about the various stages."))
-  ("version,V", N_("Output version information and exit."))
-  ("skip-comments", N_("Turn off Comments"))
-  ("skip-create", N_("Turn off create-options"))
-  ("skip-extended-insert", N_("Turn off extended-insert"))
-  ("skip-dump-date",N_( "Turn off dump date at the end of the output"))
-  ("no-defaults", N_("Do not read from the configuration files"))
+  _("Print info about the various stages."))
+  ("version,V", _("Output version information and exit."))
+  ("skip-comments", _("Turn off Comments"))
+  ("skip-create", _("Turn off create-options"))
+  ("skip-extended-insert", _("Turn off extended-insert"))
+  ("skip-dump-date", _( "Turn off dump date at the end of the output"))
+  ("no-defaults", _("Do not read from the configuration files"))
   ;
 
-  po::options_description dump_options(N_("Options specific to the drizzle client"));
+  po::options_description dump_options(_("Options specific to the drizzle client"));
   dump_options.add_options()
   ("add-drop-database", po::value<bool>(&opt_drop_database)->default_value(false)->zero_tokens(),
-  N_("Add a 'DROP DATABASE' before each create."))
-  ("skip-drop-table", N_("Do not add a 'drop table' before each create."))
-  ("allow-keywords", po::value<bool>(&opt_keywords)->default_value(false)->zero_tokens(),
-  N_("Allow creation of column names that are keywords."))
+  _("Add a 'DROP DATABASE' before each create."))
+  ("skip-drop-table", _("Do not add a 'drop table' before each create."))
   ("compact", po::value<bool>(&opt_compact)->default_value(false)->zero_tokens(),
-  N_("Give less verbose output (useful for debugging). Disables structure comments and header/footer constructs.  Enables options --skip-add-drop-table --no-set-names --skip-disable-keys --skip-add-locks"))
+  _("Give less verbose output (useful for debugging). Disables structure comments and header/footer constructs.  Enables options --skip-add-drop-table --no-set-names --skip-disable-keys"))
   ("databases,B", po::value<bool>(&opt_databases)->default_value(false)->zero_tokens(),
-  N_("To dump several databases. Note the difference in usage; In this case no tables are given. All name arguments are regarded as databasenames. 'USE db_name;' will be included in the output."))
-  ("delayed-insert", po::value<bool>(&opt_delayed)->default_value(false)->zero_tokens(),
-  N_("Insert rows with INSERT DELAYED;"))
+  _("To dump several databases. Note the difference in usage; In this case no tables are given. All name arguments are regarded as databasenames. 'USE db_name;' will be included in the output."))
   ("skip-disable-keys,K",
-  N_("'ALTER TABLE tb_name DISABLE KEYS; and 'ALTER TABLE tb_name ENABLE KEYS; will not be put in the output."))
+  _("'ALTER TABLE tb_name DISABLE KEYS;' and 'ALTER TABLE tb_name ENABLE KEYS;' will not be put in the output."))
   ("ignore-table", po::value<string>(),
-  N_("Do not dump the specified table. To specify more than one table to ignore, use the directive multiple times, once for each table.  Each table must be specified with both database and table names, e.g. --ignore-table=database.table"))
+  _("Do not dump the specified table. To specify more than one table to ignore, use the directive multiple times, once for each table.  Each table must be specified with both database and table names, e.g. --ignore-table=database.table"))
   ("insert-ignore", po::value<bool>(&opt_ignore)->default_value(false)->zero_tokens(),
-  N_("Insert rows with INSERT IGNORE."))
-  ("lines-terminated-by", po::value<string>(&lines_terminated)->default_value(""),
-  N_("Lines in the i.file are terminated by ..."))
+  _("Insert rows with INSERT IGNORE."))
   ("no-autocommit", po::value<bool>(&opt_autocommit)->default_value(false)->zero_tokens(),
-  N_("Wrap tables with autocommit/commit statements."))
+  _("Wrap a table's data in START TRANSACTION/COMMIT statements."))
   ("no-create-db,n", po::value<bool>(&opt_create_db)->default_value(false)->zero_tokens(),
-  N_("'CREATE DATABASE IF NOT EXISTS db_name;' will not be put in the output. The above line will be added otherwise, if --databases or --all-databases option was given."))
-  ("no-create-info,t", po::value<bool>(&opt_no_create_info)->default_value(false)->zero_tokens(),
-  N_("Don't write table creation info."))
+  _("'CREATE DATABASE IF NOT EXISTS db_name;' will not be put in the output. The above line will be added otherwise, if --databases or --all-databases option was given."))
   ("no-data,d", po::value<bool>(&opt_no_data)->default_value(false)->zero_tokens(),
-  N_("No row information."))
-  ("no-set-names,N", N_("Deprecated. Use --skip-set-charset instead."))
-  ("set-charset", po::value<bool>(&opt_set_charset)->default_value(false)->zero_tokens(),
-  N_("Enable set-name"))
-  ("slow", N_("Buffer query instead of dumping directly to stdout."))
+  _("No row information."))
   ("replace", po::value<bool>(&opt_replace_into)->default_value(false)->zero_tokens(),
-  N_("Use REPLACE INTO instead of INSERT INTO."))
-  ("result-file,r", po::value<string>(),
-  N_("Direct output to a given file. This option should be used in MSDOS, because it prevents new line '\\n' from being converted to '\\r\\n' (carriage return + line feed)."))
+  _("Use REPLACE INTO instead of INSERT INTO."))
   ("destination-type", po::value<string>()->default_value("stdout"),
-  N_("Where to send output to (stdout|database"))
+  _("Where to send output to (stdout|database"))
   ("destination-host", po::value<string>(&opt_destination_host)->default_value("localhost"),
-  N_("Hostname for destination db server (requires --destination=database)"))
-  ("destination-port", po::value<uint16_t>(&opt_destination_port)->default_value(3306),
-  N_("Port number for destination db server (requires --destination=database)"))
+  _("Hostname for destination db server (requires --destination-type=database)"))
+  ("destination-port", po::value<uint16_t>(&opt_destination_port)->default_value(4427),
+  _("Port number for destination db server (requires --destination-type=database)"))
   ("destination-user", po::value<string>(&opt_destination_user),
-  N_("User name for destination db server (resquires --destination=database)"))
+  _("User name for destination db server (resquires --destination-type=database)"))
   ("destination-password", po::value<string>(&opt_destination_password),
-  N_("Password for destination db server (requires --destination=database)"))
+  _("Password for destination db server (requires --destination-type=database)"))
   ("destination-database", po::value<string>(&opt_destination_database),
-  N_("The database in the destination db server (requires --destination=database, not for use with --all-databases)"))
+  _("The database in the destination db server (requires --destination-type=database, not for use with --all-databases)"))
+  ("my-data-is-mangled", po::value<bool>(&opt_data_is_mangled)->default_value(false)->zero_tokens(),
+  _("Do not make a UTF8 connection to MySQL, use if you have UTF8 data in a non-UTF8 table"))
   ;
 
-  po::options_description client_options(N_("Options specific to the client"));
+  const char* unix_user= getlogin();
+
+  po::options_description client_options(_("Options specific to the client"));
   client_options.add_options()
   ("host,h", po::value<string>(&current_host)->default_value("localhost"),
-  N_("Connect to host."))
+  _("Connect to host."))
   ("password,P", po::value<string>(&password)->default_value(PASSWORD_SENTINEL),
-  N_("Password to use when connecting to server. If password is not given it's solicited on the tty."))
+  _("Password to use when connecting to server. If password is not given it's solicited on the tty."))
   ("port,p", po::value<uint32_t>(&opt_drizzle_port)->default_value(0),
-  N_("Port number to use for connection."))
-  ("user,u", po::value<string>(&current_user)->default_value(""),
-  N_("User for login if not current user."))
+  _("Port number to use for connection."))
+  ("user,u", po::value<string>(&current_user)->default_value((unix_user ? unix_user : "")),
+  _("User for login if not current user."))
   ("protocol",po::value<string>(&opt_protocol)->default_value("mysql"),
-  N_("The protocol of connection (mysql or drizzle)."))
+  _("The protocol of connection (mysql or drizzle)."))
   ;
 
-  po::options_description hidden_options(N_("Hidden Options"));
+  po::options_description hidden_options(_("Hidden Options"));
   hidden_options.add_options()
-  ("database-used", po::value<vector<string> >(), N_("Used to select the database"))
-  ("Table-used", po::value<vector<string> >(), N_("Used to select the tables"))
+  ("database-used", po::value<vector<string> >(), _("Used to select the database"))
+  ("Table-used", po::value<vector<string> >(), _("Used to select the tables"))
   ;
 
-  po::options_description all_options(N_("Allowed Options + Hidden Options"));
+  po::options_description all_options(_("Allowed Options + Hidden Options"));
   all_options.add(commandline_options).add(dump_options).add(client_options).add(hidden_options);
 
-  po::options_description long_options(N_("Allowed Options"));
+  po::options_description long_options(_("Allowed Options"));
   long_options.add(commandline_options).add(dump_options).add(client_options);
 
   std::string system_config_dir_dump(SYSCONFDIR); 
@@ -602,6 +569,14 @@ try
 
   std::string user_config_dir((getenv("XDG_CONFIG_HOME")? getenv("XDG_CONFIG_HOME"):"~/.config"));
 
+  if (user_config_dir.compare(0, 2, "~/") == 0)
+  {
+    char *homedir;
+    homedir= getenv("HOME");
+    if (homedir != NULL)
+      user_config_dir.replace(0, 1, homedir);
+  }
+
   po::positional_options_description p;
   p.add("database-used", 1);
   p.add("Table-used",-1);
@@ -669,7 +644,6 @@ try
   extended_insert= (vm.count("skip-extended-insert")) ? false : true;
   opt_dump_date= (vm.count("skip-dump-date")) ? false : true;
   opt_disable_keys= (vm.count("skip-disable-keys")) ? false : true;
-  quick= (vm.count("slow")) ? false : true;
   opt_quoted= (vm.count("skip-quote-names")) ? false : true;
 
   if (vm.count("protocol"))
@@ -720,17 +694,6 @@ try
       tty_password= true;
   }
 
-  if (vm.count("result-file"))
-  {
-    if (!(md_result_file= fopen(vm["result-file"].as<string>().c_str(), "w")))
-      exit(1);
-  }
-
-  if (vm.count("no-set-names"))
-  {
-    opt_set_charset= 0;
-  }
- 
   if (! path.empty())
   { 
     opt_disable_keys= 0;
@@ -738,20 +701,19 @@ try
 
   if (vm.count("skip-opt"))
   {
-    extended_insert= opt_drop= quick= create_options= 0;
-    opt_disable_keys= opt_set_charset= 0;
+    extended_insert= opt_drop= create_options= 0;
+    opt_disable_keys= 0;
   }
 
   if (opt_compact)
   { 
     opt_comments= opt_drop= opt_disable_keys= 0;
-    opt_set_charset= 0;
   }
 
   if (vm.count("opt"))
   {
-    extended_insert= opt_drop= quick= create_options= 1;
-    opt_disable_keys= opt_set_charset= 1;
+    extended_insert= opt_drop= create_options= 1;
+    opt_disable_keys= 1;
   }
 
   if (vm.count("tables"))
@@ -781,11 +743,17 @@ try
     free_resources();
     exit(exit_code);
   }
+  try
+  {
+    db_connection = new DrizzleDumpConnection(current_host, opt_drizzle_port,
+      current_user, opt_password, use_drizzle_protocol);
+  }
+  catch (std::exception&)
+  {
+    maybe_exit(EX_DRIZZLEERR);
+  }
 
-  db_connection = new DrizzleDumpConnection(current_host, opt_drizzle_port,
-    current_user, opt_password, use_drizzle_protocol);
-
-  if (db_connection->getServerType() == DrizzleDumpConnection::SERVER_MYSQL_FOUND)
+  if ((db_connection->getServerType() == ServerDetect::SERVER_MYSQL_FOUND) and (not opt_data_is_mangled))
     db_connection->queryNoResult("SET NAMES 'utf8'");
 
   if (vm.count("destination-type"))
@@ -812,8 +780,6 @@ try
     goto err;
   if (opt_lock_all_tables)
     db_connection->queryNoResult("FLUSH LOGS");
-  if (opt_single_transaction && do_unlock_tables()) /* unlock but no commit! */
-    goto err;
 
   if (opt_alldbs)
   {
@@ -827,10 +793,8 @@ try
     dump_selected_tables(database_used, vm["Table-used"].as< vector<string> >());
   }
 
-  if (vm.count("Table-used") && opt_databases)
+  if (vm.count("Table-used") and opt_databases)
   {
-/*
- * This is not valid!
     vector<string> database_used= vm["database-used"].as< vector<string> >();
     vector<string> table_used= vm["Table-used"].as< vector<string> >();
 
@@ -840,16 +804,17 @@ try
     {
       database_used.insert(database_used.end(), *it);
     }
+
     dump_databases(database_used);
-    dump_tables();
-*/
+    dump_all_tables();
   }
-  
+
   if (vm.count("database-used") && ! vm.count("Table-used"))
   {
     dump_databases(vm["database-used"].as< vector<string> >());
     dump_all_tables();
   }
+
   if (opt_destination == DESTINATION_STDOUT)
     generate_dump();
   else
@@ -871,8 +836,7 @@ try
   */
 err:
   delete db_connection;
-  if (destination_connection)
-    delete destination_connection;
+  delete destination_connection;
   if (path.empty())
     write_footer(md_result_file);
   free_resources();
