@@ -22,6 +22,7 @@
 
 #define DRIZZLE_MAX_LINE_LENGTH 1024*1024L-1025
 #include "client_priv.h"
+#include "server_detect.h"
 #include <string>
 #include <iostream>
 #include <iomanip>
@@ -33,6 +34,29 @@ class DrizzleDumpConnection;
 class DrizzleDumpDatabase;
 class DrizzleDumpData;
 
+class DrizzleDumpForeignKey
+{
+  public:
+    DrizzleDumpConnection *dcon;
+    std::string constraintName;
+
+    DrizzleDumpForeignKey(std::string name, DrizzleDumpConnection* connection) :
+      dcon(connection),
+      constraintName(name)
+    { }
+
+    virtual ~DrizzleDumpForeignKey() { }
+
+    std::string parentColumns;
+    std::string childColumns;
+    std::string childTable;
+    std::string matchOption;
+    std::string deleteRule;
+    std::string updateRule;
+
+    friend std::ostream& operator <<(std::ostream &os, const DrizzleDumpForeignKey &obj);
+};
+
 class DrizzleDumpIndex
 {
   public:
@@ -41,7 +65,10 @@ class DrizzleDumpIndex
 
     DrizzleDumpIndex(std::string &index, DrizzleDumpConnection* connection) :
       dcon(connection),
-      indexName(index)
+      indexName(index),
+      isPrimary(false),
+      isUnique(false),
+      isHash(false)
     { }
 
     virtual ~DrizzleDumpIndex() { }
@@ -50,7 +77,9 @@ class DrizzleDumpIndex
     bool isUnique;
     bool isHash;
 
-    std::vector<std::string> columns;
+    /* Stores the column name and the length of the index part */
+    typedef std::pair<std::string,uint32_t> columnData;
+    std::vector<columnData> columns;
     friend std::ostream& operator <<(std::ostream &os, const DrizzleDumpIndex &obj);
 };
 
@@ -59,7 +88,13 @@ class DrizzleDumpField
   public:
     DrizzleDumpField(std::string &field, DrizzleDumpConnection* connection) :
       dcon(connection),
-      fieldName(field)
+      fieldName(field),
+      isNull(false),
+      isUnsigned(false),
+      isAutoIncrement(false),
+      defaultIsNull(false),
+      convertDateTime(false),
+      rangeCheck(false)
     { }
 
     virtual ~DrizzleDumpField() { }
@@ -77,8 +112,10 @@ class DrizzleDumpField
     bool isAutoIncrement;
     bool defaultIsNull;
     bool convertDateTime;
+    bool rangeCheck;
     std::string defaultValue;
     std::string collation;
+    std::string comment;
 
     /* For enum type */
     std::string enumValues;
@@ -96,7 +133,9 @@ class DrizzleDumpTable
   public:
     DrizzleDumpTable(std::string &table, DrizzleDumpConnection* connection) :
       dcon(connection),
-      tableName(table)
+      tableName(table),
+      replicate(true),
+      database(NULL)
     { }
 
     virtual ~DrizzleDumpTable() { }
@@ -106,15 +145,19 @@ class DrizzleDumpTable
 
     virtual bool populateFields() { return false; }
     virtual bool populateIndexes() { return false; }
+    virtual bool populateFkeys() { return false; }
     virtual DrizzleDumpData* getData() { return NULL; }
     std::vector<DrizzleDumpField*> fields;
     std::vector<DrizzleDumpIndex*> indexes;
+    std::vector<DrizzleDumpForeignKey*> fkeys;
 
     friend std::ostream& operator <<(std::ostream &os, const DrizzleDumpTable &obj);
     std::string tableName;
     std::string displayName;
     std::string engineName;
     std::string collate;
+    std::string comment;
+    bool replicate;
 
     // Currently MySQL only, hard to do in Drizzle
     uint64_t autoIncrement;
@@ -156,15 +199,16 @@ class DrizzleDumpData
     drizzle_result_st *result;
     DrizzleDumpData(DrizzleDumpTable *dataTable, DrizzleDumpConnection *connection) :
       dcon(connection),
-      table(dataTable)
+      table(dataTable),
+      result(NULL)
     { }
 
     virtual ~DrizzleDumpData() { }
     friend std::ostream& operator <<(std::ostream &os, const DrizzleDumpData &obj);
 
-    virtual std::ostream& checkDateTime(std::ostream &os, const char*, uint32_t) const { return os; }
+    virtual std::string checkDateTime(const char*, uint32_t) const { return std::string(""); }
     std::string convertHex(const unsigned char* from, size_t from_size) const;
-    std::string escape(const char* from, size_t from_size) const;
+    static std::string escape(const char* from, size_t from_size);
 };
 
 class DrizzleDumpConnection
@@ -174,14 +218,10 @@ class DrizzleDumpConnection
     drizzle_con_st connection;
     std::string hostName;
     bool drizzleProtocol;
-    int serverType;
+    ServerDetect::server_type serverType;
+    std::string serverVersion;
 
   public:
-    enum server_type {
-      SERVER_MYSQL_FOUND,
-      SERVER_DRIZZLE_FOUND,
-      SERVER_UNKNOWN_FOUND
-    };
     DrizzleDumpConnection(std::string &host, uint16_t port,
       std::string &username, std::string &password, bool drizzle_protocol);
     ~DrizzleDumpConnection();
@@ -202,9 +242,9 @@ class DrizzleDumpConnection
 
     void freeResult(drizzle_result_st* result);
     bool setDB(std::string databaseName);
-    bool usingDrizzleProtocol(void) { return drizzleProtocol; }
-    bool getServerType(void) { return serverType; }
-    const char* getServerVersion(void) { return drizzle_con_server_version(&connection); }
+    bool usingDrizzleProtocol(void) const { return drizzleProtocol; }
+    bool getServerType(void) const { return serverType; }
+    std::string getServerVersion(void) const { return serverVersion; }
 };
 
 class DrizzleStringBuf : public std::streambuf
@@ -224,7 +264,8 @@ class DrizzleStringBuf : public std::streambuf
 
     void writeString(std::string &str)
     {
-      connection->queryNoResult(str);
+      if (not connection->queryNoResult(str))
+        throw std::exception();
     }
 
     void setConnection(DrizzleDumpConnection *conn) { connection= conn; }
@@ -253,23 +294,23 @@ class DrizzleStringBuf : public std::streambuf
 
     int	sync()
     {
-        size_t len = size_t(pptr() - pbase());
-        std::string temp(pbase(), len);
+      size_t len = size_t(pptr() - pbase());
+      std::string temp(pbase(), len);
 
-        /* Drop newlines */
-        temp.erase(std::remove(temp.begin(), temp.end(), '\n'), temp.end());
+      /* Drop newlines */
+      temp.erase(std::remove(temp.begin(), temp.end(), '\n'), temp.end());
 
-        if (temp.compare(0, 2, "--") == 0)
-        {
-          /* Drop comments */
-          setp(pbase(), epptr());
-        }
-        if (temp.find(";") != std::string::npos)
-        {
-            writeString(temp);
-            setp(pbase(), epptr());
-        }
-        return 0;
+      if (temp.compare(0, 2, "--") == 0)
+      {
+        /* Drop comments */
+        setp(pbase(), epptr());
+      }
+      if (temp.find(";") != std::string::npos)
+      {
+        writeString(temp);
+        setp(pbase(), epptr());
+      }
+      return 0;
     }
 };
 
