@@ -26,7 +26,8 @@
 #include <boost/date_time/posix_time/posix_time.hpp>
 #include <drizzled/gettext.h>
 
-extern bool  verbose;
+extern bool verbose;
+extern bool ignore_errors;
 
 bool DrizzleDumpDatabaseMySQL::populateTables()
 {
@@ -40,7 +41,7 @@ bool DrizzleDumpDatabaseMySQL::populateTables()
   if (verbose)
     std::cerr << _("-- Retrieving table structures for ") << databaseName << "..." << std::endl;
 
-  query="SELECT TABLE_NAME, TABLE_COLLATION, ENGINE, AUTO_INCREMENT FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA='";
+  query="SELECT TABLE_NAME, TABLE_COLLATION, ENGINE, AUTO_INCREMENT, TABLE_COMMENT FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_TYPE != 'VIEW' AND TABLE_SCHEMA='";
   query.append(databaseName);
   query.append("' ORDER BY TABLE_NAME");
 
@@ -51,6 +52,7 @@ bool DrizzleDumpDatabaseMySQL::populateTables()
 
   while ((row= drizzle_row_next(result)))
   {
+    size_t* row_sizes= drizzle_row_field_sizes(result);
     std::string tableName(row[0]);
     std::string displayName(tableName);
     cleanTableName(displayName);
@@ -66,11 +68,20 @@ bool DrizzleDumpDatabaseMySQL::populateTables()
     else
       table->autoIncrement= 0;
 
+    if ((row[4]) and (strstr(row[4], "InnoDB free") == NULL))
+      table->comment= DrizzleDumpData::escape(row[4], row_sizes[4]);
+    else
+      table->comment= "";
+
     table->database= this;
-    if ((not table->populateFields()) or (not table->populateIndexes()))
+    if ((not table->populateFields()) or (not table->populateIndexes()) or
+     (not table->populateFkeys()))
     {
       delete table;
-      return false;
+      if (not ignore_errors)
+        return false;
+      else
+        continue;
     }
     tables.push_back(table);
   }
@@ -125,7 +136,10 @@ bool DrizzleDumpDatabaseMySQL::populateTables(const std::vector<std::string> &ta
       if ((not table->populateFields()) or (not table->populateIndexes()))
       {
         delete table;
-        return false;
+        if (not ignore_errors)
+          return false;
+        else
+          continue;
       }
       tables.push_back(table);
       dcon->freeResult(result);
@@ -133,7 +147,10 @@ bool DrizzleDumpDatabaseMySQL::populateTables(const std::vector<std::string> &ta
     else
     {
       dcon->freeResult(result);
-      return false;
+      if (not ignore_errors)
+        return false;
+      else
+        continue;
     }
   }
 
@@ -150,7 +167,7 @@ bool DrizzleDumpTableMySQL::populateFields()
   if (verbose)
     std::cerr << _("-- Retrieving fields for ") << tableName << "..." << std::endl;
 
-  query="SELECT COLUMN_NAME, COLUMN_TYPE, COLUMN_DEFAULT, IS_NULLABLE, CHARACTER_MAXIMUM_LENGTH, NUMERIC_PRECISION, NUMERIC_SCALE, COLLATION_NAME, EXTRA FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA='";
+  query="SELECT COLUMN_NAME, COLUMN_TYPE, COLUMN_DEFAULT, IS_NULLABLE, CHARACTER_MAXIMUM_LENGTH, NUMERIC_PRECISION, NUMERIC_SCALE, COLLATION_NAME, EXTRA, COLUMN_COMMENT FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA='";
   query.append(database->databaseName);
   query.append("' AND TABLE_NAME='");
   query.append(tableName);
@@ -167,28 +184,45 @@ bool DrizzleDumpTableMySQL::populateFields()
     DrizzleDumpFieldMySQL *field = new DrizzleDumpFieldMySQL(fieldName, dcon);
     /* Stop valgrind warning */
     field->convertDateTime= false;
+    field->isNull= (strcmp(row[3], "YES") == 0) ? true : false;
     /* Also sets collation */
     field->setType(row[1], row[8]);
-    if (row[2])
+    if (field->type.compare("ENUM") == 0)
+      field->isNull= true;
+
+    if ((row[2]) and (field->type.compare("TEXT") != 0))
     {
+      field->defaultValue= row[2];
       if (field->convertDateTime)
       {
-        field->dateTimeConvert(row[2]);
+        field->dateTimeConvert();
       }
-      else
-        field->defaultValue= row[2];
     }
     else
-     field->defaultValue= "";
+    {
+      field->defaultValue= "";
+    }
 
-    field->isNull= (strcmp(row[3], "YES") == 0) ? true : false;
     field->isAutoIncrement= (strcmp(row[8], "auto_increment") == 0) ? true : false;
     field->defaultIsNull= field->isNull;
-    field->length= (row[4]) ? boost::lexical_cast<uint32_t>(row[4]) : 0;
+
+    /* Seriously MySQL, why is BIT length in NUMERIC_PRECISION? */
+    if ((strncmp(row[1], "bit", 3) == 0) and (row[5] != NULL))
+      field->length= ((boost::lexical_cast<uint32_t>(row[5]) - 1) / 8) + 1;
+    else
+      field->length= (row[4]) ? boost::lexical_cast<uint32_t>(row[4]) : 0;
+
+    /* Also, CHAR(0) is valid?? */
+    if (((field->type.compare("VARBINARY") == 0) 
+      or (field->type.compare("VARCHAR") == 0))
+      and (field->length == 0))
+    {
+      field->length= 1;
+    }
+
     field->decimalPrecision= (row[5]) ? boost::lexical_cast<uint32_t>(row[5]) : 0;
     field->decimalScale= (row[6]) ? boost::lexical_cast<uint32_t>(row[6]) : 0;
-
-
+    field->comment= (row[9]) ? row[9] : "";
     fields.push_back(field);
   }
 
@@ -197,32 +231,25 @@ bool DrizzleDumpTableMySQL::populateFields()
 }
 
 
-void DrizzleDumpFieldMySQL::dateTimeConvert(const char* oldDefault)
+void DrizzleDumpFieldMySQL::dateTimeConvert(void)
 {
   boost::match_flag_type flags = boost::match_default;
 
-  if (strcmp(oldDefault, "CURRENT_TIMESTAMP") == 0)
-  {
-    defaultValue= oldDefault;
+  if (strcmp(defaultValue.c_str(), "CURRENT_TIMESTAMP") == 0)
     return;
-  }
 
   if (type.compare("INT") == 0)
   {
     /* We were a TIME, now we are an INT */
-    std::string ts(oldDefault);
+    std::string ts(defaultValue);
     boost::posix_time::time_duration td(boost::posix_time::duration_from_string(ts));
     defaultValue= boost::lexical_cast<std::string>(td.total_seconds());
     return;
   }
 
-  boost::regex date_regex("([0-9]{3}[1-9]-(0[1-9]|1[012])-(0[1-9]|[12][0-9]|3[01]))");
+  boost::regex date_regex("(0000|-00)");
 
-  if (regex_search(oldDefault, date_regex, flags))
-  {
-    defaultValue= oldDefault;
-  }
-  else
+  if (regex_search(defaultValue, date_regex, flags))
   {
     defaultIsNull= true;
     defaultValue="";
@@ -267,7 +294,8 @@ bool DrizzleDumpTableMySQL::populateIndexes()
       lastKey= row[2];
       firstIndex= false;
     }
-    index->columns.push_back(row[4]);
+    uint32_t length= (row[7]) ? boost::lexical_cast<uint32_t>(row[7]) : 0;
+    index->columns.push_back(std::make_pair(row[4], length));
   }
   if (!firstIndex)
     indexes.push_back(index);
@@ -276,13 +304,79 @@ bool DrizzleDumpTableMySQL::populateIndexes()
   return true;
 }
 
+bool DrizzleDumpTableMySQL::populateFkeys()
+{
+  drizzle_result_st *result;
+  drizzle_row_t row;
+  std::string query;
+  DrizzleDumpForeignKey *fkey;
+
+  if (verbose)
+    std::cerr << _("-- Retrieving foreign keys for ") << tableName << "..." << std::endl;
+
+  query= "SHOW CREATE TABLE `";
+  query.append(database->databaseName);
+  query.append("`.`");
+  query.append(tableName);
+  query.append("`");
+  result= dcon->query(query);
+
+  if (result == NULL)
+    return false;
+
+  if ((row= drizzle_row_next(result)))
+  {
+    boost::match_flag_type flags = boost::match_default;
+    boost::regex constraint_regex("CONSTRAINT `(.*?)` FOREIGN KEY \\((.*?)\\) REFERENCES `(.*?)` \\((.*?)\\)( ON (UPDATE|DELETE) (CASCADE|RESTRICT|SET NULL))?( ON (UPDATE|DELETE) (CASCADE|RESTRICT|SET NULL))?");
+
+    boost::match_results<std::string::const_iterator> constraint_results;
+
+    std::string search_body(row[1]);
+    std::string::const_iterator start, end;
+    start= search_body.begin();
+    end= search_body.end();
+    while (regex_search(start, end, constraint_results, constraint_regex, flags))
+    {
+      fkey= new DrizzleDumpForeignKey(constraint_results[1], dcon);
+      fkey->parentColumns= constraint_results[2];
+      fkey->childTable= constraint_results[3];
+      fkey->childColumns= constraint_results[4];
+        
+      if (constraint_results[5].compare("") != 0)
+      {
+        if (constraint_results[6].compare("UPDATE") == 0)
+          fkey->updateRule= constraint_results[7];
+        else if (constraint_results[6].compare("DELETE") == 0)
+          fkey->deleteRule= constraint_results[7];
+      }
+      if (constraint_results[8].compare("") != 0)
+      {
+        if (constraint_results[9].compare("UPDATE") == 0)
+          fkey->updateRule= constraint_results[10];
+        else if (constraint_results[9].compare("DELETE") == 0)
+          fkey->deleteRule= constraint_results[10];
+      }
+      fkey->matchOption= "";
+
+      fkeys.push_back(fkey);
+
+      start= constraint_results[0].second;
+      flags |= boost::match_prev_avail; 
+      flags |= boost::match_not_bob;
+    }
+  }
+  dcon->freeResult(result);
+  return true;
+}
+
 void DrizzleDumpFieldMySQL::setType(const char* raw_type, const char* raw_collation)
 {
   std::string old_type(raw_type);
   std::string extra;
   size_t pos;
   
-  if ((pos= old_type.find("(")) != std::string::npos)
+  if (((pos= old_type.find("(")) != std::string::npos) or
+    ((pos= old_type.find(" ")) != std::string::npos))
   {
     extra= old_type.substr(pos);
     old_type.erase(pos, std::string::npos);
@@ -293,6 +387,12 @@ void DrizzleDumpFieldMySQL::setType(const char* raw_type, const char* raw_collat
     (old_type.find("TEXT") != std::string::npos))
     setCollate(raw_collation);
 
+  if ((old_type.compare("BIGINT") == 0) and
+    ((extra.find("unsigned") != std::string::npos)))
+  {
+    rangeCheck= true;
+  }
+
   if ((old_type.compare("INT") == 0) and 
     ((extra.find("unsigned") != std::string::npos)))
   {
@@ -334,6 +434,7 @@ void DrizzleDumpFieldMySQL::setType(const char* raw_type, const char* raw_collat
   if (old_type.compare("BINARY") == 0)
   {
     type= "VARBINARY";
+    
     return;
   }
 
@@ -351,9 +452,10 @@ void DrizzleDumpFieldMySQL::setType(const char* raw_type, const char* raw_collat
     /* Intended to catch TIME/DATE/TIMESTAMP/DATETIME 
        We may have a default TIME/DATE which needs converting */
     convertDateTime= true;
+    isNull= true;
   }
 
-  if (old_type.compare("TIME") == 0)
+  if ((old_type.compare("TIME") == 0) or (old_type.compare("YEAR") == 0))
   {
     type= "INT";
     return;
@@ -365,13 +467,19 @@ void DrizzleDumpFieldMySQL::setType(const char* raw_type, const char* raw_collat
     return;
   }
 
+  if (old_type.compare("BIT") == 0)
+  {
+    type= "VARBINARY";
+    return;
+  }
+
   type= old_type;
   return;
 }
 
 void DrizzleDumpTableMySQL::setEngine(const char* newEngine)
 {
-  if (strcmp(newEngine, "MyISAM") == 0)
+  if ((strcmp(newEngine, "MyISAM") == 0) || (strcmp(newEngine, "MEMORY") == 0))
     engineName= "InnoDB";
   else
     engineName= newEngine; 
@@ -443,13 +551,13 @@ DrizzleDumpDataMySQL::DrizzleDumpDataMySQL(DrizzleDumpTable *dataTable,
 
   result= dcon->query(query);
   if (result == NULL)
-    throw 1;
+    throw std::exception();
 }
 
 DrizzleDumpDataMySQL::~DrizzleDumpDataMySQL()
 {
   drizzle_result_free(result);
-  if (result) delete result;
+  delete result;
 }
 
 long DrizzleDumpDataMySQL::convertTime(const char* oldTime) const
@@ -464,9 +572,9 @@ std::string DrizzleDumpDataMySQL::convertDate(const char* oldDate) const
 {
   boost::match_flag_type flags = boost::match_default;
   std::string output;
-  boost::regex date_regex("([0-9]{3}[1-9]-(0[1-9]|1[012])-(0[1-9]|[12][0-9]|3[01]))");
+  boost::regex date_regex("(0000|-00)");
 
-  if (regex_search(oldDate, date_regex, flags))
+  if (not regex_search(oldDate, date_regex, flags))
   {
     output.push_back('\'');
     output.append(oldDate);
@@ -478,15 +586,17 @@ std::string DrizzleDumpDataMySQL::convertDate(const char* oldDate) const
   return output;
 }
 
-std::ostream& DrizzleDumpDataMySQL::checkDateTime(std::ostream &os, const char* item, uint32_t field) const
+std::string DrizzleDumpDataMySQL::checkDateTime(const char* item, uint32_t field) const
 {
+  std::string ret;
+
   if (table->fields[field]->convertDateTime)
   {
     if (table->fields[field]->type.compare("INT") == 0)
-      os << convertTime(item);
+      ret= boost::lexical_cast<std::string>(convertTime(item));
     else
-      os << convertDate(item);
+      ret= convertDate(item);
   }
-  return os;
+  return ret;
 }
 
