@@ -2,7 +2,7 @@
   Copyright (C) 2010 Vijay Samuel
   Copyright (C) 2010 Brian Aker
   Copyright (C) 2000-2006 MySQL AB
-  Copyright (C) 2008-2009 Sun Microsystems, Inc
+  Copyright (C) 2008-2009 Sun Microsystems, Inc.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 #define IMPORT_VERSION "4.0"
 
@@ -39,7 +39,7 @@ extern "C" void * worker_thread(void *arg);
 
 int exitcode= 0;
 
-const char *program_name= "drizzlesimport";
+const char *program_name= "drizzleimport";
 
 /* Global Thread counter */
 uint32_t counter;
@@ -397,6 +397,8 @@ try
   "Load files in parallel. The argument is the number of threads to use for loading data (default is 4.")
   ;
 
+  const char* unix_user= getlogin();
+
   po::options_description client_options("Options specific to the client");
   client_options.add_options()
   ("host,h", po::value<string>(&current_host)->default_value("localhost"),
@@ -407,7 +409,7 @@ try
   "Port number to use for connection") 
   ("protocol", po::value<string>(&opt_protocol)->default_value("mysql"),
   "The protocol of connection (mysql or drizzle).")
-  ("user,u", po::value<string>(&current_user)->default_value(""),
+  ("user,u", po::value<string>(&current_user)->default_value((unix_user ? unix_user : "")),
   "User for login if not current user.")
   ;
 
@@ -422,6 +424,14 @@ try
   
   std::string user_config_dir((getenv("XDG_CONFIG_HOME")? getenv("XDG_CONFIG_HOME"):"~/.config"));
 
+  if (user_config_dir.compare(0, 2, "~/") == 0)
+  {
+    char *homedir;
+    homedir= getenv("HOME");
+    if (homedir != NULL)
+      user_config_dir.replace(0, 1, homedir);
+  }
+
   po::variables_map vm;
 
   // Disable allow_guessing
