@@ -11,27 +11,28 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 #ifndef CLIENT_LINEBUFFER_H
 #define CLIENT_LINEBUFFER_H
 
 #include <vector>
 #include <sstream>
+#include <iostream>
+#include <boost/iostreams/stream.hpp>
+#include <boost/iostreams/device/file_descriptor.hpp>
 
 class LineBuffer
 {
 public:
   LineBuffer(uint32_t max_size,FILE *file);
-
   void addString(const std::string &argument);
   char *readline();
 private:
   FILE *file;
-  std::stringstream buffer;
   std::vector<char> line;
+  std::iostream *file_stream;
   uint32_t max_size;
-  bool eof;
 };
 
 #endif /* CLIENT_LINEBUFFER_H */
