@@ -9,8 +9,10 @@
 
 /*
  * SHA-1 in C
- * By Steve Reid <steve@edmweb.com>
- * 100% Public Domain
+ * 
+ * This file is based on public domain code.
+ * Initial source code is in the public domain, 
+ * so clarified by Steve Reid <steve@edmweb.com>
  *
  * Test Vectors (from FIPS PUB 180-1)
  * "abc"
@@ -21,7 +23,7 @@
  *   34AA973C D4C4DAA4 F61EEB2B DBAD2731 6534016F
  */
 
-#include "config.h"
+#include <config.h>
 #include "sha1.h"
 #include <string.h>
 
