@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,12 +22,12 @@
  * @file Implementation of the AlterInfo class
  */
 
-#include "config.h"
-#include "drizzled/alter_info.h"
-#include "drizzled/alter_drop.h"
-#include "drizzled/alter_column.h"
-#include "drizzled/key.h"
-#include "drizzled/create_field.h"
+#include <config.h>
+#include <drizzled/alter_info.h>
+#include <drizzled/alter_drop.h>
+#include <drizzled/alter_column.h>
+#include <drizzled/key.h>
+#include <drizzled/create_field.h>
 
 namespace drizzled
 {
@@ -38,7 +38,6 @@ AlterInfo::AlterInfo() :
   tablespace_op(NO_TABLESPACE_OP),
   no_parts(0),
   build_method(HA_BUILD_DEFAULT),
-  datetime_field(NULL),
   error_if_not_empty(false)
 {}
 
