@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,12 +17,13 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_CHECK_STACK_OVERRUN_H
-#define DRIZZLED_CHECK_STACK_OVERRUN_H
+#pragma once
 
 namespace drizzled
 {
 
+class Session;
+
 /**
   @note
   Note: The 'buf' parameter is necessary, even if it is unused here.
@@ -34,4 +35,3 @@ bool check_stack_overrun(Session *session, long margin, void *buff);
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_CHECK_STACK_OVERRUN_H */
