@@ -11,12 +11,12 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
-#include "config.h"
+#include <config.h>
 
-#include "drizzled/internal/m_string.h"
-#include "drizzled/charset_info.h"
+#include <drizzled/internal/m_string.h>
+#include <drizzled/charset_info.h>
 #include <cerrno>
 #include <cstdio>
 #include <cstdlib>
@@ -65,11 +65,11 @@ long my_strntol_8bit(const CHARSET_INFO * const cs,
 		     char **endptr, int *err)
 {
   int negative;
-  register uint32_t cutoff;
-  register uint32_t cutlim;
-  register uint32_t i;
-  register const char *s;
-  register unsigned char c;
+  uint32_t cutoff;
+  uint32_t cutlim;
+  uint32_t i;
+  const char *s;
+  unsigned char c;
   const char *save, *e;
   int overflow;
 
@@ -188,11 +188,11 @@ ulong my_strntoul_8bit(const CHARSET_INFO * const cs,
 		       char **endptr, int *err)
 {
   int negative;
-  register uint32_t cutoff;
-  register uint32_t cutlim;
-  register uint32_t i;
-  register const char *s;
-  register unsigned char c;
+  uint32_t cutoff;
+  uint32_t cutlim;
+  uint32_t i;
+  const char *s;
+  unsigned char c;
   const char *save, *e;
   int overflow;
 
@@ -284,7 +284,7 @@ ulong my_strntoul_8bit(const CHARSET_INFO * const cs,
   if (overflow)
   {
     err[0]= ERANGE;
-    return (~(uint32_t) 0);
+    return UINT32_MAX;
   }
 
   return (negative ? -((long) i) : (long) i);
@@ -302,10 +302,10 @@ int64_t my_strntoll_8bit(const CHARSET_INFO * const cs,
 			  char **endptr,int *err)
 {
   int negative;
-  register uint64_t cutoff;
-  register uint32_t cutlim;
-  register uint64_t i;
-  register const char *s, *e;
+  uint64_t cutoff;
+  uint32_t cutlim;
+  uint64_t i;
+  const char *s, *e;
   const char *save;
   int overflow;
 
@@ -370,7 +370,7 @@ int64_t my_strntoll_8bit(const CHARSET_INFO * const cs,
   i = 0;
   for ( ; s != e; s++)
   {
-    register unsigned char c= *s;
+    unsigned char c= *s;
     if (c>='0' && c<='9')
       c -= '0';
     else if (c>='A' && c<='Z')
@@ -425,10 +425,10 @@ uint64_t my_strntoull_8bit(const CHARSET_INFO * const cs,
 			   char **endptr, int *err)
 {
   int negative;
-  register uint64_t cutoff;
-  register uint32_t cutlim;
-  register uint64_t i;
-  register const char *s, *e;
+  uint64_t cutoff;
+  uint32_t cutlim;
+  uint64_t i;
+  const char *s, *e;
   const char *save;
   int overflow;
 
@@ -493,7 +493,7 @@ uint64_t my_strntoull_8bit(const CHARSET_INFO * const cs,
   i = 0;
   for ( ; s != e; s++)
   {
-    register unsigned char c= *s;
+    unsigned char c= *s;
 
     if (c>='0' && c<='9')
       c -= '0';
@@ -580,7 +580,7 @@ size_t my_long10_to_str_8bit(const CHARSET_INFO * const,
                              char *dst, size_t len, int radix, long int val)
 {
   char buffer[66];
-  register char *p, *e;
+  char *p, *e;
   long int new_val;
   uint32_t sign=0;
   unsigned long int uval = (unsigned long int) val;
@@ -622,7 +622,7 @@ size_t my_int64_t10_to_str_8bit(const CHARSET_INFO * const,
                                 int64_t val)
 {
   char buffer[65];
-  register char *p, *e;
+  char *p, *e;
   long long_val;
   uint32_t sign= 0;
   uint64_t uval = (uint64_t)val;
@@ -679,14 +679,24 @@ cnv:
 **	 1 if matched with wildcard
 */
 
+inline static int likeconv(const charset_info_st *cs, const char c) 
+{
 #ifdef LIKE_CMP_TOUPPER
-#define likeconv(s,A) (unsigned char) my_toupper(s,A)
+  return (unsigned char) my_toupper(cs, c);
 #else
-#define likeconv(s,A) (unsigned char) (s)->sort_order[(unsigned char) (A)]
-#endif
+  return cs->sort_order[(unsigned char)c];
+#endif    
+}
 
-#define INC_PTR(cs,A,B) (A)++
 
+inline static const char* inc_ptr(const charset_info_st *cs, const char *str, const char *str_end)
+{
+  // (Strange this macro have been used. If str_end would actually
+  // have been used it would have made sense. /Gustaf)
+  (void)cs;
+  (void)str_end;
+  return str++; 
+}
 
 int my_wildcmp_8bit(const CHARSET_INFO * const cs,
 		    const char *str,const char *str_end,
@@ -714,7 +724,7 @@ int my_wildcmp_8bit(const CHARSET_INFO * const cs,
       {
 	if (str == str_end)			/* Skip one char if possible */
 	  return(result);
-	INC_PTR(cs,str,str_end);
+	inc_ptr(cs,str,str_end);
       } while (++wildstr < wildend && *wildstr == w_one);
       if (wildstr == wildend)
 	break;
@@ -733,7 +743,7 @@ int my_wildcmp_8bit(const CHARSET_INFO * const cs,
 	{
 	  if (str == str_end)
 	    return(-1);
-	  INC_PTR(cs,str,str_end);
+	  inc_ptr(cs,str,str_end);
 	  continue;
 	}
 	break;					/* Not a wild character */
@@ -746,7 +756,7 @@ int my_wildcmp_8bit(const CHARSET_INFO * const cs,
       if ((cmp= *wildstr) == escape && wildstr+1 != wildend)
 	cmp= *++wildstr;
 
-      INC_PTR(cs,wildstr,wildend);	/* This is compared trough cmp */
+      inc_ptr(cs,wildstr,wildend);	/* This is compared trough cmp */
       cmp=likeconv(cs,cmp);
       do
       {
@@ -913,7 +923,7 @@ uint32_t my_instr_simple(const CHARSET_INFO * const cs,
                      const char *s, size_t s_length,
                      my_match_t *match, uint32_t nmatch)
 {
-  register const unsigned char *str, *search, *end, *search_end;
+  const unsigned char *str, *search, *end, *search_end;
 
   if (s_length <= b_length)
   {
@@ -938,7 +948,7 @@ skip:
     {
       if (cs->sort_order[*str++] == cs->sort_order[*search])
       {
-	register const unsigned char *i,*j;
+	const unsigned char *i,*j;
 
 	i= str;
 	j= search+1;
@@ -976,7 +986,10 @@ typedef struct
 
 #define PLANE_SIZE	0x100
 #define PLANE_NUM	0x100
-#define PLANE_NUMBER(x)	(((x)>>8) % PLANE_NUM)
+inline static int plane_number(uint16_t x)
+{
+  return ((x >> 8) % PLANE_NUM);
+}
 
 static int pcmp(const void * f, const void * s)
 {
@@ -1010,7 +1023,7 @@ static bool create_fromuni(CHARSET_INFO *cs, cs_alloc_func alloc)
   for (i=0; i< 0x100; i++)
   {
     uint16_t wc=cs->tab_to_uni[i];
-    int pl= PLANE_NUMBER(wc);
+    int pl= plane_number(wc);
 
     if (wc || !i)
     {
