@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,31 +17,25 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_CURSOR_H
-#define DRIZZLED_CURSOR_H
+#pragma once
 
-#include <drizzled/xid.h>
-#include <drizzled/discrete_interval.h>
-#include <drizzled/identifier.h>
-
-/* Definitions for parameters to do with Cursor-routines */
-
-#include <drizzled/thr_lock.h>
-#include <drizzled/sql_string.h>
-#include <drizzled/sql_list.h>
-#include <drizzled/plugin/storage_engine.h>
-#include <drizzled/handler_structs.h>
-#include <drizzled/ha_statistics.h>
 #include <drizzled/atomics.h>
-
-#include <drizzled/message/table.pb.h>
-
-/* Bits to show what an alter table will do */
-#include <drizzled/sql_bitmap.h>
+#include <drizzled/definitions.h>
+#include <drizzled/discrete_interval.h>
+#include <drizzled/error_t.h>
+#include <drizzled/ha_statistics.h>
+#include <drizzled/handler_structs.h>
+#include <drizzled/identifier.h>
+#include <drizzled/key_map.h>
+#include <drizzled/message/table.h>
+#include <drizzled/sql_list.h>
+#include <drizzled/thr_lock.h>
 
 #include <bitset>
 #include <algorithm>
 
+#include <drizzled/visibility.h>
+
 namespace drizzled
 {
 
@@ -49,24 +43,21 @@ namespace drizzled
 
 typedef std::bitset<HA_MAX_ALTER_FLAGS> HA_ALTER_FLAGS;
 
-extern uint64_t refresh_version;  /* Increments on each reload */
-
+class AlterInfo;
+class CreateField;
+class ForeignKeyInfo;
+class Item;
+class Item_ident;
+class LEX;
+class Select_Lex;
+class Select_Lex_Unit;
+class String;
 class Table;
 class TableList;
 class TableShare;
-class Select_Lex_Unit;
-class ForeignKeyInfo;
-struct order_st;
-
-class Item;
-
-class LEX;
-class Select_Lex;
-class AlterInfo;
 class select_result;
-class CreateField;
 class sys_var_str;
-class Item_ident;
+struct Order;
 
 typedef List<Item> List_item;
 extern KEY_CREATE_INFO default_key_create_info;
@@ -76,10 +67,8 @@ typedef class Item COND;
 
 typedef struct system_status_var system_status_var;
 
-namespace optimizer
-{
-  class CostVector;
-}
+namespace optimizer { class CostVector; }
+namespace plugin { class StorageEngine; }
 
 /*
   bitmap with first N+1 bits set
@@ -144,25 +133,28 @@ inline key_part_map make_prev_keypart_map(T a)
   If a blob column has NULL value, then its length and blob data pointer
   must be set to 0.
 */
-class Cursor
+class DRIZZLED_API Cursor
 {
-protected:
-  TableShare *table_share;   /* The table definition */
-  Table *table;               /* The current open table */
+  friend class SEAPITesterCursor;
+  Table &table;               /* The current open table */
+  plugin::StorageEngine &engine;      /* storage engine of this Cursor */
 
+protected:
   ha_rows estimation_rows_to_insert;
-  plugin::StorageEngine *engine;      /* storage engine of this Cursor */
+
 public:
   inline plugin::StorageEngine *getEngine() const	/* table_type for handler */
   {
-    return engine;
+    return &engine;
   }
   unsigned char *ref;				/* Pointer to current row */
   unsigned char *dup_ref;			/* Pointer to duplicate row */
 
-  TableShare *getShare() const
+  TableShare *getShare();
+
+  Table *getTable() const
   {
-    return table_share;
+    return &table;
   }
 
   ha_statistics stats;
@@ -210,6 +202,14 @@ public:
     return next_insert_id;
   }
 
+  /**
+    Used by SHOW TABLE STATUS to get the current auto_inc from the engine
+  */
+  uint64_t getAutoIncrement()
+  {
+    return stats.auto_increment_value;
+  }
+
   /**
     insert id for the current row (*autogenerated*; if not
     autogenerated, it's 0).
@@ -223,16 +223,16 @@ public:
   */
   Discrete_interval auto_inc_interval_for_cur_row;
 
-  Cursor(plugin::StorageEngine &engine_arg, TableShare &share_arg);
+  Cursor(plugin::StorageEngine &engine_arg, Table &share_arg);
   virtual ~Cursor(void);
   virtual Cursor *clone(memory::Root *mem_root);
 
   /* ha_ methods: pubilc wrappers for private virtual API */
 
-  int ha_open(const TableIdentifier &identifier, Table *table, int mode, int test_if_locked);
-  int startIndexScan(uint32_t idx, bool sorted);
+  int ha_open(const identifier::Table &identifier, int mode, int test_if_locked);
+  int startIndexScan(uint32_t idx, bool sorted) __attribute__ ((warn_unused_result));
   int endIndexScan();
-  int startTableScan(bool scan);
+  int startTableScan(bool scan) __attribute__ ((warn_unused_result));
   int endTableScan();
   int ha_reset();
 
@@ -246,9 +246,9 @@ public:
     and doDeleteRecord() below.
   */
   int ha_external_lock(Session *session, int lock_type);
-  int insertRecord(unsigned char * buf);
-  int updateRecord(const unsigned char * old_data, unsigned char * new_data);
-  int deleteRecord(const unsigned char * buf);
+  int insertRecord(unsigned char * buf) __attribute__ ((warn_unused_result));
+  int updateRecord(const unsigned char * old_data, unsigned char * new_data) __attribute__ ((warn_unused_result));
+  int deleteRecord(const unsigned char * buf) __attribute__ ((warn_unused_result));
   void ha_release_auto_increment();
 
   /** to be actually called to get 'check()' functionality*/
@@ -267,13 +267,12 @@ public:
 
   void adjust_next_insert_id_after_explicit_value(uint64_t nr);
   int update_auto_increment();
-  virtual void change_table_ptr(Table *table_arg, TableShare *share);
 
   /* Estimates calculation */
   virtual double scan_time(void)
-  { return uint64_t2double(stats.data_file_length) / IO_SIZE + 2; }
+  { return static_cast<double>(stats.data_file_length) / IO_SIZE + 2; }
   virtual double read_time(uint32_t, uint32_t ranges, ha_rows rows)
-  { return rows2double(ranges+rows); }
+  { return ranges + rows; }
 
   virtual double index_only_read_time(uint32_t keynr, double records);
 
@@ -349,7 +348,7 @@ public:
                                  const unsigned char * key,
                                  key_part_map keypart_map,
                                  enum ha_rkey_function find_flag);
-  virtual int index_next(unsigned char *)
+  virtual int index_next(unsigned char *) __attribute__ ((warn_unused_result))
    { return  HA_ERR_WRONG_COMMAND; }
   virtual int index_prev(unsigned char *)
    { return  HA_ERR_WRONG_COMMAND; }
@@ -475,7 +474,7 @@ public:
     or partitioned.
 
     @note that one can NOT rely on table->in_use in store_lock().  It may
-    refer to a different thread if called from mysql_lock_abort_for_thread().
+    refer to a different thread if called from abortLockForThread().
 
     @note If the table is MERGE, store_lock() can return less locks
     than lock_count() claimed. This can happen when the MERGE children
@@ -522,8 +521,8 @@ private:
     the corresponding 'ha_*' method above.
   */
 
-  virtual int open(const char *, int , uint32_t ) { assert(0); return -1; };
-  virtual int doOpen(const TableIdentifier &identifier, int mode, uint32_t test_if_locked);
+  virtual int open(const char *, int , uint32_t ) { assert(0); return -1; }
+  virtual int doOpen(const identifier::Table &identifier, int mode, uint32_t test_if_locked);
   virtual int doStartIndexScan(uint32_t idx, bool)
   { active_index= idx; return 0; }
   virtual int doEndIndexScan() { active_index= MAX_KEY; return 0; }
@@ -534,7 +533,7 @@ private:
     if rnd_init allocates the cursor, second call should position it
     to the start of the table, no need to deallocate and allocate it again
   */
-  virtual int doStartTableScan(bool scan)= 0;
+  virtual int doStartTableScan(bool scan) __attribute__ ((warn_unused_result)) = 0;
   virtual int doEndTableScan() { return 0; }
   virtual int doInsertRecord(unsigned char *)
   {
@@ -583,7 +582,7 @@ private:
   {
     return 0;
   }
-  virtual void release_auto_increment(void) { return; };
+  virtual void release_auto_increment(void) { return; }
   /** admin commands - called from mysql_admin_table */
   virtual int check(Session *)
   { return HA_ADMIN_NOT_IMPLEMENTED; }
@@ -640,12 +639,12 @@ extern const char *ha_row_type[];
 void ha_init_errors(void);
 
 class SortField;
-SortField *make_unireg_sortorder(order_st *order, uint32_t *length,
+SortField *make_unireg_sortorder(Order *order, uint32_t *length,
                                  SortField *sortorder);
 int setup_order(Session *session, Item **ref_pointer_array, TableList *tables,
-                List<Item> &fields, List <Item> &all_fields, order_st *order);
+                List<Item> &fields, List <Item> &all_fields, Order *order);
 int setup_group(Session *session, Item **ref_pointer_array, TableList *tables,
-                List<Item> &fields, List<Item> &all_fields, order_st *order,
+                List<Item> &fields, List<Item> &all_fields, Order *order,
                 bool *hidden_group_fields);
 bool fix_inner_refs(Session *session, List<Item> &all_fields, Select_Lex *select,
                     Item **ref_pointer_array);
@@ -654,66 +653,66 @@ bool handle_select(Session *session, LEX *lex, select_result *result,
                    uint64_t setup_tables_done_option);
 void free_underlaid_joins(Session *session, Select_Lex *select);
 
-bool mysql_handle_derived(LEX *lex, bool (*processor)(Session *session,
+bool handle_derived(LEX *lex, bool (*processor)(Session *session,
                                                       LEX *lex,
                                                       TableList *table));
-bool mysql_derived_prepare(Session *session, LEX *lex, TableList *t);
-bool mysql_derived_filling(Session *session, LEX *lex, TableList *t);
+bool derived_prepare(Session *session, LEX *lex, TableList *t);
+bool derived_filling(Session *session, LEX *lex, TableList *t);
 int prepare_create_field(CreateField *sql_field,
                          uint32_t *blob_columns,
                          int *timestamps, int *timestamps_with_niladic);
 
-bool mysql_create_table(Session *session,
-                        TableIdentifier &identifier,
-                        HA_CREATE_INFO *create_info,
-                        message::Table &table_proto,
-                        AlterInfo *alter_info,
-                        bool tmp_table, uint32_t select_field_count,
-                        bool is_if_not_exists);
+bool create_table(Session *session,
+                  const identifier::Table &identifier,
+                  HA_CREATE_INFO *create_info,
+                  message::Table &table_proto,
+                  AlterInfo *alter_info,
+                  bool tmp_table, uint32_t select_field_count,
+                  bool is_if_not_exists);
 
-bool mysql_create_table_no_lock(Session *session,
-                                TableIdentifier &identifier,
-                                HA_CREATE_INFO *create_info,
-                                message::Table &table_proto,
-                                AlterInfo *alter_info,
-                                bool tmp_table, uint32_t select_field_count,
-                                bool is_if_not_exists);
+bool create_table_no_lock(Session *session,
+                          const identifier::Table &identifier,
+                          HA_CREATE_INFO *create_info,
+                          message::Table &table_proto,
+                          AlterInfo *alter_info,
+                          bool tmp_table, uint32_t select_field_count,
+                          bool is_if_not_exists);
 
-bool mysql_create_like_table(Session* session,
-                             TableIdentifier &destination_identifier,
-                             TableList* table, TableList* src_table,
-                             message::Table &create_table_proto,
-                             bool is_if_not_exists,
-                             bool is_engine_set);
+bool create_like_table(Session* session,
+                       identifier::Table::const_reference destination_identifier,
+                       identifier::Table::const_reference source_identifier,
+                       message::Table &create_table_proto,
+                       bool is_if_not_exists,
+                       bool is_engine_set);
 
-bool mysql_rename_table(Session &session,
+bool rename_table(Session &session,
                         plugin::StorageEngine *base,
-                        TableIdentifier &old_identifier,
-                        TableIdentifier &new_identifier);
+                        const identifier::Table &old_identifier,
+                        const identifier::Table &new_identifier);
 
-bool mysql_prepare_update(Session *session, TableList *table_list,
-                          Item **conds, uint32_t order_num, order_st *order);
-int mysql_update(Session *session,TableList *tables,List<Item> &fields,
+bool prepare_update(Session *session, TableList *table_list,
+                          Item **conds, uint32_t order_num, Order *order);
+int update_query(Session *session,TableList *tables,List<Item> &fields,
                  List<Item> &values,COND *conds,
-                 uint32_t order_num, order_st *order, ha_rows limit,
+                 uint32_t order_num, Order *order, ha_rows limit,
                  enum enum_duplicates handle_duplicates, bool ignore);
-bool mysql_prepare_insert(Session *session, TableList *table_list, Table *table,
+bool prepare_insert(Session *session, TableList *table_list, Table *table,
                           List<Item> &fields, List_item *values,
                           List<Item> &update_fields,
                           List<Item> &update_values, enum_duplicates duplic,
                           COND **where, bool select_insert,
                           bool check_fields, bool abort_on_warning);
-bool mysql_insert(Session *session,TableList *table,List<Item> &fields,
+bool insert_query(Session *session,TableList *table,List<Item> &fields,
                   List<List_item> &values, List<Item> &update_fields,
                   List<Item> &update_values, enum_duplicates flag,
                   bool ignore);
 int check_that_all_fields_are_given_values(Session *session, Table *entry,
                                            TableList *table_list);
-int mysql_prepare_delete(Session *session, TableList *table_list, Item **conds);
-bool mysql_delete(Session *session, TableList *table_list, COND *conds,
+int prepare_delete(Session *session, TableList *table_list, Item **conds);
+bool delete_query(Session *session, TableList *table_list, COND *conds,
                   SQL_LIST *order, ha_rows rows, uint64_t options,
                   bool reset_auto_increment);
-bool mysql_truncate(Session& session, TableList *table_list);
+bool truncate(Session& session, TableList *table_list);
 TableShare *get_table_share(Session *session, TableList *table_list, char *key,
                              uint32_t key_length, uint32_t db_flags, int *error);
 TableShare *get_cached_table_share(const char *db, const char *table_name);
@@ -722,8 +721,8 @@ bool reopen_tables(Session *session,bool get_locks,bool in_refresh);
 void close_handle_and_leave_table_as_lock(Table *table);
 bool wait_for_tables(Session *session);
 bool table_is_used(Table *table, bool wait_for_name_lock);
-Table *drop_locked_tables(Session *session, const drizzled::TableIdentifier &identifier);
-void abort_locked_tables(Session *session, const drizzled::TableIdentifier &identifier);
+Table *drop_locked_tables(Session *session, const drizzled::identifier::Table &identifier);
+void abort_locked_tables(Session *session, const drizzled::identifier::Table &identifier);
 extern Field *not_found_field;
 extern Field *view_ref_found;
 
@@ -746,4 +745,3 @@ find_field_in_table(Session *session, Table *table, const char *name, uint32_t l
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_CURSOR_H */
