@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,12 +18,11 @@
  */
 
 
-#ifndef DRIZZLED_DISCRETE_INTERVAL_H
-#define DRIZZLED_DISCRETE_INTERVAL_H
+#pragma once
 
 #include <cstdlib>
 
-#include "drizzled/definitions.h"
+#include <drizzled/definitions.h>
 
 namespace drizzled
 {
@@ -54,14 +53,14 @@ public:
     interval_min(start), interval_values(val),
     interval_max((val == UINT64_MAX) ? val : start + val * incr),
     next(NULL)
-  {};
+  {}
   Discrete_interval() :
     interval_min(0), interval_values(0),
     interval_max(0), next(NULL)
-  {};
-  uint64_t minimum() const { return interval_min;    };
-  uint64_t values()  const { return interval_values; };
-  uint64_t maximum() const { return interval_max;    };
+  {}
+  uint64_t minimum() const { return interval_min;    }
+  uint64_t values()  const { return interval_values; }
+  uint64_t maximum() const { return interval_max;    }
   /*
     If appending [3,5] to [1,2], we merge both in [1,5] (they should have the
     same increment for that, user of the class has to ensure that). That is
@@ -83,7 +82,7 @@ public:
       return 0;
     }
     return 1;
-  };
+  }
 };
 
 
@@ -114,7 +113,7 @@ private:
 public:
   Discrete_intervals_list() :
     head(NULL), tail(NULL),
-    current(NULL), elements(0) {};
+    current(NULL), elements(0) {}
   Discrete_intervals_list(const Discrete_intervals_list& from) :
     head(NULL), tail(NULL),
     current(NULL), elements(0)
@@ -150,9 +149,9 @@ public:
       current= current->next;
     return tmp;
   }
-  ~Discrete_intervals_list() { empty(); };
-  uint64_t minimum()     const { return (head ? head->minimum() : 0); };
-  uint64_t maximum()     const { return (head ? tail->maximum() : 0); };
+  ~Discrete_intervals_list() { empty(); }
+  uint64_t minimum()     const { return (head ? head->minimum() : 0); }
+  uint64_t maximum()     const { return (head ? tail->maximum() : 0); }
   uint32_t      nb_elements() const { return elements; }
 
   bool append(uint64_t start, uint64_t val, uint64_t incr)
@@ -184,4 +183,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_DISCRETE_INTERVAL_H */
