@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *  Copyright (C) 2010 Monty Taylor
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -18,13 +18,15 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_DRIZZLED_H
-#define DRIZZLED_DRIZZLED_H
+#pragma once
 
 #include <bitset>
 #include <boost/program_options.hpp>
 
-#include "drizzled/atomics.h"
+#include <boost/detail/atomic_count.hpp>
+
+#include <drizzled/global_buffer.h>
+#include <drizzled/definitions.h>
 
 struct passwd;
 
@@ -36,8 +38,7 @@ namespace module
 class Registry;
 }
 
-extern std::bitset<12> test_flags;
-extern atomic<uint32_t> connection_count;
+extern boost::detail::atomic_count connection_count;
 extern const char *load_default_groups[];
 extern bool volatile select_thread_in_use;
 extern bool volatile abort_loop;
@@ -47,19 +48,25 @@ extern bool opt_help_extended;
 extern passwd *user_info;
 extern char *drizzled_user;
 
+extern global_buffer_constraint<uint64_t> global_sort_buffer;
+extern global_buffer_constraint<uint64_t> global_join_buffer;
+extern global_buffer_constraint<uint64_t> global_read_rnd_buffer;
+extern global_buffer_constraint<uint64_t> global_read_buffer;
+
+extern size_t transaction_message_threshold;
+
 extern const char * const DRIZZLE_CONFIG_NAME;
 
 boost::program_options::variables_map &getVariablesMap();
 
 int init_thread_environment();
 int init_server_components(module::Registry &modules);
-int init_common_variables(int argc, char **argv, module::Registry &modules);
+int init_basic_variables(int argc, char **argv);
+int init_remaining_variables(module::Registry &modules);
 
 passwd *check_user(const char *user);
 void set_user(const char *user, passwd *user_info_arg);
 void clean_up(bool print_message);
-bool drizzle_rm_tmp_tables();
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_DRIZZLED_H */
