@@ -600,6 +600,7 @@ typedef struct Bigint
 {
   union {
     ULong *x;              /* points right after this Bigint object */
+    struct Bigint *next;   /* to maintain free lists */
   } p;
   int k;                   /* 2^k = maxwds */
   int maxwds;              /* maximum length in 32-bit words */
@@ -621,8 +622,12 @@ static Bigint *Bcopy(Bigint* dst, Bigint* src)
 
 static Bigint *Balloc(int k)
 {
+  Bigint *rv;
+
+  /* TODO: some malloc failure checking */
+
   int x= 1 << k;
-  Bigint* rv= (Bigint*) malloc(sizeof(Bigint));
+  rv= (Bigint*) malloc(sizeof(Bigint));
 
   rv->p.x= (ULong*)malloc(x * sizeof(ULong));
 
