@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,24 +22,26 @@
    errmsg_printf()
 */
 
-#ifndef DRIZZLED_ERRMSG_PRINT_H
-#define DRIZZLED_ERRMSG_PRINT_H
+
+
+#pragma once
+
+#include <drizzled/visibility.h>
+#include <drizzled/error/level_t.h>
+
+#include <string>
 
 namespace drizzled
 {
 
-#define ERRMSG_LVL_DBUG 1
-#define ERRMSG_LVL_INFO 2
-#define ERRMSG_LVL_WARN 3
-#define ERRMSG_LVL_ERROR 4
+DRIZZLED_API bool errmsg_printf(error::level_t priority, char const *format, ...)
+  __attribute__((format(printf, 2, 3)));
 
-// todo: add __attribute__((format(printf, 1, 2)))
-bool errmsg_printf (int priority, char const *format, ...);
-
-void sql_perror (const char *message);
+DRIZZLED_API void sql_perror(const char *message);
+DRIZZLED_API void sql_perror(const std::string &message);
+DRIZZLED_API void sql_perror(std::string message, const std::string &extra);
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ERRMSG_PRINT_H */
 
 
