@@ -22,7 +22,13 @@
 
 #include <drizzled/visibility.h>
 
-namespace drizzled {
+namespace drizzled
+{
+
+namespace sql
+{
+  class ResultSet;
+}
 
 class DRIZZLED_API Execute
 {
@@ -31,9 +37,11 @@ class DRIZZLED_API Execute
 
 public:
   Execute(Session&, bool wait_arg);
+  ~Execute();
 
-  void run(str_ref);
-  void run(str_ref, sql::ResultSet&);
+  void run(std::string &to_execute);
+  void run(const char *arg, size_t length);
+  void run(std::string &execution_string, sql::ResultSet &result_set);
 
   Session &session()
   {
