@@ -18,24 +18,26 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_FIELD_BLOB_H
-#define DRIZZLED_FIELD_BLOB_H
+#pragma once
 
 #include <drizzled/field/str.h>
 
-#include "drizzled/global_charset_info.h"
+#include <drizzled/global_charset_info.h>
 
 #include <string>
 
+#include <drizzled/visibility.h>
+
 namespace drizzled
 {
 
 /**
  * Class representing a BLOB data type column
  */
-class Field_blob :public Field_str {
+class DRIZZLED_API Field_blob :
+  public Field_str
+{
 protected:
-  uint32_t packlength;
   String value;				// For temporaries
 public:
 
@@ -51,7 +53,6 @@ public:
              unsigned char null_bit_arg,
              const char *field_name_arg,
              TableShare *share,
-             uint32_t blob_pack_length,
              const CHARSET_INFO * const cs);
   Field_blob(uint32_t len_arg,
              bool maybe_null_arg,
@@ -62,42 +63,11 @@ public:
                maybe_null_arg ? (unsigned char *) "": 0,
                0,
                field_name_arg,
-               cs),
-    packlength(4)
+               cs)
   {
     flags|= BLOB_FLAG;
   }
-  Field_blob(uint32_t len_arg,
-             bool maybe_null_arg,
-             const char *field_name_arg,
-             const CHARSET_INFO * const cs,
-             bool set_packlength)
-    :Field_str((unsigned char*) NULL,
-               len_arg,
-               maybe_null_arg ? (unsigned char*) "": 0,
-               0,
-               field_name_arg,
-               cs),
-    packlength(4)
-  {
-    flags|= BLOB_FLAG;
-    if (set_packlength)
-    {
-      uint32_t l_char_length= len_arg/cs->mbmaxlen;
-      packlength= l_char_length <= 255 ? 1 :
-                  l_char_length <= 65535 ? 2 :
-                  l_char_length <= 16777215 ? 3 : 4;
-    }
-  }
-  Field_blob(uint32_t packlength_arg)
-    :Field_str((unsigned char*) 0,
-               0,
-               (unsigned char*) "",
-               0,
-               "temp",
-               system_charset_info),
-    packlength(packlength_arg) 
-  {}
+
   enum_field_types type() const { return DRIZZLE_TYPE_BLOB;}
   enum ha_base_keytype key_type() const
     { return binary() ? HA_KEYTYPE_VARBINARY2 : HA_KEYTYPE_VARTEXT2; }
@@ -106,10 +76,10 @@ public:
   int  store(double nr);
   int  store(int64_t nr, bool unsigned_val);
 
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*,String *);
-  my_decimal *val_decimal(my_decimal *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*,String *) const;
+  type::Decimal *val_decimal(type::Decimal *) const;
   int cmp_max(const unsigned char *, const unsigned char *, uint32_t max_length);
   int cmp(const unsigned char *a,const unsigned char *b)
     { return cmp_max(a, b, UINT32_MAX); }
@@ -131,25 +101,24 @@ public:
      @returns The length of the raw data itself without the pointer.
   */
   uint32_t pack_length_no_ptr() const
-  { return (uint32_t) (packlength); }
+  { return (uint32_t) (sizeof(uint32_t)); }
+
   uint32_t sort_length() const;
   virtual uint32_t max_data_length() const
   {
-    return (uint32_t) (((uint64_t) 1 << (packlength*8)) -1);
+    return (uint32_t) (((uint64_t) 1 << 32) -1);
   }
-  int reset(void) { memset(ptr, 0, packlength+sizeof(unsigned char*)); return 0; }
+  int reset(void) { memset(ptr, 0, sizeof(uint32_t)+sizeof(unsigned char*)); return 0; }
   void reset_fields() { memset(&value, 0, sizeof(value)); }
 #ifndef WORDS_BIGENDIAN
   static
 #endif
-  void store_length(unsigned char *i_ptr, uint32_t i_packlength,
-                    uint32_t i_number, bool low_byte_first);
-  void store_length(unsigned char *i_ptr, uint32_t i_packlength,
-                    uint32_t i_number);
+  void store_length(unsigned char *i_ptr, uint32_t i_number, bool low_byte_first);
+  void store_length(unsigned char *i_ptr, uint32_t i_number);
 
   inline void store_length(uint32_t number)
   {
-    store_length(ptr, packlength, number);
+    store_length(ptr, number);
   }
 
   /**
@@ -162,29 +131,28 @@ public:
   */
   uint32_t get_packed_size(const unsigned char *ptr_arg, bool low_byte_first);
 
-  uint32_t get_length(uint32_t row_offset= 0);
-  uint32_t get_length(const unsigned char *ptr, uint32_t packlength,
-                      bool low_byte_first);
-  uint32_t get_length(const unsigned char *ptr_arg);
+  DRIZZLED_API uint32_t get_length(uint32_t row_offset= 0) const;
+  DRIZZLED_API uint32_t get_length(const unsigned char *ptr, bool low_byte_first) const;
+  DRIZZLED_API uint32_t get_length(const unsigned char *ptr_arg) const;
   void put_length(unsigned char *pos, uint32_t length);
   inline void get_ptr(unsigned char **str)
     {
-      memcpy(str,ptr+packlength,sizeof(unsigned char*));
+      memcpy(str,ptr+sizeof(uint32_t),sizeof(unsigned char*));
     }
   inline void get_ptr(unsigned char **str, uint32_t row_offset)
     {
-      memcpy(str,ptr+packlength+row_offset,sizeof(char*));
+      memcpy(str,ptr+sizeof(uint32_t)+row_offset,sizeof(char*));
     }
   inline void set_ptr(unsigned char *length, unsigned char *data)
     {
-      memcpy(ptr,length,packlength);
-      memcpy(ptr+packlength,&data,sizeof(char*));
+      memcpy(ptr,length,sizeof(uint32_t));
+      memcpy(ptr+sizeof(uint32_t),&data,sizeof(char*));
     }
   void set_ptr_offset(ptrdiff_t ptr_diff, uint32_t length, unsigned char *data)
     {
       unsigned char *ptr_ofs= ADD_TO_PTR(ptr,ptr_diff,unsigned char*);
-      store_length(ptr_ofs, packlength, length);
-      memcpy(ptr_ofs+packlength,&data,sizeof(char*));
+      store_length(ptr_ofs, length);
+      memcpy(ptr_ofs+sizeof(uint32_t),&data,sizeof(char*));
     }
   inline void set_ptr(uint32_t length, unsigned char *data)
     {
@@ -204,7 +172,7 @@ public:
       return 1;
     }
     tmp=(unsigned char*) value.ptr();
-    memcpy(ptr+packlength,&tmp,sizeof(char*));
+    memcpy(ptr+sizeof(uint32_t),&tmp,sizeof(char*));
     return 0;
   }
   virtual unsigned char *pack(unsigned char *to, const unsigned char *from,
@@ -212,7 +180,7 @@ public:
   unsigned char *pack_key(unsigned char *to, const unsigned char *from,
                   uint32_t max_length, bool low_byte_first);
   virtual const unsigned char *unpack(unsigned char *to, const unsigned char *from,
-                              uint32_t param_data, bool low_byte_first);
+                              uint32_t , bool low_byte_first);
   void free() { value.free(); }
   inline void clear_temporary() { memset(&value, 0, sizeof(value)); }
   friend int field_conv(Field *to,Field *from);
@@ -224,5 +192,4 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_FIELD_BLOB_H */
 
