@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_FIELD_DATETIME_H
-#define DRIZZLED_FIELD_DATETIME_H
+#pragma once
 
 #include <drizzled/field/str.h>
 
@@ -37,25 +36,25 @@ public:
   Field_datetime(unsigned char *ptr_arg,
                  unsigned char *null_ptr_arg,
                  unsigned char null_bit_arg,
-                 const char *field_name_arg,
-                 const CHARSET_INFO * const cs)
-    :Field_str(ptr_arg,
+                 const char *field_name_arg) :
+    Field_str(ptr_arg,
                19,
                null_ptr_arg,
                null_bit_arg,
                field_name_arg,
-               cs)
+               &my_charset_bin)
   {}
+
   Field_datetime(bool maybe_null_arg,
-                 const char *field_name_arg,
-                 const CHARSET_INFO * const cs)
-    :Field_str((unsigned char*) 0,
+                 const char *field_name_arg) :
+    Field_str((unsigned char*) 0,
                19,
                maybe_null_arg ? (unsigned char*) "": 0,
                0,
                field_name_arg,
-               cs) 
+               &my_charset_bin) 
   {}
+
   enum_field_types type() const { return DRIZZLE_TYPE_DATETIME;}
   enum ha_base_keytype key_type() const { return HA_KEYTYPE_ULONGLONG; }
   enum Item_result cmp_type () const { return INT_RESULT; }
@@ -63,25 +62,24 @@ public:
   int  store(const char *to,uint32_t length, const CHARSET_INFO * const charset);
   int  store(double nr);
   int  store(int64_t nr, bool unsigned_val);
-  int store_time(DRIZZLE_TIME *ltime, enum enum_drizzle_timestamp_type type);
+  int store_time(type::Time &ltime, type::timestamp_t type);
   int reset(void)
   {
     ptr[0]=ptr[1]=ptr[2]=ptr[3]=ptr[4]=ptr[5]=ptr[6]=ptr[7]=0;
     return 0;
   }
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*,String *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*,String *) const;
   int cmp(const unsigned char *,const unsigned char *);
   void sort_string(unsigned char *buff,uint32_t length);
   uint32_t pack_length() const { return 8; }
   void sql_type(String &str) const;
   bool can_be_compared_as_int64_t() const { return true; }
   bool zero_pack() const { return 1; }
-  bool get_date(DRIZZLE_TIME *ltime,uint32_t fuzzydate);
-  bool get_time(DRIZZLE_TIME *ltime);
+  bool get_date(type::Time &ltime,uint32_t fuzzydate) const;
+  bool get_time(type::Time &ltime) const;
 };
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_FIELD_DATETIME_H */
