@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_FIELD_DECIMAL_H
-#define DRIZZLED_FIELD_DECIMAL_H
+#pragma once
 
 #include <drizzled/field/num.h>
 
@@ -51,29 +50,29 @@ public:
                 unsigned char null_bit_arg,
                 enum utype unireg_check_arg,
                 const char *field_name_arg,
-                uint8_t dec_arg,
-                bool zero_arg,
-                bool unsigned_arg);
+                uint8_t dec_arg);
+
   Field_decimal(uint32_t len_arg,
                 bool maybe_null_arg,
                 const char *field_name_arg,
                 uint8_t dec_arg,
                 bool unsigned_arg);
+
   enum_field_types type() const { return DRIZZLE_TYPE_DECIMAL;}
   enum ha_base_keytype key_type() const { return HA_KEYTYPE_BINARY; }
   Item_result result_type () const { return DECIMAL_RESULT; }
   int  reset(void);
-  bool store_value(const my_decimal *decimal_value);
-  void set_value_on_overflow(my_decimal *decimal_value, bool sign);
+  bool store_value(const type::Decimal *decimal_value);
+  void set_value_on_overflow(type::Decimal *decimal_value, bool sign);
   int  store(const char *to, uint32_t length, const CHARSET_INFO * const charset);
   int  store(double nr);
   int  store(int64_t nr, bool unsigned_val);
-  int store_time(DRIZZLE_TIME *ltime, enum enum_drizzle_timestamp_type t_type);
-  int  store_decimal(const my_decimal *);
-  double val_real(void);
-  int64_t val_int(void);
-  my_decimal *val_decimal(my_decimal *);
-  String *val_str(String*, String *);
+  int store_time(type::Time &ltime, type::timestamp_t t_type);
+  int  store_decimal(const type::Decimal *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  type::Decimal *val_decimal(type::Decimal *) const;
+  String *val_str(String*, String *) const;
   int cmp(const unsigned char *, const unsigned char *);
   void sort_string(unsigned char *buff, uint32_t length);
   bool zero_pack() const { return 0; }
@@ -89,5 +88,4 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_FIELD_DECIMAL_H */
 
