@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_FIELD_DOUBLE_H
-#define DRIZZLED_FIELD_DOUBLE_H
+#pragma once
 
 #include <drizzled/field/real.h>
 
@@ -59,9 +58,9 @@ public:
   int  store(double nr);
   int  store(int64_t nr, bool unsigned_val);
   int reset(void) { memset(ptr, 0, sizeof(double)); return 0; }
-  double val_real(void);
-  int64_t val_int(void);
-  String *val_str(String*,String *);
+  double val_real(void) const;
+  int64_t val_int(void) const;
+  String *val_str(String*,String *) const;
   int cmp(const unsigned char *,const unsigned char *);
   void sort_string(unsigned char *buff,uint32_t length);
   uint32_t pack_length() const { return sizeof(double); }
@@ -70,5 +69,4 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_FIELD_DOUBLE_H */
 
