@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_FIELD_NULL_H
-#define DRIZZLED_FIELD_NULL_H
+#pragma once
 
 #include <drizzled/field/str.h>
 
@@ -42,15 +41,15 @@ public:
 
   Field_null(unsigned char *ptr_arg,
              uint32_t len_arg,
-             const char *field_name_arg,
-             const CHARSET_INFO * const cs)
-    :Field_str(ptr_arg,
-               len_arg,
-               null,
-               1,
-	             field_name_arg,
-               cs)
+             const char *field_name_arg) :
+    Field_str(ptr_arg,
+              len_arg,
+              null,
+              1,
+              field_name_arg,
+              &my_charset_bin)
   {}
+
   enum_field_types type() const
   {
     return DRIZZLE_TYPE_NULL;
@@ -70,7 +69,7 @@ public:
     null[0]= 1;
     return 0;
   }
-  int store_decimal(const my_decimal *)
+  int store_decimal(const type::Decimal *)
   {
     null[0]= 1;
     return 0;
@@ -79,19 +78,19 @@ public:
   {
     return 0;
   }
-  double val_real(void)
+  double val_real(void) const
   {
     return 0.0;
   }
-  int64_t val_int(void)
+  int64_t val_int(void) const
   {
     return 0;
   }
-  my_decimal *val_decimal(my_decimal *)
+  type::Decimal *val_decimal(type::Decimal *) const
   {
     return 0;
   }
-  String *val_str(String *, String *value2)
+  String *val_str(String *, String *value2) const
   {
     value2->length(0);
     return value2;
@@ -119,4 +118,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_FIELD_NULL_H */
