@@ -11,7 +11,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 
 /**
@@ -24,25 +24,28 @@
     gives much more speed.
 */
 
-#include "config.h"
+#include <config.h>
+
 #include <drizzled/error.h>
 #include <drizzled/table.h>
 #include <drizzled/session.h>
+#include <drizzled/current_session.h>
 
-#include <drizzled/field/str.h>
-#include <drizzled/field/num.h>
+#include <drizzled/copy_field.h>
 #include <drizzled/field/blob.h>
-#include <drizzled/field/enum.h>
-#include <drizzled/field/null.h>
 #include <drizzled/field/date.h>
-#include <drizzled/field/decimal.h>
-#include <drizzled/field/real.h>
-#include <drizzled/field/double.h>
-#include <drizzled/field/long.h>
-#include <drizzled/field/int64_t.h>
-#include <drizzled/field/num.h>
-#include <drizzled/field/timestamp.h>
 #include <drizzled/field/datetime.h>
+#include <drizzled/field/decimal.h>
+#include <drizzled/field/double.h>
+#include <drizzled/field/enum.h>
+#include <drizzled/field/epoch.h>
+#include <drizzled/field/int32.h>
+#include <drizzled/field/int64.h>
+#include <drizzled/field/null.h>
+#include <drizzled/field/num.h>
+#include <drizzled/field/num.h>
+#include <drizzled/field/real.h>
+#include <drizzled/field/str.h>
 #include <drizzled/field/varstring.h>
 
 namespace drizzled
@@ -180,6 +183,7 @@ set_field_to_null_with_conversions(Field *field, bool no_conversions)
     field->reset();
     return 0;
   }
+
   if (no_conversions)
     return -1;
 
@@ -188,24 +192,28 @@ set_field_to_null_with_conversions(Field *field, bool no_conversions)
     when set to NULL (TIMESTAMP fields which allow setting to NULL
     are handled by first check).
   */
-  if (field->type() == DRIZZLE_TYPE_TIMESTAMP)
+  if (field->is_timestamp())
   {
-    ((Field_timestamp*) field)->set_time();
+    ((field::Epoch::pointer) field)->set_time();
     return 0;					// Ok to set time to NULL
   }
+
   field->reset();
   if (field == field->getTable()->next_number_field)
   {
     field->getTable()->auto_increment_field_not_null= false;
     return 0;				  // field is set in fill_record()
   }
+
   if (field->getTable()->in_use->count_cuted_fields == CHECK_FIELD_WARN)
   {
     field->set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN, ER_BAD_NULL_ERROR, 1);
     return 0;
   }
+
   if (!field->getTable()->in_use->no_errors)
     my_error(ER_BAD_NULL_ERROR, MYF(0), field->field_name);
+
   return -1;
 }
 
@@ -248,14 +256,20 @@ static void do_outer_field_null(CopyField *copy)
 
 static void do_copy_not_null(CopyField *copy)
 {
-  if (*copy->from_null_ptr & copy->from_bit)
+  if (copy->to_field->hasDefault() and *copy->from_null_ptr & copy->from_bit)
+  {
+    copy->to_field->set_default();
+  }
+  else if (*copy->from_null_ptr & copy->from_bit)
   {
     copy->to_field->set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN,
                                 ER_WARN_DATA_TRUNCATED, 1);
     copy->to_field->reset();
   }
   else
+  {
     (copy->do_copy2)(copy);
+  }
 }
 
 
@@ -272,10 +286,12 @@ static void do_copy_timestamp(CopyField *copy)
   if (*copy->from_null_ptr & copy->from_bit)
   {
     /* Same as in set_field_to_null_with_conversions() */
-    ((Field_timestamp*) copy->to_field)->set_time();
+    ((field::Epoch::pointer) copy->to_field)->set_time();
   }
   else
+  {
     (copy->do_copy2)(copy);
+  }
 }
 
 
@@ -288,7 +304,9 @@ static void do_copy_next_number(CopyField *copy)
     copy->to_field->reset();
   }
   else
+  {
     (copy->do_copy2)(copy);
+  }
 }
 
 
@@ -301,7 +319,7 @@ static void do_copy_blob(CopyField *copy)
 
 static void do_conv_blob(CopyField *copy)
 {
-  copy->from_field->val_str(&copy->tmp);
+  copy->from_field->val_str_internal(&copy->tmp);
   ((Field_blob *) copy->to_field)->store(copy->tmp.ptr(),
                                          copy->tmp.length(),
                                          copy->tmp.charset());
@@ -313,7 +331,7 @@ static void do_save_blob(CopyField *copy)
 {
   char buff[MAX_FIELD_WIDTH];
   String res(buff, sizeof(buff), copy->tmp.charset());
-  copy->from_field->val_str(&res);
+  copy->from_field->val_str_internal(&res);
   copy->tmp.copy(res);
   ((Field_blob *) copy->to_field)->store(copy->tmp.ptr(),
                                          copy->tmp.length(),
@@ -325,7 +343,7 @@ static void do_field_string(CopyField *copy)
 {
   char buff[MAX_FIELD_WIDTH];
   copy->tmp.set_quick(buff,sizeof(buff),copy->tmp.charset());
-  copy->from_field->val_str(&copy->tmp);
+  copy->from_field->val_str_internal(&copy->tmp);
   copy->to_field->store(copy->tmp.c_ptr_quick(),copy->tmp.length(),
                         copy->tmp.charset());
 }
@@ -356,7 +374,7 @@ static void do_field_real(CopyField *copy)
 
 static void do_field_decimal(CopyField *copy)
 {
-  my_decimal value;
+  type::Decimal value;
   copy->to_field->store_decimal(copy->from_field->val_decimal(&value));
 }
 
@@ -369,7 +387,7 @@ static void do_field_decimal(CopyField *copy)
 static void do_cut_string(CopyField *copy)
 {
   const CHARSET_INFO * const cs= copy->from_field->charset();
-  memcpy(copy->to_ptr,copy->from_ptr,copy->to_length);
+  memcpy(copy->to_ptr, copy->from_ptr, copy->to_length);
 
   /* Check if we loosed any important characters */
   if (cs->cset->scan(cs,
@@ -446,8 +464,10 @@ static void do_varstring1(CopyField *copy)
   {
     length= copy->to_length - 1;
     if (copy->from_field->getTable()->in_use->count_cuted_fields)
+    {
       copy->to_field->set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN,
                                   ER_WARN_DATA_TRUNCATED, 1);
+    }
   }
   *(unsigned char*) copy->to_ptr= (unsigned char) length;
   memcpy(copy->to_ptr+1, copy->from_ptr + 1, length);
@@ -467,8 +487,10 @@ static void do_varstring1_mb(CopyField *copy)
   if (length < from_length)
   {
     if (current_session->count_cuted_fields)
+    {
       copy->to_field->set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN,
                                   ER_WARN_DATA_TRUNCATED, 1);
+    }
   }
   *copy->to_ptr= (unsigned char) length;
   memcpy(copy->to_ptr + 1, from_ptr, length);
@@ -482,8 +504,10 @@ static void do_varstring2(CopyField *copy)
   {
     length=copy->to_length-HA_KEY_BLOB_LENGTH;
     if (copy->from_field->getTable()->in_use->count_cuted_fields)
+    {
       copy->to_field->set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN,
                                   ER_WARN_DATA_TRUNCATED, 1);
+    }
   }
   int2store(copy->to_ptr,length);
   memcpy(copy->to_ptr+HA_KEY_BLOB_LENGTH, copy->from_ptr + HA_KEY_BLOB_LENGTH,
@@ -504,8 +528,10 @@ static void do_varstring2_mb(CopyField *copy)
   if (length < from_length)
   {
     if (current_session->count_cuted_fields)
+    {
       copy->to_field->set_warning(DRIZZLE_ERROR::WARN_LEVEL_WARN,
                                   ER_WARN_DATA_TRUNCATED, 1);
+    }
   }
   int2store(copy->to_ptr, length);
   memcpy(copy->to_ptr+HA_KEY_BLOB_LENGTH, from_beg, length);
@@ -594,7 +620,9 @@ void CopyField::set(Field *to,Field *from,bool save)
       to_null_ptr= to->null_ptr;
       to_bit= to->null_bit;
       if (from_null_ptr)
+      {
         do_copy= do_copy_null;
+      }
       else
       {
         null_row= &from->getTable()->null_row;
@@ -603,12 +631,18 @@ void CopyField::set(Field *to,Field *from,bool save)
     }
     else
     {
-      if (to_field->type() == DRIZZLE_TYPE_TIMESTAMP)
+      if (to_field->is_timestamp())
+      {
         do_copy= do_copy_timestamp;               // Automatic timestamp
+      }
       else if (to_field == to_field->getTable()->next_number_field)
+      {
         do_copy= do_copy_next_number;
+      }
       else
+      {
         do_copy= do_copy_not_null;
+      }
     }
   }
   else if (to_field->real_maybe_null())
@@ -641,8 +675,8 @@ CopyField::get_copy_func(Field *to,Field *from)
     if (from_length != to_length || !compatible_db_low_byte_first)
     {
       // Correct pointer to point at char pointer
-      to_ptr+= to_length - to->getTable()->getShare()->blob_ptr_size;
-      from_ptr+= from_length- from->getTable()->getShare()->blob_ptr_size;
+      to_ptr+= to_length - to->getTable()->getShare()->sizeBlobPtr();
+      from_ptr+= from_length- from->getTable()->getShare()->sizeBlobPtr();
       return do_copy_blob;
     }
   }
@@ -668,11 +702,11 @@ CopyField::get_copy_func(Field *to,Field *from)
           {
             return do_field_int;  // Convert SET to number
           }
-          
+
           return do_field_string;
         }
       }
-      
+
       if (to->real_type() == DRIZZLE_TYPE_ENUM)
       {
         if (!to->eq_def(from))
@@ -688,19 +722,30 @@ CopyField::get_copy_func(Field *to,Field *from)
         return do_field_string;
       else if (to->real_type() == DRIZZLE_TYPE_VARCHAR)
       {
-        if (((Field_varstring*) to)->pack_length_no_ptr() !=
-            ((Field_varstring*) from)->pack_length_no_ptr())
+        /* Field_blob is not part of the Field_varstring hierarchy,
+          and casting to varstring for calling pack_length_no_ptr()
+          is always incorrect. Previously the below comparison has
+          always evaluated to false as pack_length_no_ptr() for BLOB
+          will return 4 and varstring can only be <= 2.
+          If your brain slightly bleeds as to why this worked for
+          so many years, you are in no way alone.
+        */
+        if (from->flags & BLOB_FLAG)
+          return do_field_string;
+
+        if ((static_cast<Field_varstring*>(to))->pack_length_no_ptr() !=
+            (static_cast<Field_varstring*>(from))->pack_length_no_ptr())
         {
           return do_field_string;
         }
-        
+
         if (to_length != from_length)
         {
           return (((Field_varstring*) to)->pack_length_no_ptr() == 1 ?
                   (from->charset()->mbmaxlen == 1 ? do_varstring1 :
-                                                    do_varstring1_mb) :
+                   do_varstring1_mb) :
                   (from->charset()->mbmaxlen == 1 ? do_varstring2 :
-                                                    do_varstring2_mb));
+                   do_varstring2_mb));
         }
       }
       else if (to_length < from_length)
@@ -780,7 +825,7 @@ int field_conv(Field *to,Field *from)
   if (to->type() == DRIZZLE_TYPE_BLOB)
   {						// Be sure the value is stored
     Field_blob *blob=(Field_blob*) to;
-    from->val_str(&blob->value);
+    from->val_str_internal(&blob->value);
     /*
       Copy value if copy_blobs is set, or source is not a string and
       we have a pointer to its internal string conversion buffer.
@@ -804,7 +849,7 @@ int field_conv(Field *to,Field *from)
   {
     char buff[MAX_FIELD_WIDTH];
     String result(buff,sizeof(buff),from->charset());
-    from->val_str(&result);
+    from->val_str_internal(&result);
     /*
       We use c_ptr_quick() here to make it easier if to is a float/double
       as the conversion routines will do a copy of the result doesn't
@@ -814,14 +859,18 @@ int field_conv(Field *to,Field *from)
     return to->store(result.c_ptr_quick(),result.length(),from->charset());
   }
   else if (from->result_type() == REAL_RESULT)
+  {
     return to->store(from->val_real());
+  }
   else if (from->result_type() == DECIMAL_RESULT)
   {
-    my_decimal buff;
+    type::Decimal buff;
     return to->store_decimal(from->val_decimal(&buff));
   }
   else
+  {
     return to->store(from->val_int(), test(from->flags & UNSIGNED_FLAG));
+  }
 }
 
 } /* namespace drizzled */
