@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,15 +18,14 @@
  */
 
 
-#ifndef DRIZZLED_FIELD_ITERATOR_H
-#define DRIZZLED_FIELD_ITERATOR_H
+#pragma once
 
-#include "drizzled/memory/sql_alloc.h"
+#include <drizzled/memory/sql_alloc.h>
 #include <drizzled/sql_list.h>
 #include <drizzled/natural_join_column.h>
+#include <drizzled/item/field.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 class Table;
 class TableList;
@@ -78,7 +77,7 @@ public:
 
 class Field_iterator_natural_join: public Field_iterator
 {
-  List_iterator_fast<Natural_join_column> column_ref_it;
+  List<Natural_join_column>::iterator column_ref_it;
   Natural_join_column *cur_column_ref;
 public:
   Field_iterator_natural_join() :cur_column_ref(NULL) {}
@@ -133,4 +132,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_FIELD_ITERATOR_H */
