@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008, 2009 Sun Microsystems
+ *  Copyright (C) 2008, 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,8 @@
  */
 
 
-#include "config.h"
-#include "drizzled/file_exchange.h"
+#include <config.h>
+#include <drizzled/file_exchange.h>
 
 namespace drizzled
 {
