@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,12 +18,11 @@
  */
 
 
-#ifndef DRIZZLED_FILE_EXCHANGE_H
-#define DRIZZLED_FILE_EXCHANGE_H
+#pragma once
 
-#include "drizzled/sql_string.h"
-#include "drizzled/memory/sql_alloc.h"
-#include "drizzled/enum.h"
+#include <drizzled/sql_string.h>
+#include <drizzled/memory/sql_alloc.h>
+#include <drizzled/enum.h>
 
 namespace drizzled
 {
@@ -40,7 +39,8 @@ static String default_field_term("\t",default_charset_info);
   XXX: We never call destructor for objects of this class.
 */
 
-class file_exchange :public memory::SqlAlloc
+class file_exchange :
+  public memory::SqlAlloc
 {
 public:
   enum enum_filetype filetype; /* load XML, Added by Arnold & Erik */
@@ -57,4 +57,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_FILE_EXCHANGE_H */
