@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,19 +17,22 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
-#include <drizzled/sql_string.h>
-#include <drizzled/sql_list.h>
-
-#include <drizzled/function/math/int.h>
-#include <drizzled/field/int64_t.h>
-#include <drizzled/field/long.h>
-#include <drizzled/field/double.h>
-#include <drizzled/field/decimal.h>
-#include <drizzled/session.h>
-#include <drizzled/error.h>
 #include <drizzled/check_stack_overrun.h>
+#include <drizzled/current_session.h>
+#include <drizzled/error.h>
+#include <drizzled/field/decimal.h>
+#include <drizzled/field/double.h>
+#include <drizzled/field/int32.h>
+#include <drizzled/field/int64.h>
+#include <drizzled/field/size.h>
+#include <drizzled/function/math/int.h>
+#include <drizzled/item/field.h>
+#include <drizzled/session.h>
+#include <drizzled/sql_list.h>
+#include <drizzled/sql_string.h>
+
 #include <limits>
 #include <algorithm>
 
@@ -39,14 +42,92 @@ namespace drizzled
 {
 
 
+Item_func::Item_func(void):
+  _session(*current_session),
+  allowed_arg_cols(1), arg_count(0),
+  const_item_cache(false)
+  {
+    with_sum_func= 0;
+    collation.set(DERIVATION_SYSCONST);
+  }
+
+Item_func::Item_func(Item *a):
+  _session(*current_session),
+  allowed_arg_cols(1), arg_count(1),
+  const_item_cache(false)
+  {
+    args= tmp_arg;
+    args[0]= a;
+    with_sum_func= a->with_sum_func;
+    collation.set(DERIVATION_SYSCONST);
+  }
+
+Item_func::Item_func(Item *a,Item *b):
+  _session(*current_session),
+  allowed_arg_cols(1), arg_count(2),
+  const_item_cache(false)
+  {
+    args= tmp_arg;
+    args[0]= a; args[1]= b;
+    with_sum_func= a->with_sum_func || b->with_sum_func;
+    collation.set(DERIVATION_SYSCONST);
+  }
+
+Item_func::Item_func(Item *a,Item *b,Item *c):
+  _session(*current_session),
+  allowed_arg_cols(1),
+  const_item_cache(false)
+  {
+    arg_count= 0;
+    if ((args= (Item**) memory::sql_alloc(sizeof(Item*)*3)))
+    {
+      arg_count= 3;
+      args[0]= a; args[1]= b; args[2]= c;
+      with_sum_func= a->with_sum_func || b->with_sum_func || c->with_sum_func;
+    }
+    collation.set(DERIVATION_SYSCONST);
+  }
+
+Item_func::Item_func(Item *a,Item *b,Item *c,Item *d):
+  _session(*current_session),
+  allowed_arg_cols(1),
+  const_item_cache(false)
+  {
+    arg_count= 0;
+    if ((args= (Item**) memory::sql_alloc(sizeof(Item*)*4)))
+    {
+      arg_count= 4;
+      args[0]= a; args[1]= b; args[2]= c; args[3]= d;
+      with_sum_func= a->with_sum_func || b->with_sum_func ||
+        c->with_sum_func || d->with_sum_func;
+    }
+    collation.set(DERIVATION_SYSCONST);
+  }
+
+Item_func::Item_func(Item *a,Item *b,Item *c,Item *d,Item* e):
+  _session(*current_session),
+  allowed_arg_cols(1),
+  const_item_cache(false)
+  {
+    arg_count= 5;
+    if ((args= (Item**) memory::sql_alloc(sizeof(Item*)*5)))
+    {
+      args[0]= a; args[1]= b; args[2]= c; args[3]= d; args[4]= e;
+      with_sum_func= a->with_sum_func || b->with_sum_func ||
+        c->with_sum_func || d->with_sum_func || e->with_sum_func ;
+    }
+    collation.set(DERIVATION_SYSCONST);
+  }
+
+
 void Item_func::set_arguments(List<Item> &list)
 {
   allowed_arg_cols= 1;
-  arg_count=list.elements;
+  arg_count=list.size();
   args= tmp_arg;                                // If 2 arguments
   if (arg_count <= 2 || (args=(Item**) memory::sql_alloc(sizeof(Item*)*arg_count)))
   {
-    List_iterator_fast<Item> li(list);
+    List<Item>::iterator li(list.begin());
     Item *item;
     Item **save_args= args;
 
@@ -56,12 +137,13 @@ void Item_func::set_arguments(List<Item> &list)
       with_sum_func|=item->with_sum_func;
     }
   }
-  list.empty();          // Fields are used
+  list.clear();          // Fields are used
 }
 
 Item_func::Item_func(List<Item> &list) :
   _session(*current_session),
-  allowed_arg_cols(1)
+  allowed_arg_cols(1),
+  const_item_cache(false)
 {
   collation.set(DERIVATION_SYSCONST);
   set_arguments(list);
@@ -82,7 +164,7 @@ Item_func::Item_func(Session *session, Item_func *item) :
       args= tmp_arg;
     else
     {
-      if (!(args=(Item**) session->alloc(sizeof(Item*)*arg_count)))
+      if (!(args=(Item**) session->getMemRoot()->allocate(sizeof(Item*)*arg_count)))
         return;
     }
     memcpy(args, item->args, sizeof(Item*)*arg_count);
@@ -133,7 +215,7 @@ Item_func::fix_fields(Session *session, Item **)
   unsigned char buff[STACK_BUFF_ALLOC];      // Max argument in function
   session->session_marker= 0;
   used_tables_cache= not_null_tables_cache= 0;
-  const_item_cache=1;
+  const_item_cache= true;
 
   if (check_stack_overrun(session, STACK_MIN_SIZE, buff))
     return true;        // Fatal error if flag is set!
@@ -188,7 +270,7 @@ void Item_func::fix_after_pullout(Select_Lex *new_parent,
   Item **arg,**arg_end;
 
   used_tables_cache= not_null_tables_cache= 0;
-  const_item_cache=1;
+  const_item_cache= false;
 
   if (arg_count)
   {
@@ -275,15 +357,7 @@ Item *Item_func::transform(Item_transformer transformer, unsigned char *argument
       Item *new_item= (*arg)->transform(transformer, argument);
       if (!new_item)
         return 0;
-
-      /*
-        Session::change_item_tree() should be called only if the tree was
-        really transformed, i.e. when a new item has been created.
-        Otherwise we'll be allocating a lot of unnecessary memory for
-        change records at each execution.
-      */
-      if (*arg != new_item)
-        getSession().change_item_tree(arg, new_item);
+      *arg= new_item;
     }
   }
   return (this->*transformer)(argument);
@@ -331,7 +405,7 @@ Item *Item_func::compile(Item_analyzer analyzer, unsigned char **arg_p,
       unsigned char *arg_v= *arg_p;
       Item *new_item= (*arg)->compile(analyzer, &arg_v, transformer, arg_t);
       if (new_item && *arg != new_item)
-        current_session->change_item_tree(arg, new_item);
+        *arg= new_item;
     }
   }
   return (this->*transformer)(arg_t);
@@ -353,7 +427,7 @@ void Item_func::split_sum_func(Session *session, Item **ref_pointer_array,
 void Item_func::update_used_tables()
 {
   used_tables_cache=0;
-  const_item_cache=1;
+  const_item_cache= true;
   for (uint32_t i=0 ; i < arg_count ; i++)
   {
     args[i]->update_used_tables();
@@ -375,37 +449,37 @@ table_map Item_func::not_null_tables() const
 }
 
 
-void Item_func::print(String *str, enum_query_type query_type)
+void Item_func::print(String *str)
 {
   str->append(func_name());
   str->append('(');
-  print_args(str, 0, query_type);
+  print_args(str, 0);
   str->append(')');
 }
 
 
-void Item_func::print_args(String *str, uint32_t from, enum_query_type query_type)
+void Item_func::print_args(String *str, uint32_t from)
 {
   for (uint32_t i=from ; i < arg_count ; i++)
   {
     if (i != from)
       str->append(',');
-    args[i]->print(str, query_type);
+    args[i]->print(str);
   }
 }
 
 
-void Item_func::print_op(String *str, enum_query_type query_type)
+void Item_func::print_op(String *str)
 {
   str->append('(');
   for (uint32_t i=0 ; i < arg_count-1 ; i++)
   {
-    args[i]->print(str, query_type);
+    args[i]->print(str);
     str->append(' ');
     str->append(func_name());
     str->append(' ');
   }
-  args[arg_count-1]->print(str, query_type);
+  args[arg_count-1]->print(str);
   str->append(')');
 }
 
@@ -433,15 +507,15 @@ bool Item_func::eq(const Item *item, bool binary_cmp) const
 }
 
 
-bool Item_func::get_arg0_date(DRIZZLE_TIME *ltime, uint32_t fuzzy_date)
+bool Item_func::get_arg0_date(type::Time &ltime, uint32_t fuzzy_date)
 {
   return (null_value=args[0]->get_date(ltime, fuzzy_date));
 }
 
 
-bool Item_func::get_arg0_time(DRIZZLE_TIME *ltime)
+bool Item_func::get_arg0_time(type::Time &ltime)
 {
-  return (null_value=args[0]->get_time(ltime));
+  return (null_value= args[0]->get_time(ltime));
 }
 
 
@@ -454,22 +528,34 @@ bool Item_func::is_null()
 
 Field *Item_func::tmp_table_field(Table *table)
 {
-  Field *field;
+  Field *field= NULL;
 
   switch (result_type()) {
   case INT_RESULT:
-    if (max_length > MY_INT32_NUM_DECIMAL_DIGITS)
-      field= new Field_int64_t(max_length, maybe_null, name, unsigned_flag);
+    if (unsigned_flag)
+    {
+      field= new field::Size(max_length, maybe_null, name, true);
+    } 
+    else if (max_length > MY_INT32_NUM_DECIMAL_DIGITS)
+    {
+      field= new field::Int64(max_length, maybe_null, name, false);
+    }
     else
-      field= new Field_long(max_length, maybe_null, name, unsigned_flag);
+    {
+      field= new field::Int32(max_length, maybe_null, name, false);
+    }
+
     break;
+
   case REAL_RESULT:
     field= new Field_double(max_length, maybe_null, name, decimals);
     break;
+
   case STRING_RESULT:
     return make_string_field(table);
+
   case DECIMAL_RESULT:
-    field= new Field_decimal(my_decimal_precision_to_length(decimal_precision(),
+    field= new Field_decimal(class_decimal_precision_to_length(decimal_precision(),
                                                             decimals,
                                                             unsigned_flag),
                              maybe_null,
@@ -478,22 +564,22 @@ Field *Item_func::tmp_table_field(Table *table)
                              unsigned_flag);
     break;
   case ROW_RESULT:
-  default:
     // This case should never be chosen
     assert(0);
-    field= 0;
     break;
   }
+
   if (field)
     field->init(table);
+
   return field;
 }
 
 
-my_decimal *Item_func::val_decimal(my_decimal *decimal_value)
+type::Decimal *Item_func::val_decimal(type::Decimal *decimal_value)
 {
   assert(fixed);
-  int2my_decimal(E_DEC_FATAL_ERROR, val_int(), unsigned_flag, decimal_value);
+  int2_class_decimal(E_DEC_FATAL_ERROR, val_int(), unsigned_flag, decimal_value);
   return decimal_value;
 }
 
@@ -567,7 +653,7 @@ void Item_func::count_decimal_length()
     set_if_smaller(unsigned_flag, args[i]->unsigned_flag);
   }
   int precision= min(max_int_part + decimals, DECIMAL_MAX_PRECISION);
-  max_length= my_decimal_precision_to_length(precision, decimals,
+  max_length= class_decimal_precision_to_length(precision, decimals,
                                              unsigned_flag);
 }
 
@@ -622,8 +708,8 @@ void Item_func::count_real_length()
 
 void Item_func::signal_divide_by_null()
 {
-  push_warning(getSessionPtr(), DRIZZLE_ERROR::WARN_LEVEL_ERROR, ER_DIVISION_BY_ZERO, ER(ER_DIVISION_BY_ZERO));
-  null_value= 1;
+  my_error(ER_DIVISION_BY_ZERO, MYF(0));
+  null_value= 0;
 }
 
 
