@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,14 +17,16 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_FUNCTION_GET_SYSTEM_VAR_H
-#define DRIZZLED_FUNCTION_GET_SYSTEM_VAR_H
+#pragma once
 
 #include <drizzled/function/func.h>
+#include <drizzled/lex_string.h>
 
 namespace drizzled
 {
 
+class sys_var;
+
 Item *get_system_var(Session *session, sql_var_t var_type, LEX_STRING name,
                      LEX_STRING component);
 
@@ -35,6 +37,7 @@ class Item_func_get_system_var :public Item_func
   sys_var *var;
   sql_var_t var_type;
   LEX_STRING component;
+
 public:
   Item_func_get_system_var(sys_var *var_arg, sql_var_t var_type_arg,
                            LEX_STRING *component_arg, const char *name_arg,
@@ -55,4 +58,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_FUNCTION_GET_SYSTEM_VAR_H */
