@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_FUNCTION_MIN_MAX_H
-#define DRIZZLED_FUNCTION_MIN_MAX_H
+#pragma once
 
 #include <drizzled/function/func.h>
 
@@ -44,7 +43,7 @@ public:
   double val_real();
   int64_t val_int();
   String *val_str(String *);
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   void fix_length_and_dec();
   enum Item_result result_type () const { return cmp_type; }
   bool result_as_int64_t() { return compare_as_dates; };
@@ -68,4 +67,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_FUNCTION_MIN_MAX_H */
