@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_FUNCTION_SET_USER_VAR_H
-#define DRIZZLED_FUNCTION_SET_USER_VAR_H
+#pragma once
 
 #include <drizzled/function/func.h>
 
@@ -35,14 +34,14 @@ class Item_func_set_user_var :public Item_func
   user_var_entry *entry;
   char buffer[MAX_FIELD_WIDTH];
   String value;
-  my_decimal decimal_buff;
+  type::Decimal decimal_buff;
   bool null_item;
   union
   {
     int64_t vint;
     double vreal;
     String *vstr;
-    my_decimal *vdec;
+    type::Decimal *vdec;
   } save_result;
 
 public:
@@ -54,11 +53,11 @@ public:
   double val_real();
   int64_t val_int();
   String *val_str(String *str);
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   double val_result();
   int64_t val_int_result();
   String *str_result(String *str);
-  my_decimal *val_decimal_result(my_decimal *);
+  type::Decimal *val_decimal_result(type::Decimal *);
   bool update_hash(void *ptr, uint32_t length, enum Item_result type,
   		   const CHARSET_INFO * const cs, Derivation dv, bool unsigned_arg);
   bool send(plugin::Client *client, String *str_arg);
@@ -68,7 +67,7 @@ public:
   enum Item_result result_type () const { return cached_result_type; }
   bool fix_fields(Session *session, Item **ref);
   void fix_length_and_dec();
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
 
   const char *func_name() const { return "set_user_var"; }
   int save_in_field(Field *field, bool no_conversions,
@@ -83,4 +82,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_FUNCTION_SET_USER_VAR_H */
