@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <drizzled/function/str/collation.h>
 
@@ -27,7 +27,7 @@ namespace drizzled
 String *Item_func_collation::val_str(String *str)
 {
   assert(fixed == 1);
-  uint32_t dummy_errors;
+  size_t dummy_errors;
   const CHARSET_INFO * const cs= args[0]->collation.collation;
 
   null_value= 0;
