@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <drizzled/function/str/concat.h>
 #include <drizzled/error.h>
@@ -121,7 +121,7 @@ String *Item_func_concat::val_str(String *str)
           more than 25% of memory will be overcommitted on average.
         */
 
-        uint32_t concat_len= res->length() + res2->length();
+        size_t concat_len= res->length() + res2->length();
 
         if (tmp_value.alloced_length() < concat_len)
         {
@@ -291,7 +291,7 @@ String *Item_func_concat_ws::val_str(String *str)
         25% of memory will be overcommitted on average.
       */
 
-      uint32_t concat_len= res->length() + sep_str->length() + res2->length();
+      size_t concat_len= res->length() + sep_str->length() + res2->length();
 
       if (tmp_value.alloced_length() < concat_len)
       {
