@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <drizzled/function/str/export_set.h>
 
@@ -74,7 +74,7 @@ String* Item_func_export_set::val_str(String* str)
   case 3:
     {
       /* errors is not checked - assume "," can always be converted */
-      uint32_t errors;
+      size_t errors;
       sep_buf.copy(STRING_WITH_LEN(","), &my_charset_bin, collation.collation, &errors);
       sep = &sep_buf;
     }
