@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <drizzled/function/str/trim.h>
 
@@ -95,7 +95,7 @@ String *Item_func_rtrim::val_str(String *str)
   ptr= (char*) res->ptr();
   end= ptr+res->length();
   char *p=ptr;
-  register uint32_t l;
+  uint32_t l;
   if (remove_length == 1)
   {
     char chr=(*remove_str)[0];
@@ -175,7 +175,7 @@ String *Item_func_trim::val_str(String *str)
   if (use_mb(res->charset()))
   {
     char *p=ptr;
-    register uint32_t l;
+    uint32_t l;
  loop:
     while (ptr + remove_length < end)
     {
@@ -220,20 +220,20 @@ void Item_func_trim::fix_length_and_dec()
   }
 }
 
-void Item_func_trim::print(String *str, enum_query_type query_type)
+void Item_func_trim::print(String *str)
 {
   if (arg_count == 1)
   {
-    Item_func::print(str, query_type);
+    Item_func::print(str);
     return;
   }
   str->append(Item_func_trim::func_name());
   str->append('(');
   str->append(mode_name());
   str->append(' ');
-  args[1]->print(str, query_type);
+  args[1]->print(str);
   str->append(STRING_WITH_LEN(" from "));
-  args[0]->print(str, query_type);
+  args[0]->print(str);
   str->append(')');
 }
 
