@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,10 +17,9 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_FUNCTION_TIME_FROM_DAYS_H
-#define DRIZZLED_FUNCTION_TIME_FROM_DAYS_H
+#pragma once
 
-#include "drizzled/function/time/date.h"
+#include <drizzled/function/time/date.h>
 
 namespace drizzled
 {
@@ -57,4 +56,3 @@ public:
 } /* namespace drizzled */
 
 
-#endif /* DRIZZLED_FUNCTION_TIME_FROM_DAYS_H */
