@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_FUNCTION_USER_VAR_AS_OUT_PARAM_H
-#define DRIZZLED_FUNCTION_USER_VAR_AS_OUT_PARAM_H
+#pragma once
 
 #include <drizzled/function/func.h>
 
@@ -45,14 +44,13 @@ public:
   double val_real();
   int64_t val_int();
   String *val_str(String *str);
-  my_decimal *val_decimal(my_decimal *decimal_buffer);
+  type::Decimal *val_decimal(type::Decimal *decimal_buffer);
   /* fix_fields() binds variable name with its entry structure */
   bool fix_fields(Session *session, Item **ref);
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   void set_null_value(const CHARSET_INFO * const cs);
   void set_value(const char *str, uint32_t length, const CHARSET_INFO * const cs);
 };
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_FUNCTION_USER_VAR_AS_OUT_PARAM_H */
