@@ -1,7 +1,7 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2010 Sun Microsystems
+ *  Copyright (C) 2010 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,23 +18,22 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_FUNCTION_CONTAINER_H
-#define DRIZZLED_FUNCTION_CONTAINER_H
+#pragma once
 
 #include <set>
 #include <boost/unordered_map.hpp>
-#include "drizzled/util/string.h"
+#include <drizzled/util/string.h>
 
 namespace drizzled {
 
-struct Native_func_registry;
-typedef boost::unordered_map<std::string, Native_func_registry *, util::insensitive_hash, util::insensitive_equal_to> NativeFunctionsMap;
+class Create_func;
 
 class FunctionContainer {
 public:
-  static NativeFunctionsMap &getMap();
+  typedef boost::unordered_map<std::string, Create_func *, util::insensitive_hash, util::insensitive_equal_to> Map;
+
+  static Map &getMap();
 };
 
 } /* namepsace drizzled */
 
-#endif /* DRIZZLED_FUNCTION_CONTAINER_H */
