@@ -18,19 +18,22 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_GENERATOR_FUNCTIONS_H
-#define DRIZZLED_GENERATOR_FUNCTIONS_H
+#pragma once
 
-#include "drizzled/plugin/function.h"
+#include <drizzled/plugin/function.h>
+
+#include <drizzled/visibility.h>
 
 namespace drizzled {
 namespace generator {
 
-class Functions
+class DRIZZLED_API Functions
 {
   Session &session;
+  typedef std::vector <std::string> vector;
   std::string function_name;
-  plugin::Function::UdfMap::const_iterator udf_iter;
+  vector function_list;
+  vector::iterator iter;
 
 public:
 
@@ -38,11 +41,11 @@ public:
 
   operator std::string*()
   {
-    if (udf_iter == plugin::Function::getMap().end())
+    if (iter == function_list.end())
       return NULL;
 
-    function_name= (*udf_iter).first;
-    udf_iter++;
+    function_name= *iter;
+    iter++;
 
     return &function_name;
   }
@@ -51,4 +54,3 @@ public:
 } /* namespace generator */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_GENERATOR_FUNCTIONS_H */
