@@ -18,58 +18,33 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_GENERATOR_SCHEMA_H
-#define DRIZZLED_GENERATOR_SCHEMA_H
+#pragma once
 
-#include "drizzled/session.h"
-#include "drizzled/plugin/storage_engine.h"
+#include <drizzled/plugin/authorization.h>
+#include <drizzled/plugin/storage_engine.h>
 
 namespace drizzled {
+
+class Session;
+
 namespace generator {
 
 class Schema
 {
   Session &session;
-  message::Schema schema;
+  message::schema::shared_ptr schema;
 
-  SchemaIdentifiers schema_names;
-  SchemaIdentifiers::const_iterator schema_iterator;
+  identifier::Schema::vector schema_names;
+  identifier::Schema::vector::const_iterator schema_iterator;
 
 public:
 
   Schema(Session &arg);
 
-  operator const drizzled::message::Schema*()
-  {
-    while (schema_iterator != schema_names.end())
-    {
-      schema.Clear();
-      SchemaIdentifier schema_identifier(*schema_iterator);
-      bool is_schema_parsed= plugin::StorageEngine::getSchemaDefinition(schema_identifier, schema);
-      schema_iterator++;
-
-      if (is_schema_parsed)
-        return &schema;
-    }
-
-    return NULL;
-  }
-
-  operator const drizzled::SchemaIdentifier*()
-  {
-    while (schema_iterator != schema_names.end())
-    {
-      const drizzled::SchemaIdentifier *_ptr= &(*schema_iterator);
-      schema_iterator++;
-
-      return _ptr;
-    }
-
-    return NULL;
-  }
+  operator const drizzled::message::schema::shared_ptr();
+  operator const drizzled::identifier::Schema*();
 };
 
 } /* namespace generator */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_GENERATOR_SCHEMA_H */
