@@ -18,47 +18,47 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_GENERATOR_TABLE_H
-#define DRIZZLED_GENERATOR_TABLE_H
+#pragma once
 
-#include "drizzled/session.h"
-#include "drizzled/plugin/storage_engine.h"
+#include <drizzled/plugin/storage_engine.h>
 
 namespace drizzled {
+
+class Session;
+
 namespace generator {
 
 class Table
 {
   Session &session;
-  message::Table table;
 
-  TableIdentifiers table_names;
-  TableIdentifiers::const_iterator table_iterator;
+  identifier::Table::vector table_names;
+  identifier::Table::vector::const_iterator table_iterator;
 
 public:
 
-  Table(Session &arg, const SchemaIdentifier &schema_identifier);
+  Table(Session &arg, const identifier::Schema &schema_identifier);
 
-  operator const drizzled::message::Table*()
+  operator const drizzled::message::table::shared_ptr()
   {
     while (table_iterator != table_names.end())
     {
-      table.Clear();
-      bool is_table_parsed= plugin::StorageEngine::getTableDefinition(session, *table_iterator, table);
+      message::table::shared_ptr table;
+      table= plugin::StorageEngine::getTableMessage(session, *table_iterator);
       table_iterator++;
 
-      if (is_table_parsed)
-        return &table;
+      if (table)
+        return table;
     }
 
-    return NULL;
+    return message::table::shared_ptr();
   }
 
-  operator const drizzled::TableIdentifier*()
+  operator const drizzled::identifier::Table*()
   {
     while (table_iterator != table_names.end())
     {
-      const drizzled::TableIdentifier *_ptr= &(*table_iterator);
+      const drizzled::identifier::Table *_ptr= &(*table_iterator);
       table_iterator++;
 
       return _ptr;
@@ -71,4 +71,3 @@ public:
 } /* namespace generator */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_GENERATOR_TABLE_H */
