@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_HYBRID_TYPE_TRAITS_INTEGER_H
-#define DRIZZLED_HYBRID_TYPE_TRAITS_INTEGER_H
+#pragma once
 
 #include <drizzled/hybrid_type_traits.h>
 
@@ -28,7 +27,11 @@ namespace drizzled
 class Item;
 class Field;
 class Hybrid_type;
-class my_decimal;
+
+namespace type {
+class Decimal;
+}
+
 class String;
 
 class Hybrid_type_traits_integer: public Hybrid_type_traits
@@ -46,7 +49,7 @@ public:
 
   virtual int64_t val_int(Hybrid_type *val, bool unsigned_flag) const;
   virtual double val_real(Hybrid_type *val) const;
-  virtual my_decimal *val_decimal(Hybrid_type *val, my_decimal *buf) const;
+  virtual type::Decimal *val_decimal(Hybrid_type *val, type::Decimal *buf) const;
   virtual String *val_str(Hybrid_type *val, String *buf,
                           uint8_t decimals) const;
 
@@ -56,4 +59,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_HYBRID_TYPE_TRAITS_INTEGER_H */
