@@ -24,4 +24,8 @@
 
 namespace drizzled {
 
+void Identifier::getSQLPath(std::string &) const
+{
+}
+
 } // namespace Identifier
