@@ -23,12 +23,13 @@
 namespace drizzled {
 namespace identifier {
 
-const Schema& data_dictionary();
-const Schema& information_schema();
-const Schema& system_schema();
+identifier::Schema::const_reference data_dictionary();
+identifier::Schema::const_reference information_schema();
+identifier::Schema::const_reference system_schema();
 
 } /* namespace identifier */
 } /* namespace drizzled */
 
 #define DATA_DICTIONARY_IDENTIFIER drizzled::identifier::data_dictionary()
 #define INFORMATION_SCHEMA_IDENTIFIER drizzled::identifier::information_schema()
+
