@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,17 +18,21 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <assert.h>
+#include <boost/lexical_cast.hpp>
+#include <drizzled/identifier.h>
+#include <drizzled/internal/my_sys.h>
 
-#include "drizzled/identifier.h"
-#include "drizzled/session.h"
-#include "drizzled/internal/my_sys.h"
+#include <drizzled/error.h>
+#include <drizzled/errmsg_print.h>
+#include <drizzled/gettext.h>
 
-#include "drizzled/table.h"
+#include <drizzled/table.h>
 
-#include "drizzled/util/string.h"
+#include <drizzled/util/string.h>
+#include <drizzled/util/tablename_to_filename.h>
 
 #include <algorithm>
 #include <sstream>
@@ -41,12 +45,15 @@ using namespace std;
 namespace drizzled
 {
 
+class Table;
+
 extern std::string drizzle_tmpdir;
 extern pid_t current_pid;
 
-static const char hexchars[]= "0123456789abcdef";
+namespace identifier {
+class Schema;
 
-static bool tablename_to_filename(const char *from, char *to, size_t to_length);
+static const char hexchars[]= "0123456789abcdef";
 
 /*
   Translate a cursor name to a table name (WL #1324).
@@ -60,7 +67,7 @@ static bool tablename_to_filename(const char *from, char *to, size_t to_length);
   RETURN
     Table name length.
 */
-uint32_t TableIdentifier::filename_to_tablename(const char *from, char *to, uint32_t to_length)
+uint32_t Table::filename_to_tablename(const char *from, char *to, uint32_t to_length)
 {
   uint32_t length= 0;
 
@@ -138,7 +145,7 @@ static uint32_t get_counter()
 
 #endif
 
-size_t TableIdentifier::build_tmptable_filename(std::string &buffer)
+size_t Table::build_tmptable_filename(std::string &buffer)
 {
   size_t tmpdir_length;
   ostringstream post_tmpdir_str;
@@ -156,7 +163,7 @@ size_t TableIdentifier::build_tmptable_filename(std::string &buffer)
   return buffer.length();
 }
 
-size_t TableIdentifier::build_tmptable_filename(std::vector<char> &buffer)
+size_t Table::build_tmptable_filename(std::vector<char> &buffer)
 {
   ostringstream post_tmpdir_str;
 
@@ -203,107 +210,42 @@ size_t TableIdentifier::build_tmptable_filename(std::vector<char> &buffer)
     path length on success, 0 on failure
 */
 
-size_t TableIdentifier::build_table_filename(std::string &path, const char *db, const char *table_name, bool is_tmp)
+size_t Table::build_table_filename(std::string &in_path, const std::string &in_db, const std::string &in_table_name, bool is_tmp)
 {
-  char dbbuff[FN_REFLEN];
-  char tbbuff[FN_REFLEN];
   bool conversion_error= false;
 
-  memset(tbbuff, 0, sizeof(tbbuff));
+  conversion_error= util::tablename_to_filename(in_db, in_path);
+  if (conversion_error)
+  {
+    errmsg_printf(error::ERROR,
+                  _("Schema name cannot be encoded and fit within filesystem "
+                    "name length restrictions."));
+    return 0;
+  }
+
+  in_path.append(FN_ROOTDIR);
+
   if (is_tmp) // It a conversion tmp
   {
-    strncpy(tbbuff, table_name, sizeof(tbbuff));
+    in_path.append(in_table_name);
   }
   else
   {
-    conversion_error= tablename_to_filename(table_name, tbbuff, sizeof(tbbuff));
+    conversion_error= util::tablename_to_filename(in_table_name, in_path);
     if (conversion_error)
     {
-      errmsg_printf(ERRMSG_LVL_ERROR,
+      errmsg_printf(error::ERROR,
                     _("Table name cannot be encoded and fit within filesystem "
                       "name length restrictions."));
       return 0;
     }
   }
-  memset(dbbuff, 0, sizeof(dbbuff));
-  conversion_error= tablename_to_filename(db, dbbuff, sizeof(dbbuff));
-  if (conversion_error)
-  {
-    errmsg_printf(ERRMSG_LVL_ERROR,
-                  _("Schema name cannot be encoded and fit within filesystem "
-                    "name length restrictions."));
-    return 0;
-  }
    
-  path.append(dbbuff);
-  path.append(FN_ROOTDIR);
-  path.append(tbbuff);
-
-  return path.length();
+  return in_path.length();
 }
 
-
-/*
-  Translate a table name to a cursor name (WL #1324).
-
-  SYNOPSIS
-    tablename_to_filename()
-      from                      The table name
-      to                OUT     The cursor name
-      to_length                 The size of the cursor name buffer.
-
-  RETURN
-    true if errors happen. false on success.
-*/
-static bool tablename_to_filename(const char *from, char *to, size_t to_length)
-{
-  
-  size_t length= 0;
-  for (; *from  && length < to_length; length++, from++)
-  {
-    if ((*from >= '0' && *from <= '9') ||
-        (*from >= 'a' && *from <= 'z') ||
-/* OSX defines an extra set of high-bit and multi-byte characters
-   that cannot be used on the filesystem. Instead of trying to sort
-   those out, we'll just escape encode all high-bit-set chars on OSX.
-   It won't really hurt anything - it'll just make some filenames ugly. */
-#if !defined(TARGET_OS_OSX)
-        ((unsigned char)*from >= 128) ||
-#endif
-        (*from == '_') ||
-        (*from == ' ') ||
-        (*from == '-'))
-    {
-      to[length]= tolower(*from);
-      continue;
-    }
-
-    if ((*from >= 'A' && *from <= 'Z'))
-    {
-      to[length]= tolower(*from);
-      continue;
-    }
-   
-    if (length + 3 >= to_length)
-      return true;
-
-    /* We need to escape this char in a way that can be reversed */
-    to[length++]= '@';
-    to[length++]= hexchars[(*from >> 4) & 15];
-    to[length]= hexchars[(*from) & 15];
-  }
-
-  if (internal::check_if_legal_tablename(to) &&
-      length + 4 < to_length)
-  {
-    memcpy(to + length, "@@@", 4);
-    length+= 3;
-  }
-  return false;
-}
-
-TableIdentifier::TableIdentifier(const drizzled::Table &table) :
-  SchemaIdentifier(table.getShare()->getSchemaName()),
+Table::Table(const drizzled::Table &table) :
+  identifier::Schema(table.getShare()->getSchemaName()),
   type(table.getShare()->getTableType()),
   table_name(table.getShare()->getTableName())
 {
@@ -313,17 +255,17 @@ TableIdentifier::TableIdentifier(const drizzled::Table &table) :
   init();
 }
 
-void TableIdentifier::init()
+void Table::init()
 {
   switch (type) {
   case message::Table::FUNCTION:
   case message::Table::STANDARD:
     assert(path.size() == 0);
-    build_table_filename(path, getSchemaName().c_str(), table_name.c_str(), false);
+    build_table_filename(path, getSchemaName(), table_name, false);
     break;
   case message::Table::INTERNAL:
     assert(path.size() == 0);
-    build_table_filename(path, getSchemaName().c_str(), table_name.c_str(), true);
+    build_table_filename(path, getSchemaName(), table_name, true);
     break;
   case message::Table::TEMPORARY:
     if (path.empty())
@@ -333,57 +275,172 @@ void TableIdentifier::init()
     break;
   }
 
+  switch (type) {
+  case message::Table::FUNCTION:
+  case message::Table::STANDARD:
+  case message::Table::INTERNAL:
+    break;
+  case message::Table::TEMPORARY:
+    {
+      size_t pos;
+
+      pos= path.find("tmp/#sql");
+      if (pos != std::string::npos) 
+      {
+        key_path= path.substr(pos);
+      }
+    }
+    break;
+  }
+
   util::insensitive_hash hasher;
   hash_value= hasher(path);
 
-  key.resize(getKeySize());
-  size_t key_length= TableIdentifier::createKey(&key[0], *this);
+  std::string tb_name(getTableName());
+  std::transform(tb_name.begin(), tb_name.end(), tb_name.begin(), ::tolower);
 
-  assert(key_length == getKeySize()); // If this is off, then we have a memory issue.
+  key.set(getKeySize(), getSchemaName(), tb_name);
 }
 
 
-const std::string &TableIdentifier::getPath() const
+const std::string &Table::getPath() const
 {
   return path;
 }
 
-const std::string &TableIdentifier::getSQLPath()  // @todo this is just used for errors, we should find a way to optimize it
+const std::string &Table::getKeyPath() const
 {
-  if (sql_path.empty())
+  if (key_path.empty())
+    return path;
+
+  return key_path;
+}
+
+void Table::getSQLPath(std::string &sql_path) const  // @todo this is just used for errors, we should find a way to optimize it
+{
+  switch (type) {
+  case message::Table::FUNCTION:
+  case message::Table::STANDARD:
+    sql_path.append(getSchemaName());
+    sql_path.append(".");
+    sql_path.append(table_name);
+    break;
+  case message::Table::INTERNAL:
+    sql_path.append("temporary.");
+    sql_path.append(table_name);
+    break;
+  case message::Table::TEMPORARY:
+    sql_path.append(getSchemaName());
+    sql_path.append(".#");
+    sql_path.append(table_name);
+    break;
+  }
+}
+
+bool Table::isValid() const
+{
+  if (not identifier::Schema::isValid())
+    return false;
+
+  bool error= false;
+  do
   {
-    switch (type) {
-    case message::Table::FUNCTION:
-    case message::Table::STANDARD:
-      sql_path.append(getSchemaName());
-      sql_path.append(".");
-      sql_path.append(table_name);
-      break;
-    case message::Table::INTERNAL:
-      sql_path.append("temporary.");
-      sql_path.append(table_name);
-      break;
-    case message::Table::TEMPORARY:
-      sql_path.append(getSchemaName());
-      sql_path.append(".#");
-      sql_path.append(table_name);
+    if (table_name.empty())
+    {
+      error= true;
       break;
     }
+
+    if (table_name.size() > NAME_LEN)
+    {
+      error= true;
+      break;
+    }
+
+    if (table_name.at(table_name.length() -1) == ' ')
+    {
+      error= true;
+      break;
+    }
+
+    if (table_name.at(0) == '.')
+    {
+      error= true;
+      break;
+    }
+
+    {
+      const CHARSET_INFO * const cs= &my_charset_utf8mb4_general_ci;
+
+      int well_formed_error;
+      uint32_t res= cs->cset->well_formed_len(cs, table_name.c_str(), table_name.c_str() + table_name.length(),
+                                              NAME_CHAR_LEN, &well_formed_error);
+      if (well_formed_error or table_name.length() != res)
+      {
+        error= true;
+        break;
+      }
+    }
+  } while (0);
+
+  if (error)
+  {
+    std::string name;
+
+    getSQLPath(name);
+    my_error(ER_WRONG_TABLE_NAME, MYF(0), name.c_str());
+
+    return false;
   }
 
-  return sql_path;
+  return true;
 }
 
 
-void TableIdentifier::copyToTableMessage(message::Table &message) const
+void Table::copyToTableMessage(message::Table &message) const
 {
   message.set_name(table_name);
   message.set_schema(getSchemaName());
 }
 
-std::size_t hash_value(TableIdentifier const& b)
+void Table::Key::set(size_t resize_arg, const std::string &a, const std::string &b)
+{
+  key_buffer.resize(resize_arg);
+
+  std::copy(a.begin(), a.end(), key_buffer.begin());
+  std::copy(b.begin(), b.end(), key_buffer.begin() + a.length() + 1);
+
+  util::sensitive_hash hasher;
+  hash_value= hasher(key_buffer);
+}
+
+std::size_t hash_value(Table const& b)
 {
   return b.getHashValue();
 }
 
+std::size_t hash_value(Table::Key const& b)
+{
+  return b.getHashValue();
+}
+
+
+std::ostream& operator<<(std::ostream& output, Table::const_reference identifier)
+{
+  output << "Table:(";
+  output <<  identifier.getSchemaName();
+  output << ", ";
+  output << identifier.getTableName();
+  output << ", ";
+  output << message::type(identifier.getType());
+  output << ", ";
+  output << identifier.getPath();
+  output << ", ";
+  output << identifier.getHashValue();
+  output << ")";
+
+  return output;  // for multiple << operators.
+}
+
+} /* namespace identifier */
 } /* namespace drizzled */
