@@ -2,7 +2,7 @@
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
  *  Copyright (C) 2010 Brian Aker
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,14 +30,11 @@
   This will replace Table_ident.
   */
 
-#ifndef DRIZZLED_IDENTIFIER_TABLE_H
-#define DRIZZLED_IDENTIFIER_TABLE_H
+#pragma once
 
 #include <drizzled/enum.h>
-#include "drizzled/definitions.h"
-#include "drizzled/message/table.pb.h"
-
-#include "drizzled/identifier.h"
+#include <drizzled/definitions.h>
+#include <drizzled/message/table.pb.h>
 
 #include <string.h>
 
@@ -50,21 +47,78 @@
 
 #include <boost/functional/hash.hpp>
 
-namespace drizzled {
+#include <drizzled/visibility.h>
 
+namespace drizzled {
 class Table;
 
-class TableIdentifier : public SchemaIdentifier
+namespace identifier {
+
+class DRIZZLED_API Table : public Schema
 {
 public:
   typedef message::Table::TableType Type;
-  typedef std::vector<char> Key;
+  typedef std::vector <Table> vector;
+  typedef const Table& const_reference;
+  typedef Table& reference;
+
+  class Key
+  {
+    std::vector<char> key_buffer;
+    size_t hash_value;
+
+  public:
+
+    Key() :
+      hash_value(0)
+    {
+    }
+
+    const char *vector() const
+    {
+      return &key_buffer[0];
+    }
+
+    std::vector<char> &vectorPtr()
+    {
+      return key_buffer;
+    }
+
+    void set(size_t resize_arg, const std::string &a, const std::string &b);
+
+    friend bool operator==(const Key &left, const Key &right)
+    {
+      if (left.hash_value == right.hash_value and left.key_buffer.size() == right.key_buffer.size())
+      {
+        if (memcmp(&left.key_buffer[0], &right.key_buffer[0], left.key_buffer.size()) == 0)
+          return true;
+      }
+
+      return false;
+    }
+
+    friend bool operator<(const Key &left, const Key &right)
+    {
+      return left.key_buffer < right.key_buffer;
+    }
+
+    size_t size() const
+    {
+      return key_buffer.size();
+    }
+
+    size_t getHashValue() const
+    {
+      return hash_value;
+    }
+  };
+
 private:
 
   Type type;
   std::string path;
+  std::string key_path;
   std::string table_name;
-  std::string sql_path;
   Key key;
   size_t hash_value;
 
@@ -76,32 +130,33 @@ private:
   }
 
 public:
-  TableIdentifier(const Table &table);
+
+  Table(const drizzled::Table &table);
                    
-  TableIdentifier( const SchemaIdentifier &schema,
-                   const std::string &table_name_arg,
-                   Type tmp_arg= message::Table::STANDARD) :
-    SchemaIdentifier(schema),
+  Table(const identifier::Schema &schema,
+        const std::string &table_name_arg,
+        Type tmp_arg= message::Table::STANDARD) :
+    Schema(schema),
     type(tmp_arg),
     table_name(table_name_arg)
   { 
     init();
   }
 
-  TableIdentifier( const std::string &db_arg,
+  Table( const std::string &db_arg,
                    const std::string &table_name_arg,
                    Type tmp_arg= message::Table::STANDARD) :
-    SchemaIdentifier(db_arg),
+    Schema(db_arg),
     type(tmp_arg),
     table_name(table_name_arg)
   { 
     init();
   }
 
-  TableIdentifier( const std::string &schema_name_arg,
+  Table( const std::string &schema_name_arg,
                    const std::string &table_name_arg,
                    const std::string &path_arg ) :
-    SchemaIdentifier(schema_name_arg),
+    Schema(schema_name_arg),
     type(message::Table::TEMPORARY),
     path(path_arg),
     table_name(table_name_arg)
@@ -109,20 +164,35 @@ public:
     init();
   }
 
-  using SchemaIdentifier::compare;
+  using Schema::compare;
 
   bool isTmp() const
   {
     if (type == message::Table::TEMPORARY || type == message::Table::INTERNAL)
       return true;
+
+    return false;
+  }
+
+  static bool isView(message::Table::TableType arg) // Not a SQL view, but a view for I_S
+  {
+    switch (arg)
+    {
+    default:
+    case message::Table::STANDARD:
+    case message::Table::TEMPORARY:
+    case message::Table::INTERNAL:
+      break;
+    case message::Table::FUNCTION:
+      return true;
+    }
+
     return false;
   }
 
   bool isView() const // Not a SQL view, but a view for I_S
   {
-    if (type == message::Table::FUNCTION)
-      return true;
-    return false;
+    return isView(type);
   }
 
   Type getType() const
@@ -130,9 +200,10 @@ public:
     return type;
   }
 
-  const std::string &getSQLPath();
+  virtual void getSQLPath(std::string &sql_path) const;
 
-  const std::string &getPath() const;
+  virtual const std::string &getPath() const;
+  const std::string &getKeyPath() const;
 
   void setPath(const std::string &new_path)
   {
@@ -146,7 +217,7 @@ public:
 
   void copyToTableMessage(message::Table &message) const;
 
-  friend bool operator<(const TableIdentifier &left, const TableIdentifier &right)
+  friend bool operator<(Table::const_reference left, Table::const_reference right)
   {
     if (left.getKey() < right.getKey())
     {
@@ -156,100 +227,24 @@ public:
     return false;
   }
 
-  friend std::ostream& operator<<(std::ostream& output, const TableIdentifier &identifier)
+  friend bool operator==(Table::const_reference left, Table::const_reference right)
   {
-    const char *type_str;
-
-    output << "TableIdentifier:(";
-    output <<  identifier.getSchemaName();
-    output << ", ";
-    output << identifier.getTableName();
-    output << ", ";
-
-    switch (identifier.type) {
-    case message::Table::STANDARD:
-      type_str= "standard";
-      break;
-    case message::Table::INTERNAL:
-      type_str= "internal";
-      break;
-    case message::Table::TEMPORARY:
-      type_str= "temporary";
-      break;
-    case message::Table::FUNCTION:
-      type_str= "function";
-      break;
+    if (left.getHashValue() == right.getHashValue())
+    {
+      if (left.getKey() == right.getKey())
+        return true;
     }
 
-    output << type_str;
-    output << ", ";
-    output << identifier.path;
-    output << ", ";
-    output << identifier.getHashValue();
-    output << ")";
-
-    return output;  // for multiple << operators.
-  }
-
-  friend bool operator==(TableIdentifier &left, TableIdentifier &right)
-  {
-    if (left.getKey() == right.getKey())
-      return true;
-
     return false;
   }
 
   static uint32_t filename_to_tablename(const char *from, char *to, uint32_t to_length);
-  static size_t build_table_filename(std::string &buff, const char *db, const char *table_name, bool is_tmp);
+  static size_t build_table_filename(std::string &path, const std::string &db, const std::string &table_name, bool is_tmp);
   static size_t build_tmptable_filename(std::string &buffer);
   static size_t build_tmptable_filename(std::vector<char> &buffer);
 
-  /*
-    Create a table cache key
-
-    SYNOPSIS
-    createKey()
-    key			Create key here (must be of size MAX_DBKEY_LENGTH)
-    table_list		Table definition
-
-    IMPLEMENTATION
-    The table cache_key is created from:
-    db_name + \0
-    table_name + \0
-
-    if the table is a tmp table, we add the following to make each tmp table
-    unique on the slave:
-
-    4 bytes for master thread id
-    4 bytes pseudo thread id
-
-    RETURN
-    Length of key
-  */
-  static uint32_t createKey(char *key, const char *db_arg, const char *table_name_arg)
-  {
-    uint32_t key_length;
-    char *key_pos= key;
-
-    key_pos= strcpy(key_pos, db_arg) + strlen(db_arg);
-    key_pos= strcpy(key_pos+1, table_name_arg) +
-      strlen(table_name_arg);
-    key_length= (uint32_t)(key_pos-key)+1;
-
-    return key_length;
-  }
-
-  static uint32_t createKey(char *key, const TableIdentifier &identifier)
-  {
-    uint32_t key_length;
-    char *key_pos= key;
-
-    key_pos= strcpy(key_pos, identifier.getSchemaName().c_str()) + identifier.getSchemaName().length();
-    key_pos= strcpy(key_pos + 1, identifier.getTableName().c_str()) + identifier.getTableName().length();
-    key_length= (uint32_t)(key_pos-key)+1;
-
-    return key_length;
-  }
+public:
+  bool isValid() const;
 
   size_t getHashValue() const
   {
@@ -262,10 +257,9 @@ public:
   }
 };
 
-std::size_t hash_value(TableIdentifier const& b);
-
-typedef std::vector <TableIdentifier> TableIdentifiers;
+std::ostream& operator<<(std::ostream& output, Table::const_reference identifier);
+std::size_t hash_value(Table const& b);
+std::size_t hash_value(Table::Key const& b);
 
+} /* namespace identifier */
 } /* namespace drizzled */
-
-#endif /* DRIZZLED_IDENTIFIER_TABLE_H */
