@@ -18,15 +18,30 @@
  */
 
 #include <config.h>
-#include <boost/make_shared.hpp>
+
+#include <drizzled/identifier.h>
 #include <drizzled/identifier/user.h>
 
-namespace drizzled {
-namespace identifier {
-
-user::mptr User::make_shared()
+namespace drizzled
 {
-  return boost::make_shared<User>();
+namespace identifier
+{
+
+User::shared_ptr User::make_shared()
+{
+  return shared_ptr(new User);
+}
+
+void User::getSQLPath(std::string &arg) const
+{
+  if (_user.empty())
+  {
+    arg+= "<no user>";
+  }
+  else
+  {
+    arg+= _user;
+  }
 }
 
 } /* namespace identifier */
