@@ -1,7 +1,7 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  Authors:
  *
@@ -27,11 +27,11 @@
  *
  * Implementation of SQL index hints
  */
-#include "config.h"
-#include "drizzled/sql_string.h"
-#include "drizzled/session.h"
-#include "drizzled/index_hint.h"
-#include "drizzled/sql_table.h"
+#include <config.h>
+#include <drizzled/sql_string.h>
+#include <drizzled/session.h>
+#include <drizzled/index_hint.h>
+#include <drizzled/sql_table.h>
 
 namespace drizzled
 {
