@@ -1,7 +1,7 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008-2009 Sun Microsystems
+ *  Copyright (C) 2008-2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,8 +24,7 @@
  * Defines the API for index hints
  */
 
-#ifndef DRIZZLED_INDEX_HINT_H
-#define DRIZZLED_INDEX_HINT_H
+#pragma once
 
 namespace drizzled
 {
@@ -82,4 +81,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_INDEX_HINT_H */
