@@ -11,16 +11,14 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /* There may be prolems include all of theese. Try to test in
    configure with ones are needed? */
 
-/*  This is needed for the definitions of strchr... on solaris */
 
 
-#ifndef DRIZZLED_INTERNAL_M_STRING_H
-#define DRIZZLED_INTERNAL_M_STRING_H
+#pragma once
 
 #if defined(HAVE_STRINGS_H)
 #include <strings.h>
@@ -40,6 +38,9 @@
 #include <memory.h>
 #endif
 
+
+#include <drizzled/visibility.h>
+
 namespace drizzled
 {
 namespace internal
@@ -68,11 +69,11 @@ typedef enum {
   MY_GCVT_ARG_DOUBLE
 } my_gcvt_arg_type;
 
-double my_strtod(const char *str, char **end, int *error);
-double my_atof(const char *nptr);
-size_t my_fcvt(double x, int precision, char *to, bool *error);
-size_t my_gcvt(double x, my_gcvt_arg_type type, int width, char *to,
-               bool *error);
+DRIZZLED_API double my_strtod(const char *str, char **end, int *error);
+DRIZZLED_API double my_atof(const char *nptr);
+DRIZZLED_API size_t my_fcvt(double x, int precision, char *to, bool *error);
+DRIZZLED_API size_t my_gcvt(double x, my_gcvt_arg_type type, int width, char *to,
+                            bool *error);
 
 #define NOT_FIXED_DEC (uint8_t)31
 
@@ -106,9 +107,9 @@ extern char *ullstr(int64_t value,char *buff);
 
 extern char *int2str(int32_t val, char *dst, int radix, int upcase);
 extern char *int10_to_str(int32_t val,char *dst,int radix);
-int64_t my_strtoll10(const char *nptr, char **endptr, int *error);
-extern char *int64_t2str(int64_t val,char *dst,int radix);
-extern char *int64_t10_to_str(int64_t val,char *dst,int radix);
+DRIZZLED_API int64_t my_strtoll10(const char *nptr, char **endptr, int *error);
+DRIZZLED_API char *int64_t2str(int64_t val,char *dst,int radix);
+DRIZZLED_API char *int64_t10_to_str(int64_t val,char *dst,int radix);
 
 
 /**
@@ -132,4 +133,3 @@ skip_trailing_space(const unsigned char *ptr, size_t len)
 } /* namespace internal */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_INTERNAL_M_STRING_H */
