@@ -11,15 +11,15 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
-#include "config.h"
-#include "drizzled/internal/my_sys.h"
+#include <config.h>
+#include <drizzled/internal/my_sys.h>
 
 #include <errno.h>
 #include <fcntl.h>
 
-#include "drizzled/error.h"
+#include <drizzled/error.h>
 
 namespace drizzled
 {
