@@ -11,16 +11,16 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /* Defines to make different thread packages compatible */
 
-#ifndef DRIZZLED_INTERNAL_THREAD_VAR_H
-#define DRIZZLED_INTERNAL_THREAD_VAR_H
+#pragma once
 
 #include <pthread.h>
 #include <boost/thread/recursive_mutex.hpp>
 #include <boost/thread/mutex.hpp>
+#include <boost/thread/shared_mutex.hpp>
 #include <boost/thread/condition_variable.hpp>
 
 namespace drizzled
@@ -28,21 +28,14 @@ namespace drizzled
 namespace internal
 {
 
-static pthread_t wrapper_pthread_self()
-{
-  return pthread_self();
-}
-
 struct st_my_thread_var
 {
-  boost::condition_variable suspend;
+  boost::condition_variable_any suspend;
   boost::mutex mutex;
   boost::mutex * volatile current_mutex;
-  boost::condition_variable * volatile current_cond;
-  pthread_t pthread_self;
+  boost::condition_variable_any * volatile current_cond;
   uint64_t id;
   int volatile abort;
-  struct st_my_thread_var *next,**prev;
   void *opt_info;
 
   st_my_thread_var() :
@@ -50,11 +43,8 @@ struct st_my_thread_var
     current_cond(0),
     id(0),
     abort(false),
-    next(0),
-    prev(0),
     opt_info(0)
   { 
-    pthread_self= wrapper_pthread_self();
   }
 
   ~st_my_thread_var()
@@ -68,4 +58,3 @@ extern struct st_my_thread_var *_my_thread_var(void);
 } /* namespace internal */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_INTERNAL_THREAD_VAR_H */
