@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,36 +17,36 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_H
-#define DRIZZLED_ITEM_H
+
+
+#pragma once
 
 #include <drizzled/dtcollation.h>
-#include <drizzled/drizzle_time.h>
-#include <drizzled/decimal.h>
-#include <drizzled/sql_bitmap.h>
+#include <drizzled/global_charset_info.h>
+#include <drizzled/item_result.h>
+#include <drizzled/memory/sql_alloc.h>
 #include <drizzled/sql_list.h>
-#include "drizzled/memory/sql_alloc.h"
-#include <drizzled/table.h>
-#include "drizzled/item_result.h"
+#include <drizzled/sql_string.h>
+
+#include <drizzled/visibility.h>
 
 namespace drizzled
 {
 
-class TableList;
-class Item_field;
-class Name_resolution_context;
-class Select_Lex;
-class Item_equal;
-class user_var_entry;
-class Item_sum;
-class Item_in_subselect;
-class SendField;
 class Field;
+class Item_equal;
+class Item_field;
+class Item_ident;
+class Item_in_subselect;
+class Item_sum;
+class Select_Lex;
+class SendField;
+class Table;
+class user_var_entry;
 
-namespace plugin
-{
-class Client;
-}
+namespace plugin { class Client; }
+namespace type { class Time; }
+namespace type { class Decimal; }
 
 /**
   Dummy error processor used by default by Name_resolution_context.
@@ -77,7 +77,7 @@ typedef bool (Item::*Item_processor) (unsigned char *arg);
  * statement "tree" or Lex.  Each item represents something in the
  * execution plan.
  */
-class Item: public memory::SqlAlloc
+class DRIZZLED_API Item : public memory::SqlAlloc
 {
   /* Prevent use of these */
   Item(const Item &);
@@ -112,6 +112,7 @@ public:
     ROW_ITEM, CACHE_ITEM,
     TYPE_HOLDER,
     PARAM_ITEM,
+    BOOLEAN_ITEM,
     DECIMAL_ITEM
   };
   enum traverse_order
@@ -135,6 +136,7 @@ public:
 
   /** Name from select */
   char *name;
+
   /** Length of name */
   uint32_t name_length;
 
@@ -149,8 +151,20 @@ public:
   bool maybe_null; /**< True if item may be null */
   bool null_value; /**< True if item is null */
   bool unsigned_flag;
+
+  bool is_unsigned() const
+  {
+    return unsigned_flag;
+  }
+
+  virtual bool negative() const
+  {
+    return false;
+  }
+
   bool with_sum_func;
   bool is_autogenerated_name; /**< indicates whether name of this Item was autogenerated or set by user */
+
   /**
    * If this item is a subselect or some of its arguments is or contains a
    * subselect. Computed by fix_fields.
@@ -158,6 +172,7 @@ public:
   bool with_subselect;
   DTCollation collation;
   Item_result cmp_context; /**< Comparison context */
+
   /**
    * Constructor
    *
@@ -166,6 +181,7 @@ public:
    * Alloc & destruct is done as start of select using memory::sql_alloc
    */
   Item();
+
   /**
    * Constructor used by Item_field, Item_ref & aggregate (sum) functions.
    *
@@ -177,10 +193,11 @@ public:
    * optimisation changes in prepared statements
    */
   Item(Session *session, Item *item);
+
   virtual ~Item()
   {
 #ifdef EXTRA_DEBUG
-    name=0;
+    name= NULL;
 #endif
   }
 
@@ -363,6 +380,7 @@ public:
    *   If value is not null null_value flag will be reset to false.
    */
   virtual String *val_str(String *str)=0;
+
   /**
    * Return decimal representation of item with fixed point.
    *
@@ -376,12 +394,13 @@ public:
    *
    * @retval
    *
-   * Return pointer on my_decimal (it can be other then passed via argument)
+   * Return pointer on type::Decimal (it can be other then passed via argument)
    * if value is not NULL (null_value flag will be reset to false).
    * In case of NULL value it return 0 pointer and set null_value flag
    * to true.
    */
-  virtual my_decimal *val_decimal(my_decimal *decimal_buffer)= 0;
+  virtual type::Decimal *val_decimal(type::Decimal *decimal_buffer)= 0;
+
   /**
    * Return boolean value of item.
    *
@@ -391,20 +410,22 @@ public:
    * true value is true (not equal to 0)
    */
   virtual bool val_bool();
+
   /* Helper functions, see item_sum.cc */
   String *val_string_from_real(String *str);
   String *val_string_from_int(String *str);
   String *val_string_from_decimal(String *str);
-  my_decimal *val_decimal_from_real(my_decimal *decimal_value);
-  my_decimal *val_decimal_from_int(my_decimal *decimal_value);
-  my_decimal *val_decimal_from_string(my_decimal *decimal_value);
-  my_decimal *val_decimal_from_date(my_decimal *decimal_value);
-  my_decimal *val_decimal_from_time(my_decimal *decimal_value);
+  type::Decimal *val_decimal_from_real(type::Decimal *decimal_value);
+  type::Decimal *val_decimal_from_int(type::Decimal *decimal_value);
+  type::Decimal *val_decimal_from_string(type::Decimal *decimal_value);
+  type::Decimal *val_decimal_from_date(type::Decimal *decimal_value);
+  type::Decimal *val_decimal_from_time(type::Decimal *decimal_value);
   int64_t val_int_from_decimal();
   double val_real_from_decimal();
 
-  int save_time_in_field(Field *field);
-  int save_date_in_field(Field *field);
+  bool save_time_in_field(Field *field);
+  bool save_date_in_field(Field *field);
+
   /**
    * Stores a string value in field directly
    *
@@ -450,7 +471,7 @@ public:
   {
     return val_str(tmp);
   }
-  virtual my_decimal *val_decimal_result(my_decimal *val)
+  virtual type::Decimal *val_decimal_result(type::Decimal *val)
   {
     return val_decimal(val);
   }
@@ -527,11 +548,11 @@ public:
 
     For more information about view definition query, INFORMATION_SCHEMA
     query and why they should be generated from the Item-tree, @see
-    mysql_register_view().
+    register_view().
   */
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
 
-  void print_item_w_name(String *, enum_query_type query_type);
+  void print_item_w_name(String *);
   virtual void update_used_tables() {}
   virtual void split_sum_func(Session *session, 
                               Item **ref_pointer_array,
@@ -561,17 +582,17 @@ public:
                       bool skip_registered);
 
   /**
-    Get the value of the function as a DRIZZLE_TIME structure.
+    Get the value of the function as a type::Time structure.
     As a extra convenience the time structure is reset on error!
   */
-  virtual bool get_date(DRIZZLE_TIME *ltime,uint32_t fuzzydate);
+  virtual bool get_date(type::Time &ltime, uint32_t fuzzydate);
   /**
     Get time of first argument.
 
     As a extra convenience the time structure is reset on error!
   */
-  virtual bool get_time(DRIZZLE_TIME *ltime);
-  virtual bool get_date_result(DRIZZLE_TIME *ltime,uint32_t fuzzydate);
+  virtual bool get_time(type::Time &ltime);
+  virtual bool get_date_result(type::Time &ltime,uint32_t fuzzydate);
 
   /**
     The method allows to determine nullness of a complex expression
@@ -762,8 +783,36 @@ public:
    *  false otherwise
    */
   bool eq_by_collation(Item *item, bool binary_cmp, const CHARSET_INFO * const cs);
+
+  inline uint32_t char_to_byte_length_safe(uint32_t char_length_arg, uint32_t mbmaxlen_arg)
+  { 
+    uint64_t tmp= ((uint64_t) char_length_arg) * mbmaxlen_arg;
+    return (tmp > UINT32_MAX) ? (uint32_t) UINT32_MAX : (uint32_t) tmp;
+  } 
+
+  uint32_t max_char_length() const;
+
+  void fix_length_and_charset(uint32_t max_char_length_arg, CHARSET_INFO *cs);
+  void fix_char_length(uint32_t max_char_length_arg);
+  void fix_char_length_uint64_t(uint64_t max_char_length_arg);
+  void fix_length_and_charset_datetime(uint32_t max_char_length_arg);
+
+protected:
+  Session &getSession()
+  {
+    return _session;
+  }
+
+private:
+  Session &_session;
 };
 
+namespace display {
+const std::string &type(Item::Type type);
+} /* namespace display */
+
+std::ostream& operator<<(std::ostream& output, const Item &item);
+
 } /* namespace drizzled */
 
 /** @TODO Why is this in the middle? */
@@ -908,4 +957,3 @@ Field *create_tmp_field(Session *session,
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_H */
