@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_BASIC_CONSTANT_H
-#define DRIZZLED_ITEM_BASIC_CONSTANT_H
+#pragma once
 
 #include <drizzled/item.h>
 
@@ -28,7 +27,10 @@ namespace drizzled
 class Item_basic_constant :public Item
 {
 public:
-  Item_basic_constant() : Item() {};
+  Item_basic_constant() :
+    Item()
+  {
+  }
 
   /* to prevent drop fixed flag (no need parent cleanup call) */
   void cleanup()
@@ -45,4 +47,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_BASIC_CONSTANT_H */
