@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <drizzled/item/cache_decimal.h>
 
@@ -26,16 +26,16 @@ namespace drizzled
 
 void Item_cache_decimal::store(Item *item)
 {
-  my_decimal *val= item->val_decimal_result(&decimal_value);
+  type::Decimal *val= item->val_decimal_result(&decimal_value);
   if (!(null_value= item->null_value) && val != &decimal_value)
-    my_decimal2decimal(val, &decimal_value);
+    class_decimal2decimal(val, &decimal_value);
 }
 
 double Item_cache_decimal::val_real()
 {
   assert(fixed);
   double res;
-  my_decimal2double(E_DEC_FATAL_ERROR, &decimal_value, &res);
+  class_decimal2double(E_DEC_FATAL_ERROR, &decimal_value, &res);
   return res;
 }
 
@@ -43,20 +43,20 @@ int64_t Item_cache_decimal::val_int()
 {
   assert(fixed);
   int64_t res;
-  my_decimal2int(E_DEC_FATAL_ERROR, &decimal_value, unsigned_flag, &res);
+  decimal_value.val_int32(E_DEC_FATAL_ERROR, unsigned_flag, &res);
   return res;
 }
 
 String* Item_cache_decimal::val_str(String *str)
 {
   assert(fixed);
-  my_decimal_round(E_DEC_FATAL_ERROR, &decimal_value, decimals, false,
+  class_decimal_round(E_DEC_FATAL_ERROR, &decimal_value, decimals, false,
                    &decimal_value);
-  my_decimal2string(E_DEC_FATAL_ERROR, &decimal_value, 0, 0, 0, str);
+  class_decimal2string(&decimal_value, 0, str);
   return str;
 }
 
-my_decimal *Item_cache_decimal::val_decimal(my_decimal *)
+type::Decimal *Item_cache_decimal::val_decimal(type::Decimal *)
 {
   assert(fixed);
   return &decimal_value;
