@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_CACHE_INT_H
-#define DRIZZLED_ITEM_CACHE_INT_H
+#pragma once
 
 #include <drizzled/item/cache.h>
 
@@ -39,11 +38,10 @@ public:
   double val_real() { assert(fixed == 1); return (double) value; }
   int64_t val_int() { assert(fixed == 1); return value; }
   String* val_str(String *str);
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   enum Item_result result_type() const { return INT_RESULT; }
   bool result_as_int64_t() { return true; }
 };
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_CACHE_INT_H */
