@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 #include <math.h>
 #include <drizzled/item/cache_real.h>
 
@@ -46,10 +46,10 @@ String* Item_cache_real::val_str(String *str)
 }
 
 
-my_decimal *Item_cache_real::val_decimal(my_decimal *decimal_val)
+type::Decimal *Item_cache_real::val_decimal(type::Decimal *decimal_val)
 {
   assert(fixed == 1);
-  double2my_decimal(E_DEC_FATAL_ERROR, value, decimal_val);
+  double2_class_decimal(E_DEC_FATAL_ERROR, value, decimal_val);
   return decimal_val;
 }
 
