@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_CACHE_ROW_H
-#define DRIZZLED_ITEM_CACHE_ROW_H
+#pragma once
 
 #include <drizzled/item/cache.h>
 
@@ -55,7 +54,7 @@ public:
   double val_real();
   int64_t val_int();
   String *val_str(String *val);
-  my_decimal *val_decimal(my_decimal *val);
+  type::Decimal *val_decimal(type::Decimal *val);
 
   enum Item_result result_type() const;
 
@@ -72,4 +71,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_CACHE_ROW_H */
