@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,9 +17,10 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <drizzled/item/cache_str.h>
+#include <drizzled/field.h>
 
 namespace drizzled
 {
@@ -76,11 +77,11 @@ int64_t Item_cache_str::val_int()
     return (int64_t)0;
 }
 
-my_decimal *Item_cache_str::val_decimal(my_decimal *decimal_val)
+type::Decimal *Item_cache_str::val_decimal(type::Decimal *decimal_val)
 {
   assert(fixed == 1);
   if (value)
-    string2my_decimal(E_DEC_FATAL_ERROR, value, decimal_val);
+    decimal_val->store(E_DEC_FATAL_ERROR, value);
   else
     decimal_val= 0;
   return decimal_val;
