@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,8 +19,7 @@
 
 #include <drizzled/item/cache.h>
 
-#ifndef DRIZZLED_ITEM_CACHE_STR_H
-#define DRIZZLED_ITEM_CACHE_STR_H
+#pragma once
 
 namespace drizzled
 {
@@ -37,7 +36,7 @@ public:
   double val_real();
   int64_t val_int();
   String* val_str(String *) { assert(fixed == 1); return value; }
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   enum Item_result result_type() const { return STRING_RESULT; }
   const CHARSET_INFO *charset() const { return value->charset(); };
   int save_in_field(Field *field, bool no_conversions);
@@ -45,4 +44,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_CACHE_STR_H */
