@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,41 +17,43 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_CMPFUNC_H
-#define DRIZZLED_ITEM_CMPFUNC_H
+#pragma once
 
 /* compare and test functions */
 
-#include "drizzled/comp_creator.h"
-#include "drizzled/item/row.h"
-#include "drizzled/item/sum.h"
-#include "drizzled/item/int.h"
-#include "drizzled/item/float.h"
-#include "drizzled/item/decimal.h"
-#include "drizzled/function/math/int.h"
-#include "drizzled/function/numhybrid.h"
-#include "drizzled/session.h"
-#include "drizzled/common.h"
-#include "drizzled/qsort_cmp.h"
+#include <drizzled/common.h>
+#include <drizzled/comp_creator.h>
+#include <drizzled/function/math/int.h>
+#include <drizzled/function/numhybrid.h>
+#include <drizzled/item/decimal.h>
+#include <drizzled/item/float.h>
+#include <drizzled/item/function/boolean.h>
+#include <drizzled/item/int.h>
+#include <drizzled/item/row.h>
+#include <drizzled/item/string.h>
+#include <drizzled/item/sum.h>
+#include <drizzled/qsort_cmp.h>
 
 namespace drizzled
 {
 
 extern Item_result item_cmp_type(Item_result a,Item_result b);
+
 class Item_bool_func2;
 class Arg_comparator;
 class Item_sum_hybrid;
 class Item_row;
+class Session;
 
 typedef int (Arg_comparator::*arg_cmp_func)();
 
 typedef int (*Item_field_cmpfunc)(Item_field *f1, Item_field *f2, void *arg);
 
-uint64_t get_datetime_value(Session *session, 
-                            Item ***item_arg, 
-                            Item **cache_arg,
-                            Item *warn_item, 
-                            bool *is_null);
+int64_t get_datetime_value(Session *session, 
+                           Item ***item_arg, 
+                           Item **cache_arg,
+                           Item *warn_item, 
+                           bool *is_null);
 
 class Arg_comparator: public memory::SqlAlloc
 {
@@ -67,14 +69,14 @@ class Arg_comparator: public memory::SqlAlloc
   bool is_nulls_eq;                // TRUE <=> compare for the EQUAL_FUNC
   enum enum_date_cmp_type { CMP_DATE_DFLT= 0, CMP_DATE_WITH_DATE,
                             CMP_DATE_WITH_STR, CMP_STR_WITH_DATE };
-  uint64_t (*get_value_func)(Session *session, Item ***item_arg, Item **cache_arg,
-                              Item *warn_item, bool *is_null);
+  int64_t (*get_value_func)(Session *session, Item ***item_arg, Item **cache_arg,
+                            Item *warn_item, bool *is_null);
 public:
   DTCollation cmp_collation;
 
-  Arg_comparator(): session(0), a_cache(0), b_cache(0) {};
-  Arg_comparator(Item **a1, Item **a2): a(a1), b(a2), session(0),
-    a_cache(0), b_cache(0) {};
+  Arg_comparator();
+
+  Arg_comparator(Item **a1, Item **a2);
 
   int set_compare_func(Item_bool_func2 *owner, Item_result type);
   inline int set_compare_func(Item_bool_func2 *owner_arg)
@@ -116,7 +118,7 @@ public:
   int compare_datetime();        // compare args[0] & args[1] as DATETIMEs
 
   static enum enum_date_cmp_type can_compare_as_dates(Item *a, Item *b,
-                                                      uint64_t *const_val_arg);
+                                                      int64_t *const_val_arg);
 
   void set_datetime_cmp_func(Item **a1, Item **b1);
   static arg_cmp_func comparator_matrix [5][2];
@@ -124,35 +126,23 @@ public:
   friend class Item_func;
 };
 
-class Item_bool_func :public Item_int_func
-{
-public:
-  Item_bool_func() :Item_int_func() {}
-  Item_bool_func(Item *a) :Item_int_func(a) {}
-  Item_bool_func(Item *a,Item *b) :Item_int_func(a,b) {}
-  Item_bool_func(Session *session, Item_bool_func *item) :Item_int_func(session, item) {}
-  bool is_bool_func() { return 1; }
-  void fix_length_and_dec() { decimals=0; max_length=1; }
-  uint32_t decimal_precision() const { return 1; }
-};
-
 
 /**
   Abstract Item class, to represent <code>X IS [NOT] (TRUE | FALSE)</code>
   boolean predicates.
 */
 
-class Item_func_truth : public Item_bool_func
+class Item_func_truth : public item::function::Boolean
 {
 public:
   virtual bool val_bool();
   virtual int64_t val_int();
   virtual void fix_length_and_dec();
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
 
 protected:
   Item_func_truth(Item *a, bool a_value, bool a_affirmative)
-  : Item_bool_func(a), value(a_value), affirmative(a_affirmative)
+  : item::function::Boolean(a), value(a_value), affirmative(a_affirmative)
   {}
 
   ~Item_func_truth()
@@ -241,7 +231,7 @@ class Item_cache;
     placed into a separate class called 'Item_in_optimizer'.
 */
 
-class Item_in_optimizer: public Item_bool_func
+class Item_in_optimizer: public item::function::Boolean
 {
 protected:
   Item_cache *cache;
@@ -255,7 +245,7 @@ protected:
   bool result_for_null_param;
 public:
   Item_in_optimizer(Item *a, Item_in_subselect *b):
-    Item_bool_func(a, reinterpret_cast<Item *>(b)), cache(0),
+    item::function::Boolean(a, reinterpret_cast<Item *>(b)), cache(0),
     save_cache(0), result_for_null_param(UNKNOWN)
   { with_subselect= true; }
   bool fix_fields(Session *, Item **);
@@ -360,9 +350,9 @@ public:
   virtual enum Functype rev_functype() const { return UNKNOWN_FUNC; }
   bool have_rev_func() const { return rev_functype() != UNKNOWN_FUNC; }
 
-  virtual inline void print(String *str, enum_query_type query_type)
+  virtual inline void print(String *str)
   {
-    Item_func::print_op(str, query_type);
+    Item_func::print_op(str);
   }
 
   bool is_null() { return test(args[0]->is_null() || args[1]->is_null()); }
@@ -387,15 +377,15 @@ public:
   { return true; }
 };
 
-class Item_func_not :public Item_bool_func
+class Item_func_not :public item::function::Boolean
 {
 public:
-  Item_func_not(Item *a) :Item_bool_func(a) {}
+  Item_func_not(Item *a) :item::function::Boolean(a) {}
   int64_t val_int();
   enum Functype functype() const { return NOT_FUNC; }
   const char *func_name() const { return "not"; }
   Item *neg_transformer(Session *session);
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
 };
 
 class Item_maxmin_subselect;
@@ -429,11 +419,11 @@ class Item_maxmin_subselect;
    - To wrap condition that is pushed down into subquery
 */
 
-class Item_func_trig_cond: public Item_bool_func
+class Item_func_trig_cond: public item::function::Boolean
 {
   bool *trig_var;
 public:
-  Item_func_trig_cond(Item *a, bool *f) : Item_bool_func(a) { trig_var= f; }
+  Item_func_trig_cond(Item *a, bool *f) : item::function::Boolean(a) { trig_var= f; }
   int64_t val_int() { return *trig_var ? args[0]->val_int() : 1; }
   enum Functype functype() const { return TRIG_COND_FUNC; };
   const char *func_name() const { return "trigcond"; };
@@ -462,7 +452,7 @@ public:
   int64_t val_int();
   enum Functype functype() const { return NOT_ALL_FUNC; }
   const char *func_name() const { return "<not>"; }
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   void set_sum_test(Item_sum_hybrid *item) { test_sum_item= item; };
   void set_sub_test(Item_maxmin_subselect *item) { test_sub_item= item; };
   bool empty_underlying_subquery();
@@ -624,7 +614,7 @@ public:
   const char *func_name() const { return "between"; }
   bool fix_fields(Session *, Item **);
   void fix_length_and_dec();
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   bool is_bool_func() { return 1; }
   const CHARSET_INFO *compare_collation() { return cmp_collation.collation; }
   uint32_t decimal_precision() const { return 1; }
@@ -639,9 +629,9 @@ public:
   optimize_type select_optimize() const { return OPTIMIZE_NONE; }
   const char *func_name() const { return "strcmp"; }
 
-  virtual inline void print(String *str, enum_query_type query_type)
+  virtual inline void print(String *str)
   {
-    Item_func::print(str, query_type);
+    Item_func::print(str);
   }
 };
 
@@ -650,7 +640,7 @@ struct interval_range
 {
   Item_result type;
   double dbl;
-  my_decimal dec;
+  type::Decimal dec;
 };
 
 class Item_func_interval :public Item_int_func
@@ -681,7 +671,7 @@ public:
   double real_op();
   int64_t int_op();
   String *str_op(String *);
-  my_decimal *decimal_op(my_decimal *);
+  type::Decimal *decimal_op(type::Decimal *);
   void fix_length_and_dec();
   void find_num_type() {}
   enum Item_result result_type () const { return hybrid_type; }
@@ -700,7 +690,7 @@ public:
   double real_op();
   int64_t int_op();
   String *str_op(String *str);
-  my_decimal *decimal_op(my_decimal *);
+  type::Decimal *decimal_op(type::Decimal *);
   enum_field_types field_type() const;
   void fix_length_and_dec();
   const char *func_name() const { return "ifnull"; }
@@ -724,7 +714,7 @@ public:
   double val_real();
   int64_t val_int();
   String *val_str(String *str);
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   enum Item_result result_type () const { return cached_result_type; }
   enum_field_types field_type() const { return cached_field_type; }
   bool fix_fields(Session *, Item **);
@@ -744,15 +734,15 @@ public:
   double val_real();
   int64_t val_int();
   String *val_str(String *str);
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   enum Item_result result_type () const { return cached_result_type; }
   void fix_length_and_dec();
   uint32_t decimal_precision() const { return args[0]->decimal_precision(); }
   const char *func_name() const { return "nullif"; }
 
-  virtual inline void print(String *str, enum_query_type query_type)
+  virtual inline void print(String *str)
   {
-    Item_func::print(str, query_type);
+    Item_func::print(str);
   }
 
   table_map not_null_tables() const { return 0; }
@@ -889,9 +879,8 @@ public:
   /* Cache for the left item. */
   Item *lval_cache;
 
-  in_datetime(Item *warn_item_arg, uint32_t elements)
-    :in_int64_t(elements), session(current_session), warn_item(warn_item_arg),
-     lval_cache(0) {};
+  in_datetime(Item *warn_item_arg, uint32_t elements);
+
   void set(uint32_t pos,Item *item);
   unsigned char *get_value(Item *item);
   friend int cmp_int64_t(void *cmp_arg, packed_int64_t *a,packed_int64_t *b);
@@ -919,7 +908,7 @@ public:
 
 class in_decimal :public in_vector
 {
-  my_decimal val;
+  type::Decimal val;
 public:
   in_decimal(uint32_t elements);
   void set(uint32_t pos, Item *item);
@@ -930,7 +919,7 @@ public:
   }
   void value_to_item(uint32_t pos, Item *item)
   {
-    my_decimal *dec= ((my_decimal *)base) + pos;
+    type::Decimal *dec= ((type::Decimal *)base) + pos;
     Item_decimal *item_dec= (Item_decimal*)item;
     item_dec->set_decimal_value(dec);
   }
@@ -947,7 +936,12 @@ class cmp_item :public memory::SqlAlloc
 {
 public:
   const CHARSET_INFO *cmp_charset;
-  cmp_item() { cmp_charset= &my_charset_bin; }
+
+  cmp_item()
+  {
+    cmp_charset= &my_charset_bin;
+  }
+
   virtual ~cmp_item() {}
   virtual void store_value(Item *item)= 0;
   virtual int cmp(Item *item)= 0;
@@ -1038,7 +1032,8 @@ public:
 */
 class cmp_item_datetime :public cmp_item
 {
-  uint64_t value;
+  int64_t value;
+
 public:
   Session *session;
   /* Item used for issuing warnings. */
@@ -1046,8 +1041,8 @@ public:
   /* Cache for the left item. */
   Item *lval_cache;
 
-  cmp_item_datetime(Item *warn_item_arg)
-    :session(current_session), warn_item(warn_item_arg), lval_cache(0) {}
+  cmp_item_datetime(Item *warn_item_arg);
+
   void store_value(Item *item);
   int cmp(Item *arg);
   int compare(cmp_item *ci);
@@ -1078,7 +1073,7 @@ public:
 
 class cmp_item_decimal :public cmp_item
 {
-  my_decimal value;
+  type::Decimal value;
 public:
   cmp_item_decimal() {}                       /* Remove gcc warning */
   void store_value(Item *item);
@@ -1149,22 +1144,22 @@ class Item_func_case :public Item_func
   Item_result cmp_type;
   DTCollation cmp_collation;
   enum_field_types cached_field_type;
-  cmp_item *cmp_items[5]; /* For all result types */
+  cmp_item *cmp_items[DECIMAL_RESULT+1]; /* For all result types */
   cmp_item *case_item;
 public:
   Item_func_case(List<Item> &list, Item *first_expr_arg, Item *else_expr_arg)
     :Item_func(), first_expr_num(-1), else_expr_num(-1),
     cached_result_type(INT_RESULT), left_result_type(INT_RESULT), case_item(0)
   {
-    ncases= list.elements;
+    ncases= list.size();
     if (first_expr_arg)
     {
-      first_expr_num= list.elements;
+      first_expr_num= list.size();
       list.push_back(first_expr_arg);
     }
     if (else_expr_arg)
     {
-      else_expr_num= list.elements;
+      else_expr_num= list.size();
       list.push_back(else_expr_arg);
     }
     set_arguments(list);
@@ -1173,7 +1168,7 @@ public:
   double val_real();
   int64_t val_int();
   String *val_str(String *);
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   bool fix_fields(Session *session, Item **ref);
   void fix_length_and_dec();
   uint32_t decimal_precision() const;
@@ -1181,7 +1176,7 @@ public:
   enum Item_result result_type () const { return cached_result_type; }
   enum_field_types field_type() const { return cached_field_type; }
   const char *func_name() const { return "case"; }
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   Item *find_item(String *str);
   const CHARSET_INFO *compare_collation() { return cmp_collation.collation; }
   void cleanup();
@@ -1234,11 +1229,10 @@ public:
   uint32_t decimal_precision() const { return 1; }
   void cleanup()
   {
-    uint32_t i;
     Item_int_func::cleanup();
     delete array;
     array= 0;
-    for (i= 0; i <= (uint32_t)DECIMAL_RESULT + 1; i++)
+    for (int i= STRING_RESULT; i <= DECIMAL_RESULT; i++)
     {
       delete cmp_items[i];
       cmp_items[i]= 0;
@@ -1247,7 +1241,7 @@ public:
   }
   optimize_type select_optimize() const
     { return OPTIMIZE_KEY; }
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   enum Functype functype() const { return IN_FUNC; }
   const char *func_name() const { return " IN "; }
   bool nulls_in_row();
@@ -1286,12 +1280,12 @@ public:
 
 /* Functions used by where clause */
 
-class Item_func_isnull :public Item_bool_func
+class Item_func_isnull :public item::function::Boolean
 {
 protected:
   int64_t cached_value;
 public:
-  Item_func_isnull(Item *a) :Item_bool_func(a) {}
+  Item_func_isnull(Item *a) :item::function::Boolean(a) {}
   int64_t val_int();
   enum Functype functype() const { return ISNULL_FUNC; }
   void fix_length_and_dec()
@@ -1353,11 +1347,11 @@ public:
 };
 
 
-class Item_func_isnotnull :public Item_bool_func
+class Item_func_isnotnull :public item::function::Boolean
 {
   bool abort_on_null;
 public:
-  Item_func_isnotnull(Item *a) :Item_bool_func(a), abort_on_null(0) {}
+  Item_func_isnotnull(Item *a) :item::function::Boolean(a), abort_on_null(0) {}
   int64_t val_int();
   enum Functype functype() const { return ISNOTNULL_FUNC; }
   void fix_length_and_dec()
@@ -1369,7 +1363,7 @@ public:
   table_map not_null_tables() const
   { return abort_on_null ? not_null_tables_cache : 0; }
   Item *neg_transformer(Session *session);
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   const CHARSET_INFO *compare_collation() { return args[0]->collation.collation; }
   void top_level_item() { abort_on_null=1; }
 };
@@ -1417,7 +1411,7 @@ public:
 
 typedef class Item COND;
 
-class Item_cond :public Item_bool_func
+class Item_cond :public item::function::Boolean
 {
 protected:
   List<Item> list;
@@ -1429,17 +1423,17 @@ public:
   using Item::split_sum_func;
 
   /* Item_cond() is only used to create top level items */
-  Item_cond(): Item_bool_func(), abort_on_null(1)
+  Item_cond(): item::function::Boolean(), abort_on_null(1)
   { const_item_cache=0; }
   Item_cond(Item *i1,Item *i2)
-    :Item_bool_func(), abort_on_null(0)
+    :item::function::Boolean(), abort_on_null(0)
   {
     list.push_back(i1);
     list.push_back(i2);
   }
   Item_cond(Session *session, Item_cond *item);
   Item_cond(List<Item> &nlist)
-    :Item_bool_func(), list(nlist), abort_on_null(0) {}
+    :item::function::Boolean(), list(nlist), abort_on_null(0) {}
   bool add(Item *item) { return list.push_back(item); }
   bool add_at_head(Item *item) { return list.push_front(item); }
   void add_at_head(List<Item> *nlist) { list.prepand(nlist); }
@@ -1450,7 +1444,7 @@ public:
   List<Item>* argument_list() { return &list; }
   table_map used_tables() const;
   void update_used_tables();
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   void split_sum_func(Session *session, Item **ref_pointer_array, List<Item> &fields);
   friend int setup_conds(Session *session, TableList *tables, TableList *leaves,
                          COND **conds);
@@ -1543,16 +1537,24 @@ public:
   object represents f1=f2= ...=fn to the projection of known fields fi1=...=fik.
 */
 
-class Item_equal: public Item_bool_func
+class Item_equal: public item::function::Boolean
 {
-  List<Item_field> fields; /* list of equal field items                    */
-  Item *const_item;        /* optional constant item equal to fields items */
-  cmp_item *eval_item;
-  bool cond_false;
 public:
-  inline Item_equal()
-    : Item_bool_func(), const_item(0), eval_item(0), cond_false(0)
-  { const_item_cache=0 ;}
+  typedef List<Item_field> fields_t;
+
+  Item_equal() :
+    const_item(0),
+    eval_item(0),
+    cond_false(0)
+  {
+    const_item_cache=0;
+  }
+
+  fields_t::iterator begin()
+  {
+    return fields.begin();
+  }
+
   Item_equal(Item_field *f1, Item_field *f2);
   Item_equal(Item *c, Item_field *f);
   Item_equal(Item_equal *item_equal);
@@ -1561,7 +1563,7 @@ public:
   void add(Item_field *f);
   uint32_t members();
   bool contains(Field *field);
-  Item_field* get_first() { return fields.head(); }
+  Item_field* get_first() { return &fields.front(); }
   void merge(Item_equal *item);
   void update_const();
   enum Functype functype() const { return MULT_EQUAL_FUNC; }
@@ -1569,15 +1571,20 @@ public:
   const char *func_name() const { return "multiple equal"; }
   optimize_type select_optimize() const { return OPTIMIZE_EQUAL; }
   void sort(Item_field_cmpfunc cmp, void *arg);
-  friend class Item_equal_iterator;
   void fix_length_and_dec();
   bool fix_fields(Session *session, Item **ref);
   void update_used_tables();
   bool walk(Item_processor processor, bool walk_subquery, unsigned char *arg);
   Item *transform(Item_transformer transformer, unsigned char *arg);
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   const CHARSET_INFO *compare_collation()
-  { return fields.head()->collation.collation; }
+  { return fields.front().collation.collation; }
+private:
+  fields_t fields; /* list of equal field items                    */
+  Item *const_item;        /* optional constant item equal to fields items */
+  cmp_item *eval_item;
+  bool cond_false;
+
 };
 
 class COND_EQUAL: public memory::SqlAlloc
@@ -1594,23 +1601,7 @@ public:
   }
 };
 
-
-class Item_equal_iterator : public List_iterator_fast<Item_field>
-{
-public:
-  inline Item_equal_iterator(Item_equal &item_equal)
-    :List_iterator_fast<Item_field> (item_equal.fields)
-  {}
-  inline Item_field* operator++(int)
-  {
-    Item_field *item= (*(List_iterator_fast<Item_field> *) this)++;
-    return  item;
-  }
-  inline void rewind(void)
-  {
-    List_iterator_fast<Item_field>::rewind();
-  }
-};
+typedef List<Item_field>::iterator Item_equal_iterator;
 
 class Item_cond_and :public Item_cond
 {
@@ -1710,4 +1701,3 @@ Item *and_expressions(Item *a, Item *b, Item **org_item);
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_CMPFUNC_H */
