@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,11 +17,11 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_COPY_STRING_H
-#define DRIZZLED_ITEM_COPY_STRING_H
+#pragma once
 
-#include <drizzled/item/ident.h>
+#include <drizzled/charset_info.h>
 #include <drizzled/item/field.h>
+#include <drizzled/item/ident.h>
 
 namespace drizzled
 {
@@ -58,7 +58,7 @@ public:
                                         &err);
   }
   String *val_str(String*);
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   void make_field(SendField *field) { item->make_field(field); }
   void copy();
   int save_in_field(Field *field, bool)
@@ -72,4 +72,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_COPY_STRING_H */
