@@ -11,7 +11,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /**
   @file
@@ -20,12 +20,12 @@
   Functions to create an item. Used by sql_yac.yy
 */
 
-#include "config.h"
+#include <config.h>
 #include <drizzled/item/create.h>
 #include <drizzled/item/func.h>
 #include <drizzled/error.h>
 
-#include "drizzled/function_container.h"
+#include <drizzled/function_container.h>
 
 #include <drizzled/function/str/binary.h>
 #include <drizzled/function/str/concat.h>
@@ -83,6 +83,11 @@
 #include <drizzled/function/math/tan.h>
 #include <drizzled/function/units.h>
 
+#include <drizzled/function/cast/boolean.h>
+#include <drizzled/function/cast/signed.h>
+#include <drizzled/function/cast/time.h>
+#include <drizzled/function/cast/unsigned.h>
+
 using namespace std;
 
 namespace drizzled
@@ -1048,7 +1053,7 @@ static bool has_named_parameters(List<Item> *params)
   if (params)
   {
     Item *param;
-    List_iterator<Item> it(*params);
+    List<Item>::iterator it(params->begin());
     while ((param= it++))
     {
       if (! param->is_autogenerated_name)
@@ -1065,7 +1070,7 @@ Create_udf_func Create_udf_func::s_singleton;
 Item*
 Create_udf_func::create(Session *session, LEX_STRING name, List<Item> *item_list)
 {
-  const plugin::Function *udf= plugin::Function::get(name.str, name.length);
+  const plugin::Function *udf= plugin::Function::get(std::string(name.str, name.length));
   assert(udf);
   return create(session, udf, item_list);
 }
@@ -1079,7 +1084,7 @@ Create_udf_func::create(Session *session, const plugin::Function *udf,
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   func= (*udf)(session->mem_root);
 
@@ -1115,7 +1120,7 @@ Create_func_arg0::create(Session *session, LEX_STRING name, List<Item> *item_lis
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   if (arg_count != 0)
   {
@@ -1133,7 +1138,7 @@ Create_func_arg1::create(Session *session, LEX_STRING name, List<Item> *item_lis
   int arg_count= 0;
 
   if (item_list)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   if (arg_count != 1)
   {
@@ -1159,7 +1164,7 @@ Create_func_arg2::create(Session *session, LEX_STRING name, List<Item> *item_lis
   int arg_count= 0;
 
   if (item_list)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   if (arg_count != 2)
   {
@@ -1187,7 +1192,7 @@ Create_func_arg3::create(Session *session, LEX_STRING name, List<Item> *item_lis
   int arg_count= 0;
 
   if (item_list)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   if (arg_count != 3)
   {
@@ -1229,7 +1234,7 @@ Create_func_concat::create_native(Session *session, LEX_STRING name,
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   if (arg_count < 1)
   {
@@ -1250,7 +1255,7 @@ Create_func_concat_ws::create_native(Session *session, LEX_STRING name,
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   /* "WS" stands for "With Separator": this function takes 2+ arguments */
   if (arg_count < 2)
@@ -1357,7 +1362,7 @@ Create_func_export_set::create_native(Session *session, LEX_STRING name,
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   switch (arg_count) {
   case 3:
@@ -1409,7 +1414,7 @@ Create_func_field::create_native(Session *session, LEX_STRING name,
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   if (arg_count < 2)
   {
@@ -1457,7 +1462,7 @@ Create_func_from_unixtime::create_native(Session *session, LEX_STRING name,
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   switch (arg_count) {
   case 1:
@@ -1494,7 +1499,7 @@ Create_func_greatest::create_native(Session *session, LEX_STRING name,
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   if (arg_count < 2)
   {
@@ -1551,7 +1556,7 @@ Create_func_last_insert_id::create_native(Session *session, LEX_STRING name,
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   switch (arg_count) {
   case 0:
@@ -1594,7 +1599,7 @@ Create_func_least::create_native(Session *session, LEX_STRING name,
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   if (arg_count < 2)
   {
@@ -1624,7 +1629,7 @@ Create_func_locate::create_native(Session *session, LEX_STRING name,
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   switch (arg_count) {
   case 2:
@@ -1690,7 +1695,7 @@ Create_func_make_set::create_native(Session *session_arg, LEX_STRING name,
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   if (arg_count < 2)
   {
@@ -1776,7 +1781,7 @@ Create_func_round::create_native(Session *session, LEX_STRING name,
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   switch (arg_count) {
   case 1:
@@ -1854,7 +1859,7 @@ Create_func_space::create(Session *session, Item *arg1)
 
   if (cs->mbminlen > 1)
   {
-    uint32_t dummy_errors;
+    size_t dummy_errors;
     sp= new (session->mem_root) Item_string("", 0, cs, DERIVATION_COERCIBLE);
     sp->str_value.copy(" ", 1, &my_charset_utf8_general_ci, cs, &dummy_errors);
   }
@@ -1919,7 +1924,7 @@ Create_func_unix_timestamp::create_native(Session *session, LEX_STRING name,
   int arg_count= 0;
 
   if (item_list != NULL)
-    arg_count= item_list->elements;
+    arg_count= item_list->size();
 
   switch (arg_count) {
   case 0:
@@ -2042,7 +2047,7 @@ int item_create_init()
   {
     func_name.assign(func->name.str, func->name.length);
 
-    FunctionContainer::getMap()[func_name]= func;
+    FunctionContainer::getMap()[func_name]= func->builder;
   }
 
   return 0;
@@ -2052,18 +2057,16 @@ int item_create_init()
 Create_func *
 find_native_function_builder(LEX_STRING name)
 {
-  Native_func_registry *func;
   Create_func *builder= NULL;
 
   string func_name(name.str, name.length);
 
-  NativeFunctionsMap::iterator func_iter=
+  FunctionContainer::Map::iterator func_iter=
     FunctionContainer::getMap().find(func_name);
 
   if (func_iter != FunctionContainer::getMap().end())
   {
-    func= (*func_iter).second;
-    builder= func->builder;
+    builder= (*func_iter).second;
   }
 
   return builder;
@@ -2083,58 +2086,72 @@ create_func_cast(Session *session, Item *a, Cast_target cast_type,
                  const char *c_len, const char *c_dec,
                  const CHARSET_INFO * const cs)
 {
-  Item *res;
+  Item *res= NULL;
   uint32_t len;
   uint32_t dec;
 
   switch (cast_type) {
+  case ITEM_CAST_SIGNED:
+    res= new (session->mem_root) function::cast::Signed(a);
+    break;
+
+  case ITEM_CAST_UNSIGNED:
+    res= new (session->mem_root) function::cast::Unsigned(a);
+    break;
+
   case ITEM_CAST_BINARY:
     res= new (session->mem_root) Item_func_binary(a);
     break;
+
+  case ITEM_CAST_BOOLEAN:
+    res= new (session->mem_root) function::cast::Boolean(a);
+    break;
+
+  case ITEM_CAST_TIME:
+    res= new (session->mem_root) function::cast::Time(a);
+    break;
+
   case ITEM_CAST_DATE:
     res= new (session->mem_root) Item_date_typecast(a);
     break;
+
   case ITEM_CAST_DATETIME:
     res= new (session->mem_root) Item_datetime_typecast(a);
     break;
+
   case ITEM_CAST_DECIMAL:
-  {
-    len= c_len ? atoi(c_len) : 0;
-    dec= c_dec ? atoi(c_dec) : 0;
-    my_decimal_trim(&len, &dec);
-    if (len < dec)
     {
-      my_error(ER_M_BIGGER_THAN_D, MYF(0), "");
-      return 0;
+      len= c_len ? atoi(c_len) : 0;
+      dec= c_dec ? atoi(c_dec) : 0;
+      class_decimal_trim(&len, &dec);
+      if (len < dec)
+      {
+        my_error(ER_M_BIGGER_THAN_D, MYF(0), "");
+        return 0;
+      }
+      if (len > DECIMAL_MAX_PRECISION)
+      {
+        my_error(ER_TOO_BIG_PRECISION, MYF(0), len, a->name,
+                 DECIMAL_MAX_PRECISION);
+        return 0;
+      }
+      if (dec > DECIMAL_MAX_SCALE)
+      {
+        my_error(ER_TOO_BIG_SCALE, MYF(0), dec, a->name,
+                 DECIMAL_MAX_SCALE);
+        return 0;
+      }
+      res= new (session->mem_root) Item_decimal_typecast(a, len, dec);
+      break;
     }
-    if (len > DECIMAL_MAX_PRECISION)
-    {
-      my_error(ER_TOO_BIG_PRECISION, MYF(0), len, a->name,
-               DECIMAL_MAX_PRECISION);
-      return 0;
-    }
-    if (dec > DECIMAL_MAX_SCALE)
-    {
-      my_error(ER_TOO_BIG_SCALE, MYF(0), dec, a->name,
-               DECIMAL_MAX_SCALE);
-      return 0;
-    }
-    res= new (session->mem_root) Item_decimal_typecast(a, len, dec);
-    break;
-  }
   case ITEM_CAST_CHAR:
-  {
-    len= c_len ? atoi(c_len) : -1;
-    res= create_func_char_cast(session, a, len, cs);
-    break;
-  }
-  default:
-  {
-    assert(0);
-    res= 0;
-    break;
-  }
+    {
+      len= c_len ? atoi(c_len) : -1;
+      res= create_func_char_cast(session, a, len, cs);
+      break;
+    }
   }
+
   return res;
 }
 
