@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <drizzled/item/direct_ref.h>
 
@@ -47,9 +47,9 @@ String *Item_direct_ref::val_str(String* tmp)
   return tmp;
 }
 
-my_decimal *Item_direct_ref::val_decimal(my_decimal *decimal_value)
+type::Decimal *Item_direct_ref::val_decimal(type::Decimal *decimal_value)
 {
-  my_decimal *tmp= (*ref)->val_decimal(decimal_value);
+  type::Decimal *tmp= (*ref)->val_decimal(decimal_value);
   null_value=(*ref)->null_value;
   return tmp;
 }
@@ -69,9 +69,9 @@ bool Item_direct_ref::is_null()
 }
 
 
-bool Item_direct_ref::get_date(DRIZZLE_TIME *ltime,uint32_t fuzzydate)
+bool Item_direct_ref::get_date(type::Time &ltime, uint32_t fuzzydate)
 {
-  return (null_value=(*ref)->get_date(ltime,fuzzydate));
+  return (null_value=(*ref)->get_date(ltime, fuzzydate));
 }
 
 } /* namespace drizzled */
