@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_DIRECT_REF_H
-#define DRIZZLED_ITEM_DIRECT_REF_H
+#pragma once
 
 #include <drizzled/item/ref.h>
 
@@ -45,13 +44,12 @@ public:
   double val_real();
   int64_t val_int();
   String *val_str(String* tmp);
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   bool val_bool();
   bool is_null();
-  bool get_date(DRIZZLE_TIME *ltime,uint32_t fuzzydate);
+  bool get_date(type::Time &ltime,uint32_t fuzzydate);
   virtual Ref_Type ref_type() { return DIRECT_REF; }
 };
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_DIRECT_REF_H */
