@@ -21,10 +21,15 @@
 
 #include <drizzled/item/boolean.h>
 
-namespace drizzled {
-namespace item {
+namespace drizzled
+{
 
-class False : public Boolean
+namespace item
+{
+
+class Boolean;
+
+class False: public Boolean
 {
 public:
   False() :
