@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <drizzled/session.h>
 #include <drizzled/table.h>
@@ -29,6 +29,10 @@
 #include <drizzled/item/field.h>
 #include <drizzled/item/outer_ref.h>
 #include <drizzled/plugin/client.h>
+#include <drizzled/item/subselect.h>
+#include <drizzled/sql_lex.h>
+
+#include <boost/dynamic_bitset.hpp>
 
 namespace drizzled
 {
@@ -54,7 +58,7 @@ namespace drizzled
 bool Item_field::collect_item_field_processor(unsigned char *arg)
 {
   List<Item_field> *item_list= (List<Item_field>*) arg;
-  List_iterator<Item_field> item_list_it(*item_list);
+  List<Item_field>::iterator item_list_it(item_list->begin());
   Item_field *curr_item;
   while ((curr_item= item_list_it++))
   {
@@ -109,7 +113,7 @@ bool Item_field::register_field_in_read_map(unsigned char *arg)
 {
   Table *table= (Table *) arg;
   if (field->getTable() == table || !table)
-    field->getTable()->setReadSet(field->field_index);
+    field->getTable()->setReadSet(field->position());
 
   return 0;
 }
@@ -163,7 +167,7 @@ Item_field::Item_field(Name_resolution_context *context_arg,
    have_privileges(0),
    any_privileges(0)
 {
-  Select_Lex *select= current_session->lex->current_select;
+  Select_Lex *select= getSession().lex().current_select;
   collation.set(DERIVATION_IMPLICIT);
 
   if (select && select->parsing_place != IN_HAVING)
@@ -244,7 +248,7 @@ int64_t Item_field::val_int()
 }
 
 
-my_decimal *Item_field::val_decimal(my_decimal *decimal_value)
+type::Decimal *Item_field::val_decimal(type::Decimal *decimal_value)
 {
   if ((null_value= field->is_null()))
     return 0;
@@ -260,32 +264,32 @@ String *Item_field::str_result(String *str)
   return result_field->val_str(str,&str_value);
 }
 
-bool Item_field::get_date(DRIZZLE_TIME *ltime,uint32_t fuzzydate)
+bool Item_field::get_date(type::Time &ltime,uint32_t fuzzydate)
 {
   if ((null_value=field->is_null()) || field->get_date(ltime,fuzzydate))
   {
-    memset(ltime, 0, sizeof(*ltime));
+    ltime.reset();
     return 1;
   }
   return 0;
 }
 
-bool Item_field::get_date_result(DRIZZLE_TIME *ltime,uint32_t fuzzydate)
+bool Item_field::get_date_result(type::Time &ltime,uint32_t fuzzydate)
 {
   if ((null_value=result_field->is_null()) ||
       result_field->get_date(ltime,fuzzydate))
   {
-    memset(ltime, 0, sizeof(*ltime));
+    ltime.reset();
     return 1;
   }
   return 0;
 }
 
-bool Item_field::get_time(DRIZZLE_TIME *ltime)
+bool Item_field::get_time(type::Time &ltime)
 {
   if ((null_value=field->is_null()) || field->get_time(ltime))
   {
-    memset(ltime, 0, sizeof(*ltime));
+    ltime.reset();
     return 1;
   }
   return 0;
@@ -306,7 +310,7 @@ int64_t Item_field::val_int_result()
 }
 
 
-my_decimal *Item_field::val_decimal_result(my_decimal *decimal_value)
+type::Decimal *Item_field::val_decimal_result(type::Decimal *decimal_value)
 {
   if ((null_value= result_field->is_null()))
     return 0;
@@ -317,26 +321,34 @@ my_decimal *Item_field::val_decimal_result(my_decimal *decimal_value)
 bool Item_field::val_bool_result()
 {
   if ((null_value= result_field->is_null()))
+  {
     return false;
+  }
+
   switch (result_field->result_type()) {
   case INT_RESULT:
     return result_field->val_int() != 0;
+
   case DECIMAL_RESULT:
-  {
-    my_decimal decimal_value;
-    my_decimal *val= result_field->val_decimal(&decimal_value);
-    if (val)
-      return !my_decimal_is_zero(val);
-    return 0;
-  }
+    {
+      type::Decimal decimal_value;
+      type::Decimal *val= result_field->val_decimal(&decimal_value);
+      if (val)
+        return not val->isZero();
+      return 0;
+    }
+
   case REAL_RESULT:
   case STRING_RESULT:
     return result_field->val_real() != 0.0;
+
   case ROW_RESULT:
-  default:
     assert(0);
     return 0;                                   // Shut up compiler
   }
+
+  assert(0);
+  return 0;                                   // Shut up compiler
 }
 
 
@@ -359,21 +371,21 @@ bool Item_field::eq(const Item *item, bool) const
     (In cases where we would choose wrong we would have to generate a
     ER_NON_UNIQ_ERROR).
   */
-  return (!my_strcasecmp(system_charset_info, item_field->name,
-			 field_name) &&
-	  (!item_field->table_name || !table_name ||
-	   (!my_strcasecmp(table_alias_charset, item_field->table_name,
-			   table_name) &&
-	    (!item_field->db_name || !db_name ||
-	     (item_field->db_name && !strcasecmp(item_field->db_name,
-					     db_name))))));
+  return (not my_strcasecmp(system_charset_info, item_field->name, field_name) &&
+          (not item_field->table_name || not table_name ||
+           (not my_strcasecmp(table_alias_charset, item_field->table_name, table_name) &&
+            (not item_field->db_name || not db_name ||
+             (item_field->db_name && not my_strcasecmp(system_charset_info, item_field->db_name, db_name))))));
 }
 
 
 table_map Item_field::used_tables() const
 {
   if (field->getTable()->const_table)
+  {
     return 0;					// const item
+  }
+
   return (depended_from ? OUTER_REF_TABLE_BIT : field->getTable()->map);
 }
 
@@ -486,7 +498,7 @@ Item_field::fix_outer_field(Session *session, Field **from_field, Item **referen
   */
   Name_resolution_context *last_checked_context= context;
   Item **ref= (Item **) not_found_item;
-  Select_Lex *current_sel= (Select_Lex *) session->lex->current_select;
+  Select_Lex *current_sel= (Select_Lex *) session->lex().current_select;
   Name_resolution_context *outer_context= 0;
   Select_Lex *select= 0;
   /* Currently derived tables cannot be correlated */
@@ -531,7 +543,7 @@ Item_field::fix_outer_field(Session *session, Field **from_field, Item **referen
         if (*from_field != view_ref_found)
         {
           prev_subselect_item->used_tables_cache|= (*from_field)->getTable()->map;
-          prev_subselect_item->const_item_cache= 0;
+          prev_subselect_item->const_item_cache= false;
           set_field(*from_field);
           if (!last_checked_context->select_lex->having_fix_field &&
               select->group_list.elements &&
@@ -550,20 +562,20 @@ Item_field::fix_outer_field(Session *session, Field **from_field, Item **referen
             ;
             if (!(rf= new Item_outer_ref(context, this)))
               return -1;
-            session->change_item_tree(reference, rf);
+            *reference= rf;
             select->inner_refs_list.push_back(rf);
-            rf->in_sum_func= session->lex->in_sum_func;
+            rf->in_sum_func= session->lex().in_sum_func;
           }
           /*
             A reference is resolved to a nest level that's outer or the same as
             the nest level of the enclosing set function : adjust the value of
             max_arg_level for the function if it's needed.
           */
-          if (session->lex->in_sum_func &&
-              session->lex->in_sum_func->nest_level >= select->nest_level)
+          if (session->lex().in_sum_func &&
+              session->lex().in_sum_func->nest_level >= select->nest_level)
           {
             Item::Type ref_type= (*reference)->type();
-            set_if_bigger(session->lex->in_sum_func->max_arg_level,
+            set_if_bigger(session->lex().in_sum_func->max_arg_level,
                           select->nest_level);
             set_field(*from_field);
             fixed= 1;
@@ -619,7 +631,7 @@ Item_field::fix_outer_field(Session *session, Field **from_field, Item **referen
       case it does not matter which used tables bits we set)
     */
     prev_subselect_item->used_tables_cache|= OUTER_REF_TABLE_BIT;
-    prev_subselect_item->const_item_cache= 0;
+    prev_subselect_item->const_item_cache= false;
   }
 
   assert(ref != 0);
@@ -630,7 +642,7 @@ Item_field::fix_outer_field(Session *session, Field **from_field, Item **referen
     if (upward_lookup)
     {
       // We can't say exactly what absent table or field
-      my_error(ER_BAD_FIELD_ERROR, MYF(0), full_name(), session->where);
+      my_error(ER_BAD_FIELD_ERROR, MYF(0), full_name(), session->where());
     }
     else
     {
@@ -672,9 +684,9 @@ Item_field::fix_outer_field(Session *session, Field **from_field, Item **referen
     if (place != IN_HAVING && select->group_list.elements)
     {
       outer_context->select_lex->inner_refs_list.push_back((Item_outer_ref*)rf);
-      ((Item_outer_ref*)rf)->in_sum_func= session->lex->in_sum_func;
+      ((Item_outer_ref*)rf)->in_sum_func= session->lex().in_sum_func;
     }
-    session->change_item_tree(reference, rf);
+    *reference= rf;
     /*
       rf is Item_ref => never substitute other items (in this case)
       during fix_fields() => we can use rf after fix_fields()
@@ -697,11 +709,11 @@ Item_field::fix_outer_field(Session *session, Field **from_field, Item **referen
     {
       Item_ref *rf;
       rf= new Item_ref(context,
-                       (cached_table->db[0] ? cached_table->db : 0),
+                       (cached_table->getSchemaName()[0] ? cached_table->getSchemaName() : 0),
                        (char*) cached_table->alias, (char*) field_name);
       if (!rf)
         return -1;
-      session->change_item_tree(reference, rf);
+      *reference= rf;
       /*
         rf is Item_ref => never substitute other items (in this case)
         during fix_fields() => we can use rf after fix_fields()
@@ -778,19 +790,19 @@ bool Item_field::fix_fields(Session *session, Item **reference)
                                           context->first_name_resolution_table,
                                           context->last_name_resolution_table,
                                           reference,
-                                          session->lex->use_only_table_context ?
+                                          session->lex().use_only_table_context ?
                                             REPORT_ALL_ERRORS :
                                             IGNORE_EXCEPT_NON_UNIQUE, true)) ==
         not_found_field)
     {
       int ret;
       /* Look up in current select's item_list to find aliased fields */
-      if (session->lex->current_select->is_item_list_lookup)
+      if (session->lex().current_select->is_item_list_lookup)
       {
         uint32_t counter;
         enum_resolution_type resolution;
         Item** res= find_item_in_list(session,
-                                      this, session->lex->current_select->item_list,
+                                      this, session->lex().current_select->item_list,
                                       &counter, REPORT_EXCEPT_NOT_FOUND,
                                       &resolution);
         if (!res)
@@ -814,7 +826,7 @@ bool Item_field::fix_fields(Session *session, Item **reference)
             {
               /* The column to which we link isn't valid. */
               my_error(ER_BAD_FIELD_ERROR, MYF(0), (*res)->name,
-                       current_session->where);
+                       session->where());
               return(1);
             }
 
@@ -831,7 +843,7 @@ bool Item_field::fix_fields(Session *session, Item **reference)
             Item_ref *rf= new Item_ref(context, db_name,table_name,field_name);
             if (!rf)
               return 1;
-            session->change_item_tree(reference, rf);
+            *reference= rf;
             /*
               Because Item_ref never substitutes itself with other items
               in Item_ref::fix_fields(), we can safely use the original
@@ -878,18 +890,18 @@ bool Item_field::fix_fields(Session *session, Item **reference)
       return false;
 
     set_field(from_field);
-    if (session->lex->in_sum_func &&
-        session->lex->in_sum_func->nest_level ==
-        session->lex->current_select->nest_level)
+    if (session->lex().in_sum_func &&
+        session->lex().in_sum_func->nest_level ==
+        session->lex().current_select->nest_level)
     {
-      set_if_bigger(session->lex->in_sum_func->max_arg_level,
-                    session->lex->current_select->nest_level);
+      set_if_bigger(session->lex().in_sum_func->max_arg_level,
+                    session->lex().current_select->nest_level);
     }
   }
   else if (session->mark_used_columns != MARK_COLUMNS_NONE)
   {
     Table *table= field->getTable();
-    MyBitmap *current_bitmap, *other_bitmap;
+    boost::dynamic_bitset<> *current_bitmap, *other_bitmap;
     if (session->mark_used_columns == MARK_COLUMNS_READ)
     {
       current_bitmap= table->read_set;
@@ -900,9 +912,10 @@ bool Item_field::fix_fields(Session *session, Item **reference)
       current_bitmap= table->write_set;
       other_bitmap=   table->read_set;
     }
-    if (! current_bitmap->testAndSet(field->field_index))
+    //if (! current_bitmap->testAndSet(field->position()))
+    if (! current_bitmap->test(field->position()))
     {
-      if (! other_bitmap->isBitSet(field->field_index))
+      if (! other_bitmap->test(field->position()))
       {
         /* First usage of column */
         table->used_fields++;                     // Used to optimize loops
@@ -969,7 +982,7 @@ Item_equal *Item_field::find_item_equal(COND_EQUAL *cond_equal)
   Item_equal *item= 0;
   while (cond_equal)
   {
-    List_iterator_fast<Item_equal> li(cond_equal->current_level);
+    List<Item_equal>::iterator li(cond_equal->current_level.begin());
     while ((item= li++))
     {
       if (item->contains(field))
@@ -1241,7 +1254,7 @@ Item *Item_field::update_value_transformer(unsigned char *select_arg)
   {
     List<Item> *all_fields= &select->join->all_fields;
     Item **ref_pointer_array= select->ref_pointer_array;
-    int el= all_fields->elements;
+    int el= all_fields->size();
     Item_ref *ref;
 
     ref_pointer_array[el]= (Item*)this;
@@ -1254,13 +1267,13 @@ Item *Item_field::update_value_transformer(unsigned char *select_arg)
 }
 
 
-void Item_field::print(String *str, enum_query_type query_type)
+void Item_field::print(String *str)
 {
   if (field && field->getTable()->const_table)
   {
     char buff[MAX_FIELD_WIDTH];
     String tmp(buff,sizeof(buff),str->charset());
-    field->val_str(&tmp);
+    field->val_str_internal(&tmp);
     if (field->is_null())  {
       str->append("NULL");
     }
@@ -1271,7 +1284,7 @@ void Item_field::print(String *str, enum_query_type query_type)
     }
     return;
   }
-  Item_ident::print(str, query_type);
+  Item_ident::print(str);
 }
 
 
