@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,12 +17,15 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
+
 #include <math.h>
+
 #include <drizzled/error.h>
+#include <drizzled/field.h>
+#include <drizzled/item/float.h>
 #include <drizzled/item/num.h>
 #include <drizzled/item/string.h>
-#include <drizzled/item/float.h>
 
 namespace drizzled
 {
@@ -74,11 +77,11 @@ int64_t Item_float::val_int()
   return (int64_t) rint(value);
 }
 
-my_decimal *Item_float::val_decimal(my_decimal *decimal_value)
+type::Decimal *Item_float::val_decimal(type::Decimal *decimal_value)
 {
   // following assert is redundant, because fixed=1 assigned in constructor
   assert(fixed == 1);
-  double2my_decimal(E_DEC_FATAL_ERROR, value, decimal_value);
+  double2_class_decimal(E_DEC_FATAL_ERROR, value, decimal_value);
   return (decimal_value);
 }
 
@@ -118,7 +121,7 @@ int Item_float::save_in_field(Field *field, bool)
 }
 
 
-void Item_float::print(String *str, enum_query_type)
+void Item_float::print(String *str)
 {
   if (presentation)
   {
