@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_FLOAT_H
-#define DRIZZLED_ITEM_FLOAT_H
+#pragma once
 
 #include <drizzled/item/num.h>
 
@@ -51,12 +50,12 @@ public:
   double val_real() { assert(fixed == 1); return value; }
   int64_t val_int();
   String *val_str(String*);
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   bool basic_const_item() const { return 1; }
   Item *clone_item()
   { return new Item_float(name, value, decimals, max_length); }
   Item_num *neg() { value= -value; return this; }
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   bool eq(const Item *, bool binary_cmp) const;
 };
 
@@ -69,7 +68,7 @@ public:
     :Item_float(NULL, val_arg, decimal_par, length), func_name(str)
   {}
 
-  virtual inline void print(String *str, enum_query_type)
+  virtual inline void print(String *str)
   {
     str->append(func_name);
   }
@@ -79,5 +78,4 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_FLOAT_H */
 
