@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,11 +17,13 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <drizzled/error.h>
-#include <drizzled/item/string.h>
+#include <drizzled/field.h>
 #include <drizzled/item/hex_string.h>
+#include <drizzled/item/string.h>
+#include <drizzled/type/decimal.h>
 
 #include <algorithm>
 
@@ -66,7 +68,7 @@ int64_t Item_hex_string::val_int()
   // following assert is redundant, because fixed=1 assigned in constructor
   assert(fixed == 1);
   char *end= (char*) str_value.ptr()+str_value.length(),
-       *ptr= end - min(str_value.length(),(uint32_t)sizeof(int64_t));
+       *ptr= end - min(str_value.length(), sizeof(int64_t));
 
   uint64_t value=0;
   for (; ptr != end ; ptr++)
@@ -75,12 +77,12 @@ int64_t Item_hex_string::val_int()
 }
 
 
-my_decimal *Item_hex_string::val_decimal(my_decimal *decimal_value)
+type::Decimal *Item_hex_string::val_decimal(type::Decimal *decimal_value)
 {
   // following assert is redundant, because fixed=1 assigned in constructor
   assert(fixed == 1);
   uint64_t value= (uint64_t)val_int();
-  int2my_decimal(E_DEC_FATAL_ERROR, value, true, decimal_value);
+  int2_class_decimal(E_DEC_FATAL_ERROR, value, true, decimal_value);
   return (decimal_value);
 }
 
@@ -113,10 +115,10 @@ warn:
   return 1;
 }
 
-void Item_hex_string::print(String *str, enum_query_type)
+void Item_hex_string::print(String *str)
 {
   char *end= (char*) str_value.ptr() + str_value.length(),
-       *ptr= end - min(str_value.length(), (uint32_t)sizeof(int64_t));
+       *ptr= end - min(str_value.length(), sizeof(int64_t));
   str->append("0x");
   for (; ptr != end ; ptr++)
   {
