@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_HEX_STRING_H
-#define DRIZZLED_ITEM_HEX_STRING_H
+#pragma once
 
 #include <drizzled/item/basic_constant.h>
 
@@ -39,16 +38,15 @@ public:
   int64_t val_int();
   bool basic_const_item() const { return 1; }
   String *val_str(String*) { assert(fixed == 1); return &str_value; }
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   int save_in_field(Field *field, bool no_conversions);
   enum Item_result result_type () const { return STRING_RESULT; }
   enum Item_result cast_to_int_type() const { return INT_RESULT; }
   enum_field_types field_type() const { return DRIZZLE_TYPE_VARCHAR; }
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   bool eq(const Item *item, bool binary_cmp) const;
   virtual Item *safe_charset_converter(const CHARSET_INFO * const tocs);
 };
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_HEX_STRING_H */
