@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,14 +17,15 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_IDENT_H
-#define DRIZZLED_ITEM_IDENT_H
+#pragma once
 
-#include "drizzled/item.h"
+#include <drizzled/item.h>
 
 namespace drizzled
 {
 
+class Name_resolution_context;
+class TableList;
 extern uint32_t lower_case_table_names;
 
 class Item_ident :public Item
@@ -66,12 +67,12 @@ public:
   const char *full_name() const;
   void cleanup();
   bool remove_dependence_processor(unsigned char * arg);
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   virtual bool change_context_processor(unsigned char *cntx)
     { context= (Name_resolution_context *)cntx; return false; }
   friend bool insert_fields(Session *session, Name_resolution_context *context,
                             const char *db_name,
-                            const char *table_name, List_iterator<Item> *it,
+                            const char *table_name, List<Item>::iterator *it,
                             bool any_privileges);
 };
 
@@ -92,10 +93,9 @@ public:
   double val_real();
   int64_t val_int();
   String *val_str(String *str);
-  my_decimal *val_decimal(my_decimal *dec);
+  type::Decimal *val_decimal(type::Decimal *dec);
   void make_field(SendField *tmp_field);
 };
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_IDENT_H */
