@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,10 +17,10 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_NULL_H
-#define DRIZZLED_ITEM_NULL_H
+#pragma once
 
-#include "drizzled/item/basic_constant.h"
+#include <drizzled/charset_info.h>
+#include <drizzled/item/basic_constant.h>
 
 namespace drizzled
 {
@@ -42,7 +42,7 @@ public:
   double val_real();
   int64_t val_int();
   String *val_str(String *str);
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   int save_in_field(Field *field, bool no_conversions);
   int save_safe_in_field(Field *field);
   bool send(plugin::Client *client, String *str);
@@ -52,7 +52,7 @@ public:
   Item *clone_item() { return new Item_null(name); }
   bool is_null() { return true; }
 
-  virtual void print(String *str, enum_query_type);
+  virtual void print(String *str);
 
   Item *safe_charset_converter(const CHARSET_INFO * const tocs);
 };
@@ -71,4 +71,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_NULL_H */
