@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,12 +17,11 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_OUTER_REF_H
-#define DRIZZLED_ITEM_OUTER_REF_H
+#pragma once
 
-#include "drizzled/item/ref.h"
-#include "drizzled/item/direct_ref.h"
-#include "drizzled/item/field.h"
+#include <drizzled/item/ref.h>
+#include <drizzled/item/direct_ref.h>
+#include <drizzled/item/field.h>
 
 /*
   Class for outer fields.
@@ -81,4 +80,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_OUTER_REF_H */
