@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,17 +17,18 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
-#include "drizzled/session.h"
-#include "drizzled/error.h"
-#include "drizzled/show.h"
-#include "drizzled/item/ref.h"
-#include "drizzled/plugin/client.h"
-#include "drizzled/item/sum.h"
+#include <drizzled/session.h>
+#include <drizzled/error.h>
+#include <drizzled/show.h>
+#include <drizzled/item/ref.h>
+#include <drizzled/plugin/client.h>
+#include <drizzled/item/sum.h>
+#include <drizzled/item/subselect.h>
+#include <drizzled/sql_lex.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 Item_ref::Item_ref(Name_resolution_context *context_arg,
                    Item **item, const char *table_name_arg,
@@ -113,7 +114,7 @@ bool Item_ref::fix_fields(Session *session, Item **reference)
 {
   enum_parsing_place place= NO_MATTER;
   assert(fixed == 0);
-  Select_Lex *current_sel= session->lex->current_select;
+  Select_Lex *current_sel= session->lex().current_select;
 
   if (!ref || ref == not_found_item)
   {
@@ -132,7 +133,7 @@ bool Item_ref::fix_fields(Session *session, Item **reference)
       {
         /* The current reference cannot be resolved in this query. */
         my_error(ER_BAD_FIELD_ERROR,MYF(0),
-                 this->full_name(), current_session->where);
+                 full_name(), session->where());
         goto error;
       }
 
@@ -247,7 +248,7 @@ bool Item_ref::fix_fields(Session *session, Item **reference)
                        cached_table->select_lex != outer_context->select_lex);
             }
             prev_subselect_item->used_tables_cache|= from_field->getTable()->map;
-            prev_subselect_item->const_item_cache= 0;
+            prev_subselect_item->const_item_cache= false;
             break;
           }
         }
@@ -255,7 +256,7 @@ bool Item_ref::fix_fields(Session *session, Item **reference)
 
         /* Reference is not found => depend on outer (or just error). */
         prev_subselect_item->used_tables_cache|= OUTER_REF_TABLE_BIT;
-        prev_subselect_item->const_item_cache= 0;
+        prev_subselect_item->const_item_cache= false;
 
         outer_context= outer_context->outer_context;
       } while (outer_context);
@@ -266,18 +267,18 @@ bool Item_ref::fix_fields(Session *session, Item **reference)
         Item_field* fld;
         if (!(fld= new Item_field(from_field)))
           goto error;
-        session->change_item_tree(reference, fld);
+        *reference= fld;
         mark_as_dependent(session, last_checked_context->select_lex,
-                          session->lex->current_select, this, fld);
+                          session->lex().current_select, this, fld);
         /*
           A reference is resolved to a nest level that's outer or the same as
           the nest level of the enclosing set function : adjust the value of
           max_arg_level for the function if it's needed.
         */
-        if (session->lex->in_sum_func &&
-            session->lex->in_sum_func->nest_level >=
+        if (session->lex().in_sum_func &&
+            session->lex().in_sum_func->nest_level >=
             last_checked_context->select_lex->nest_level)
-          set_if_bigger(session->lex->in_sum_func->max_arg_level,
+          set_if_bigger(session->lex().in_sum_func->max_arg_level,
                         last_checked_context->select_lex->nest_level);
         return false;
       }
@@ -285,7 +286,7 @@ bool Item_ref::fix_fields(Session *session, Item **reference)
       {
         /* The item was not a table field and not a reference */
         my_error(ER_BAD_FIELD_ERROR, MYF(0),
-                 this->full_name(), current_session->where);
+                 full_name(), session->where());
         goto error;
       }
       /* Should be checked in resolve_ref_in_select_and_group(). */
@@ -297,10 +298,10 @@ bool Item_ref::fix_fields(Session *session, Item **reference)
         the nest level of the enclosing set function : adjust the value of
         max_arg_level for the function if it's needed.
       */
-      if (session->lex->in_sum_func &&
-          session->lex->in_sum_func->nest_level >=
+      if (session->lex().in_sum_func &&
+          session->lex().in_sum_func->nest_level >=
           last_checked_context->select_lex->nest_level)
-        set_if_bigger(session->lex->in_sum_func->max_arg_level,
+        set_if_bigger(session->lex().in_sum_func->max_arg_level,
                       last_checked_context->select_lex->nest_level);
     }
   }
@@ -368,7 +369,7 @@ void Item_ref::cleanup()
 }
 
 
-void Item_ref::print(String *str, enum_query_type query_type)
+void Item_ref::print(String *str)
 {
   if (ref)
   {
@@ -378,10 +379,10 @@ void Item_ref::print(String *str, enum_query_type query_type)
       str->append_identifier(name, (uint32_t) strlen(name));
     }
     else
-      (*ref)->print(str, query_type);
+      (*ref)->print(str);
   }
   else
-    Item_ident::print(str, query_type);
+    Item_ident::print(str);
 }
 
 
@@ -430,7 +431,7 @@ String *Item_ref::str_result(String* str)
 }
 
 
-my_decimal *Item_ref::val_decimal_result(my_decimal *decimal_value)
+type::Decimal *Item_ref::val_decimal_result(type::Decimal *decimal_value)
 {
   if (result_field)
   {
@@ -451,22 +452,25 @@ bool Item_ref::val_bool_result()
     switch (result_field->result_type()) {
     case INT_RESULT:
       return result_field->val_int() != 0;
+
     case DECIMAL_RESULT:
-    {
-      my_decimal decimal_value;
-      my_decimal *val= result_field->val_decimal(&decimal_value);
-      if (val)
-        return !my_decimal_is_zero(val);
-      return 0;
-    }
+      {
+        type::Decimal decimal_value;
+        type::Decimal *val= result_field->val_decimal(&decimal_value);
+        if (val)
+          return not val->isZero();
+        return 0;
+      }
+
     case REAL_RESULT:
     case STRING_RESULT:
       return result_field->val_real() != 0.0;
+
     case ROW_RESULT:
-    default:
       assert(0);
     }
   }
+
   return val_bool();
 }
 
@@ -514,15 +518,15 @@ bool Item_ref::is_null()
 }
 
 
-bool Item_ref::get_date(DRIZZLE_TIME *ltime,uint32_t fuzzydate)
+bool Item_ref::get_date(type::Time &ltime,uint32_t fuzzydate)
 {
   return (null_value=(*ref)->get_date_result(ltime,fuzzydate));
 }
 
 
-my_decimal *Item_ref::val_decimal(my_decimal *decimal_value)
+type::Decimal *Item_ref::val_decimal(type::Decimal *decimal_value)
 {
-  my_decimal *val= (*ref)->val_decimal_result(decimal_value);
+  type::Decimal *val= (*ref)->val_decimal_result(decimal_value);
   null_value= (*ref)->null_value;
   return val;
 }
