@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,10 +17,9 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_REF_H
-#define DRIZZLED_ITEM_REF_H
+#pragma once
 
-#include "drizzled/item/ident.h"
+#include <drizzled/item/ident.h>
 
 namespace drizzled
 {
@@ -67,15 +66,15 @@ public:
   }
   double val_real();
   int64_t val_int();
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   bool val_bool();
   String *val_str(String* tmp);
   bool is_null();
-  bool get_date(DRIZZLE_TIME *ltime,uint32_t fuzzydate);
+  bool get_date(type::Time &ltime,uint32_t fuzzydate);
   double val_result();
   int64_t val_int_result();
   String *str_result(String* tmp);
-  my_decimal *val_decimal_result(my_decimal *);
+  type::Decimal *val_decimal_result(type::Decimal *);
   bool val_bool_result();
   bool send(plugin::Client *client, String *tmp);
   void make_field(SendField *field);
@@ -114,7 +113,7 @@ public:
   }
   bool walk(Item_processor processor, bool walk_subquery, unsigned char *arg)
   { return (*ref)->walk(processor, walk_subquery, arg); }
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   bool result_as_int64_t()
   {
     return (*ref)->result_as_int64_t();
@@ -157,4 +156,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_REF_H */
