@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,10 +17,12 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
+
 #include <drizzled/item/ref.h>
 #include <drizzled/item/ref_null_helper.h>
 #include <drizzled/item/subselect.h>
+#include <drizzled/lex_string.h>
 
 namespace drizzled
 {
@@ -43,10 +45,10 @@ int64_t Item_ref_null_helper::val_int()
 }
 
 
-my_decimal *Item_ref_null_helper::val_decimal(my_decimal *decimal_value)
+type::Decimal *Item_ref_null_helper::val_decimal(type::Decimal *decimal_value)
 {
   assert(fixed == 1);
-  my_decimal *val= (*ref)->val_decimal_result(decimal_value);
+  type::Decimal *val= (*ref)->val_decimal_result(decimal_value);
   owner->was_null|= null_value= (*ref)->null_value;
   return val;
 }
@@ -68,16 +70,16 @@ String* Item_ref_null_helper::val_str(String* s)
   return tmp;
 }
 
-bool Item_ref_null_helper::get_date(DRIZZLE_TIME *ltime, uint32_t fuzzydate)
+bool Item_ref_null_helper::get_date(type::Time &ltime, uint32_t fuzzydate)
 {
   return (owner->was_null|= null_value= (*ref)->get_date(ltime, fuzzydate));
 }
 
-void Item_ref_null_helper::print(String *str, enum_query_type query_type)
+void Item_ref_null_helper::print(String *str)
 {
   str->append(STRING_WITH_LEN("<ref_null_helper>("));
   if (ref)
-    (*ref)->print(str, query_type);
+    (*ref)->print(str);
   else
     str->append('?');
   str->append(')');
