@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,10 +17,10 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_STRING_H
-#define DRIZZLED_ITEM_STRING_H
+#pragma once
 
 #include <drizzled/item/basic_constant.h>
+#include <drizzled/charset_info.h>
 
 namespace drizzled
 {
@@ -77,7 +77,7 @@ public:
     assert(fixed == 1);
     return (String*) &str_value;
   }
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   int save_in_field(Field *field, bool no_conversions);
   enum Item_result result_type () const { return STRING_RESULT; }
   enum_field_types field_type() const { return DRIZZLE_TYPE_VARCHAR; }
@@ -94,7 +94,7 @@ public:
     str_value.append(str, length);
     max_length= str_value.numchars() * collation.collation->mbmaxlen;
   }
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
 
   /**
     Return true if character-set-introducer was explicitly specified in the
@@ -151,7 +151,7 @@ public:
   {}
   Item *safe_charset_converter(const CHARSET_INFO * const tocs);
 
-  virtual inline void print(String *str, enum_query_type)
+  virtual inline void print(String *str)
   {
     str->append(func_name);
   }
@@ -159,4 +159,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_STRING_H */
