@@ -11,7 +11,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /**
   @file
@@ -20,14 +20,15 @@
   subselect Item
 
   @todo
-    - add function from mysql_select that use JOIN* as parameter to JOIN
+    - add function from select_query that use JOIN* as parameter to JOIN
     methods (sql_select.h/sql_select.cc)
 */
-#include "config.h"
+#include <config.h>
 
 #include <cstdio>
 #include <limits.h>
 
+#include <drizzled/session.h>
 #include <drizzled/sql_select.h>
 #include <drizzled/error.h>
 #include <drizzled/item/cache.h>
@@ -39,9 +40,14 @@
 #include <drizzled/item/ref_null_helper.h>
 #include <drizzled/item/direct_ref.h>
 #include <drizzled/join.h>
+#include <drizzled/plugin/storage_engine.h>
+#include <drizzled/select_singlerow_subselect.h>
+#include <drizzled/select_max_min_finder_subselect.h>
+#include <drizzled/select_exists_subselect.h>
+#include <drizzled/select_union.h>
+#include <drizzled/sql_lex.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 extern plugin::StorageEngine *myisam_engine;
 
@@ -180,8 +186,7 @@ Item_subselect::select_transformer(Join *)
 
 bool Item_subselect::fix_fields(Session *session_param, Item **ref)
 {
-  char const *save_where= session_param->where;
-  uint8_t uncacheable;
+  char const *save_where= session_param->where();
   bool res;
 
   assert(fixed == 0);
@@ -209,19 +214,28 @@ bool Item_subselect::fix_fields(Session *session_param, Item **ref)
 
       // did we changed top item of WHERE condition
       if (unit->outer_select()->where == (*ref))
-	unit->outer_select()->where= substitution; // correct WHERE for PS
+      {
+        unit->outer_select()->where= substitution; // correct WHERE for PS
+      }
       else if (unit->outer_select()->having == (*ref))
-	unit->outer_select()->having= substitution; // correct HAVING for PS
+      {
+        unit->outer_select()->having= substitution; // correct HAVING for PS
+      }
 
       (*ref)= substitution;
       substitution->name= name;
       if (have_to_be_excluded)
-	engine->exclude();
+      {
+        engine->exclude();
+      }
       substitution= 0;
-      session->where= "checking transformed subquery";
-      if (!(*ref)->fixed)
-	ret= (*ref)->fix_fields(session, ref);
-      session->where= save_where;
+      session->setWhere("checking transformed subquery");
+      if (! (*ref)->fixed)
+      {
+        ret= (*ref)->fix_fields(session, ref);
+      }
+      session->setWhere(save_where);
+
       return ret;
     }
     // Is it one field subselect?
@@ -235,16 +249,18 @@ bool Item_subselect::fix_fields(Session *session_param, Item **ref)
   else
     goto err;
 
-  if ((uncacheable= engine->uncacheable()))
+  if (engine->uncacheable())
   {
-    const_item_cache= 0;
-    if (uncacheable & UNCACHEABLE_RAND)
+    const_item_cache= false;
+    if (engine->uncacheable(UNCACHEABLE_RAND))
+    {
       used_tables_cache|= RAND_TABLE_BIT;
+    }
   }
   fixed= 1;
 
 err:
-  session->where= save_where;
+  session->setWhere(save_where);
   return res;
 }
 
@@ -257,9 +273,9 @@ bool Item_subselect::walk(Item_processor processor, bool walk_subquery,
   {
     for (Select_Lex *lex= unit->first_select(); lex; lex= lex->next_select())
     {
-      List_iterator<Item> li(lex->item_list);
+      List<Item>::iterator li(lex->item_list.begin());
       Item *item;
-      order_st *order;
+      Order *order;
 
       if (lex->where && (lex->where)->walk(processor, walk_subquery, argument))
         return 1;
@@ -272,12 +288,12 @@ bool Item_subselect::walk(Item_processor processor, bool walk_subquery,
         if (item->walk(processor, walk_subquery, argument))
           return 1;
       }
-      for (order= (order_st*) lex->order_list.first ; order; order= order->next)
+      for (order= (Order*) lex->order_list.first ; order; order= order->next)
       {
         if ((*order->item)->walk(processor, walk_subquery, argument))
           return 1;
       }
-      for (order= (order_st*) lex->group_list.first ; order; order= order->next)
+      for (order= (Order*) lex->group_list.first ; order; order= order->next)
       {
         if ((*order->item)->walk(processor, walk_subquery, argument))
           return 1;
@@ -381,19 +397,19 @@ Item *Item_subselect::get_tmp_table_item(Session *session_arg)
 
 void Item_subselect::update_used_tables()
 {
-  if (!engine->uncacheable())
+  if (! engine->uncacheable())
   {
     // did all used tables become static?
     if (!(used_tables_cache & ~engine->upper_select_const_tables()))
-      const_item_cache= 1;
+      const_item_cache= true;
   }
 }
 
 
-void Item_subselect::print(String *str, enum_query_type query_type)
+void Item_subselect::print(String *str)
 {
   str->append('(');
-  engine->print(str, query_type);
+  engine->print(str);
   str->append(')');
 }
 
@@ -471,10 +487,10 @@ void Item_maxmin_subselect::cleanup()
 }
 
 
-void Item_maxmin_subselect::print(String *str, enum_query_type query_type)
+void Item_maxmin_subselect::print(String *str)
 {
   str->append(max?"<max>":"<min>", 5);
-  Item_singlerow_subselect::print(str, query_type);
+  Item_singlerow_subselect::print(str);
 }
 
 
@@ -506,8 +522,8 @@ Item_singlerow_subselect::select_transformer(Join *join)
 
   if (!select_lex->master_unit()->is_union() &&
       !select_lex->table_list.elements &&
-      select_lex->item_list.elements == 1 &&
-      !select_lex->item_list.head()->with_sum_func &&
+      select_lex->item_list.size() == 1 &&
+      !select_lex->item_list.front().with_sum_func &&
       /*
 	We cant change name of Item_field or Item_ref, because it will
 	prevent it's correct resolving, but we should save name of
@@ -515,21 +531,21 @@ Item_singlerow_subselect::select_transformer(Join *join)
 	list is field or reference.
 	TODO: solve above problem
       */
-      !(select_lex->item_list.head()->type() == FIELD_ITEM ||
-	select_lex->item_list.head()->type() == REF_ITEM) &&
+      !(select_lex->item_list.front().type() == FIELD_ITEM ||
+	select_lex->item_list.front().type() == REF_ITEM) &&
       !join->conds && !join->having
       )
   {
 
     have_to_be_excluded= 1;
-    if (session->lex->describe)
+    if (session->lex().describe)
     {
       char warn_buff[DRIZZLE_ERRMSG_SIZE];
       snprintf(warn_buff, sizeof(warn_buff), ER(ER_SELECT_REDUCED), select_lex->select_number);
       push_warning(session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
 		   ER_SELECT_REDUCED, warn_buff);
     }
-    substitution= select_lex->item_list.head();
+    substitution= &select_lex->item_list.front();
     /*
       as far as we moved content to upper level, field which depend of
       'upper' select is not really dependent => we remove this dependence
@@ -659,7 +675,7 @@ String *Item_singlerow_subselect::val_str(String *str)
 }
 
 
-my_decimal *Item_singlerow_subselect::val_decimal(my_decimal *decimal_value)
+type::Decimal *Item_singlerow_subselect::val_decimal(type::Decimal *decimal_value)
 {
   if (!exec() && !value->null_value)
   {
@@ -702,10 +718,10 @@ Item_exists_subselect::Item_exists_subselect(Select_Lex *select_lex):
 }
 
 
-void Item_exists_subselect::print(String *str, enum_query_type query_type)
+void Item_exists_subselect::print(String *str)
 {
   str->append(STRING_WITH_LEN("exists"));
-  Item_subselect::print(str, query_type);
+  Item_subselect::print(str);
 }
 
 
@@ -809,7 +825,7 @@ String *Item_exists_subselect::val_str(String *str)
 }
 
 
-my_decimal *Item_exists_subselect::val_decimal(my_decimal *decimal_value)
+type::Decimal *Item_exists_subselect::val_decimal(type::Decimal *decimal_value)
 {
   assert(fixed == 1);
   if (exec())
@@ -817,7 +833,7 @@ my_decimal *Item_exists_subselect::val_decimal(my_decimal *decimal_value)
     reset();
     return 0;
   }
-  int2my_decimal(E_DEC_FATAL_ERROR, value, 0, decimal_value);
+  int2_class_decimal(E_DEC_FATAL_ERROR, value, 0, decimal_value);
   return decimal_value;
 }
 
@@ -920,7 +936,7 @@ bool Item_in_subselect::val_bool()
   return value;
 }
 
-my_decimal *Item_in_subselect::val_decimal(my_decimal *decimal_value)
+type::Decimal *Item_in_subselect::val_decimal(type::Decimal *decimal_value)
 {
   /*
     As far as Item_in_subselect called only from Item_in_optimizer this
@@ -937,7 +953,7 @@ my_decimal *Item_in_subselect::val_decimal(my_decimal *decimal_value)
   }
   if (was_null && !value)
     null_value= 1;
-  int2my_decimal(E_DEC_FATAL_ERROR, value, 0, decimal_value);
+  int2_class_decimal(E_DEC_FATAL_ERROR, value, 0, decimal_value);
   return decimal_value;
 }
 
@@ -986,7 +1002,7 @@ Item_in_subselect::single_value_transformer(Join *join,
     Check that the right part of the subselect contains no more than one
     column. E.g. in SELECT 1 IN (SELECT * ..) the right part is (SELECT * ...)
   */
-  if (select_lex->item_list.elements > 1)
+  if (select_lex->item_list.size() > 1)
   {
     my_error(ER_OPERAND_COLUMNS, MYF(0), 1);
     return(RES_ERROR);
@@ -1004,7 +1020,7 @@ Item_in_subselect::single_value_transformer(Join *join,
     later in this method.
   */
   if ((abort_on_null || (upper_item && upper_item->top_level())) &&
-      !select_lex->master_unit()->uncacheable && !func->eqne_op())
+      select_lex->master_unit()->uncacheable.none() && !func->eqne_op())
   {
     if (substitution)
     {
@@ -1041,13 +1057,13 @@ Item_in_subselect::single_value_transformer(Join *join,
         upper_item->set_sum_test(item);
       *select_lex->ref_pointer_array= item;
       {
-	List_iterator<Item> it(select_lex->item_list);
+	List<Item>::iterator it(select_lex->item_list.begin());
 	it++;
 	it.replace(item);
       }
 
-      save_allow_sum_func= session->lex->allow_sum_func;
-      session->lex->allow_sum_func|= 1 << session->lex->current_select->nest_level;
+      save_allow_sum_func= session->lex().allow_sum_func;
+      session->lex().allow_sum_func|= 1 << session->lex().current_select->nest_level;
       /*
 	Item_sum_(max|min) can't substitute other item => we can use 0 as
         reference, also Item_sum_(max|min) can't be fixed after creation, so
@@ -1055,7 +1071,7 @@ Item_in_subselect::single_value_transformer(Join *join,
       */
       if (item->fix_fields(session, 0))
 	return(RES_ERROR);
-      session->lex->allow_sum_func= save_allow_sum_func;
+      session->lex().allow_sum_func= save_allow_sum_func;
       /* we added aggregate function => we have to change statistic */
       count_field_types(select_lex, &join->tmp_table_param, join->all_fields,
                         0);
@@ -1080,16 +1096,16 @@ Item_in_subselect::single_value_transformer(Join *join,
     Select_Lex_Unit *master_unit= select_lex->master_unit();
     substitution= optimizer;
 
-    Select_Lex *current= session->lex->current_select, *up;
+    Select_Lex *current= session->lex().current_select, *up;
 
-    session->lex->current_select= up= current->return_after_parsing();
+    session->lex().current_select= up= current->return_after_parsing();
     //optimizer never use Item **ref => we can pass 0 as parameter
     if (!optimizer || optimizer->fix_left(session, 0))
     {
-      session->lex->current_select= current;
+      session->lex().current_select= current;
       return(RES_ERROR);
     }
-    session->lex->current_select= current;
+    session->lex().current_select= current;
 
     /*
       As far as  Item_ref_in_optimizer do not substitute itself on fix_fields
@@ -1100,12 +1116,12 @@ Item_in_subselect::single_value_transformer(Join *join,
 			      (char *)"<no matter>",
 			      (char *)in_left_expr_name);
 
-    master_unit->uncacheable|= UNCACHEABLE_DEPENDENT;
+    master_unit->uncacheable.set(UNCACHEABLE_DEPENDENT);
   }
 
   if (!abort_on_null && left_expr->maybe_null && !pushed_cond_guards)
   {
-    if (!(pushed_cond_guards= (bool*)join->session->alloc(sizeof(bool))))
+    if (!(pushed_cond_guards= (bool*)join->session->getMemRoot()->allocate(sizeof(bool))))
       return(RES_ERROR);
     pushed_cond_guards[0]= true;
   }
@@ -1163,7 +1179,7 @@ Item_in_subselect::single_value_in_to_exists_transformer(Join * join, const Comp
 {
   Select_Lex *select_lex= join->select_lex;
 
-  select_lex->uncacheable|= UNCACHEABLE_DEPENDENT;
+  select_lex->uncacheable.set(UNCACHEABLE_DEPENDENT);
   if (join->having || select_lex->with_sum_func ||
       select_lex->group_list.elements)
   {
@@ -1192,6 +1208,7 @@ Item_in_subselect::single_value_in_to_exists_transformer(Join * join, const Comp
     select_lex->having= join->having= and_items(join->having, item);
     if (join->having == item)
       item->name= (char*)in_having_cond;
+    select_lex->having->top_level_item();
     select_lex->having_fix_field= 1;
     /*
       we do not check join->having->fixed, because Item_and (from and_items)
@@ -1204,17 +1221,17 @@ Item_in_subselect::single_value_in_to_exists_transformer(Join * join, const Comp
   }
   else
   {
-    Item *item= (Item*) select_lex->item_list.head();
+    Item *item= &select_lex->item_list.front();
 
     if (select_lex->table_list.elements)
     {
       bool tmp;
       Item *having= item, *orig_item= item;
-      select_lex->item_list.empty();
+      select_lex->item_list.clear();
       select_lex->item_list.push_back(new Item_int("Not_used",
                                                    (int64_t) 1,
                                                    MY_INT64_NUM_DECIMAL_DIGITS));
-      select_lex->ref_pointer_array[0]= select_lex->item_list.head();
+      select_lex->ref_pointer_array[0]= &select_lex->item_list.front();
 
       item= func->create(expr, item);
       if (!abort_on_null && orig_item->maybe_null)
@@ -1318,7 +1335,7 @@ Item_in_subselect::single_value_in_to_exists_transformer(Join * join, const Comp
 	// fix_field of item will be done in time of substituting
 	substitution= item;
 	have_to_be_excluded= 1;
-	if (session->lex->describe)
+	if (session->lex().describe)
 	{
 	  char warn_buff[DRIZZLE_ERRMSG_SIZE];
 	  snprintf(warn_buff, sizeof(warn_buff), ER(ER_SELECT_REDUCED), select_lex->select_number);
@@ -1340,7 +1357,7 @@ Item_in_subselect::row_value_transformer(Join *join)
   Select_Lex *select_lex= join->select_lex;
   uint32_t cols_num= left_expr->cols();
 
-  if (select_lex->item_list.elements != left_expr->cols())
+  if (select_lex->item_list.size() != left_expr->cols())
   {
     my_error(ER_OPERAND_COLUMNS, MYF(0), left_expr->cols());
     return(RES_ERROR);
@@ -1356,24 +1373,24 @@ Item_in_subselect::row_value_transformer(Join *join)
     Select_Lex_Unit *master_unit= select_lex->master_unit();
     substitution= optimizer;
 
-    Select_Lex *current= session->lex->current_select, *up;
-    session->lex->current_select= up= current->return_after_parsing();
+    Select_Lex *current= session->lex().current_select, *up;
+    session->lex().current_select= up= current->return_after_parsing();
     //optimizer never use Item **ref => we can pass 0 as parameter
     if (!optimizer || optimizer->fix_left(session, 0))
     {
-      session->lex->current_select= current;
+      session->lex().current_select= current;
       return(RES_ERROR);
     }
 
     // we will refer to upper level cache array => we have to save it in PS
     optimizer->keep_top_level_cache();
 
-    session->lex->current_select= current;
-    master_unit->uncacheable|= UNCACHEABLE_DEPENDENT;
+    session->lex().current_select= current;
+    master_unit->uncacheable.set(UNCACHEABLE_DEPENDENT);
 
     if (!abort_on_null && left_expr->maybe_null && !pushed_cond_guards)
     {
-      if (!(pushed_cond_guards= (bool*)join->session->alloc(sizeof(bool) *
+      if (!(pushed_cond_guards= (bool*)join->session->getMemRoot()->allocate(sizeof(bool) *
                                                         left_expr->cols())))
         return(RES_ERROR);
       for (uint32_t i= 0; i < cols_num; i++)
@@ -1421,7 +1438,7 @@ Item_in_subselect::row_value_in_to_exists_transformer(Join * join)
                         select_lex->group_list.first ||
                         !select_lex->table_list.elements);
 
-  select_lex->uncacheable|= UNCACHEABLE_DEPENDENT;
+  select_lex->uncacheable.set(UNCACHEABLE_DEPENDENT);
   if (is_having_used)
   {
     /*
@@ -1640,8 +1657,8 @@ Item_in_subselect::select_transformer(Join *join)
 Item_subselect::trans_res
 Item_in_subselect::select_in_like_transformer(Join *join, const Comp_creator *func)
 {
-  Select_Lex *current= session->lex->current_select, *up;
-  const char *save_where= session->where;
+  Select_Lex *current= session->lex().current_select, *up;
+  const char *save_where= session->where();
   Item_subselect::trans_res res= RES_ERROR;
   bool result;
 
@@ -1661,7 +1678,7 @@ Item_in_subselect::select_in_like_transformer(Join *join, const Comp_creator *fu
   if (changed)
     return(RES_OK);
 
-  session->where= "IN/ALL/ANY subquery";
+  session->setWhere("IN/ALL/ANY subquery");
 
   /*
     In some optimisation cases we will not need this Item_in_optimizer
@@ -1675,13 +1692,13 @@ Item_in_subselect::select_in_like_transformer(Join *join, const Comp_creator *fu
       goto err;
   }
 
-  session->lex->current_select= up= current->return_after_parsing();
+  session->lex().current_select= up= current->return_after_parsing();
   result= (!left_expr->fixed &&
            left_expr->fix_fields(session, optimizer->arguments()));
   /* fix_fields can change reference to left_expr, we need reassign it */
   left_expr= optimizer->arguments()[0];
 
-  session->lex->current_select= current;
+  session->lex().current_select= current;
   if (result)
     goto err;
 
@@ -1712,21 +1729,21 @@ Item_in_subselect::select_in_like_transformer(Join *join, const Comp_creator *fu
     res= row_value_transformer(join);
   }
 err:
-  session->where= save_where;
+  session->setWhere(save_where);
   return(res);
 }
 
 
-void Item_in_subselect::print(String *str, enum_query_type query_type)
+void Item_in_subselect::print(String *str)
 {
   if (exec_method == IN_TO_EXISTS)
     str->append(STRING_WITH_LEN("<exists>"));
   else
   {
-    left_expr->print(str, query_type);
+    left_expr->print(str);
     str->append(STRING_WITH_LEN(" in "));
   }
-  Item_subselect::print(str, query_type);
+  Item_subselect::print(str);
 }
 
 
@@ -1889,18 +1906,18 @@ Item_allany_subselect::select_transformer(Join *join)
 }
 
 
-void Item_allany_subselect::print(String *str, enum_query_type query_type)
+void Item_allany_subselect::print(String *str)
 {
   if (exec_method == IN_TO_EXISTS)
     str->append(STRING_WITH_LEN("<exists>"));
   else
   {
-    left_expr->print(str, query_type);
+    left_expr->print(str);
     str->append(' ');
     str->append(func->symbol(all));
     str->append(all ? " all " : " any ", 5);
   }
-  Item_subselect::print(str, query_type);
+  Item_subselect::print(str);
 }
 
 
@@ -2022,20 +2039,20 @@ int subselect_single_select_engine::prepare()
   if (!join || !result)
     return 1; /* Fatal error is set already. */
   prepared= 1;
-  Select_Lex *save_select= session->lex->current_select;
-  session->lex->current_select= select_lex;
+  Select_Lex *save_select= session->lex().current_select;
+  session->lex().current_select= select_lex;
   if (join->prepare(&select_lex->ref_pointer_array,
 		    (TableList*) select_lex->table_list.first,
 		    select_lex->with_wild,
 		    select_lex->where,
 		    select_lex->order_list.elements +
 		    select_lex->group_list.elements,
-		    (order_st*) select_lex->order_list.first,
-		    (order_st*) select_lex->group_list.first,
+		    (Order*) select_lex->order_list.first,
+		    (Order*) select_lex->group_list.first,
 		    select_lex->having,
 		    select_lex, select_lex->master_unit()))
     return 1;
-  session->lex->current_select= save_select;
+  session->lex().current_select= save_select;
   return 0;
 }
 
@@ -2080,7 +2097,7 @@ bool subselect_single_select_engine::no_rows()
 void subselect_engine::set_row(List<Item> &item_list, Item_cache **row)
 {
   Item *sel_item;
-  List_iterator_fast<Item> li(item_list);
+  List<Item>::iterator li(item_list.begin());
   res_type= STRING_RESULT;
   res_field_type= DRIZZLE_TYPE_VARCHAR;
   for (uint32_t i= 0; (sel_item= li++); i++)
@@ -2095,13 +2112,13 @@ void subselect_engine::set_row(List<Item> &item_list, Item_cache **row)
       return;
     row[i]->setup(sel_item);
   }
-  if (item_list.elements > 1)
+  if (item_list.size() > 1)
     res_type= ROW_RESULT;
 }
 
 void subselect_single_select_engine::fix_length_and_dec(Item_cache **row)
 {
-  assert(row || select_lex->item_list.elements==1);
+  assert(row || select_lex->item_list.size() == 1);
   set_row(select_lex->item_list, row);
   item->collation.set(row[0]->collation);
   if (cols() != 1)
@@ -2110,9 +2127,9 @@ void subselect_single_select_engine::fix_length_and_dec(Item_cache **row)
 
 void subselect_union_engine::fix_length_and_dec(Item_cache **row)
 {
-  assert(row || unit->first_select()->item_list.elements==1);
+  assert(row || unit->first_select()->item_list.size() == 1);
 
-  if (unit->first_select()->item_list.elements == 1)
+  if (unit->first_select()->item_list.size() == 1)
   {
     set_row(unit->types, row);
     item->collation.set(row[0]->collation);
@@ -2131,15 +2148,11 @@ void subselect_uniquesubquery_engine::fix_length_and_dec(Item_cache **)
   assert(0);
 }
 
-int  init_read_record_seq(JoinTable *tab);
-int join_read_always_key_or_null(JoinTable *tab);
-int join_read_next_same_or_null(ReadRecord *info);
-
 int subselect_single_select_engine::exec()
 {
-  char const *save_where= session->where;
-  Select_Lex *save_select= session->lex->current_select;
-  session->lex->current_select= select_lex;
+  char const *save_where= session->where();
+  Select_Lex *save_select= session->lex().current_select;
+  session->lex().current_select= select_lex;
   if (!join->optimized)
   {
     Select_Lex_Unit *unit= select_lex->master_unit();
@@ -2147,40 +2160,28 @@ int subselect_single_select_engine::exec()
     unit->set_limit(unit->global_parameters);
     if (join->optimize())
     {
-      session->where= save_where;
+      session->setWhere(save_where);
       executed= 1;
-      session->lex->current_select= save_select;
+      session->lex().current_select= save_select;
       return(join->error ? join->error : 1);
     }
-    if (!select_lex->uncacheable && session->lex->describe &&
-        !(join->select_options & SELECT_DESCRIBE) &&
-        join->need_tmp && item->const_item())
-    {
-      /*
-        Force join->join_tmp creation, because this subquery will be replaced
-        by a simple select from the materialization temp table by optimize()
-        called by EXPLAIN and we need to preserve the initial query structure
-        so we can display it.
-       */
-      select_lex->uncacheable|= UNCACHEABLE_EXPLAIN;
-      select_lex->master_unit()->uncacheable|= UNCACHEABLE_EXPLAIN;
-      if (join->init_save_join_tab())
-        return(1);
-    }
+    if (save_join_if_explain())
+     return(1);
+
     if (item->engine_changed)
     {
       return(1);
     }
   }
-  if (select_lex->uncacheable &&
-      select_lex->uncacheable != UNCACHEABLE_EXPLAIN
-      && executed)
+  if (select_lex->uncacheable.any() &&
+      ! select_lex->uncacheable.test(UNCACHEABLE_EXPLAIN) &&
+      executed)
   {
     if (join->reinit())
     {
-      session->where= save_where;
-      session->lex->current_select= save_select;
-      return(1);
+      session->setWhere(save_where);
+      session->lex().current_select= save_select;
+      return 1;
     }
     item->reset();
     item->assigned((executed= 0));
@@ -2237,20 +2238,59 @@ int subselect_single_select_engine::exec()
       tab->read_record.read_record= tab->save_read_record;
     }
     executed= 1;
-    session->where= save_where;
-    session->lex->current_select= save_select;
+    session->setWhere(save_where);
+    session->lex().current_select= save_select;
     return(join->error||session->is_fatal_error);
   }
-  session->where= save_where;
-  session->lex->current_select= save_select;
+  session->setWhere(save_where);
+  session->lex().current_select= save_select;
   return(0);
 }
 
+bool 
+subselect_single_select_engine::save_join_if_explain()
+{
+  /*
+    Save this JOIN to join->tmp_join since the original layout will be
+    replaced when JOIN::exec() calls make_simple_join() if:
+     1) We are executing an EXPLAIN query
+     2) An uncacheable flag has not been set for the select_lex. If
+        set, JOIN::optimize() has already saved the JOIN
+     3) Call does not come from select_describe()). If it does,
+        JOIN::exec() will not call make_simple_join() and the JOIN we
+        plan to save will not be replaced anyway.
+     4) A temp table is needed. This is what triggers JOIN::exec() to
+        make a replacement JOIN by calling make_simple_join(). 
+     5) The Item_subselect is cacheable
+  */
+  if (session->lex().describe &&                          // 1
+      select_lex->uncacheable.none() &&                  // 2
+      !(join->select_options & SELECT_DESCRIBE) &&       // 3
+      join->need_tmp &&                                  // 4
+      item->const_item())                                // 5
+  {
+    /*
+      Save this JOIN to join->tmp_join since the original layout will
+      be replaced when JOIN::exec() calls make_simple_join() due to
+      need_tmp==TRUE. The original layout is needed so we can describe
+      the query. No need to do this if uncacheable != 0 since in this
+      case the JOIN has already been saved during JOIN::optimize()
+    */
+    select_lex->uncacheable.set(UNCACHEABLE_EXPLAIN);
+    select_lex->master_unit()->uncacheable.set(UNCACHEABLE_EXPLAIN);
+    if (join->init_save_join_tab())
+      return true;
+  }
+  return false;
+}
+
+
 int subselect_union_engine::exec()
 {
-  char const *save_where= session->where;
+  char const *save_where= session->where();
   int res= unit->exec();
-  session->where= save_where;
+  session->setWhere(save_where);
+
   return res;
 }
 
@@ -2281,9 +2321,15 @@ int subselect_uniquesubquery_engine::scan_table()
   if (table->cursor->inited)
     table->cursor->endIndexScan();
 
-  table->cursor->startTableScan(1);
+  if ((error= table->cursor->startTableScan(1)))
+  {
+    table->print_error(error, MYF(0));
+    return 1;
+  }
+
+  assert(table->getSession());
   table->cursor->extra_opt(HA_EXTRA_CACHE,
-                           current_session->variables.read_buff_size);
+                           table->getSession()->variables.read_buff_size);
   table->null_row= 0;
   for (;;)
   {
@@ -2458,7 +2504,16 @@ int subselect_uniquesubquery_engine::exec()
     return(scan_table());
 
   if (!table->cursor->inited)
-    table->cursor->startIndexScan(tab->ref.key, 0);
+  {
+    error= table->cursor->startIndexScan(tab->ref.key, 0);
+
+    if (error != 0)
+    {
+      error= table->report_error(error);
+      return (error != 0);
+    }
+  }
+
   error= table->cursor->index_read_map(table->record[0],
                                      tab->ref.key_buff,
                                      make_prev_keypart_map(tab->ref.key_parts),
@@ -2571,7 +2626,15 @@ int subselect_indexsubquery_engine::exec()
     return(scan_table());
 
   if (!table->cursor->inited)
-    table->cursor->startIndexScan(tab->ref.key, 1);
+  {
+    error= table->cursor->startIndexScan(tab->ref.key, 1);
+
+    if (error != 0)
+    {
+      error= table->report_error(error);
+      return(error != 0);
+    }
+  }
   error= table->cursor->index_read_map(table->record[0],
                                      tab->ref.key_buff,
                                      make_prev_keypart_map(tab->ref.key_parts),
@@ -2623,25 +2686,37 @@ int subselect_indexsubquery_engine::exec()
 
 uint32_t subselect_single_select_engine::cols()
 {
-  return select_lex->item_list.elements;
+  return select_lex->item_list.size();
 }
 
 
 uint32_t subselect_union_engine::cols()
 {
-  return unit->types.elements;
+  return unit->types.size();
 }
 
 
-uint8_t subselect_single_select_engine::uncacheable()
+bool subselect_single_select_engine::uncacheable()
 {
-  return select_lex->uncacheable;
+  return select_lex->uncacheable.any();
 }
 
 
-uint8_t subselect_union_engine::uncacheable()
+bool subselect_single_select_engine::uncacheable(uint32_t bit_pos)
 {
-  return unit->uncacheable;
+  return select_lex->uncacheable.test(bit_pos);
+}
+
+
+bool subselect_union_engine::uncacheable()
+{
+  return unit->uncacheable.any();
+}
+
+
+bool subselect_union_engine::uncacheable(uint32_t bit_pos)
+{
+  return unit->uncacheable.test(bit_pos);
 }
 
 
@@ -2689,25 +2764,23 @@ table_map subselect_union_engine::upper_select_const_tables()
 }
 
 
-void subselect_single_select_engine::print(String *str,
-                                           enum_query_type query_type)
+void subselect_single_select_engine::print(String *str)
 {
-  select_lex->print(session, str, query_type);
+  select_lex->print(session, str);
 }
 
 
-void subselect_union_engine::print(String *str, enum_query_type query_type)
+void subselect_union_engine::print(String *str)
 {
-  unit->print(str, query_type);
+  unit->print(str);
 }
 
 
-void subselect_uniquesubquery_engine::print(String *str,
-                                            enum_query_type query_type)
+void subselect_uniquesubquery_engine::print(String *str)
 {
-  char *table_name= const_cast<char *>(tab->table->getShare()->getTableName());
+  const char *table_name= tab->table->getShare()->getTableName();
   str->append(STRING_WITH_LEN("<primary_index_lookup>("));
-  tab->ref.items[0]->print(str, query_type);
+  tab->ref.items[0]->print(str);
   str->append(STRING_WITH_LEN(" in "));
   if (tab->table->getShare()->isTemporaryCategory())
   {
@@ -2725,7 +2798,7 @@ void subselect_uniquesubquery_engine::print(String *str,
   if (cond)
   {
     str->append(STRING_WITH_LEN(" where "));
-    cond->print(str, query_type);
+    cond->print(str);
   }
   str->append(')');
 }
@@ -2754,11 +2827,10 @@ void subselect_uniquesubquery_engine::print(String *str)
 }
 */
 
-void subselect_indexsubquery_engine::print(String *str,
-                                           enum_query_type query_type)
+void subselect_indexsubquery_engine::print(String *str)
 {
   str->append(STRING_WITH_LEN("<index_lookup>("));
-  tab->ref.items[0]->print(str, query_type);
+  tab->ref.items[0]->print(str);
   str->append(STRING_WITH_LEN(" in "));
   str->append(tab->table->getShare()->getTableName(), tab->table->getShare()->getTableNameSize());
   KeyInfo *key_info= tab->table->key_info+ tab->ref.key;
@@ -2769,12 +2841,12 @@ void subselect_indexsubquery_engine::print(String *str,
   if (cond)
   {
     str->append(STRING_WITH_LEN(" where "));
-    cond->print(str, query_type);
+    cond->print(str);
   }
   if (having)
   {
     str->append(STRING_WITH_LEN(" having "));
-    having->print(str, query_type);
+    having->print(str);
   }
   str->append(')');
 }
@@ -2987,7 +3059,7 @@ bool subselect_hash_sj_engine::init_permanent(List<Item> *tmp_columns)
     Make sure there is only one index on the temp table, and it doesn't have
     the extra key part created when s->uniques > 0.
   */
-  assert(tmp_table->getShare()->sizeKeys() == 1 && tmp_columns->elements == tmp_key_parts);
+  assert(tmp_table->getShare()->sizeKeys() == 1 && tmp_columns->size() == tmp_key_parts);
 
 
   /* 2. Create/initialize execution related objects. */
@@ -2999,18 +3071,19 @@ bool subselect_hash_sj_engine::init_permanent(List<Item> *tmp_columns)
     - here we initialize only those members that are used by
       subselect_uniquesubquery_engine, so these objects are incomplete.
   */
-  if (!(tab= (JoinTable*) session->alloc(sizeof(JoinTable))))
+  if (!(tab= (JoinTable*) session->getMemRoot()->allocate(sizeof(JoinTable))))
     return(true);
+  new (tab) JoinTable();
   tab->table= tmp_table;
   tab->ref.key= 0; /* The only temp table index. */
   tab->ref.key_length= tmp_key->key_length;
   if (!(tab->ref.key_buff=
         (unsigned char*) session->calloc(ALIGN_SIZE(tmp_key->key_length) * 2)) ||
       !(tab->ref.key_copy=
-        (StoredKey**) session->alloc((sizeof(StoredKey*) *
+        (StoredKey**) session->getMemRoot()->allocate((sizeof(StoredKey*) *
                                   (tmp_key_parts + 1)))) ||
       !(tab->ref.items=
-        (Item**) session->alloc(sizeof(Item*) * tmp_key_parts)))
+        (Item**) session->getMemRoot()->allocate(sizeof(Item*) * tmp_key_parts)))
     return(true);
 
   KeyPartInfo *cur_key_part= tmp_key->key_part;
@@ -3111,10 +3184,14 @@ int subselect_hash_sj_engine::exec()
   if (!is_materialized)
   {
     int res= 0;
-    Select_Lex *save_select= session->lex->current_select;
-    session->lex->current_select= materialize_engine->select_lex;
+    Select_Lex *save_select= session->lex().current_select;
+    session->lex().current_select= materialize_engine->select_lex;
     if ((res= materialize_join->optimize()))
       goto err;
+
+    if (materialize_engine->save_join_if_explain())
+      goto err;
+
     materialize_join->exec();
     if ((res= test(materialize_join->error || session->is_fatal_error)))
       goto err;
@@ -3149,7 +3226,7 @@ int subselect_hash_sj_engine::exec()
       tmp_param= NULL;
 
 err:
-    session->lex->current_select= save_select;
+    session->lex().current_select= save_select;
     if (res)
       return(res);
   }
@@ -3165,13 +3242,13 @@ err:
   Print the state of this engine into a string for debugging and views.
 */
 
-void subselect_hash_sj_engine::print(String *str, enum_query_type query_type)
+void subselect_hash_sj_engine::print(String *str)
 {
   str->append(STRING_WITH_LEN(" <materialize> ("));
-  materialize_engine->print(str, query_type);
+  materialize_engine->print(str);
   str->append(STRING_WITH_LEN(" ), "));
   if (tab)
-    subselect_uniquesubquery_engine::print(str, query_type);
+    subselect_uniquesubquery_engine::print(str);
   else
     str->append(STRING_WITH_LEN(
            "<the access method for lookups is not yet created>"
