@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,16 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_SUBSELECT_H
-#define DRIZZLED_ITEM_SUBSELECT_H
+#pragma once
 
 /* subselect Item */
 
 
-#include "drizzled/comp_creator.h"
-#include "drizzled/item/ref.h"
-#include "drizzled/item/field.h"
-#include "drizzled/item/bin_string.h"
+#include <drizzled/comp_creator.h>
+#include <drizzled/item/ref.h>
+#include <drizzled/item/field.h>
+#include <drizzled/item/bin_string.h>
+#include <drizzled/util/test.h>
 
 namespace drizzled
 {
@@ -122,7 +122,7 @@ public:
   inline bool get_const_item_cache() { return const_item_cache; }
   Item *get_tmp_table_item(Session *session);
   void update_used_tables();
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   virtual bool have_guarded_conds() { return false; }
   bool change_engine(subselect_engine *eng)
   {
@@ -182,7 +182,7 @@ public:
   double val_real();
   int64_t val_int ();
   String *val_str (String *);
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   bool val_bool();
   enum Item_result result_type() const;
   enum_field_types field_type() const;
@@ -213,7 +213,6 @@ public:
 };
 
 /* used in static ALL/ANY optimization */
-class select_max_min_finder_subselect;
 class Item_maxmin_subselect :public Item_singlerow_subselect
 {
 protected:
@@ -222,7 +221,7 @@ protected:
 public:
   Item_maxmin_subselect(Session *session, Item_subselect *parent,
 			Select_Lex *select_lex, bool max);
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   void cleanup();
   bool any_value() { return was_values; }
   void register_value() { was_values= true; }
@@ -250,10 +249,10 @@ public:
   int64_t val_int();
   double val_real();
   String *val_str(String*);
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   bool val_bool();
   void fix_length_and_dec();
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
 
   friend class select_exists_subselect;
   friend class subselect_uniquesubquery_engine;
@@ -367,13 +366,13 @@ public:
   int64_t val_int();
   double val_real();
   String *val_str(String*);
-  my_decimal *val_decimal(my_decimal *);
+  type::Decimal *val_decimal(type::Decimal *);
   void update_null_value () { (void) val_bool(); }
   bool val_bool();
   void top_level_item() { abort_on_null=1; }
   inline bool is_top_level_item() { return abort_on_null; }
   bool test_limit(Select_Lex_Unit *unit);
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   bool fix_fields(Session *session, Item **ref);
   bool setup_engine();
   bool init_left_expr_cache();
@@ -401,7 +400,7 @@ public:
   // only ALL subquery has upper not
   subs_type substype() { return all?ALL_SUBS:ANY_SUBS; }
   trans_res select_transformer(Join *join);
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
 };
 
 
@@ -429,7 +428,7 @@ public:
     res_field_type= DRIZZLE_TYPE_VARCHAR;
     maybe_null= 0;
   }
-  virtual ~subselect_engine() {}; // to satisfy compiler
+  virtual ~subselect_engine() {} // to satisfy compiler
   virtual void cleanup()= 0;
 
   /*
@@ -462,14 +461,15 @@ public:
   */
   virtual int exec()= 0;
   virtual uint32_t cols()= 0; /* return number of columns in select */
-  virtual uint8_t uncacheable()= 0; /* query is uncacheable */
+  virtual bool uncacheable()= 0; /* query is uncacheable */
+  virtual bool uncacheable(uint32_t bit_pos)= 0; /* query is uncacheable */
   enum Item_result type() { return res_type; }
   enum_field_types field_type() { return res_field_type; }
   virtual void exclude()= 0;
-  virtual bool may_be_null() { return maybe_null; };
+  virtual bool may_be_null() { return maybe_null; }
   virtual table_map upper_select_const_tables()= 0;
   static table_map calc_const_tables(TableList *);
-  virtual void print(String *str, enum_query_type query_type)= 0;
+  virtual void print(String *str)= 0;
   virtual bool change_result(Item_subselect *si,
                              select_result_interceptor *result)= 0;
   virtual bool no_tables()= 0;
@@ -499,16 +499,18 @@ public:
   void fix_length_and_dec(Item_cache** row);
   int exec();
   uint32_t cols();
-  uint8_t uncacheable();
+  bool uncacheable();
+  bool uncacheable(uint32_t bit_pos);
   void exclude();
   table_map upper_select_const_tables();
-  virtual void print (String *str, enum_query_type query_type);
+  virtual void print (String *str);
   bool change_result(Item_subselect *si, select_result_interceptor *result);
   bool no_tables();
   bool may_be_null();
   bool is_executed() const { return executed; }
   bool no_rows();
   virtual enum_engine_type engine_type() { return SINGLE_SELECT_ENGINE; }
+  bool save_join_if_explain();
 
   friend class subselect_hash_sj_engine;
   friend class Item_in_subselect;
@@ -527,10 +529,11 @@ public:
   void fix_length_and_dec(Item_cache** row);
   int exec();
   uint32_t cols();
-  uint8_t uncacheable();
+  bool uncacheable();
+  bool uncacheable(uint32_t bit_pos);
   void exclude();
   table_map upper_select_const_tables();
-  virtual void print (String *str, enum_query_type query_type);
+  virtual void print (String *str);
   bool change_result(Item_subselect *si, select_result_interceptor *result);
   bool no_tables();
   bool is_executed() const;
@@ -584,10 +587,11 @@ public:
   void fix_length_and_dec(Item_cache** row);
   int exec();
   uint32_t cols() { return 1; }
-  uint8_t uncacheable() { return UNCACHEABLE_DEPENDENT; }
+  bool uncacheable() { return true; }
+  bool uncacheable(uint32_t) { return true; }
   void exclude();
   table_map upper_select_const_tables() { return 0; }
-  virtual void print (String *str, enum_query_type query_type);
+  virtual void print (String *str);
   bool change_result(Item_subselect *si, select_result_interceptor *result);
   bool no_tables();
   int scan_table();
@@ -642,7 +646,7 @@ public:
      having(having_arg)
   {}
   int exec();
-  virtual void print (String *str, enum_query_type query_type);
+  virtual void print (String *str);
   virtual enum_engine_type engine_type() { return INDEXSUBQUERY_ENGINE; }
 };
 
@@ -699,7 +703,7 @@ public:
   void cleanup();
   int prepare() { return 0; }
   int exec();
-  virtual void print (String *str, enum_query_type query_type);
+  virtual void print (String *str);
   uint32_t cols()
   {
     return materialize_engine->cols();
@@ -709,4 +713,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_SUBSELECT_H */
