@@ -19,10 +19,15 @@
 
 #pragma once
 
-namespace drizzled {
-namespace item {
+namespace drizzled
+{
 
-class True : public Boolean
+namespace item
+{
+
+class Boolean;
+
+class True: public Boolean
 {
 public:
   True() :
