@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,15 +17,16 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_TYPE_HOLDER_H
-#define DRIZZLED_ITEM_TYPE_HOLDER_H
+#pragma once
 
 namespace drizzled
 {
 
 typedef struct st_typelib TYPELIB;
 class String;
-class my_decimal;
+namespace type {
+class Decimal;
+}
 class Session;
 class Item;
 
@@ -67,7 +68,7 @@ public:
   enum Type type() const { return TYPE_HOLDER; }
   double val_real();
   int64_t val_int();
-  my_decimal *val_decimal(my_decimal *val);
+  type::Decimal *val_decimal(type::Decimal *val);
   String *val_str(String* val);
 
   /**
@@ -116,4 +117,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_TYPE_HOLDER_H */
