@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ITEM_UINT_H
-#define DRIZZLED_ITEM_UINT_H
+#pragma once
 
 #include <drizzled/item/int.h>
 
@@ -36,11 +35,10 @@ public:
   String *val_str(String*);
   Item *clone_item() { return new Item_uint(name, value, max_length); }
   int save_in_field(Field *field, bool no_conversions);
-  virtual void print(String *str, enum_query_type query_type);
+  virtual void print(String *str);
   Item_num *neg ();
   uint32_t decimal_precision() const { return max_length; }
 };
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ITEM_UINT_H */
