@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,11 +18,10 @@
  */
 
 
-#ifndef DRIZZLED_KEY_PART_SPEC_H
-#define DRIZZLED_KEY_PART_SPEC_H
+#pragma once
 
-#include "drizzled/memory/sql_alloc.h"
-#include "drizzled/lex_string.h"
+#include <drizzled/memory/sql_alloc.h>
+#include <drizzled/lex_string.h>
 
 namespace drizzled
 {
@@ -59,4 +58,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_KEY_PART_SPEC_H */
