@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_KORR_H
-#define DRIZZLED_KORR_H
+#pragma once
 
 
 /*
@@ -42,7 +41,7 @@
                                     ((uint32_t) (unsigned char) (A)[0])))
 #define sint4korr(A)	(*((long *) (A)))
 #define uint2korr(A)	(*((uint16_t *) (A)))
-#if defined(HAVE_purify)
+#if defined(HAVE_VALGRIND)
 #define uint3korr(A)	(uint32_t) (((uint32_t) ((unsigned char) (A)[0])) +\
 				  (((uint32_t) ((unsigned char) (A)[1])) << 8) +\
 				  (((uint32_t) ((unsigned char) (A)[2])) << 16))
@@ -54,7 +53,7 @@
     It means, that you have to provide enough allocated space !
 */
 #define uint3korr(A)	(long) (*((unsigned int *) (A)) & 0xFFFFFF)
-#endif /* HAVE_purify */
+#endif /* HAVE_VALGRIND */
 #define uint4korr(A)	(*((uint32_t *) (A)))
 #define uint8korr(A)	(*((uint64_t *) (A)))
 #define sint8korr(A)	(*((int64_t *) (A)))
@@ -241,4 +240,3 @@ do { doubleget_union _tmp; \
 
 #endif /* WORDS_BIGENDIAN */
 
-#endif /* DRIZZLED_KORR_H */
