@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
  */
 
 
-#ifndef DRIZZLED_LEX_COLUMN_H
-#define DRIZZLED_LEX_COLUMN_H
+#pragma once
 
 namespace drizzled
 {
@@ -29,9 +28,8 @@ class Lex_Column : public memory::SqlAlloc
 public:
   String column;
   uint32_t rights;
-  Lex_Column (const String& x,const  uint& y ): column (x),rights (y) {}
+  Lex_Column (const String& x,const  uint32_t& y ): column (x),rights (y) {}
 };
 
 }
 
-#endif /* DRIZZLED_LEX_COLUMN_H */
