@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_LEX_INPUT_STREAM_H
-#define DRIZZLED_LEX_INPUT_STREAM_H
+#pragma once
 
 /**
   @brief This class represents the character input stream consumed during
@@ -371,7 +370,7 @@ public:
     Starting position of the TEXT_STRING or IDENT in the pre-processed
     buffer.
 
-    NOTE: this member must be used within DRIZZLElex() function only.
+    NOTE: this member must be used within base_sql_lex() function only.
   */
   const char *m_cpp_text_start;
 
@@ -379,7 +378,7 @@ public:
     Ending position of the TEXT_STRING or IDENT in the pre-processed
     buffer.
 
-    NOTE: this member must be used within DRIZZLElex() function only.
+    NOTE: this member must be used within base_sql_lex() function only.
     */
   const char *m_cpp_text_end;
 
@@ -387,4 +386,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_LEX_INPUT_STREAM_H */
