@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,8 +20,7 @@
 
 /* This struct includes all reserved words and functions */
 
-#ifndef DRIZZLED_LEX_SYMBOL_H
-#define DRIZZLED_LEX_SYMBOL_H
+#pragma once
 
 namespace drizzled
 {
@@ -43,11 +42,9 @@ typedef struct st_lex_symbol
   uint32_t   length;
 } LEX_SYMBOL;
 
-
 extern SYM_GROUP sym_group_common;
 extern SYM_GROUP sym_group_geom;
 extern SYM_GROUP sym_group_rtree;
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_LEX_SYMBOL_H */
