@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <pthread.h>
 #include <signal.h>
@@ -44,35 +44,47 @@
 
 #include <boost/filesystem.hpp>
 
-#include "drizzled/plugin.h"
-#include "drizzled/gettext.h"
-#include "drizzled/configmake.h"
-#include "drizzled/session.h"
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/unireg.h"
-#include "drizzled/drizzled.h"
-#include "drizzled/errmsg_print.h"
-#include "drizzled/data_home.h"
-#include "drizzled/plugin/listen.h"
-#include "drizzled/plugin/client.h"
-#include "drizzled/pthread_globals.h"
-#include "drizzled/tztime.h"
-#include "drizzled/signal_handler.h"
-#include "drizzled/replication_services.h"
+#include <drizzled/abort_exception.h>
+#include <drizzled/catalog/local.h>
+#include <drizzled/configmake.h>
+#include <drizzled/data_home.h>
+#include <drizzled/debug.h>
+#include <drizzled/drizzled.h>
+#include <drizzled/errmsg_print.h>
+#include <drizzled/gettext.h>
+#include <drizzled/internal/my_sys.h>
+#include <drizzled/plugin.h>
+#include <drizzled/plugin/client.h>
+#include <drizzled/plugin/listen.h>
+#include <drizzled/plugin/monitored_in_transaction.h>
+#include <drizzled/pthread_globals.h>
+#include <drizzled/replication_services.h>
+#include <drizzled/session.h>
+#include <drizzled/session/cache.h>
+#include <drizzled/signal_handler.h>
+#include <drizzled/transaction_services.h>
+#include <drizzled/tztime.h>
+#include <drizzled/unireg.h>
+#include <drizzled/util/backtrace.h>
+#include <drizzled/current_session.h>
+#include <drizzled/daemon.h>
+#include <drizzled/sql_base.h>
+#include <drizzled/sql_lex.h>
 
 using namespace drizzled;
 using namespace std;
-namespace fs=boost::filesystem;
 
 static pthread_t select_thread;
 static uint32_t thr_kill_signal;
 
+extern bool opt_daemon;
+
 
 /**
   All global error messages are sent here where the first one is stored
   for the client.
 */
-static void my_message_sql(uint32_t error, const char *str, myf MyFlags)
+static void my_message_sql(drizzled::error_t error, const char *str, myf MyFlags)
 {
   Session *session;
   /*
@@ -85,26 +97,27 @@ static void my_message_sql(uint32_t error, const char *str, myf MyFlags)
       session->is_fatal_error= 1;
 
     /*
-      TODO: There are two exceptions mechanism (Session and sp_rcontext),
+      @TODO There are two exceptions mechanism (Session and sp_rcontext),
       this could be improved by having a common stack of handlers.
     */
-    if (session->handle_error(error, str,
-                          DRIZZLE_ERROR::WARN_LEVEL_ERROR))
-      return;;
+    if (session->handle_error(error, str, DRIZZLE_ERROR::WARN_LEVEL_ERROR))
+      return;
 
     /*
-      session->lex->current_select == 0 if lex structure is not inited
+      session->lex().current_select == 0 if lex structure is not inited
       (not query command (COM_QUERY))
     */
-    if (! (session->lex->current_select &&
-        session->lex->current_select->no_error && !session->is_fatal_error))
+    if (! (session->lex().current_select &&
+           session->lex().current_select->no_error && !session->is_fatal_error))
     {
       if (! session->main_da.is_error())            // Return only first message
       {
-        if (error == 0)
+        if (error == EE_OK)
           error= ER_UNKNOWN_ERROR;
+
         if (str == NULL)
           str= ER(error);
+
         session->main_da.set_error_status(error, str);
       }
     }
@@ -118,10 +131,13 @@ static void my_message_sql(uint32_t error, const char *str, myf MyFlags)
       session->no_warnings_for_error= true;
       push_warning(session, DRIZZLE_ERROR::WARN_LEVEL_ERROR, error, str);
       session->no_warnings_for_error= false;
-      }
     }
-    if (!session || MyFlags & ME_NOREFRESH)
-        errmsg_printf(ERRMSG_LVL_ERROR, "%s: %s",internal::my_progname,str);
+  }
+
+  if (not session || MyFlags & ME_NOREFRESH)
+  {
+    errmsg_printf(error::ERROR, "%s: %s",internal::my_progname,str);
+  }
 }
 
 static void init_signals(void)
@@ -129,8 +145,8 @@ static void init_signals(void)
   sigset_t set;
   struct sigaction sa;
 
-  if (!(test_flags.test(TEST_NO_STACKTRACE) || 
-        test_flags.test(TEST_CORE_ON_SIGNAL)))
+  if (not (getDebug().test(debug::NO_STACKTRACE) ||
+        getDebug().test(debug::CORE_ON_SIGNAL)))
   {
     sa.sa_flags = SA_RESETHAND | SA_NODEFER;
     sigemptyset(&sa.sa_mask);
@@ -146,13 +162,13 @@ static void init_signals(void)
     sigaction(SIGFPE, &sa, NULL);
   }
 
-  if (test_flags.test(TEST_CORE_ON_SIGNAL))
+  if (getDebug().test(debug::CORE_ON_SIGNAL))
   {
     /* Change limits so that we will get a core file */
     struct rlimit rl;
     rl.rlim_cur = rl.rlim_max = RLIM_INFINITY;
     if (setrlimit(RLIMIT_CORE, &rl) && global_system_variables.log_warnings)
-        errmsg_printf(ERRMSG_LVL_WARN,
+        errmsg_printf(error::WARN,
                       _("setrlimit could not change the size of core files "
                         "to 'infinity';  We may not be able to generate a "
                         "core file on signals"));
@@ -177,7 +193,7 @@ static void init_signals(void)
 #ifdef SIGTSTP
   sigaddset(&set,SIGTSTP);
 #endif
-  if (test_flags.test(TEST_SIGINT))
+  if (getDebug().test(debug::ALLOW_SIGINT))
   {
     sa.sa_flags= 0;
     sa.sa_handler= drizzled_end_thread_signal;
@@ -195,12 +211,10 @@ static void init_signals(void)
   return;
 }
 
-static void GoogleProtoErrorThrower(google::protobuf::LogLevel level, const char* filename,
-                       int line, const string& message) throw(const char *)
+static void GoogleProtoErrorThrower(google::protobuf::LogLevel level,
+                                    const char* ,
+                                    int, const string& ) throw(const char *)
 {
-  (void)filename;
-  (void)line;
-  (void)message;
   switch(level)
   {
   case google::protobuf::LOGLEVEL_INFO:
@@ -219,13 +233,11 @@ int main(int argc, char **argv)
 # if defined(HAVE_LOCALE_H)
   setlocale(LC_ALL, "");
 # endif
-  bindtextdomain("drizzle", LOCALEDIR);
-  textdomain("drizzle");
+  bindtextdomain("drizzle7", LOCALEDIR);
+  textdomain("drizzle7");
 #endif
 
   module::Registry &modules= module::Registry::singleton();
-  plugin::Client *client;
-  Session *session;
 
   MY_INIT(argv[0]);		// init my_sys library & pthreads
   /* nothing should come before this line ^^^ */
@@ -237,9 +249,26 @@ int main(int argc, char **argv)
 
   /* Function generates error messages before abort */
   error_handler_hook= my_message_sql;
+
   /* init_common_variables must get basic settings such as data_home_dir
      and plugin_load_list. */
-  if (init_common_variables(argc, argv, modules))
+  if (init_basic_variables(argc, argv))
+    unireg_abort(1);				// Will do exit
+
+  if (opt_daemon)
+  {
+    if (signal(SIGHUP, SIG_IGN) == SIG_ERR)
+    {
+      perror("Failed to ignore SIGHUP");
+    }
+    if (daemonize())
+    {
+      fprintf(stderr, "failed to daemon() in order to daemonize\n");
+      exit(EXIT_FAILURE);
+    }
+  }
+
+  if (init_remaining_variables(modules))
     unireg_abort(1);				// Will do exit
 
   /*
@@ -254,11 +283,11 @@ int main(int argc, char **argv)
 
   if (not opt_help)
   {
-    if (chdir(getDataHome().c_str()))
+    if (chdir(getDataHome().file_string().c_str()))
     {
-      errmsg_printf(ERRMSG_LVL_ERROR,
+      errmsg_printf(error::ERROR,
                     _("Data directory %s does not exist\n"),
-                    getDataHome().c_str());
+                    getDataHome().file_string().c_str());
       unireg_abort(1);
     }
     if (mkdir("local", 0700))
@@ -267,19 +296,15 @@ int main(int argc, char **argv)
     }
     if (chdir("local"))
     {
-      errmsg_printf(ERRMSG_LVL_ERROR,
+      errmsg_printf(error::ERROR,
                     _("Local catalog %s/local does not exist\n"),
-                    getDataHome().c_str());
+                    getDataHome().file_string().c_str());
       unireg_abort(1);
     }
-    /* TODO: This is a hack until we can properly support std::string in sys_var*/
-    char **data_home_ptr= getDatadirPtr();
-    fs::path full_data_home_path(fs::system_complete(fs::path(getDataHome())));
-    std::string full_data_home(full_data_home_path.file_string());
-    *data_home_ptr= new char[full_data_home.size()+1] ();
-    memcpy(*data_home_ptr, full_data_home.c_str(), full_data_home.size());
-    getDataHomeCatalog()= "./";
-    getDataHome()= "../";
+
+    boost::filesystem::path &full_data_home= getFullDataHome();
+    full_data_home= boost::filesystem::system_complete(getDataHome());
+    errmsg_printf(error::INFO, "Data Home directory is : %s", full_data_home.native_file_string().c_str());
   }
 
 
@@ -289,8 +314,22 @@ int main(int argc, char **argv)
     server_id= 1;
   }
 
-  if (init_server_components(modules))
+  try
+  {
+    if (init_server_components(modules))
+      DRIZZLE_ABORT;
+  }
+  catch (abort_exception& ex)
+  {
+#if defined(DEBUG)
+    cout << _("Drizzle has receieved an abort event.") << endl;
+    cout << _("In Function: ") << *::boost::get_error_info<boost::throw_function>(ex) << endl;
+    cout << _("In File: ") << *::boost::get_error_info<boost::throw_file>(ex) << endl;
+    cout << _("On Line: ") << *::boost::get_error_info<boost::throw_line>(ex) << endl;
+#endif
     unireg_abort(1);
+  }
+
 
   /**
    * This check must be done after init_server_components for now
@@ -309,51 +348,85 @@ int main(int argc, char **argv)
   if (plugin::Listen::setup())
     unireg_abort(1);
 
-
   assert(plugin::num_trx_monitored_objects > 0);
-  if (drizzle_rm_tmp_tables() ||
-      my_tz_init((Session *)0, default_tz_name))
+  if (drizzle_rm_tmp_tables())
   {
     abort_loop= true;
     select_thread_in_use=0;
     (void) pthread_kill(signal_thread, SIGTERM);
 
-    (void) unlink(pidfile_name);	// Not needed anymore
+    (void) unlink(pid_file.file_string().c_str());	// Not needed anymore
 
-    exit(1);
+    unireg_abort(1);
   }
 
-  errmsg_printf(ERRMSG_LVL_INFO, _(ER(ER_STARTUP)), internal::my_progname,
+  errmsg_printf(error::INFO, _(ER(ER_STARTUP)), internal::my_progname,
                 PANDORA_RELEASE_VERSION, COMPILATION_COMMENT);
 
 
-  /* Listen for new connections and start new session for each connection
+  TransactionServices &transaction_services= TransactionServices::singleton();
+
+  /* Send server startup event */
+  {
+    Session::shared_ptr session;
+
+    if ((session= Session::make_shared(plugin::Listen::getNullClient(), catalog::local())))
+    {
+      currentSession().release();
+      currentSession().reset(session.get());
+
+
+      transaction_services.sendStartupEvent(*session);
+
+      plugin_startup_window(modules, *(session.get()));
+    }
+  }
+
+  if (opt_daemon)
+    daemon_is_ready();
+
+  /*
+    Listen for new connections and start new session for each connection
      accepted. The listen.getClient() method will return NULL when the server
-     should be shutdown. */
+     should be shutdown.
+   */
+  plugin::Client *client;
   while ((client= plugin::Listen::getClient()) != NULL)
   {
-    if (!(session= new Session(client)))
+    Session::shared_ptr session;
+    session= Session::make_shared(client, client->catalog());
+
+    if (not session)
     {
       delete client;
       continue;
     }
 
     /* If we error on creation we drop the connection and delete the session. */
-    if (session->schedule())
+    if (Session::schedule(session))
       Session::unlink(session);
   }
 
-  LOCK_thread_count.lock();
-  select_thread_in_use=0;			// For close_connections
-  LOCK_thread_count.unlock();
+  /* Send server shutdown event */
+  {
+    Session::shared_ptr session;
+
+    if ((session= Session::make_shared(plugin::Listen::getNullClient(), catalog::local())))
+    {
+      currentSession().release();
+      currentSession().reset(session.get());
+      transaction_services.sendShutdownEvent(*session.get());
+    }
+  }
+
+  {
+    boost::mutex::scoped_lock scopedLock(session::Cache::singleton().mutex());
+    select_thread_in_use= false;			// For close_connections
+  }
   COND_thread_count.notify_all();
 
   /* Wait until cleanup is done */
-  {
-    boost::mutex::scoped_lock scopedLock(LOCK_thread_count);
-    while (!ready_to_exit)
-      COND_server_end.wait(scopedLock);
-  }
+  session::Cache::singleton().shutdownSecond();
 
   clean_up(1);
   module::Registry::shutdown();
