@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_MEMORY_MULTI_MALLOC_H
-#define DRIZZLED_MEMORY_MULTI_MALLOC_H
+#pragma once
 
 namespace drizzled
 {
@@ -28,5 +27,4 @@ void* multi_malloc(bool zerofill, ...) __attribute__((malloc));
 } /* namespace memory */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_MEMORY_MULTI_MALLOC_H */
 
