@@ -11,29 +11,29 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 
 /* Mallocs for used in threads */
 
-#include "config.h"
+#include <config.h>
 
 #include <string.h>
 
-#include "drizzled/errmsg_print.h"
-#include "drizzled/memory/sql_alloc.h"
-#include "drizzled/current_session.h"
-#include "drizzled/error.h"
-#include "drizzled/definitions.h"
+#include <drizzled/errmsg_print.h>
+#include <drizzled/memory/sql_alloc.h>
+#include <drizzled/current_session.h>
+#include <drizzled/error.h>
+#include <drizzled/definitions.h>
 
-#include "drizzled/internal/my_sys.h"
+#include <drizzled/internal/my_sys.h>
 
 namespace drizzled
 {
 
 static void sql_alloc_error_handler(void)
 {
-  errmsg_printf(ERRMSG_LVL_ERROR, "%s",ER(ER_OUT_OF_RESOURCES));
+  errmsg_printf(error::ERROR, "%s",ER(ER_OUT_OF_RESOURCES));
 }
 
 void memory::init_sql_alloc(memory::Root *mem_root, size_t block_size, size_t)
