@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,11 +17,14 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_MEMORY_SQL_ALLOC_H
-#define DRIZZLED_MEMORY_SQL_ALLOC_H
+
+
+#pragma once
 
 #include <unistd.h>
-#include "drizzled/memory/root.h"
+#include <drizzled/memory/root.h>
+
+#include <drizzled/visibility.h>
 
 namespace drizzled
 {
@@ -37,7 +40,7 @@ char *sql_strdup(const char *str);
 char *sql_strmake(const char *str, size_t len);
 void *sql_memdup(const void * ptr, size_t size);
 
-class SqlAlloc
+class DRIZZLED_API SqlAlloc
 {
 public:
   static void *operator new(size_t size);
@@ -63,4 +66,3 @@ public:
 }
 }
 
-#endif /* DRIZZLED_MEMORY_SQL_ALLOC_H */
