@@ -1,8 +1,8 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
- *  Copyright (c) 2010 Jay Pipes
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
+ *  Copyright (C) 2010 Jay Pipes
  *
  *  Authors:
  *
@@ -29,14 +29,16 @@
  * Statement messages to other formats, including SQL strings.
  */
 
-#include "config.h"
+#include <config.h>
 
-#include "drizzled/message/statement_transform.h"
-#include "drizzled/message/transaction.pb.h"
-#include "drizzled/message/table.pb.h"
-#include "drizzled/charset.h"
-#include "drizzled/charset_info.h"
-#include "drizzled/global_charset_info.h"
+#include <boost/lexical_cast.hpp>
+
+#include <drizzled/charset.h>
+#include <drizzled/charset_info.h>
+#include <drizzled/global_charset_info.h>
+#include <drizzled/message.h>
+#include <drizzled/message/statement_transform.h>
+#include <drizzled/message/transaction.pb.h>
 
 #include <string>
 #include <vector>
@@ -126,6 +128,15 @@ transformStatementToSql(const Statement &source,
 
   switch (source.type())
   {
+  case Statement::ROLLBACK_STATEMENT:
+    {
+      break;
+    }
+  case Statement::ROLLBACK:
+    {
+      sql_strings.push_back("ROLLBACK");
+      break;
+    }
   case Statement::INSERT:
     {
       if (! source.has_insert_header())
@@ -142,12 +153,11 @@ transformStatementToSql(const Statement &source,
       const InsertHeader &insert_header= source.insert_header();
       const InsertData &insert_data= source.insert_data();
       size_t num_keys= insert_data.record_size();
-      size_t x;
 
       if (num_keys > 1 && ! already_in_transaction)
         sql_strings.push_back("START TRANSACTION");
 
-      for (x= 0; x < num_keys; ++x)
+      for (size_t x= 0; x < num_keys; ++x)
       {
         string destination;
 
@@ -308,6 +318,16 @@ transformStatementToSql(const Statement &source,
       sql_strings.push_back(destination);
     }
     break;
+  case Statement::ALTER_SCHEMA:
+    {
+      assert(source.has_alter_schema_statement());
+      string destination;
+      error= transformAlterSchemaStatementToSql(source.alter_schema_statement(),
+                                                destination,
+                                                sql_variant);
+      sql_strings.push_back(destination);
+    }
+    break;
   case Statement::SET_VARIABLE:
     {
       assert(source.has_set_variable_statement());
@@ -319,6 +339,16 @@ transformStatementToSql(const Statement &source,
     }
     break;
   case Statement::RAW_SQL:
+    {
+      if (source.has_raw_sql_schema())
+      {
+        string destination("USE ");
+        destination.append(source.raw_sql_schema());
+        sql_strings.push_back(destination);
+      }
+      sql_strings.push_back(source.sql());
+    }
+    break;
   default:
     sql_strings.push_back(source.sql());
     break;
@@ -795,6 +825,37 @@ transformDeleteStatementToSql(const DeleteHeader &header,
   return error;
 }
 
+enum TransformSqlError
+transformAlterSchemaStatementToSql(const AlterSchemaStatement &statement,
+                                   string &destination,
+                                   enum TransformSqlVariant sql_variant)
+{
+  const Schema &before= statement.before();
+  const Schema &after= statement.after();
+
+  /* Make sure we are given the before and after for the same object */
+  if (before.uuid() != after.uuid())
+    return UUID_MISMATCH;
+
+  char quoted_identifier= '`';
+  if (sql_variant == ANSI)
+    quoted_identifier= '"';
+
+  destination.append("ALTER SCHEMA ");
+  destination.push_back(quoted_identifier);
+  destination.append(before.name());
+  destination.push_back(quoted_identifier);
+
+  /*
+   * Diff our schemas. Currently, only collation can change so a
+   * diff of the two structures is not really necessary.
+   */
+  destination.append(" COLLATE = ");
+  destination.append(after.collation());
+
+  return NONE;
+}
+
 enum TransformSqlError
 transformDropSchemaStatementToSql(const DropSchemaStatement &statement,
                                   string &destination,
@@ -823,17 +884,22 @@ transformCreateSchemaStatementToSql(const CreateSchemaStatement &statement,
 
   const Schema &schema= statement.schema();
 
-  destination.append("CREATE SCHEMA ", 14);
+  destination.append("CREATE SCHEMA ");
   destination.push_back(quoted_identifier);
   destination.append(schema.name());
   destination.push_back(quoted_identifier);
 
   if (schema.has_collation())
   {
-    destination.append(" COLLATE ", 9);
+    destination.append(" COLLATE ");
     destination.append(schema.collation());
   }
 
+  if (not message::is_replicated(schema))
+  {
+    destination.append(" REPLICATE = FALSE");
+  }
+
   return NONE;
 }
 
@@ -848,13 +914,13 @@ transformDropTableStatementToSql(const DropTableStatement &statement,
 
   const TableMetadata &table_metadata= statement.table_metadata();
 
-  destination.append("DROP TABLE ", 11);
+  destination.append("DROP TABLE ");
 
   /* Add the IF EXISTS clause if necessary */
   if (statement.has_if_exists_clause() &&
       statement.if_exists_clause() == true)
   {
-    destination.append("IF EXISTS ", 10);
+    destination.append("IF EXISTS ");
   }
 
   destination.push_back(quoted_identifier);
@@ -879,7 +945,7 @@ transformTruncateTableStatementToSql(const TruncateTableStatement &statement,
 
   const TableMetadata &table_metadata= statement.table_metadata();
 
-  destination.append("TRUNCATE TABLE ", 15);
+  destination.append("TRUNCATE TABLE ");
   destination.push_back(quoted_identifier);
   destination.append(table_metadata.schema_name());
   destination.push_back(quoted_identifier);
@@ -900,7 +966,7 @@ transformSetVariableStatementToSql(const SetVariableStatement &statement,
   const FieldMetadata &variable_metadata= statement.variable_metadata();
   bool should_quote_field_value= shouldQuoteFieldValue(variable_metadata.type());
 
-  destination.append("SET GLOBAL ", 11); /* Only global variables are replicated */
+  destination.append("SET GLOBAL "); /* Only global variables are replicated */
   destination.append(variable_metadata.name());
   destination.push_back('=');
 
@@ -932,19 +998,19 @@ transformTableDefinitionToSql(const Table &table,
   if (sql_variant == ANSI)
     quoted_identifier= '"';
 
-  destination.append("CREATE ", 7);
+  destination.append("CREATE ");
 
   if (table.type() == Table::TEMPORARY)
-    destination.append("TEMPORARY ", 10);
+    destination.append("TEMPORARY ");
   
-  destination.append("TABLE ", 6);
+  destination.append("TABLE ");
   if (with_schema)
   {
     append_escaped_string(&destination, table.schema(), quoted_identifier);
     destination.push_back('.');
   }
   append_escaped_string(&destination, table.name(), quoted_identifier);
-  destination.append(" (\n", 3);
+  destination.append(" (\n");
 
   enum TransformSqlError result= NONE;
   size_t num_fields= table.field_size();
@@ -953,7 +1019,7 @@ transformTableDefinitionToSql(const Table &table,
     const Table::Field &field= table.field(x);
 
     if (x != 0)
-      destination.append(",\n", 2);
+      destination.append(",\n");
 
     destination.append("  ");
 
@@ -966,14 +1032,14 @@ transformTableDefinitionToSql(const Table &table,
   size_t num_indexes= table.indexes_size();
   
   if (num_indexes > 0)
-    destination.append(",\n", 2);
+    destination.append(",\n");
 
   for (size_t x= 0; x < num_indexes; ++x)
   {
     const message::Table::Index &index= table.indexes(x);
 
     if (x != 0)
-      destination.append(",\n", 2);
+      destination.append(",\n");
 
     result= transformIndexDefinitionToSql(index, table, destination, sql_variant);
     
@@ -984,14 +1050,14 @@ transformTableDefinitionToSql(const Table &table,
   size_t num_foreign_keys= table.fk_constraint_size();
 
   if (num_foreign_keys > 0)
-    destination.append(",\n", 2);
+    destination.append(",\n");
 
   for (size_t x= 0; x < num_foreign_keys; ++x)
   {
     const message::Table::ForeignKeyConstraint &fkey= table.fk_constraint(x);
 
     if (x != 0)
-      destination.append(",\n", 2);
+      destination.append(",\n");
 
     result= transformForeignKeyConstraintDefinitionToSql(fkey, table, destination, sql_variant);
 
@@ -999,12 +1065,12 @@ transformTableDefinitionToSql(const Table &table,
       return result;
   }
 
-  destination.append("\n)", 2);
+  destination.append("\n)");
 
   /* Add ENGINE = " clause */
   if (table.has_engine())
   {
-    destination.append(" ENGINE=", 8);
+    destination.append(" ENGINE=");
     destination.append(table.engine().name());
 
     size_t num_engine_options= table.engine().options_size();
@@ -1014,17 +1080,24 @@ transformTableDefinitionToSql(const Table &table,
     {
       const Engine::Option &option= table.engine().options(x);
       destination.append(option.name());
-      destination.append("='", 2);
+      destination.append("='");
       destination.append(option.state());
-      destination.append("'", 1);
-      if(x != num_engine_options-1)
-        destination.append(", ", 2);
+      destination.append("'");
+      if (x != num_engine_options-1)
+      {
+        destination.append(", ");
+      }
     }
   }
 
   if (table.has_options())
     (void) transformTableOptionsToSql(table.options(), destination, sql_variant);
 
+  if (not message::is_replicated(table))
+  {
+    destination.append(" REPLICATE = FALSE");
+  }
+
   return NONE;
 }
 
@@ -1036,73 +1109,62 @@ transformTableOptionsToSql(const Table::TableOptions &options,
   if (sql_variant == ANSI)
     return NONE; /* ANSI does not support table options... */
 
-  stringstream ss;
-
   if (options.has_comment())
   {
-    destination.append(" COMMENT=", 9);
+    destination.append(" COMMENT=");
     append_escaped_string(&destination, options.comment());
   }
 
   if (options.has_collation())
   {
-    destination.append(" COLLATE = ", 11);
+    destination.append(" COLLATE = ");
     destination.append(options.collation());
   }
 
   if (options.has_data_file_name())
   {
-    destination.append("\nDATA_FILE_NAME = '", 19);
+    destination.append("\nDATA_FILE_NAME = '");
     destination.append(options.data_file_name());
     destination.push_back('\'');
   }
 
   if (options.has_index_file_name())
   {
-    destination.append("\nINDEX_FILE_NAME = '", 20);
+    destination.append("\nINDEX_FILE_NAME = '");
     destination.append(options.index_file_name());
     destination.push_back('\'');
   }
 
   if (options.has_max_rows())
   {
-    ss << options.max_rows();
-    destination.append("\nMAX_ROWS = ", 12);
-    destination.append(ss.str());
-    ss.clear();
+    destination.append("\nMAX_ROWS = ");
+    destination.append(boost::lexical_cast<string>(options.max_rows()));
   }
 
   if (options.has_min_rows())
   {
-    ss << options.min_rows();
-    destination.append("\nMIN_ROWS = ", 12);
-    destination.append(ss.str());
-    ss.clear();
+    destination.append("\nMIN_ROWS = ");
+    destination.append(boost::lexical_cast<string>(options.min_rows()));
   }
 
   if (options.has_user_set_auto_increment_value()
       && options.has_auto_increment_value())
   {
-    ss << options.auto_increment_value();
-    destination.append(" AUTO_INCREMENT=", 16);
-    destination.append(ss.str());
-    ss.clear();
+    destination.append(" AUTO_INCREMENT=");
+    destination.append(boost::lexical_cast<string>(options.auto_increment_value()));
   }
 
   if (options.has_avg_row_length())
   {
-    ss << options.avg_row_length();
-    destination.append("\nAVG_ROW_LENGTH = ", 18);
-    destination.append(ss.str());
-    ss.clear();
+    destination.append("\nAVG_ROW_LENGTH = ");
+    destination.append(boost::lexical_cast<string>(options.avg_row_length()));
   }
 
-  if (options.has_checksum() &&
-      options.checksum())
-    destination.append("\nCHECKSUM = TRUE", 16);
-  if (options.has_page_checksum() &&
-      options.page_checksum())
-    destination.append("\nPAGE_CHECKSUM = TRUE", 21);
+  if (options.has_checksum() && options.checksum())
+    destination.append("\nCHECKSUM = TRUE");
+
+  if (options.has_page_checksum() && options.page_checksum())
+    destination.append("\nPAGE_CHECKSUM = TRUE");
 
   return NONE;
 }
@@ -1120,9 +1182,9 @@ transformIndexDefinitionToSql(const Table::Index &index,
   destination.append("  ", 2);
 
   if (index.is_primary())
-    destination.append("PRIMARY ", 8);
+    destination.append("PRIMARY ");
   else if (index.is_unique())
-    destination.append("UNIQUE ", 7);
+    destination.append("UNIQUE ");
 
   destination.append("KEY ", 4);
   if (! (index.is_primary() && index.name().compare("PRIMARY")==0))
@@ -1160,10 +1222,8 @@ transformIndexDefinitionToSql(const Table::Index &index,
       {
         if (part.compare_length() != field.string_options().length())
         {
-          stringstream ss;
           destination.push_back('(');
-          ss << part.compare_length();
-          destination.append(ss.str());
+          destination.append(boost::lexical_cast<string>(part.compare_length()));
           destination.push_back(')');
         }
       }
@@ -1176,22 +1236,22 @@ transformIndexDefinitionToSql(const Table::Index &index,
   case Table::Index::UNKNOWN_INDEX:
     break;
   case Table::Index::BTREE:
-    destination.append(" USING BTREE", 12);
+    destination.append(" USING BTREE");
     break;
   case Table::Index::RTREE:
-    destination.append(" USING RTREE", 12);
+    destination.append(" USING RTREE");
     break;
   case Table::Index::HASH:
-    destination.append(" USING HASH", 11);
+    destination.append(" USING HASH");
     break;
   case Table::Index::FULLTEXT:
-    destination.append(" USING FULLTEXT", 15);
+    destination.append(" USING FULLTEXT");
     break;
   }
 
   if (index.has_comment())
   {
-    destination.append(" COMMENT ", 9);
+    destination.append(" COMMENT ");
     append_escaped_string(&destination, index.comment());
   }
 
@@ -1202,8 +1262,6 @@ static void transformForeignKeyOptionToSql(Table::ForeignKeyConstraint::ForeignK
 {
   switch (opt)
   {
-  case Table::ForeignKeyConstraint::OPTION_UNDEF:
-    break;
   case Table::ForeignKeyConstraint::OPTION_RESTRICT:
     destination.append("RESTRICT");
     break;
@@ -1213,10 +1271,11 @@ static void transformForeignKeyOptionToSql(Table::ForeignKeyConstraint::ForeignK
   case Table::ForeignKeyConstraint::OPTION_SET_NULL:
     destination.append("SET NULL");
     break;
+  case Table::ForeignKeyConstraint::OPTION_UNDEF:
   case Table::ForeignKeyConstraint::OPTION_NO_ACTION:
     destination.append("NO ACTION");
     break;
-  case Table::ForeignKeyConstraint::OPTION_DEFAULT:
+  case Table::ForeignKeyConstraint::OPTION_SET_DEFAULT:
     destination.append("SET DEFAULT");
     break;
   }
@@ -1232,16 +1291,16 @@ transformForeignKeyConstraintDefinitionToSql(const Table::ForeignKeyConstraint &
   if (sql_variant == ANSI)
     quoted_identifier= '"';
 
-  destination.append("  ", 2);
+  destination.append("  ");
 
   if (fkey.has_name())
   {
-    destination.append("CONSTRAINT ", 11);
+    destination.append("CONSTRAINT ");
     append_escaped_string(&destination, fkey.name(), quoted_identifier);
     destination.append(" ", 1);
   }
 
-  destination.append("FOREIGN KEY (", 13);
+  destination.append("FOREIGN KEY (");
 
   for (ssize_t x= 0; x < fkey.column_names_size(); ++x)
   {
@@ -1252,11 +1311,11 @@ transformForeignKeyConstraintDefinitionToSql(const Table::ForeignKeyConstraint &
                           quoted_identifier);
   }
 
-  destination.append(") REFERENCES ", 13);
+  destination.append(") REFERENCES ");
 
   append_escaped_string(&destination, fkey.references_table_name(),
                         quoted_identifier);
-  destination.append(" (", 2);
+  destination.append(" (");
 
   for (ssize_t x= 0; x < fkey.references_columns_size(); ++x)
   {
@@ -1269,15 +1328,15 @@ transformForeignKeyConstraintDefinitionToSql(const Table::ForeignKeyConstraint &
 
   destination.push_back(')');
 
-  if (fkey.update_option() != Table::ForeignKeyConstraint::OPTION_UNDEF)
+  if (fkey.has_update_option() and fkey.update_option() != Table::ForeignKeyConstraint::OPTION_UNDEF)
   {
-    destination.append(" ON UPDATE ", 11);
+    destination.append(" ON UPDATE ");
     transformForeignKeyOptionToSql(fkey.update_option(), destination);
   }
 
-  if (fkey.delete_option() != Table::ForeignKeyConstraint::OPTION_UNDEF)
+  if (fkey.has_delete_option() and fkey.delete_option() != Table::ForeignKeyConstraint::OPTION_UNDEF)
   {
-    destination.append(" ON DELETE ", 11);
+    destination.append(" ON DELETE ");
     transformForeignKeyOptionToSql(fkey.delete_option(), destination);
   }
 
@@ -1307,7 +1366,7 @@ transformFieldDefinitionToSql(const Table::Field &field,
   switch (field_type)
   {
     case Table::Field::DOUBLE:
-    destination.append(" DOUBLE", 7);
+    destination.append(" DOUBLE");
     if (field.has_numeric_options()
         && field.numeric_options().has_precision())
     {
@@ -1321,28 +1380,27 @@ transformFieldDefinitionToSql(const Table::Field &field,
     {
       if (field.string_options().has_collation()
           && field.string_options().collation().compare("binary") == 0)
-        destination.append(" VARBINARY(", 11);
+        destination.append(" VARBINARY(");
       else
-        destination.append(" VARCHAR(", 9);
+        destination.append(" VARCHAR(");
 
-      stringstream ss;
-      ss << field.string_options().length() << ")";
-      destination.append(ss.str());
+      destination.append(boost::lexical_cast<string>(field.string_options().length()));
+      destination.append(")");
     }
     break;
   case Table::Field::BLOB:
     {
       if (field.string_options().has_collation()
           && field.string_options().collation().compare("binary") == 0)
-        destination.append(" BLOB", 5);
+        destination.append(" BLOB");
       else
-        destination.append(" TEXT", 5);
+        destination.append(" TEXT");
     }
     break;
   case Table::Field::ENUM:
     {
       size_t num_field_values= field.enumeration_values().field_value_size();
-      destination.append(" ENUM(", 6);
+      destination.append(" ENUM(");
       for (size_t x= 0; x < num_field_values; ++x)
       {
         const string &type= field.enumeration_values().field_value(x);
@@ -1357,15 +1415,29 @@ transformFieldDefinitionToSql(const Table::Field &field,
       destination.push_back(')');
       break;
     }
+  case Table::Field::UUID:
+    destination.append(" UUID");
+    break;
+  case Table::Field::BOOLEAN:
+    destination.append(" BOOLEAN");
+    break;
   case Table::Field::INTEGER:
-    destination.append(" INT", 4);
+    destination.append(" INT");
     break;
   case Table::Field::BIGINT:
-    destination.append(" BIGINT", 7);
+    if (field.has_constraints() and
+        field.constraints().is_unsigned())
+    {
+      destination.append(" BIGINT UNSIGNED");
+    }
+    else
+    {
+      destination.append(" BIGINT");
+    }
     break;
   case Table::Field::DECIMAL:
     {
-      destination.append(" DECIMAL(", 9);
+      destination.append(" DECIMAL(");
       stringstream ss;
       ss << field.numeric_options().precision() << ",";
       ss << field.numeric_options().scale() << ")";
@@ -1373,25 +1445,26 @@ transformFieldDefinitionToSql(const Table::Field &field,
     }
     break;
   case Table::Field::DATE:
-    destination.append(" DATE", 5);
+    destination.append(" DATE");
     break;
-  case Table::Field::TIMESTAMP:
-    destination.append(" TIMESTAMP",  10);
-    break;
-  case Table::Field::DATETIME:
-    destination.append(" DATETIME",  9);
-    break;
-  }
 
-  if (field.type() == Table::Field::INTEGER || 
-      field.type() == Table::Field::BIGINT)
-  {
-    if (field.has_constraints() &&
-        field.constraints().has_is_unsigned() &&
-        field.constraints().is_unsigned())
+  case Table::Field::EPOCH:
+    if (field.time_options().microseconds())
     {
-      destination.append(" UNSIGNED", 9);
+      destination.append(" TIMESTAMP(6)");
     }
+    else
+    {
+      destination.append(" TIMESTAMP");
+    }
+    break;
+
+  case Table::Field::DATETIME:
+    destination.append(" DATETIME");
+    break;
+  case Table::Field::TIME:
+    destination.append(" TIME");
+    break;
   }
 
   if (field.type() == Table::Field::BLOB ||
@@ -1400,18 +1473,24 @@ transformFieldDefinitionToSql(const Table::Field &field,
     if (field.string_options().has_collation()
         && field.string_options().collation().compare("binary"))
     {
-      destination.append(" COLLATE ", 9);
+      destination.append(" COLLATE ");
       destination.append(field.string_options().collation());
     }
   }
 
-  if (field.has_constraints() &&
-      ! field.constraints().is_nullable())
+  if (field.has_constraints() and field.constraints().is_unique())
   {
-    destination.append(" NOT NULL", 9);
+    destination.append(" UNIQUE");
+  }
+
+  if (field.has_constraints() && field.constraints().is_notnull())
+  {
+    destination.append(" NOT NULL");
+  }
+  else if (field.type() == Table::Field::EPOCH)
+  {
+    destination.append(" NULL");
   }
-  else if (field.type() == Table::Field::TIMESTAMP)
-    destination.append(" NULL", 5);
 
   if (field.type() == Table::Field::INTEGER || 
       field.type() == Table::Field::BIGINT)
@@ -1420,28 +1499,30 @@ transformFieldDefinitionToSql(const Table::Field &field,
     if (field.has_numeric_options() &&
         field.numeric_options().is_autoincrement())
     {
-      destination.append(" AUTO_INCREMENT", 15);
+      destination.append(" AUTO_INCREMENT");
     }
   }
 
   if (field.options().has_default_value())
   {
-    destination.append(" DEFAULT ", 9);
+    destination.append(" DEFAULT ");
     append_escaped_string(&destination, field.options().default_value());
   }
   else if (field.options().has_default_expression())
   {
-    destination.append(" DEFAULT ", 9);
+    destination.append(" DEFAULT ");
     destination.append(field.options().default_expression());
   }
   else if (field.options().has_default_bin_value())
   {
     const string &v= field.options().default_bin_value();
     if (v.length() == 0)
-      destination.append(" DEFAULT ''", 11);
+    {
+      destination.append(" DEFAULT ''");
+    }
     else
     {
-      destination.append(" DEFAULT 0x", 11);
+      destination.append(" DEFAULT 0x");
       for (size_t x= 0; x < v.length(); x++)
       {
         char hex[3];
@@ -1454,18 +1535,18 @@ transformFieldDefinitionToSql(const Table::Field &field,
            && field.options().default_null()
            && field.type() != Table::Field::BLOB)
   {
-    destination.append(" DEFAULT NULL", 13);
+    destination.append(" DEFAULT NULL");
   }
 
   if (field.has_options() && field.options().has_update_expression())
   {
-    destination.append(" ON UPDATE ", 11);
+    destination.append(" ON UPDATE ");
     destination.append(field.options().update_expression());
   }
 
   if (field.has_comment())
   {
-    destination.append(" COMMENT ", 9);
+    destination.append(" COMMENT ");
     append_escaped_string(&destination, field.comment(), quoted_default);
   }
   return NONE;
@@ -1495,12 +1576,15 @@ Table::Field::FieldType internalFieldTypeToFieldProtoType(enum enum_field_types
   case DRIZZLE_TYPE_NULL:
     assert(false); /* Not a user definable type */
     return Table::Field::INTEGER; /* unreachable */
+  case DRIZZLE_TYPE_MICROTIME:
   case DRIZZLE_TYPE_TIMESTAMP:
-    return Table::Field::TIMESTAMP;
+    return Table::Field::EPOCH;
   case DRIZZLE_TYPE_LONGLONG:
     return Table::Field::BIGINT;
   case DRIZZLE_TYPE_DATETIME:
     return Table::Field::DATETIME;
+  case DRIZZLE_TYPE_TIME:
+    return Table::Field::TIME;
   case DRIZZLE_TYPE_DATE:
     return Table::Field::DATE;
   case DRIZZLE_TYPE_VARCHAR:
@@ -1511,6 +1595,10 @@ Table::Field::FieldType internalFieldTypeToFieldProtoType(enum enum_field_types
     return Table::Field::ENUM;
   case DRIZZLE_TYPE_BLOB:
     return Table::Field::BLOB;
+  case DRIZZLE_TYPE_UUID:
+    return Table::Field::UUID;
+  case DRIZZLE_TYPE_BOOLEAN:
+    return Table::Field::BOOLEAN;
   }
 
   assert(false);
