@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_MODULE_CONTEXT_H
-#define DRIZZLED_MODULE_CONTEXT_H
+#pragma once
 
 /**
  * @file Defines a Plugin Context
@@ -35,27 +34,21 @@
  * to force things like proper name prefixing and the like.
  */
 
-#include "drizzled/module/registry.h"
+#include <boost/noncopyable.hpp>
+#include <drizzled/module/registry.h>
+#include <drizzled/visibility.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 class sys_var;
 
-namespace module
-{
+namespace module {
 
 class Module;
 class option_map;
 
-class Context
+class DRIZZLED_API Context : boost::noncopyable
 {
-private:
-  module::Registry &registry;
-  module::Module *module;
-
-  Context(const Context&);
-  Context& operator=(const Context&);
 public:
 
   Context(module::Registry &registry_arg,
@@ -80,17 +73,15 @@ public:
   void registerVariable(sys_var *var);
 
   option_map getOptions();
+
+  static std::string prepend_name(std::string module_name,
+                                  const std::string &var_name);
+private:
+  module::Registry &registry;
+  module::Module *module;
 };
 
-inline void Context::registerVariable(sys_var *)
-{
-/* In here, you can do:
-  sys_var->append_name_prefix(module->getName());
-  register_variable_whatever();
-*/
-}
 
 } /* namespace module */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_MODULE_CONTEXT_H */
