@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,20 +17,23 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <dlfcn.h>
 
 #include <cerrno>
 #include <string>
 
-#include "drizzled/plugin.h"
-#include "drizzled/definitions.h"
-#include "drizzled/error.h"
-#include "drizzled/errmsg_print.h"
-#include "drizzled/module/library.h"
+#include <boost/filesystem.hpp>
+
+#include <drizzled/plugin.h>
+#include <drizzled/definitions.h>
+#include <drizzled/error.h>
+#include <drizzled/errmsg_print.h>
+#include <drizzled/module/library.h>
 
 using namespace std;
+namespace fs=boost::filesystem;
 
 namespace drizzled
 {
@@ -50,22 +53,19 @@ module::Library::~Library()
   */
 }
 
-const string module::Library::getLibraryPath(const string &plugin_name)
+const fs::path module::Library::getLibraryPath(const string &plugin_name)
 {
-  /* Compile dll path */
-  string dlpath;
-  dlpath.reserve(FN_REFLEN);
-  dlpath.append(opt_plugin_dir);
-  dlpath.append("/");
-  dlpath.append("lib");
-  dlpath.append(plugin_name);
-  dlpath.append("_plugin");
+  string plugin_lib_name("lib");
+  plugin_lib_name.append(plugin_name);
+  plugin_lib_name.append("_plugin");
 #if defined(TARGET_OS_OSX)
-  dlpath.append(".dylib");
+  plugin_lib_name.append(".dylib");
 #else
-  dlpath.append(".so");
+  plugin_lib_name.append(".so");
 #endif
-  return dlpath;
+
+  /* Compile dll path */
+  return plugin_dir / plugin_lib_name;
 }
 
 module::Library *module::Library::loadLibrary(const string &plugin_name, bool builtin)
@@ -78,21 +78,21 @@ module::Library *module::Library::loadLibrary(const string &plugin_name, bool bu
   size_t found= plugin_name.find(FN_LIBCHAR);
   if (found != string::npos)
   {
-    errmsg_printf(ERRMSG_LVL_ERROR, "%s",ER(ER_PLUGIN_NO_PATHS));
+    errmsg_printf(error::ERROR, "%s",ER(ER_PLUGIN_NO_PATHS));
     return NULL;
   }
 
-  void *handle= NULL;
+  void *dl_handle= NULL;
   string dlpath("");
 
   if (builtin)
   {
     dlpath.assign("<builtin>");
-    handle= dlopen(NULL, RTLD_NOW|RTLD_LOCAL);
-    if (handle == NULL)
+    dl_handle= dlopen(NULL, RTLD_NOW|RTLD_LOCAL);
+    if (dl_handle == NULL)
     {
       const char *errmsg= dlerror();
-      errmsg_printf(ERRMSG_LVL_ERROR, ER(ER_CANT_OPEN_LIBRARY),
+      errmsg_printf(error::ERROR, ER(ER_CANT_OPEN_LIBRARY),
                     dlpath.c_str(), errno, errmsg);
       (void)dlerror();
 
@@ -102,9 +102,9 @@ module::Library *module::Library::loadLibrary(const string &plugin_name, bool bu
   else
   {
   /* Open new dll handle */
-    dlpath.assign(Library::getLibraryPath(plugin_name));
-    handle= dlopen(dlpath.c_str(), RTLD_NOW|RTLD_GLOBAL);
-    if (handle == NULL)
+    dlpath.assign(Library::getLibraryPath(plugin_name).file_string());
+    dl_handle= dlopen(dlpath.c_str(), RTLD_NOW|RTLD_GLOBAL);
+    if (dl_handle == NULL)
     {
       const char *errmsg= dlerror();
       uint32_t dlpathlen= dlpath.length();
@@ -114,7 +114,7 @@ module::Library *module::Library::loadLibrary(const string &plugin_name, bool bu
         if (*errmsg == ':') errmsg++;
         if (*errmsg == ' ') errmsg++;
       }
-      errmsg_printf(ERRMSG_LVL_ERROR, ER(ER_CANT_OPEN_LIBRARY),
+      errmsg_printf(error::ERROR, ER(ER_CANT_OPEN_LIBRARY),
                     dlpath.c_str(), errno, errmsg);
 
       // This, in theory, should cause dlerror() to deallocate the error
@@ -130,31 +130,31 @@ module::Library *module::Library::loadLibrary(const string &plugin_name, bool bu
   plugin_decl_sym.append("_plugin_");
 
   /* Find plugin declarations */
-  void *sym= dlsym(handle, plugin_decl_sym.c_str());
+  void *sym= dlsym(dl_handle, plugin_decl_sym.c_str());
   if (sym == NULL)
   {
     const char* errmsg= dlerror();
-    errmsg_printf(ERRMSG_LVL_ERROR, errmsg);
-    errmsg_printf(ERRMSG_LVL_ERROR, ER(ER_CANT_FIND_DL_ENTRY),
+    errmsg_printf(error::ERROR, errmsg);
+    errmsg_printf(error::ERROR, ER(ER_CANT_FIND_DL_ENTRY),
                   plugin_decl_sym.c_str(), dlpath.c_str());
     (void)dlerror();
-    dlclose(handle);
+    dlclose(dl_handle);
     return NULL;
   }
 
-  const Manifest *manifest= static_cast<module::Manifest *>(sym); 
-  if (manifest->drizzle_version != DRIZZLE_VERSION_ID)
+  const Manifest *module_manifest= static_cast<module::Manifest *>(sym); 
+  if (module_manifest->drizzle_version != DRIZZLE_VERSION_ID)
   {
-    errmsg_printf(ERRMSG_LVL_ERROR,
+    errmsg_printf(error::ERROR,
                   _("Plugin module %s was compiled for version %" PRIu64 ", "
                     "which does not match the current running version of "
                     "Drizzle: %" PRIu64"."),
-                 dlpath.c_str(), manifest->drizzle_version,
-                 DRIZZLE_VERSION_ID);
+                 dlpath.c_str(), module_manifest->drizzle_version,
+                 static_cast<uint64_t>(DRIZZLE_VERSION_ID));
     return NULL;
   }
 
-  return new (nothrow) module::Library(plugin_name, handle, manifest);
+  return new (nothrow) module::Library(plugin_name, dl_handle, module_manifest);
 }
 
 } /* namespace drizzled */
