@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_MODULE_LIBRARY_H
-#define DRIZZLED_MODULE_LIBRARY_H
+#pragma once
 
 /**
  * @file Defines a Plugin Library Wrapper
@@ -30,12 +29,14 @@
 
 #include <string>
 
+#include <boost/filesystem.hpp>
+
 namespace drizzled
 {
 namespace module
 {
 
-class Manifest;
+struct Manifest;
 
 /* A handle for the dynamic library containing a plugin or plugins. */
 class Library
@@ -67,11 +68,10 @@ public:
     return manifest;
   }
 
-  static const std::string getLibraryPath(const std::string &plugin_name);
+  static const boost::filesystem::path getLibraryPath(const std::string &plugin_name);
   static Library *loadLibrary(const std::string &plugin_name, bool builtin);
 };
 
 } /* namespace module */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_MODULE_LIBRARY_H */
