@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_MODULE_MODULE_H
-#define DRIZZLED_MODULE_MODULE_H
+#pragma once
 
 /**
  * @file Defines a Plugin Module
@@ -28,45 +27,40 @@
  * or more plugin::Plugin objects. 
  */
 
-#include <cassert>
-#include <boost/program_options.hpp>
+#include <string>
+#include <vector>
 
-#include "drizzled/module/manifest.h"
-#include "drizzled/module/registry.h"
+namespace drizzled {
 
-
-namespace drizzled
-{
+class set_var;
 class sys_var;
 
-void module_shutdown(module::Registry &registry);
+namespace module { class Registry; }
 
-namespace module
-{
+void module_shutdown(module::Registry&);
+
+namespace module {
 
 class Library;
+class Manifest;
+class VertexHandle;
 
 /* A plugin module */
 class Module
 {
-  const std::string name;
-  const Manifest *manifest;
-
 public:
+  typedef std::vector<sys_var *> Variables;
+  typedef std::vector<std::string> Depends;
+
   Library *plugin_dl;
   bool isInited;
-  sys_var *system_vars;         /* server variables for this plugin */
-  Module(const Manifest *manifest_arg,
-         Library *library_arg) :
-    name(manifest_arg->name),
-    manifest(manifest_arg),
-    plugin_dl(library_arg),
-    isInited(false),
-    system_vars(NULL)
-  {
-    assert(manifest != NULL);
-  }
-      
+  Variables system_vars;         /* server variables for this plugin */
+  Variables sys_vars;
+  Depends depends_;
+
+  Module(const Manifest *manifest_arg, Library *library_arg);
+  ~Module();
+
   const std::string& getName() const
   {
     return name;
@@ -74,12 +68,45 @@ public:
 
   const Manifest& getManifest() const
   {
-    return *manifest;
+    return manifest;
   }
 
+  void addMySysVar(sys_var *var)
+  {
+    sys_vars.push_back(var);
+    addSysVar(var);
+  }
+
+  void addSysVar(sys_var *var)
+  {
+    system_vars.push_back(var);
+  }
+
+  Variables &getSysVars()
+  {
+    return system_vars;
+  }
+
+  const Depends &getDepends() const
+  {
+    return depends_;
+  }
+
+  void setVertexHandle(VertexHandle *vertex)
+  {
+    vertex_= vertex;
+  }
+
+  VertexHandle *getVertexHandle()
+  {
+    return vertex_;
+  }
+private:
+  const std::string name;
+  const Manifest &manifest;
+  VertexHandle *vertex_;
 };
 
 } /* namespace module */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_MODULE_MODULE_H */
