@@ -21,22 +21,33 @@
 
 #include <drizzled/module/vertex.h>
 
-namespace drizzled {
-namespace module {
 
-class VertexHandle : boost::noncopyable
+namespace drizzled
 {
+
+namespace module
+{
+
+class VertexHandle
+{
+
+private:
+  VertexDesc vertex_desc_;
+
+  VertexHandle();
+  VertexHandle(const VertexHandle&);
+  VertexHandle& operator=(const VertexHandle&);
+
 public:
   explicit VertexHandle(VertexDesc vertex_desc) :
     vertex_desc_(vertex_desc)
   { }
 
-  VertexDesc getVertexDesc() const
+  VertexDesc getVertexDesc()
   {
     return vertex_desc_;
   }
-private:
-  VertexDesc vertex_desc_;
+
 };
 
 } /* namespace module */
