@@ -18,11 +18,11 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
-#include "drizzled/session.h"
-#include "drizzled/join_table.h"
-#include "drizzled/sql_select.h"
-#include "drizzled/optimizer/access_method/unique_index.h"
+#include <config.h>
+#include <drizzled/session.h>
+#include <drizzled/join_table.h>
+#include <drizzled/sql_select.h>
+#include <drizzled/optimizer/access_method/unique_index.h>
 
 using namespace drizzled;
 
