@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008-2009 Sun Microsystems
+ *  Copyright (C) 2008-2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,21 +17,26 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
-#include "drizzled/session.h"
-#include "drizzled/item/uint.h"
-#include "drizzled/item/float.h"
-#include "drizzled/optimizer/explain_plan.h"
-#include "drizzled/optimizer/position.h"
-#include "drizzled/optimizer/quick_ror_intersect_select.h"
-#include "drizzled/optimizer/range.h"
-#include "drizzled/sql_select.h"
-#include "drizzled/join.h"
-#include "drizzled/internal/m_string.h"
+#include <config.h>
+
+#include <drizzled/session.h>
+#include <drizzled/item/uint.h>
+#include <drizzled/item/float.h>
+#include <drizzled/item/string.h>
+#include <drizzled/optimizer/explain_plan.h>
+#include <drizzled/optimizer/position.h>
+#include <drizzled/optimizer/quick_ror_intersect_select.h>
+#include <drizzled/optimizer/range.h>
+#include <drizzled/sql_select.h>
+#include <drizzled/join.h>
+#include <drizzled/internal/m_string.h>
+#include <drizzled/select_result.h>
+#include <drizzled/sql_lex.h>
 
 #include <cstdio>
 #include <string>
 #include <sstream>
+#include <bitset>
 
 using namespace std;
 
@@ -71,7 +76,6 @@ static const string select_type_str[]=
 
 void optimizer::ExplainPlan::printPlan()
 {
-  List<Item> field_list;
   List<Item> item_list;
   Session *session= join->session;
   select_result *result= join->result;
@@ -96,7 +100,7 @@ void optimizer::ExplainPlan::printPlan()
     for (uint32_t i= 0; i < 7; i++)
       item_list.push_back(item_null);
 
-    if (join->session->lex->describe & DESCRIBE_EXTENDED)
+    if (join->session->lex().describe & DESCRIBE_EXTENDED)
       item_list.push_back(item_null);
 
     item_list.push_back(new Item_string(message,strlen(message),cs));
@@ -113,7 +117,7 @@ void optimizer::ExplainPlan::printPlan()
        appreciated :)
      */
     char table_name_buffer[NAME_LEN];
-    item_list.empty();
+    item_list.clear();
     /* id */
     item_list.push_back(new Item_null);
     /* select_type */
@@ -156,7 +160,7 @@ void optimizer::ExplainPlan::printPlan()
     /* ref */
     item_list.push_back(item_null);
     /* in_rows */
-    if (join->session->lex->describe & DESCRIBE_EXTENDED)
+    if (join->session->lex().describe & DESCRIBE_EXTENDED)
       item_list.push_back(item_null);
     /* rows */
     item_list.push_back(item_null);
@@ -178,21 +182,15 @@ void optimizer::ExplainPlan::printPlan()
     {
       JoinTable *tab= join->join_tab + i;
       Table *table= tab->table;
-      char buff[512];
-      char buff1[512], buff2[512], buff3[512];
       char keylen_str_buf[64];
-      String extra(buff, sizeof(buff),cs);
+      string extra;
       char table_name_buffer[NAME_LEN];
-      String tmp1(buff1,sizeof(buff1),cs);
-      String tmp2(buff2,sizeof(buff2),cs);
-      String tmp3(buff3,sizeof(buff3),cs);
-      extra.length(0);
-      tmp1.length(0);
-      tmp2.length(0);
-      tmp3.length(0);
+      string tmp1;
+      string tmp2;
+      string tmp3;
 
       quick_type= -1;
-      item_list.empty();
+      item_list.clear();
       /* id */
       item_list.push_back(new Item_uint((uint32_t)
             join->select_lex->select_number));
@@ -239,15 +237,14 @@ void optimizer::ExplainPlan::printPlan()
           if (tab->keys.test(j))
           {
             if (tmp1.length())
-              tmp1.append(',');
+              tmp1.append(",");
             tmp1.append(table->key_info[j].name,
-                        strlen(table->key_info[j].name),
-                        system_charset_info);
+                        strlen(table->key_info[j].name));
           }
         }
       }
       if (tmp1.length())
-        item_list.push_back(new Item_string(tmp1.ptr(),tmp1.length(),cs));
+        item_list.push_back(new Item_string(tmp1.c_str(),tmp1.length(),cs));
       else
         item_list.push_back(item_null);
 
@@ -266,12 +263,11 @@ void optimizer::ExplainPlan::printPlan()
         for (StoredKey **ref= tab->ref.key_copy; *ref; ref++)
         {
           if (tmp2.length())
-            tmp2.append(',');
-          tmp2.append((*ref)->name(), 
-                       strlen((*ref)->name()),
-                       system_charset_info);
+            tmp2.append(",");
+          tmp2.append((*ref)->name(),
+                      strlen((*ref)->name()));
         }
-        item_list.push_back(new Item_string(tmp2.ptr(),tmp2.length(),cs));
+        item_list.push_back(new Item_string(tmp2.c_str(),tmp2.length(),cs));
       }
       else if (tab->type == AM_NEXT)
       {
@@ -288,8 +284,8 @@ void optimizer::ExplainPlan::printPlan()
       else if (tab->select && tab->select->quick)
       {
         tab->select->quick->add_keys_and_lengths(&tmp2, &tmp3);
-        item_list.push_back(new Item_string(tmp2.ptr(),tmp2.length(),cs));
-        item_list.push_back(new Item_string(tmp3.ptr(),tmp3.length(),cs));
+        item_list.push_back(new Item_string(tmp2.c_str(),tmp2.length(),cs));
+        item_list.push_back(new Item_string(tmp3.c_str(),tmp3.length(),cs));
         item_list.push_back(item_null);
       }
       else
@@ -303,12 +299,11 @@ void optimizer::ExplainPlan::printPlan()
       double examined_rows;
       if (tab->select && tab->select->quick)
       {
-        examined_rows= rows2double(tab->select->quick->records);
+        examined_rows= tab->select->quick->records;
       }
       else if (tab->type == AM_NEXT || tab->type == AM_ALL)
       {
-        examined_rows= rows2double(tab->limit ? tab->limit :
-                                                tab->table->cursor->records());
+        examined_rows= tab->limit ? tab->limit : tab->table->cursor->records();
       }
       else
       {
@@ -320,7 +315,7 @@ void optimizer::ExplainPlan::printPlan()
                                        MY_INT64_NUM_DECIMAL_DIGITS));
 
       /* Add "filtered" field to item_list. */
-      if (join->session->lex->describe & DESCRIBE_EXTENDED)
+      if (join->session->lex().describe & DESCRIBE_EXTENDED)
       {
         float f= 0.0;
         if (examined_rows)
@@ -345,20 +340,14 @@ void optimizer::ExplainPlan::printPlan()
       else if (tab->packed_info & TAB_INFO_HAVE_VALUE)
       {
         if (tab->packed_info & TAB_INFO_USING_INDEX)
-          extra.append(STRING_WITH_LEN("; Using index"));
+          extra.append("; Using index");
         if (tab->packed_info & TAB_INFO_USING_WHERE)
-          extra.append(STRING_WITH_LEN("; Using where"));
+          extra.append("; Using where");
         if (tab->packed_info & TAB_INFO_FULL_SCAN_ON_NULL)
-          extra.append(STRING_WITH_LEN("; Full scan on NULL key"));
-        /* Skip initial "; "*/
-        const char *str= extra.ptr();
-        uint32_t len= extra.length();
-        if (len)
-        {
-          str += 2;
-          len -= 2;
-        }
-        item_list.push_back(new Item_string(str, len, cs));
+          extra.append("; Full scan on NULL key");
+        if (extra.length())
+          extra.erase(0, 2);        /* Skip initial "; "*/
+        item_list.push_back(new Item_string(extra.c_str(), extra.length(), cs));
       }
       else
       {
@@ -372,7 +361,7 @@ void optimizer::ExplainPlan::printPlan()
             quick_type == optimizer::QuickSelectInterface::QS_TYPE_ROR_INTERSECT ||
             quick_type == optimizer::QuickSelectInterface::QS_TYPE_INDEX_MERGE)
         {
-          extra.append(STRING_WITH_LEN("; Using "));
+          extra.append("; Using ");
           tab->select->quick->add_info_string(&extra);
         }
         if (tab->select)
@@ -397,65 +386,58 @@ void optimizer::ExplainPlan::printPlan()
               if (tmp.any())
                 s << uppercase << hex << tmp.to_ulong();
             }
-            extra.append(STRING_WITH_LEN("; Range checked for each "
-                  "record (index map: 0x"));
+            extra.append("; Range checked for each record (index map: 0x");
             extra.append(s.str().c_str());
-            extra.append(')');
+            extra.append(")");
           }
           else if (tab->select->cond)
           {
-            extra.append(STRING_WITH_LEN("; Using where"));
+            extra.append("; Using where");
           }
         }
         if (key_read)
         {
           if (quick_type == optimizer::QuickSelectInterface::QS_TYPE_GROUP_MIN_MAX)
-            extra.append(STRING_WITH_LEN("; Using index for group-by"));
+            extra.append("; Using index for group-by");
           else
-            extra.append(STRING_WITH_LEN("; Using index"));
+            extra.append("; Using index");
         }
         if (table->reginfo.not_exists_optimize)
-          extra.append(STRING_WITH_LEN("; Not exists"));
+          extra.append("; Not exists");
 
         if (need_tmp_table)
         {
           need_tmp_table=0;
-          extra.append(STRING_WITH_LEN("; Using temporary"));
+          extra.append("; Using temporary");
         }
         if (need_order)
         {
           need_order=0;
-          extra.append(STRING_WITH_LEN("; Using filesort"));
+          extra.append("; Using filesort");
         }
         if (distinct & test_all_bits(used_tables,session->used_tables))
-          extra.append(STRING_WITH_LEN("; Distinct"));
+          extra.append("; Distinct");
 
         if (tab->insideout_match_tab)
         {
-          extra.append(STRING_WITH_LEN("; LooseScan"));
+          extra.append("; LooseScan");
         }
 
         for (uint32_t part= 0; part < tab->ref.key_parts; part++)
         {
           if (tab->ref.cond_guards[part])
           {
-            extra.append(STRING_WITH_LEN("; Full scan on NULL key"));
+            extra.append("; Full scan on NULL key");
             break;
           }
         }
 
         if (i > 0 && tab[-1].next_select == sub_select_cache)
-          extra.append(STRING_WITH_LEN("; Using join buffer"));
+          extra.append("; Using join buffer");
 
-        /* Skip initial "; "*/
-        const char *str= extra.ptr();
-        uint32_t len= extra.length();
-        if (len)
-        {
-          str += 2;
-          len -= 2;
-        }
-        item_list.push_back(new Item_string(str, len, cs));
+        if (extra.length())
+          extra.erase(0, 2);
+        item_list.push_back(new Item_string(extra.c_str(), extra.length(), cs));
       }
       // For next iteration
       used_tables|=table->map;
@@ -485,8 +467,8 @@ bool optimizer::ExplainPlan::explainUnion(Session *session,
        sl= sl->next_select())
   {
     // drop UNCACHEABLE_EXPLAIN, because it is for internal usage only
-    uint8_t uncacheable= (sl->uncacheable & ~UNCACHEABLE_EXPLAIN);
-    if (&session->lex->select_lex == sl)
+    sl->uncacheable.reset(UNCACHEABLE_EXPLAIN);
+    if (&session->lex().select_lex == sl)
     {
       if (sl->first_inner_unit() || sl->next_select())
       {
@@ -507,13 +489,13 @@ bool optimizer::ExplainPlan::explainUnion(Session *session,
         }
         else
         {
-          if (uncacheable & UNCACHEABLE_DEPENDENT)
+          if (sl->uncacheable.test(UNCACHEABLE_DEPENDENT))
           {
             sl->type= optimizer::ST_DEPENDENT_SUBQUERY;
           }
           else
           {
-            if (uncacheable)
+            if (sl->uncacheable.any())
             {
               sl->type= optimizer::ST_UNCACHEABLE_SUBQUERY;
             }
@@ -526,13 +508,13 @@ bool optimizer::ExplainPlan::explainUnion(Session *session,
       }
       else
       {
-        if (uncacheable & UNCACHEABLE_DEPENDENT)
+        if (sl->uncacheable.test(UNCACHEABLE_DEPENDENT))
         {
           sl->type= optimizer::ST_DEPENDENT_UNION;
         }
         else
         {
-          if (uncacheable)
+          if (sl->uncacheable.any())
           {
             sl->type= optimizer::ST_UNCACHEABLE_UNION;
           }
@@ -559,17 +541,17 @@ bool optimizer::ExplainPlan::explainUnion(Session *session,
   }
   else
   {
-    session->lex->current_select= first;
+    session->lex().current_select= first;
     unit->set_limit(unit->global_parameters);
-    res= mysql_select(session, 
+    res= select_query(session, 
                       &first->ref_pointer_array,
                       (TableList*) first->table_list.first,
                       first->with_wild, 
                       first->item_list,
                       first->where,
                       first->order_list.elements + first->group_list.elements,
-                      (order_st*) first->order_list.first,
-                      (order_st*) first->group_list.first,
+                      (Order*) first->order_list.first,
+                      (Order*) first->group_list.first,
                       first->having,
                       first->options | session->options | SELECT_DESCRIBE,
                       result, 
