@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_OPTIMIZER_POSITION_H
-#define DRIZZLED_OPTIMIZER_POSITION_H
+#pragma once
 
 #include <drizzled/join_table.h>
 
@@ -131,14 +130,7 @@ public:
     return (cmp_table != table->table);
   }
 
-  bool examinePosition(table_map found_ref)
-  {
-    if (table->table->map & found_ref)
-    {
-      return true;
-    }
-    return false;
-  }
+  bool examinePosition(table_map found_ref);
 
   KeyUse *getKeyUse()
   {
@@ -188,4 +180,3 @@ private:
 
 } /* end namespace drizzled */
 
-#endif /* DRIZZLED_OPTIMIZER_POSITION_H */
