@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008-2009 Sun Microsystems
+ *  Copyright (C) 2008-2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,17 +17,19 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
-#include "drizzled/session.h"
-#include "drizzled/sql_select.h"
-#include "drizzled/join.h"
-#include "drizzled/optimizer/range.h"
-#include "drizzled/optimizer/quick_group_min_max_select.h"
-#include "drizzled/optimizer/quick_range.h"
-#include "drizzled/optimizer/quick_range_select.h"
-#include "drizzled/optimizer/sel_arg.h"
-#include "drizzled/internal/m_string.h"
-#include "drizzled/util/functors.h"
+#include <config.h>
+#include <drizzled/session.h>
+#include <drizzled/sql_select.h>
+#include <drizzled/join.h>
+#include <drizzled/optimizer/range.h>
+#include <drizzled/optimizer/quick_group_min_max_select.h>
+#include <drizzled/optimizer/quick_range.h>
+#include <drizzled/optimizer/quick_range_select.h>
+#include <drizzled/optimizer/sel_arg.h>
+#include <drizzled/internal/m_string.h>
+#include <drizzled/util/functors.h>
+#include <drizzled/key.h>
+#include <drizzled/table.h>
 
 #include <vector>
 
@@ -150,13 +152,13 @@ int optimizer::QuickGroupMinMaxSelect::init()
 
     if (have_min)
     {
-      if (! (min_functions_it= new List_iterator<Item_sum>(*min_functions)))
+      if (! (min_functions_it= new List<Item_sum>::iterator(min_functions->begin())))
         return 1;
     }
 
     if (have_max)
     {
-      if (! (max_functions_it= new List_iterator<Item_sum>(*max_functions)))
+      if (! (max_functions_it= new List<Item_sum>::iterator(max_functions->begin())))
         return 1;
     }
   }
@@ -223,16 +225,9 @@ void optimizer::QuickGroupMinMaxSelect::adjust_prefix_ranges()
   if (quick_prefix_select &&
       group_prefix_len < quick_prefix_select->max_used_key_length)
   {
-    DYNAMIC_ARRAY *arr= NULL;
-    uint32_t inx;
-
-    for (inx= 0, arr= &quick_prefix_select->ranges; inx < arr->elements; inx++)
-    {
-      optimizer::QuickRange *range= NULL;
-
-      get_dynamic(arr, (unsigned char*)&range, inx);
-      range->flag &= ~(NEAR_MIN | NEAR_MAX);
-    }
+    DYNAMIC_ARRAY& arr= quick_prefix_select->ranges;
+    for (size_t inx= 0; inx < arr.size(); inx++)
+      reinterpret_cast<optimizer::QuickRange**>(arr.buffer)[inx]->flag &= ~(NEAR_MIN | NEAR_MAX);
   }
 }
 
@@ -719,26 +714,22 @@ int optimizer::QuickGroupMinMaxSelect::next_max_in_range()
 
 void optimizer::QuickGroupMinMaxSelect::update_min_result()
 {
-  Item_sum *min_func= NULL;
-
-  min_functions_it->rewind();
-  while ((min_func= (*min_functions_it)++))
+  *min_functions_it= min_functions->begin();
+  for (Item_sum *min_func; (min_func= (*min_functions_it)++); )
     min_func->reset();
 }
 
 
 void optimizer::QuickGroupMinMaxSelect::update_max_result()
 {
-  Item_sum *max_func= NULL;
-
-  max_functions_it->rewind();
-  while ((max_func= (*max_functions_it)++))
+  *max_functions_it= max_functions->begin();
+  for (Item_sum *max_func; (max_func= (*max_functions_it)++); )
     max_func->reset();
 }
 
 
-void optimizer::QuickGroupMinMaxSelect::add_keys_and_lengths(String *key_names,
-                                                             String *used_lengths)
+void optimizer::QuickGroupMinMaxSelect::add_keys_and_lengths(string *key_names,
+                                                             string *used_lengths)
 {
   char buf[64];
   key_names->append(index_info->name);
