@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008-2009 Sun Microsystems
+ *  Copyright (C) 2008-2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,11 +17,12 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_OPTIMIZER_QUICK_RANGE_SELECT_H
-#define DRIZZLED_OPTIMIZER_QUICK_RANGE_SELECT_H
+#pragma once
 
-#include "drizzled/optimizer/range.h"
+#include <drizzled/dynamic_array.h>
+#include <drizzled/optimizer/range.h>
 
+#include <boost/dynamic_bitset.hpp>
 #include <vector>
 
 namespace drizzled
@@ -46,9 +47,9 @@ protected:
 
   /** Members to deal with case when this quick select is a ROR-merged scan */
   bool in_ror_merged_scan;
-  MyBitmap column_bitmap;
-  MyBitmap *save_read_set;
-  MyBitmap *save_write_set;
+  boost::dynamic_bitset<> *column_bitmap;
+  boost::dynamic_bitset<> *save_read_set;
+  boost::dynamic_bitset<> *save_write_set;
   bool free_file; /**< True when this->file is "owned" by this quick select */
 
   /* Range pointers to be used when not using MRR interface */
@@ -106,8 +107,7 @@ public:
                      Table *table,
                      uint32_t index_arg,
                      bool no_alloc,
-                     memory::Root *parent_alloc,
-                     bool *create_err);
+                     memory::Root *parent_alloc);
 
   ~QuickRangeSelect();
 
@@ -203,9 +203,9 @@ public:
     return QS_TYPE_RANGE;
   }
 
-  void add_keys_and_lengths(String *key_names, String *used_lengths);
+  void add_keys_and_lengths(std::string *key_names, std::string *used_lengths);
 
-  void add_info_string(String *str);
+  void add_info_string(std::string *str);
 
   void resetCursor()
   {
@@ -309,4 +309,3 @@ private:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_OPTIMIZER_QUICK_RANGE_SELECT_H */
