@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008-2009 Sun Microsystems
+ *  Copyright (C) 2008-2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,10 +17,9 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_OPTIMIZER_QUICK_ROR_UNION_SELECT_H
-#define DRIZZLED_OPTIMIZER_QUICK_ROR_UNION_SELECT_H
+#pragma once
 
-#include "drizzled/optimizer/range.h"
+#include <drizzled/optimizer/range.h>
 
 #include <vector>
 
@@ -103,9 +102,9 @@ public:
     return QS_TYPE_ROR_UNION;
   }
 
-  void add_keys_and_lengths(String *key_names, String *used_lengths);
-  void add_info_string(String *str);
-  bool is_keys_used(const MyBitmap *fields);
+  void add_keys_and_lengths(std::string *key_names, std::string *used_lengths);
+  void add_info_string(std::string *str);
+  bool is_keys_used(const boost::dynamic_bitset<>& fields);
 
   bool push_quick_back(QuickSelectInterface *quick_sel_range);
 
@@ -128,4 +127,3 @@ private:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_OPTIMIZER_QUICK_ROR_UNION_SELECT_H */
