@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008-2009 Sun Microsystems
+ *  Copyright (C) 2008-2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,10 +17,9 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_OPTIMIZER_SEL_TREE_H
-#define DRIZZLED_OPTIMIZER_SEL_TREE_H
+#pragma once
 
-#include "drizzled/memory/sql_alloc.h"
+#include <drizzled/memory/sql_alloc.h>
 
 namespace drizzled
 {
@@ -31,6 +30,7 @@ namespace optimizer
 class RangeParameter;
 class SEL_IMERGE;
 class SEL_ARG;
+class RorScanInfo;
 
 class SEL_TREE : public drizzled::memory::SqlAlloc
 {
@@ -74,8 +74,8 @@ public:
   key_map ror_scans_map;   /* bitmask of ROR scan-able elements in keys */
   uint32_t n_ror_scans;     /* number of set bits in ror_scans_map */
 
-  struct st_ror_scan_info **ror_scans;     /* list of ROR key scans */
-  struct st_ror_scan_info **ror_scans_end; /* last ROR scan */
+  RorScanInfo **ror_scans;     /* list of ROR key scans */
+  RorScanInfo **ror_scans_end; /* last ROR scan */
   /* Note that #records for each key scan is stored in table->quick_rows */
 
 };
@@ -152,4 +152,3 @@ bool remove_nonrange_trees(RangeParameter *param, SEL_TREE *tree);
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_OPTIMIZER_SEL_TREE_H */
