@@ -1,7 +1,7 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008-2009 Sun Microsystems
+ *  Copyright (C) 2008-2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -51,11 +51,15 @@
   (assuming a index for column d of table t2 is defined)
 */
 
-#include "config.h"
-#include "drizzled/sql_select.h"
-#include "drizzled/item/sum.h"
-#include "drizzled/item/cmpfunc.h"
-#include "drizzled/optimizer/sum.h"
+#include <config.h>
+
+#include <drizzled/sql_select.h>
+#include <drizzled/item/sum.h>
+#include <drizzled/item/cmpfunc.h>
+#include <drizzled/optimizer/sum.h>
+#include <drizzled/plugin/storage_engine.h>
+#include <drizzled/table_list.h>
+#include <drizzled/key.h>
 
 namespace drizzled
 {
@@ -110,7 +114,7 @@ static uint64_t get_exact_record_count(TableList *tables)
 
 int optimizer::sum_query(TableList *tables, List<Item> &all_fields, COND *conds)
 {
-  List_iterator_fast<Item> it(all_fields);
+  List<Item>::iterator it(all_fields.begin());
   int const_result= 1;
   bool recalc_const_item= false;
   uint64_t count= 1;
@@ -262,6 +266,16 @@ int optimizer::sum_query(TableList *tables, List<Item> &all_fields, COND *conds)
                 break;
               }
               error= table->cursor->startIndexScan(static_cast<uint32_t>(ref.key), 1);
+              if (error)
+              {
+                if (table->key_read)
+                {
+                  table->key_read= 0;
+                  table->cursor->extra(HA_EXTRA_NO_KEYREAD);
+                }
+                table->print_error(error, MYF(0));
+                return error;
+              }
 
               if (! ref.key_length)
               {
@@ -541,7 +555,7 @@ bool optimizer::simple_pred(Item_func *func_item, Item **args, bool &inv_order)
     /* MULT_EQUAL_FUNC */
     {
       Item_equal *item_equal= (Item_equal *) func_item;
-      Item_equal_iterator it(*item_equal);
+      Item_equal_iterator it(item_equal->begin());
       args[0]= it++;
       if (it++)
       {
@@ -675,7 +689,7 @@ static bool matching_cond(bool max_fl,
     }
 
     /* AND */
-    List_iterator_fast<Item> li(*((Item_cond*) cond)->argument_list());
+    List<Item>::iterator li(((Item_cond*) cond)->argument_list()->begin());
     Item *item;
     while ((item= li++))
     {
@@ -1057,7 +1071,7 @@ static int maxmin_in_range(bool max_fl, Field* field, COND *cond)
   /* If AND/OR condition */
   if (cond->type() == Item::COND_ITEM)
   {
-    List_iterator_fast<Item> li(*((Item_cond*) cond)->argument_list());
+    List<Item>::iterator li(((Item_cond*) cond)->argument_list()->begin());
     Item *item;
     while ((item= li++))
     {
