@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008-2009 Sun Microsystems
+ *  Copyright (C) 2008-2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,23 +17,21 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_OPTIMIZER_TABLE_READ_PLAN_H
-#define DRIZZLED_OPTIMIZER_TABLE_READ_PLAN_H
+#pragma once
 
-#include "drizzled/util/functors.h"
+#include <drizzled/util/functors.h>
 #include <algorithm>
 
 namespace drizzled
 {
 
-struct st_ror_scan_info;
-
 namespace optimizer
 {
 
 class Parameter;
 class SEL_ARG;
 class SEL_TREE;
+class RorScanInfo;
 
 /*
   Table rows retrieval plan. Range optimizer creates QuickSelectInterface-derived
@@ -134,9 +132,9 @@ public:
                                    memory::Root *parent_alloc);
 
   /* Array of pointers to ROR range scans used in this intersection */
-  struct st_ror_scan_info **first_scan;
-  struct st_ror_scan_info **last_scan; /* End of the above array */
-  struct st_ror_scan_info *cpk_scan;  /* Clustered PK scan, if there is one */
+  RorScanInfo **first_scan;
+  RorScanInfo **last_scan; /* End of the above array */
+  RorScanInfo *cpk_scan;  /* Clustered PK scan, if there is one */
 
   bool is_covering; /* true if no row retrieval phase is necessary */
   double index_scan_costs; /* SUM(cost(index_scan)) */
@@ -251,4 +249,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_OPTIMIZER_TABLE_READ_PLAN_H */
