@@ -11,16 +11,17 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
-#include "config.h"
-#include "drizzled/internal/my_sys.h"
+#include <config.h>
+#include <drizzled/internal/my_sys.h>
 #include <drizzled/gettext.h>
 
-#include "drizzled/internal/m_string.h"
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/error.h"
-#include "drizzled/option.h"
+#include <drizzled/internal/m_string.h>
+#include <drizzled/internal/my_sys.h>
+#include <drizzled/error.h>
+#include <drizzled/option.h>
+#include <drizzled/typelib.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -643,11 +644,11 @@ Will set the option value to given value
             return EXIT_OUT_OF_MEMORY;
           break;
         case GET_ENUM:
-          if (((*(int*)result_pos)= find_type(argument, opts->typelib, 2) - 1) < 0)
+          if (((*(int*)result_pos)= opts->typelib->find_type(argument, 2) - 1) < 0)
             return EXIT_ARGUMENT_INVALID;
           break;
         case GET_SET:
-          *((uint64_t*)result_pos)= find_typeset(argument, opts->typelib, &err);
+          *((uint64_t*)result_pos)= opts->typelib->find_typeset(argument, &err);
           if (err)
             return EXIT_ARGUMENT_INVALID;
           break;
@@ -723,7 +724,7 @@ Works like strncmp, other than 1.) considers '-' and '_' the same.
 2.) Returns -1 if strings differ, 0 if they are equal
    */
 
-  bool getopt_compare_strings(register const char *s, register const char *t,
+  bool getopt_compare_strings(const char *s, const char *t,
       uint32_t length)
   {
     char const *end= s + length;
@@ -1234,11 +1235,11 @@ Print variables.
                 if (!(bit & llvalue))
                   continue;
                 llvalue&= ~bit;
-                printf( llvalue ? "%s," : "%s\n", get_type(optp->typelib, nr));
+                printf( llvalue ? "%s," : "%s\n", optp->typelib->get_type(nr));
               }
             break;
           case GET_ENUM:
-            printf("%s\n", get_type(optp->typelib, *(uint*) value));
+            printf("%s\n", optp->typelib->get_type(*(uint*) value));
             break;
           case GET_STR:
           case GET_STR_ALLOC:                    /* fall through */
