@@ -11,12 +11,9 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
-#ifndef DRIZZLED_OPTION_H
-#define DRIZZLED_OPTION_H
-
-#include "drizzled/typelib.h"
+#pragma once
 
 namespace drizzled
 {
@@ -93,5 +90,4 @@ bool getopt_compare_strings(const char *s, const char *t, uint32_t length);
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_OPTION_H */
 
