@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,10 +17,8 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_ORDER_H
-#define DRIZZLED_ORDER_H
+#pragma once
 
-#include <drizzled/sql_bitmap.h>
 #include <drizzled/field.h>
 
 namespace drizzled
@@ -30,22 +28,38 @@ class Item;
 
 /* Order clause list element */
 
-struct order_st {
-  struct order_st *next;
-  Item	 **item;			/* Point at item in select fields */
-  Item	 *item_ptr;			/* Storage for initial item */
-  Item   **item_copy;			/* For SPs; the original item ptr */
-  int    counter;                       /* position in SELECT list, correct
-                                           only if counter_used is true*/
-  bool	 asc;				/* true if ascending */
-  bool	 free_me;			/* true if item isn't shared  */
-  bool	 in_field_list;			/* true if in select field list */
-  bool   counter_used;                  /* parameter was counter of columns */
-  Field  *field;			/* If tmp-table group */
-  char	 *buff;				/* If tmp-table group */
+/* Order clause list element */
+class Order{
+public:
+  struct Order *next;
+  Item **item;          /* Point at item in select fields */
+  Item *item_ptr;       /* Storage for initial item */
+  Item **item_copy;     /* For SPs; the original item ptr */
+  int  counter;         /* position in SELECT list, correct
+                           only if counter_used is true*/
+  bool asc;             /* true if ascending */
+  bool free_me;         /* true if item isn't shared  */
+  bool in_field_list;   /* true if in select field list */
+  bool counter_used;    /* parameter was counter of columns */
+  Field  *field;        /* If tmp-table group */
+  char   *buff;         /* If tmp-table group */
   table_map used, depend_map;
-};
 
+  Order():
+    next(NULL),
+    item(NULL),
+    item_ptr(NULL),
+    item_copy(NULL),
+    counter(0),
+    asc(false),
+    free_me(false),
+    in_field_list(false),
+    counter_used(false),
+    field(NULL),
+    buff(NULL),
+    used(0),
+    depend_map(0)
+  {}
+};
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_ORDER_H */
