@@ -19,13 +19,11 @@
  */
 
 #include <config.h>
+#include <drizzled/session.h>
 #include <drizzled/parser.h>
 #include <drizzled/alter_info.h>
-#include <drizzled/create_field.h>
+#include <drizzled/alter_drop.h>
 #include <drizzled/item/subselect.h>
-#include <drizzled/lex_input_stream.h>
-#include <drizzled/message/alter_table.pb.h>
-#include <drizzled/session.h>
 #include <drizzled/sql_lex.h>
 
 namespace drizzled {
@@ -67,6 +65,8 @@ Item* handle_sql2003_note184_exception(Session *session, Item* left, bool equal,
     expression the <subquery> is.
   */
 
+  Item *result;
+
   if (expr->type() == Item::SUBSELECT_ITEM)
   {
     Item_subselect *expr2 = (Item_subselect*) expr;
@@ -74,6 +74,7 @@ Item* handle_sql2003_note184_exception(Session *session, Item* left, bool equal,
     if (expr2->substype() == Item_subselect::SINGLEROW_SUBS)
     {
       Item_singlerow_subselect *expr3 = (Item_singlerow_subselect*) expr2;
+      Select_Lex *subselect;
 
       /*
         Implement the mandated change, by altering the semantic tree:
@@ -83,14 +84,22 @@ Item* handle_sql2003_note184_exception(Session *session, Item* left, bool equal,
         which is represented as
           Item_in_subselect(left, subselect)
       */
-      Select_Lex* subselect= expr3->invalidate_and_restore_select_lex();
-      Item* result= new (session->mem_root) Item_in_subselect(left, subselect);
-      return equal ? result : negate_expression(session, result);
+      subselect= expr3->invalidate_and_restore_select_lex();
+      result= new (session->mem_root) Item_in_subselect(left, subselect);
+
+      if (! equal)
+        result = negate_expression(session, result);
+
+      return(result);
     }
   }
-  return equal
-    ? (Item*) new (session->mem_root) Item_func_eq(left, expr)
-    : (Item*) new (session->mem_root) Item_func_ne(left, expr);
+
+  if (equal)
+    result= new (session->mem_root) Item_func_eq(left, expr);
+  else
+    result= new (session->mem_root) Item_func_ne(left, expr);
+
+  return(result);
 }
 
 /**
@@ -210,11 +219,14 @@ void my_parse_error(const char *message)
   my_printf_error(ER_PARSE_ERROR_UNKNOWN, ER(ER_PARSE_ERROR_UNKNOWN), MYF(0), message);
 }
 
-bool check_reserved_words(str_ref name)
+bool check_reserved_words(LEX_STRING *name)
 {
-  return not system_charset_info->strcasecmp(name.data(), "GLOBAL") 
-    || not system_charset_info->strcasecmp(name.data(), "LOCAL")
-    || not system_charset_info->strcasecmp(name.data(), "SESSION");
+  if (!my_strcasecmp(system_charset_info, name->str, "GLOBAL") ||
+      !my_strcasecmp(system_charset_info, name->str, "LOCAL") ||
+      !my_strcasecmp(system_charset_info, name->str, "SESSION"))
+    return true;
+
+  return false;
 }
 
 
@@ -287,11 +299,11 @@ bool buildOrderBy(LEX *lex)
   return true;
 }
 
-void buildEngineOption(LEX *lex, const char *key, str_ref value)
+void buildEngineOption(LEX *lex, const char *key, const LEX_STRING &value)
 {
   message::Engine::Option *opt= lex->table()->mutable_engine()->add_options();
   opt->set_name(key);
-  opt->set_state(value.data(), value.size());
+  opt->set_state(value.str, value.length);
 }
 
 void buildEngineOption(LEX *lex, const char *key, uint64_t value)
@@ -301,66 +313,72 @@ void buildEngineOption(LEX *lex, const char *key, uint64_t value)
   opt->set_state(boost::lexical_cast<std::string>(value));
 }
 
-void buildSchemaOption(LEX *lex, const char *key, str_ref value)
+void buildSchemaOption(LEX *lex, const char *key, const LEX_STRING &value)
 {
-  statement::CreateSchema *statement= static_cast<statement::CreateSchema*>(lex->statement);
+  statement::CreateSchema *statement= (statement::CreateSchema *)lex->statement;
   message::Engine::Option *opt= statement->schema_message.mutable_engine()->add_options();
   opt->set_name(key);
-  opt->set_state(value.data(), value.size());
-}
-
-void buildSchemaDefiner(LEX *lex, const identifier::User &user)
-{
-  statement::CreateSchema *statement= static_cast<statement::CreateSchema*>(lex->statement);
-  message::set_definer(statement->schema_message, user);
+  opt->set_state(value.str, value.length);
 }
 
 void buildSchemaOption(LEX *lex, const char *key, uint64_t value)
 {
-  statement::CreateSchema *statement= static_cast<statement::CreateSchema*>(lex->statement);
+  statement::CreateSchema *statement= (statement::CreateSchema *)lex->statement;
   message::Engine::Option *opt= statement->schema_message.mutable_engine()->add_options();
   opt->set_name(key);
   opt->set_state(boost::lexical_cast<std::string>(value));
 }
 
-bool checkFieldIdent(LEX *lex, str_ref schema_name, str_ref table_name)
+bool checkFieldIdent(LEX *lex, const LEX_STRING &schema_name, const LEX_STRING &table_name)
 {
   TableList *table= reinterpret_cast<TableList*>(lex->current_select->table_list.first);
 
-  if (schema_name.size() && table_alias_charset->strcasecmp(schema_name.data(), table->getSchemaName()))
+  if (schema_name.length)
   {
-    my_error(ER_WRONG_DB_NAME, MYF(0), schema_name.data());
-    return false;
+    if (my_strcasecmp(table_alias_charset, schema_name.str, table->getSchemaName()))
+    {
+      my_error(ER_WRONG_DB_NAME, MYF(0), schema_name.str);
+      return false;
+    }
   }
 
-  if (table_alias_charset->strcasecmp(table_name.data(), table->getTableName()))
+  if (my_strcasecmp(table_alias_charset, table_name.str,
+                    table->getTableName()))
   {
-    my_error(ER_WRONG_TABLE_NAME, MYF(0), table_name.data());
+    my_error(ER_WRONG_TABLE_NAME, MYF(0), table_name.str);
     return false;
   }
 
   return true;
 }
 
-Item *buildIdent(LEX *lex, str_ref schema_name, str_ref table_name, str_ref field_name)
+Item *buildIdent(LEX *lex,
+                 const LEX_STRING &schema_name,
+                 const LEX_STRING &table_name,
+                 const LEX_STRING &field_name)
 {
   Select_Lex *sel= lex->current_select;
 
-  if (table_name.size() and sel->no_table_names_allowed)
+  if (table_name.length and sel->no_table_names_allowed)
   {
-    my_error(ER_TABLENAME_NOT_ALLOWED_HERE, MYF(0), table_name.data(), lex->session->where());
+    my_error(ER_TABLENAME_NOT_ALLOWED_HERE,
+             MYF(0), table_name.str, lex->session->where());
   }
 
-  return sel->parsing_place != IN_HAVING || sel->get_in_sum_expr() > 0
-    ? (Item*) new Item_field(lex->current_context(), schema_name.data(), table_name.data(), field_name.data()) 
-    : (Item*) new Item_ref(lex->current_context(), schema_name.data(), table_name.data(), field_name.data());
+  Item *item= (sel->parsing_place != IN_HAVING or
+               sel->get_in_sum_expr() > 0) ?
+    (Item*) new Item_field(lex->current_context(), schema_name.str, table_name.str, field_name.str) :
+    (Item*) new Item_ref(lex->current_context(), schema_name.str, table_name.str, field_name.str);
+
+  return item;
 }
 
-Item *buildTableWild(LEX *lex, str_ref schema_name, str_ref table_name)
+Item *buildTableWild(LEX *lex, const LEX_STRING &schema_name, const LEX_STRING &table_name)
 {
   Select_Lex *sel= lex->current_select;
-  Item *item= new Item_field(lex->current_context(), schema_name.data(), table_name.data(), "*");
+  Item *item= new Item_field(lex->current_context(), schema_name.str, table_name.str, "*");
   sel->with_wild++;
+
   return item;
 }
 
@@ -370,23 +388,23 @@ void buildCreateFieldIdent(LEX *lex)
   lex->length= lex->dec=0;
   lex->type=0;
   statement->default_value= statement->on_update_value= 0;
-  statement->comment= null_lex_string();
+  statement->comment= null_lex_str;
   lex->charset= NULL;
   statement->column_format= COLUMN_FORMAT_TYPE_DEFAULT;
 
-  message::AddedFields &added_fields_proto= ((statement::CreateTable *)lex->statement)->alter_info.added_fields_proto;
-  lex->setField(added_fields_proto.add_added_field());
+  message::AlterTable &alter_proto= ((statement::CreateTable *)lex->statement)->alter_info.alter_proto;
+  lex->setField(alter_proto.add_added_field());
 }
 
 void storeAlterColumnPosition(LEX *lex, const char *position)
 {
   statement::AlterTable *statement= (statement::AlterTable *)lex->statement;
 
-  lex->last_field->after= position;
+  lex->last_field->after=const_cast<char*> (position);
   statement->alter_info.flags.set(ALTER_COLUMN_ORDER);
 }
 
-bool buildCollation(LEX *lex, const charset_info_st *arg)
+bool buildCollation(LEX *lex, const CHARSET_INFO *arg)
 {
   statement::CreateTable *statement= (statement::CreateTable *)lex->statement;
 
@@ -405,21 +423,30 @@ bool buildCollation(LEX *lex, const charset_info_st *arg)
   return true;
 }
 
-void buildKey(LEX *lex, Key::Keytype type_par, str_ref name_arg)
+void buildKey(LEX *lex, Key::Keytype type_par, const lex_string_t &name_arg)
 {
   statement::AlterTable *statement= (statement::AlterTable *)lex->statement;
-  Key *key= new Key(type_par, name_arg, &statement->key_create_info, 0, lex->col_list);
+  Key *key= new Key(type_par, name_arg, &statement->key_create_info, 0,
+                    lex->col_list);
   statement->alter_info.key_list.push_back(key);
   lex->col_list.clear(); /* Alloced by memory::sql_alloc */
 }
 
-void buildForeignKey(LEX *lex, str_ref name_arg, drizzled::Table_ident *table)
+void buildForeignKey(LEX *lex, const lex_string_t &name_arg, drizzled::Table_ident *table)
 {
   statement::AlterTable *statement= (statement::AlterTable *)lex->statement;
-  statement->alter_info.key_list.push_back(new Foreign_key(name_arg, lex->col_list, table, lex->ref_list, 
-    statement->fk_delete_opt, statement->fk_update_opt, statement->fk_match_option));
+  Key *key= new Foreign_key(name_arg, lex->col_list,
+                            table,
+                            lex->ref_list,
+                            statement->fk_delete_opt,
+                            statement->fk_update_opt,
+                            statement->fk_match_option);
 
-  statement->alter_info.key_list.push_back(new Key(Key::MULTIPLE, name_arg, &default_key_create_info, 1, lex->col_list));
+  statement->alter_info.key_list.push_back(key);
+  key= new Key(Key::MULTIPLE, name_arg,
+               &default_key_create_info, 1,
+               lex->col_list);
+  statement->alter_info.key_list.push_back(key);
   lex->col_list.clear(); /* Alloced by memory::sql_alloc */
   /* Only used for ALTER TABLE. Ignored otherwise. */
   statement->alter_info.flags.set(ALTER_FOREIGN_KEY);
@@ -427,7 +454,7 @@ void buildForeignKey(LEX *lex, str_ref name_arg, drizzled::Table_ident *table)
 
 drizzled::enum_field_types buildIntegerColumn(LEX *lex, drizzled::enum_field_types final_type, const bool is_unsigned)
 { 
-  lex->length= NULL; /* use default length */
+  lex->length=(char*) 0; /* use default length */
 
   if (is_unsigned)
   {
@@ -476,7 +503,7 @@ drizzled::enum_field_types buildSerialColumn(LEX *lex)
 
 drizzled::enum_field_types buildVarcharColumn(LEX *lex, const char *length)
 {
-  lex->length= length;
+  lex->length= const_cast<char *>(length);
 
   if (lex->field())
   {
@@ -502,7 +529,7 @@ drizzled::enum_field_types buildDecimalColumn(LEX *lex)
 
 drizzled::enum_field_types buildVarbinaryColumn(LEX *lex, const char *length)
 {
-  lex->length= length;
+  lex->length= const_cast<char *>(length);
   lex->charset= &my_charset_bin;
 
   if (lex->field())
@@ -555,14 +582,6 @@ drizzled::enum_field_types buildUuidColumn(LEX *lex)
   return DRIZZLE_TYPE_UUID;
 }
 
-drizzled::enum_field_types buildIPv6Column(LEX *lex)
-{
-  if (lex->field())
-    lex->field()->set_type(message::Table::Field::IPV6);
-
-  return DRIZZLE_TYPE_IPV6;
-}
-
 drizzled::enum_field_types buildDoubleColumn(LEX *lex)
 {
   if (lex->field())
@@ -582,7 +601,7 @@ drizzled::enum_field_types buildTimestampColumn(LEX *lex, const char *length)
 
   if (length)
   {
-    lex->length= length;
+    lex->length= const_cast<char *>(length);
     return DRIZZLE_TYPE_MICROTIME;
   }
 
@@ -629,7 +648,7 @@ void buildPrimaryOnColumn(LEX *lex)
 
 void buildReplicationOption(LEX *lex, bool arg)
 {
-  statement::CreateSchema *statement= static_cast<statement::CreateSchema*>(lex->statement);
+  statement::CreateSchema *statement= (statement::CreateSchema *)lex->statement;
   message::set_is_replicated(statement->schema_message, arg);
 }
 
@@ -637,19 +656,15 @@ void buildAddAlterDropIndex(LEX *lex, const char *name, bool is_foreign_key)
 {
   statement::AlterTable *statement= (statement::AlterTable *)lex->statement;
 
-  message::AlterTable::AlterTableOperation *operation;
-  operation= lex->alter_table()->add_operations();
-  operation->set_drop_name(name);
-
   statement->alter_info.flags.set(ALTER_DROP_INDEX);
   if (is_foreign_key)
   {
     statement->alter_info.flags.set(ALTER_FOREIGN_KEY);
-    operation->set_operation(message::AlterTable::AlterTableOperation::DROP_FOREIGN_KEY);
+    statement->alter_info.drop_list.push_back(AlterDrop(AlterDrop::FOREIGN_KEY, name));
   }
   else
   {
-    operation->set_operation(message::AlterTable::AlterTableOperation::DROP_KEY);
+    statement->alter_info.drop_list.push_back(AlterDrop(AlterDrop::KEY, name));
   }
 }
 
