@@ -3,7 +3,7 @@
  *
  *  Definitions required for Authentication plugin
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,22 +19,27 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_PLUGIN_AUTHENTICATION_H
-#define DRIZZLED_PLUGIN_AUTHENTICATION_H
+#pragma once
 
 #include <string>
 
-#include "drizzled/plugin.h"
-#include "drizzled/plugin/plugin.h"
+#include <drizzled/plugin.h>
+#include <drizzled/plugin/plugin.h>
+#include <drizzled/identifier.h>
+
+#include <drizzled/visibility.h>
 
 namespace drizzled
 {
-class SecurityContext;
+
+namespace identifier {
+class User;
+} 
 
 namespace plugin
 {
 
-class Authentication : public Plugin
+class DRIZZLED_API Authentication : public Plugin
 {
   Authentication();
   Authentication(const Authentication &);
@@ -45,16 +50,15 @@ public:
   {}
   virtual ~Authentication() {}
 
-  virtual bool authenticate(const SecurityContext &sctx,
+  virtual bool authenticate(const identifier::User &sctx,
                             const std::string &passwd)= 0;
 
   static bool addPlugin(plugin::Authentication *auth);
   static void removePlugin(plugin::Authentication *auth);
-  static bool isAuthenticated(const SecurityContext &sctx,
+  static bool isAuthenticated(drizzled::identifier::User::const_reference sctx,
                               const std::string &password);
 };
 
 } /* namespace plugin */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_PLUGIN_AUTHENTICATION_H */
