@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,17 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
-#include <cstdio>
-#include "drizzled/plugin/client.h"
+#include <config.h>
 
-using namespace std;
+#include <cstdio>
+
+#include <drizzled/plugin/client.h>
+#include <drizzled/type/time.h>
 
 namespace drizzled
 {
 
-bool plugin::Client::store(const DRIZZLE_TIME *from)
+bool plugin::Client::store(const type::Time *from)
 {
   const size_t buff_len= 40;
   char buff[buff_len];
@@ -35,7 +36,7 @@ bool plugin::Client::store(const DRIZZLE_TIME *from)
 
   switch (from->time_type)
   {
-  case DRIZZLE_TIMESTAMP_DATETIME:
+  case type::DRIZZLE_TIMESTAMP_DATETIME:
     length= snprintf(buff, (buff_len-length), "%04d-%02d-%02d %02d:%02d:%02d",
                     (int) from->year,
                     (int) from->month,
@@ -47,14 +48,14 @@ bool plugin::Client::store(const DRIZZLE_TIME *from)
       length+= snprintf(buff+length, (buff_len-length), ".%06d", (int)from->second_part);
     break;
 
-  case DRIZZLE_TIMESTAMP_DATE:
+  case type::DRIZZLE_TIMESTAMP_DATE:
     length= snprintf(buff, (buff_len-length), "%04d-%02d-%02d",
                     (int) from->year,
                     (int) from->month,
                     (int) from->day);
     break;
 
-  case DRIZZLE_TIMESTAMP_TIME:
+  case type::DRIZZLE_TIMESTAMP_TIME:
     day= (from->year || from->month) ? 0 : from->day;
     length= snprintf(buff, (buff_len-length), "%s%02ld:%02d:%02d",
                     from->neg ? "-" : "",
@@ -65,8 +66,8 @@ bool plugin::Client::store(const DRIZZLE_TIME *from)
       length+= snprintf(buff+length, (buff_len-length), ".%06d", (int)from->second_part);
     break;
 
-  case DRIZZLE_TIMESTAMP_NONE:
-  case DRIZZLE_TIMESTAMP_ERROR:
+  case type::DRIZZLE_TIMESTAMP_NONE:
+  case type::DRIZZLE_TIMESTAMP_ERROR:
   default:
     assert(0);
     return false;
@@ -79,6 +80,7 @@ bool plugin::Client::store(const char *from)
 {
   if (from == NULL)
     return store();
+
   return store(from, strlen(from));
 }
 
