@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,11 +17,15 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_PLUGIN_CLIENT_H
-#define DRIZZLED_PLUGIN_CLIENT_H
+#pragma once
 
-#include <drizzled/sql_list.h>
+#include <drizzled/catalog/instance.h>
+#include <drizzled/catalog/local.h>
+#include <drizzled/error_t.h>
 #include <drizzled/item.h>
+#include <drizzled/sql_list.h>
+
+#include <drizzled/visibility.h>
 
 namespace drizzled
 {
@@ -38,7 +42,7 @@ namespace plugin
  * file-descriptor based, so for non-fd client sources (like from another
  * thread), derived classes will need to use a pipe() for event notifications.
  */
-class Client
+class DRIZZLED_API Client
 {
 protected:
   Session *session;
@@ -104,6 +108,26 @@ public:
    */
   virtual bool authenticate(void)= 0;
 
+  virtual bool isConsole() const
+  {
+    return false;
+  }
+
+  virtual bool isInteractive() const
+  {
+    return false;
+  }
+
+  virtual bool isAdmin() const
+  {
+    return false;
+  }
+
+  virtual catalog::Instance::shared_ptr catalog()
+  {
+    return catalog::local();
+  }
+
   /**
    * Read command from client.
    */
@@ -112,7 +136,7 @@ public:
   /* Send responses. */
   virtual void sendOK(void)= 0;
   virtual void sendEOF(void)= 0;
-  virtual void sendError(uint32_t sql_errno, const char *err)= 0;
+  virtual void sendError(const drizzled::error_t sql_errno, const char *err)= 0;
 
   /**
    * Send field list for result set.
@@ -127,7 +151,7 @@ public:
   virtual bool store(int64_t from)= 0;
   virtual bool store(uint64_t from)= 0;
   virtual bool store(double from, uint32_t decimals, String *buffer)= 0;
-  virtual bool store(const DRIZZLE_TIME *from);
+  virtual bool store(const type::Time *from);
   virtual bool store(const char *from);
   virtual bool store(const char *from, size_t length)= 0;
   virtual bool store(const std::string &from)
@@ -145,4 +169,3 @@ public:
 } /* namespace plugin */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_PLUGIN_CLIENT_H */
