@@ -19,10 +19,11 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_PLUGIN_DAEMON_H
-#define DRIZZLED_PLUGIN_DAEMON_H
+#pragma once
 
-#include "drizzled/plugin/plugin.h"
+#include <drizzled/plugin/plugin.h>
+
+#include <drizzled/visibility.h>
 
 namespace drizzled
 {
@@ -31,7 +32,7 @@ class Session;
 namespace plugin
 {
 
-class Daemon : public Plugin
+class DRIZZLED_API Daemon : public Plugin
 {
   Daemon();
   Daemon(const Daemon &);
@@ -58,4 +59,3 @@ public:
 } /* namespace plugin */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_PLUGIN_DAEMON_H */
