@@ -3,7 +3,7 @@
  *
  *  Definitions required for Error Message plugin
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,44 +19,48 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_PLUGIN_ERROR_MESSAGE_H
-#define DRIZZLED_PLUGIN_ERROR_MESSAGE_H
+#pragma once
 
-#include "drizzled/plugin/plugin.h"
+#include <drizzled/plugin/plugin.h>
+#include <drizzled/error/level_t.h>
 
 #include <stdarg.h>
 
 #include <string>
 
+#include <drizzled/visibility.h>
+
 namespace drizzled
 {
-class Session;
 
 namespace plugin
 {
 
-class ErrorMessage : public Plugin
+class DRIZZLED_API ErrorMessage : public Plugin
 {
   ErrorMessage();
   ErrorMessage(const ErrorMessage &);
   ErrorMessage& operator=(const ErrorMessage &);
+
 public:
   explicit ErrorMessage(std::string name_arg)
    : Plugin(name_arg, "ErrorMessage")
   {}
   virtual ~ErrorMessage() {}
 
-  virtual bool errmsg(Session *session, int priority,
-                      const char *format, va_list ap)=0;
+  virtual bool errmsg(error::level_t priority, const char *format, va_list ap)=0;
 
   static bool addPlugin(plugin::ErrorMessage *handler);
   static void removePlugin(plugin::ErrorMessage *handler);
 
-  static bool vprintf(Session *session, int priority, char const *format,
-                      va_list ap);
+  static bool vprintf(error::level_t priority, char const *format, va_list ap);
+
+  bool removeLast() const
+  {
+    return true;
+  }
 };
 
 } /* namespace plugin */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_PLUGIN_ERROR_MESSAGE_H */
