@@ -21,23 +21,21 @@
  * 2010-05-12
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <string>
 #include <vector>
 
-#include "drizzled/session.h"
-#include "drizzled/table_list.h"
-#include "drizzled/table_share.h"
-#include "drizzled/module/registry.h"
-#include "drizzled/plugin/event_observer.h"
+#include <drizzled/session.h>
+#include <drizzled/table_list.h>
+#include <drizzled/table/instance.h>
+#include <drizzled/module/registry.h>
+#include <drizzled/plugin/event_observer.h>
 #include <drizzled/util/functors.h>
 #include <algorithm>
 
 
 
-using namespace std;
-
 namespace drizzled
 {
 
@@ -46,7 +44,12 @@ namespace plugin
 
 /*============================*/
   // Basic plugin registration stuff.
-  static vector<EventObserver *> all_event_plugins;
+  EventObserverVector all_event_plugins;
+
+  const EventObserverVector &EventObserver::getEventObservers(void)
+  {
+    return all_event_plugins;
+  }
 
   //---------
   bool EventObserver::addPlugin(EventObserver *handler)
@@ -60,7 +63,7 @@ namespace plugin
   void EventObserver::removePlugin(EventObserver *handler)
   {
     if (handler != NULL)
-      all_event_plugins.erase(find(all_event_plugins.begin(), all_event_plugins.end(), handler));
+      all_event_plugins.erase(std::find(all_event_plugins.begin(), all_event_plugins.end(), handler));
   }
 
 
@@ -76,28 +79,26 @@ namespace plugin
   {
 
   public:
-    typedef multimap<uint32_t, EventObserver *> ObserverMap;
+    typedef std::multimap<uint32_t, EventObserver *> ObserverMap;
 
   private:
     /* A list of lists indexed by event type. */
-    vector<ObserverMap *> event_observer_lists;
+    std::vector<ObserverMap *> event_observer_lists;
 
   public:
 
     EventObserverList()
     {
-      uint32_t i;
-
-      event_observer_lists.reserve(EventObserver::MAX_EVENT_COUNT);
-      for (i=0; i < EventObserver::MAX_EVENT_COUNT; i++)
-      {
-        event_observer_lists[i]= NULL;
-      }
+			// Initialize the list with NULL pointers.
+			event_observer_lists.assign(EventObserver::MAX_EVENT_COUNT, NULL);
     }
 
     ~EventObserverList()
     {
-      clearAllObservers();
+      std::for_each(event_observer_lists.begin(),
+                    event_observer_lists.end(),
+                    DeletePtr());
+      event_observer_lists.clear();
     }
 
     /* Add the observer to the observer list for the even, positioning it if required.
@@ -126,9 +127,9 @@ namespace plugin
       /* If positioned then check if the position is already taken. */
       if (position) 
       {
-        if (observers->find(event_pos) != observers->end())
+        if (observers->count(event_pos))
         {
-          errmsg_printf(ERRMSG_LVL_WARN,
+          errmsg_printf(error::WARN,
                         _("EventObserverList::addEventObserver() Duplicate event position %d for event '%s' from EventObserver plugin '%s'"),
                         position,
                         EventObserver::eventName(event), 
@@ -136,16 +137,7 @@ namespace plugin
         }
       }
 
-      observers->insert(pair<uint32_t, EventObserver *>(event_pos, eventObserver) );
-    }
-
-    /* Remove all observer from all lists. */
-    void clearAllObservers()
-    {
-      for_each(event_observer_lists.begin(),
-               event_observer_lists.end(),
-               DeletePtr());
-      event_observer_lists.clear();
+      observers->insert(std::pair<uint32_t, EventObserver *>(event_pos, eventObserver) );
     }
 
 
@@ -174,7 +166,7 @@ namespace plugin
   /* For each EventObserver plugin call its registerTableEventsDo() meathod so that it can
    * register what events, if any, it is interested in on this table.
    */ 
-  class RegisterTableEventsIterate : public unary_function<EventObserver *, void>
+  class RegisterTableEventsIterate : public std::unary_function<EventObserver *, void>
   {
     TableShare &table_share;
     EventObserverList &observers;
@@ -202,22 +194,20 @@ namespace plugin
 
     observers= table_share.getTableObservers();
 
-    if (observers == NULL) 
-    {
-      observers= new EventObserverList();
-      table_share.setTableObservers(observers);
-    } 
-    else 
-    {
-      /* Calling registerTableEvents() for a table that already has
-       * events registered on it is probably a programming error.
-     */
-      observers->clearAllObservers();
+    if (observers != NULL) 
+		{
+			errmsg_printf(error::WARN,
+									_("EventObserver::registerTableEvents(): Table already has events registered on it: probable programming error."));
+			table_share.setTableObservers(NULL);
+      delete observers;
     }
 
+		observers= new EventObserverList();
+		table_share.setTableObservers(observers);
+ 
 
-    for_each(all_event_plugins.begin(), all_event_plugins.end(),
-             RegisterTableEventsIterate(table_share, *observers));
+    std::for_each(all_event_plugins.begin(), all_event_plugins.end(),
+                  RegisterTableEventsIterate(table_share, *observers));
 
   }
 
@@ -225,7 +215,7 @@ namespace plugin
   /* Cleanup before freeing the TableShare object. */
   void EventObserver::deregisterTableEvents(TableShare &table_share)
   {
-    if (all_event_plugins.empty())
+   if (all_event_plugins.empty())
       return;
 
     EventObserverList *observers;
@@ -235,7 +225,6 @@ namespace plugin
     if (observers) 
     {
       table_share.setTableObservers(NULL);
-      observers->clearAllObservers();
       delete observers;
     }
   }
@@ -249,7 +238,7 @@ namespace plugin
   /* For each EventObserver plugin call its registerSchemaEventsDo() meathod so that it can
    * register what events, if any, it is interested in on the schema.
    */ 
-  class RegisterSchemaEventsIterate : public unary_function<EventObserver *, void>
+  class RegisterSchemaEventsIterate : public std::unary_function<EventObserver *, void>
   {
     const std::string &db;
     EventObserverList &observers;
@@ -282,31 +271,19 @@ namespace plugin
     {
       observers= new EventObserverList();
       session.setSchemaObservers(db, observers);
-    }
+   }
 
-    for_each(all_event_plugins.begin(), all_event_plugins.end(),
-             RegisterSchemaEventsIterate(db, *observers));
+    std::for_each(all_event_plugins.begin(), all_event_plugins.end(),
+                  RegisterSchemaEventsIterate(db, *observers));
 
   }
 
   //----------
   /* Cleanup before freeing the Session object. */
-  void EventObserver::deregisterSchemaEvents(Session &session, const std::string &db)
+  void EventObserver::deregisterSchemaEvents(EventObserverList *observers)
   {
-    if (all_event_plugins.empty())
-      return;
-
-    EventObserverList *observers;
-
-    observers= session.getSchemaObservers(db);
-
-    if (observers) 
-    {
-      session.setSchemaObservers(db, NULL);
-      observers->clearAllObservers();
       delete observers;
-    }
-  }
+   }
 
   /*========================================================*/
   /*             Session Event Observer handling:           */
@@ -316,7 +293,7 @@ namespace plugin
   /* For each EventObserver plugin call its registerSessionEventsDo() meathod so that it can
    * register what events, if any, it is interested in on this session.
    */ 
-  class RegisterSessionEventsIterate : public unary_function<EventObserver *, void>
+  class RegisterSessionEventsIterate : public std::unary_function<EventObserver *, void>
   {
     Session &session;
     EventObserverList &observers;
@@ -342,49 +319,38 @@ namespace plugin
     EventObserverList *observers;
 
     observers= session.getSessionObservers();
+		if (observers) { // This should not happed
+			errmsg_printf(error::WARN,
+									_("EventObserver::registerSessionEvents(): Session already has events registered on it: probable programming error."));
+			session.setSessionObservers(NULL);
+			delete observers;
+		}
 
-    if (observers == NULL) 
-    {
-      observers= new EventObserverList();
-      session.setSessionObservers(observers);
-    }
+	observers= new EventObserverList();
+	session.setSessionObservers(observers);
 
-    observers->clearAllObservers();
-
-    for_each(all_event_plugins.begin(), all_event_plugins.end(),
-             RegisterSessionEventsIterate(session, *observers));
+  std::for_each(all_event_plugins.begin(), all_event_plugins.end(),
+                RegisterSessionEventsIterate(session, *observers));
 
   }
 
   //----------
   /* Cleanup before freeing the session object. */
-  void EventObserver::deregisterSessionEvents(Session &session)
+  void EventObserver::deregisterSessionEvents(EventObserverList *observers)
   {
-    if (all_event_plugins.empty())
-      return;
-
-    EventObserverList *observers;
-
-    observers= session.getSessionObservers();
-
-    if (observers) 
-    {
-      session.setSessionObservers(NULL);
-      observers->clearAllObservers();
       delete observers;
-    }
   }
 
 
   /* Event observer list iterator: */
   //----------
-  class EventIterate : public unary_function<pair<uint32_t, EventObserver *>, bool>
+  class EventIterate : public std::unary_function<std::pair<uint32_t, EventObserver *>, bool>
   {
     EventData &data;
 
   public:
     EventIterate(EventData &data_arg) :
-      unary_function<pair<uint32_t, EventObserver *>, bool>(),
+      std::unary_function<std::pair<uint32_t, EventObserver *>, bool>(),
       data(data_arg)
     {}
 
@@ -395,7 +361,7 @@ namespace plugin
       {
         /* TRANSLATORS: The leading word "EventObserver" is the name
           of the plugin api, and so should not be translated. */
-        errmsg_printf(ERRMSG_LVL_ERROR,
+        errmsg_printf(error::ERROR,
                       _("EventIterate event handler '%s' failed for event '%s'"),
                       handler.second->getName().c_str(), handler.second->eventName(data.event));
 
@@ -415,6 +381,9 @@ namespace plugin
   {
     EventObserverList::ObserverMap *eventObservers;
 
+    if (observerList == NULL)
+      return false; // Nobody was interested in the event. :(
+
     eventObservers = observerList->getObservers(event);
 
     if (eventObservers == NULL)
@@ -422,8 +391,8 @@ namespace plugin
 
     /* Use find_if instead of foreach so that we can collect return codes */
     EventObserverList::ObserverMap::iterator iter=
-      find_if(eventObservers->begin(), eventObservers->end(),
-              EventIterate(*this)); 
+      std::find_if(eventObservers->begin(), eventObservers->end(),
+                   EventIterate(*this)); 
     /* If iter is == end() here, that means that all of the plugins returned
      * false, which in this case means they all succeeded. Since we want to 
      * return false on success, we return the value of the two being !=.
@@ -439,6 +408,11 @@ namespace plugin
     return EventData::callEventObservers();
   }
 
+  bool SessionEventData::hasEvents(Session &in_session)
+  {
+    return (in_session.getSessionObservers() != NULL);
+  }
+
   //--------
   bool SchemaEventData::callEventObservers()
   {
@@ -455,16 +429,21 @@ namespace plugin
   //--------
   bool TableEventData::callEventObservers()
   {
-    observerList= table.s->getTableObservers();
+    observerList= table.getMutableShare()->getTableObservers();
 
     return EventData::callEventObservers();
   }
 
+  bool TableEventData::hasEvents(Table &in_table)
+  {
+    return (in_table.getMutableShare()->getTableObservers() != NULL);
+  }
+
   /*==========================================================*/
   /* Static meathods called by drizzle to notify interested plugins 
-   * of a schema event,
+   * of a schema event.
  */
-  bool EventObserver::beforeDropTable(Session &session, const drizzled::TableIdentifier &table)
+  bool EventObserver::beforeDropTable(Session &session, const drizzled::identifier::Table &table)
   {
     if (all_event_plugins.empty())
       return false;
@@ -473,7 +452,7 @@ namespace plugin
     return eventData.callEventObservers();
   }
 
-  bool EventObserver::afterDropTable(Session &session, const drizzled::TableIdentifier &table, int err)
+  bool EventObserver::afterDropTable(Session &session, const drizzled::identifier::Table &table, int err)
   {
     if (all_event_plugins.empty())
       return false;
@@ -482,7 +461,7 @@ namespace plugin
     return eventData.callEventObservers();
   }
 
-  bool EventObserver::beforeRenameTable(Session &session, const drizzled::TableIdentifier &from, const drizzled::TableIdentifier &to)
+  bool EventObserver::beforeRenameTable(Session &session, const drizzled::identifier::Table &from, const drizzled::identifier::Table &to)
   {
     if (all_event_plugins.empty())
       return false;
@@ -491,7 +470,7 @@ namespace plugin
     return eventData.callEventObservers();
   }
 
-  bool EventObserver::afterRenameTable(Session &session, const drizzled::TableIdentifier &from, const drizzled::TableIdentifier &to, int err)
+  bool EventObserver::afterRenameTable(Session &session, const drizzled::identifier::Table &from, const drizzled::identifier::Table &to, int err)
   {
     if (all_event_plugins.empty())
       return false;
@@ -502,11 +481,13 @@ namespace plugin
 
   /*==========================================================*/
   /* Static meathods called by drizzle to notify interested plugins 
-   * of a table event,
+   * of a table event.
+   *
+   * A quick test is done first to see if there are any interested observers.
  */
   bool EventObserver::beforeInsertRecord(Table &table, unsigned char *buf)
   {
-    if (all_event_plugins.empty())
+    if (all_event_plugins.empty() || !TableEventData::hasEvents(table))
       return false;
 
     BeforeInsertRecordEventData eventData(*(table.in_use), table, buf);
@@ -515,7 +496,7 @@ namespace plugin
 
   bool EventObserver::afterInsertRecord(Table &table, const unsigned char *buf, int err)
   {
-    if (all_event_plugins.empty())
+    if (all_event_plugins.empty() || !TableEventData::hasEvents(table))
       return false;
 
     AfterInsertRecordEventData eventData(*(table.in_use), table, buf, err);
@@ -524,7 +505,7 @@ namespace plugin
 
   bool EventObserver::beforeDeleteRecord(Table &table, const unsigned char *buf)
   {
-    if (all_event_plugins.empty())
+    if (all_event_plugins.empty() || !TableEventData::hasEvents(table))
       return false;
 
     BeforeDeleteRecordEventData eventData(*(table.in_use), table, buf);
@@ -533,7 +514,7 @@ namespace plugin
 
   bool EventObserver::afterDeleteRecord(Table &table, const unsigned char *buf, int err)
   {
-    if (all_event_plugins.empty())
+    if (all_event_plugins.empty() || !TableEventData::hasEvents(table))
       return false;
 
     AfterDeleteRecordEventData eventData(*(table.in_use), table, buf, err);
@@ -542,7 +523,7 @@ namespace plugin
 
   bool EventObserver::beforeUpdateRecord(Table &table, const unsigned char *old_data, unsigned char *new_data)
   {
-    if (all_event_plugins.empty())
+    if (all_event_plugins.empty() || !TableEventData::hasEvents(table))
       return false;
 
     BeforeUpdateRecordEventData eventData(*(table.in_use), table, old_data, new_data);
@@ -551,7 +532,7 @@ namespace plugin
 
   bool EventObserver::afterUpdateRecord(Table &table, const unsigned char *old_data, unsigned char *new_data, int err)
   {
-    if (all_event_plugins.empty())
+    if (all_event_plugins.empty() || !TableEventData::hasEvents(table))
       return false;
 
     AfterUpdateRecordEventData eventData(*(table.in_use), table, old_data, new_data, err);
@@ -560,11 +541,13 @@ namespace plugin
 
   /*==========================================================*/
   /* Static meathods called by drizzle to notify interested plugins 
-   * of a session event,
- */
+   * of a session event.
+   *
+   * A quick test is done first to see if there are any interested observers.
+*/
   bool EventObserver::beforeCreateDatabase(Session &session, const std::string &db)
   {
-    if (all_event_plugins.empty())
+    if (all_event_plugins.empty() || !SessionEventData::hasEvents(session))
       return false;
 
     BeforeCreateDatabaseEventData eventData(session, db);
@@ -573,7 +556,7 @@ namespace plugin
 
   bool EventObserver::afterCreateDatabase(Session &session, const std::string &db, int err)
   {
-    if (all_event_plugins.empty())
+    if (all_event_plugins.empty() || !SessionEventData::hasEvents(session))
       return false;
 
     AfterCreateDatabaseEventData eventData(session, db, err);
@@ -582,7 +565,7 @@ namespace plugin
 
   bool EventObserver::beforeDropDatabase(Session &session, const std::string &db)
   {
-    if (all_event_plugins.empty())
+    if (all_event_plugins.empty() || !SessionEventData::hasEvents(session))
       return false;
 
     BeforeDropDatabaseEventData eventData(session, db);
@@ -591,13 +574,49 @@ namespace plugin
 
   bool EventObserver::afterDropDatabase(Session &session, const std::string &db, int err)
   {
-    if (all_event_plugins.empty())
+    if (all_event_plugins.empty() || !SessionEventData::hasEvents(session))
       return false;
 
     AfterDropDatabaseEventData eventData(session, db, err);
     return eventData.callEventObservers();
   }
 
+  bool EventObserver::connectSession(Session &session)
+  {
+    if (all_event_plugins.empty() || !SessionEventData::hasEvents(session))
+      return false;
+
+    ConnectSessionEventData eventData(session);
+    return eventData.callEventObservers();
+  }
+
+  bool EventObserver::disconnectSession(Session &session)
+  {
+    if (all_event_plugins.empty() || !SessionEventData::hasEvents(session))
+      return false;
+
+    DisconnectSessionEventData eventData(session);
+    return eventData.callEventObservers();
+  }
+
+  bool EventObserver::beforeStatement(Session &session)
+  {
+    if (all_event_plugins.empty() || !SessionEventData::hasEvents(session))
+      return false;
+
+    BeforeStatementEventData eventData(session);
+    return eventData.callEventObservers();
+  }
+
+  bool EventObserver::afterStatement(Session &session)
+  {
+    if (all_event_plugins.empty() || !SessionEventData::hasEvents(session))
+      return false;
+
+    AfterStatementEventData eventData(session);
+    return eventData.callEventObservers();
+  }
+
 
 } /* namespace plugin */
 } /* namespace drizzled */
