@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,35 +17,55 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_PLUGIN_LISTEN_H
-#define DRIZZLED_PLUGIN_LISTEN_H
-
-#include "drizzled/plugin/plugin.h"
+#pragma once
 
+#include <drizzled/plugin/plugin.h>
+#include <drizzled/atomics.h>
 #include <vector>
 
+#include <drizzled/visibility.h>
+
 namespace drizzled
 {
 namespace plugin
 {
 
 class Client;
-
+class Listen;
+typedef std::vector<Listen *> ListenVector;
+typedef std::pair<std::string*, drizzled::atomic<uint64_t>*> ListenCounter;
 /**
  * This class is used by client plugins to provide and manage the listening
  * interface for new client instances.
  */
-class Listen : public Plugin
+class DRIZZLED_API Listen : public Plugin
 {
   Listen();
   Listen(const Listen&);
   Listen& operator=(const Listen&);
+protected:
+  std::vector<ListenCounter*> counters;
 public:
   explicit Listen(std::string name_arg)
     : Plugin(name_arg, "Listen")
   {}
-  virtual ~Listen() {}
+  virtual ~Listen()
+  {
+    std::vector<ListenCounter*>::iterator it;
+    for (it= counters.begin(); it < counters.end(); ++it)
+    {
+      ListenCounter* counter= *it;
+      delete counter->first;
+      delete counter;
+    }
+  }
 
+  static ListenVector &getListenProtocols();
+
+  std::vector<ListenCounter*>& getListenCounters()
+  {
+    return counters;
+  }
   /**
    * This provides a list of file descriptors to watch that will trigger new
    * Client instances. When activity is detected on one of the returned file
@@ -96,6 +116,6 @@ public:
 };
 
 } /* namespace plugin */
+
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_PLUGIN_LISTEN_H */
