@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,13 +17,14 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_PLUGIN_LISTEN_TCP_H
-#define DRIZZLED_PLUGIN_LISTEN_TCP_H
+#pragma once
 
 #include <drizzled/plugin/listen.h>
 
 #include <netinet/in.h>
 
+#include <drizzled/visibility.h>
+
 namespace drizzled
 {
 namespace plugin
@@ -33,7 +34,7 @@ namespace plugin
  * This class is used by client plugins to provide and manage TCP listening
  * interfaces for new client instances.
  */
-class ListenTcp : public Listen
+class DRIZZLED_API ListenTcp : public Listen
 {
   ListenTcp();
   ListenTcp(const ListenTcp&);
@@ -69,7 +70,7 @@ public:
    * Get the host address to bind to.
    * @retval The host address.
    */
-  virtual const char* getHost(void) const;
+  virtual const std::string getHost(void) const;
 
   /**
    * Get the port to bind to.
@@ -81,4 +82,3 @@ public:
 } /* end namespace plugin */
 } /* end namespace drizzled */
 
-#endif /* DRIZZLED_PLUGIN_LISTEN_TCP_H */
