@@ -3,7 +3,7 @@
  *
  *  Definitions required for Query Logging plugin
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,13 +19,14 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_PLUGIN_LOGGING_H
-#define DRIZZLED_PLUGIN_LOGGING_H
+#pragma once
 
-#include "drizzled/plugin/plugin.h"
+#include <drizzled/plugin/plugin.h>
 
 #include <string>
 
+#include <drizzled/visibility.h>
+
 namespace drizzled
 {
 class Session;
@@ -33,7 +34,7 @@ class Session;
 namespace plugin
 {
 
-class Logging : public Plugin
+class DRIZZLED_API Logging : public Plugin
 {
   Logging();
   Logging(const Logging &);
@@ -51,15 +52,16 @@ public:
   virtual bool pre(Session *) {return false;}
   virtual bool post(Session *) {return false;}
   virtual bool postEnd(Session*) {return false;}
+  virtual bool resetGlobalScoreboard() {return false;}
 
   static bool addPlugin(Logging *handler);
   static void removePlugin(Logging *handler);
   static bool preDo(Session *session);
   static bool postDo(Session *session);
   static bool postEndDo(Session *session);
+  static bool resetStats(Session *session);
 };
 
 } /* namespace plugin */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_PLUGIN_LOGGING_H */
