@@ -21,11 +21,12 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_PLUGIN_QUERY_REWRITE_H
-#define DRIZZLED_PLUGIN_QUERY_REWRITE_H
+#pragma once
 
-#include "drizzled/atomics.h"
-#include "drizzled/plugin/plugin.h"
+#include <drizzled/atomics.h>
+#include <drizzled/plugin/plugin.h>
+
+#include <drizzled/visibility.h>
 
 /**
  * @file Defines the API for a QueryRewriter.  
@@ -40,7 +41,7 @@ namespace plugin
 /**
  * Class which rewrites queries
  */
-class QueryRewriter : public Plugin
+class DRIZZLED_API QueryRewriter : public Plugin
 {
 
 public:
@@ -69,7 +70,7 @@ public:
    * TODO: does it make sense to have multiple rewriters?
    *
    * @param[in] schema the schema the current session is
-   * @param[out] to_rewrite string representing the query to rewrite
+   * @param[out] to_rewrite the query to rewrite
    */
   static void rewriteQuery(const std::string &schema, std::string &to_rewrite);
 
@@ -86,4 +87,3 @@ private:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_PLUGIN_QUERY_REWRITE_H */
