@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <fcntl.h>
 #include <unistd.h>
@@ -32,8 +32,7 @@
 #include <google/protobuf/io/zero_copy_stream.h>
 #include <google/protobuf/io/zero_copy_stream_impl.h>
 
-#include "drizzled/cached_directory.h"
-
+#include <drizzled/cached_directory.h>
 #include <drizzled/definitions.h>
 #include <drizzled/base.h>
 #include <drizzled/cursor.h>
@@ -43,23 +42,23 @@
 #include <drizzled/gettext.h>
 #include <drizzled/unireg.h>
 #include <drizzled/data_home.h>
-#include "drizzled/errmsg_print.h"
-#include "drizzled/xid.h"
-#include "drizzled/sql_table.h"
-#include "drizzled/global_charset_info.h"
-#include "drizzled/charset.h"
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/db.h"
-
+#include <drizzled/errmsg_print.h>
+#include <drizzled/xid.h>
+#include <drizzled/sql_table.h>
+#include <drizzled/global_charset_info.h>
+#include <drizzled/charset.h>
+#include <drizzled/internal/my_sys.h>
 #include <drizzled/table_proto.h>
 #include <drizzled/plugin/event_observer.h>
+#include <drizzled/internal_error_handler.h>
+#include <drizzled/table/shell.h>
+#include <drizzled/message/cache.h>
+#include <drizzled/key.h>
 
 #include <boost/algorithm/string/compare.hpp>
 
 static bool shutdown_has_begun= false; // Once we put in the container for the vector/etc for engines this will go away.
 
-using namespace std;
-
 namespace drizzled
 {
 
@@ -80,8 +79,8 @@ EngineVector &StorageEngine::getSchemaEngines()
   return vector_of_schema_engines;
 }
 
-StorageEngine::StorageEngine(const string name_arg,
-                             const bitset<HTON_BIT_SIZE> &flags_arg) :
+StorageEngine::StorageEngine(const std::string name_arg,
+                             const std::bitset<HTON_BIT_SIZE> &flags_arg) :
   Plugin(name_arg, "StorageEngine"),
   MonitoredInTransaction(), /* This gives the storage engine a "slot" or ID */
   flags(flags_arg)
@@ -99,7 +98,7 @@ void StorageEngine::setTransactionReadWrite(Session& session)
 }
 
 
-int StorageEngine::renameTable(Session &session, const TableIdentifier &from, const TableIdentifier &to)
+int StorageEngine::renameTable(Session &session, const identifier::Table &from, const identifier::Table &to)
 {
   int error;
   setTransactionReadWrite(session);
@@ -135,7 +134,7 @@ int StorageEngine::renameTable(Session &session, const TableIdentifier &from, co
   @retval
     !0  Error
 */
-int StorageEngine::doDropTable(Session&, const TableIdentifier &identifier)
+int StorageEngine::doDropTable(Session&, const identifier::Table &identifier)
                                
 {
   int error= 0;
@@ -190,12 +189,12 @@ void StorageEngine::removePlugin(StorageEngine *)
 }
 
 class FindEngineByName
-  : public unary_function<StorageEngine *, bool>
+  : public std::unary_function<StorageEngine *, bool>
 {
-  const string &predicate;
+  const std::string &predicate;
 
 public:
-  explicit FindEngineByName(const string &target_arg) :
+  explicit FindEngineByName(const std::string &target_arg) :
     predicate(target_arg)
   {
   }
@@ -206,11 +205,11 @@ public:
   }
 };
 
-StorageEngine *StorageEngine::findByName(const string &predicate)
+StorageEngine *StorageEngine::findByName(const std::string &predicate)
 {
-  EngineVector::iterator iter= find_if(vector_of_engines.begin(),
-                                       vector_of_engines.end(),
-                                       FindEngineByName(predicate));
+  EngineVector::iterator iter= std::find_if(vector_of_engines.begin(),
+                                            vector_of_engines.end(),
+                                            FindEngineByName(predicate));
   if (iter != vector_of_engines.end())
   {
     StorageEngine *engine= *iter;
@@ -221,14 +220,14 @@ StorageEngine *StorageEngine::findByName(const string &predicate)
   return NULL;
 }
 
-StorageEngine *StorageEngine::findByName(Session& session, const string &predicate)
+StorageEngine *StorageEngine::findByName(Session& session, const std::string &predicate)
 {
   if (boost::iequals(predicate, DEFAULT_STRING))
     return session.getDefaultStorageEngine();
 
-  EngineVector::iterator iter= find_if(vector_of_engines.begin(),
-                                       vector_of_engines.end(),
-                                       FindEngineByName(predicate));
+  EngineVector::iterator iter= std::find_if(vector_of_engines.begin(),
+                                            vector_of_engines.end(),
+                                            FindEngineByName(predicate));
   if (iter != vector_of_engines.end())
   {
     StorageEngine *engine= *iter;
@@ -239,7 +238,7 @@ StorageEngine *StorageEngine::findByName(Session& session, const string &predica
   return NULL;
 }
 
-class StorageEngineCloseConnection : public unary_function<StorageEngine *, void>
+class StorageEngineCloseConnection : public std::unary_function<StorageEngine *, void>
 {
   Session *session;
 public:
@@ -261,16 +260,16 @@ public:
 */
 void StorageEngine::closeConnection(Session* session)
 {
-  for_each(vector_of_engines.begin(), vector_of_engines.end(),
-           StorageEngineCloseConnection(session));
+  std::for_each(vector_of_engines.begin(), vector_of_engines.end(),
+                StorageEngineCloseConnection(session));
 }
 
 bool StorageEngine::flushLogs(StorageEngine *engine)
 {
   if (engine == NULL)
   {
-    if (find_if(vector_of_engines.begin(), vector_of_engines.end(),
-                mem_fun(&StorageEngine::flush_logs))
+    if (std::find_if(vector_of_engines.begin(), vector_of_engines.end(),
+                     std::mem_fun(&StorageEngine::flush_logs))
         != vector_of_engines.begin())
       return true;
   }
@@ -282,18 +281,18 @@ bool StorageEngine::flushLogs(StorageEngine *engine)
   return false;
 }
 
-class StorageEngineGetTableDefinition: public unary_function<StorageEngine *,bool>
+class StorageEngineGetTableDefinition: public std::unary_function<StorageEngine *,bool>
 {
   Session& session;
-  const TableIdentifier &identifier;
+  const identifier::Table &identifier;
   message::Table &table_message;
-  int &err;
+  drizzled::error_t &err;
 
 public:
   StorageEngineGetTableDefinition(Session& session_arg,
-                                  const TableIdentifier &identifier_arg,
+                                  const identifier::Table &identifier_arg,
                                   message::Table &table_message_arg,
-                                  int &err_arg) :
+                                  drizzled::error_t &err_arg) :
     session(session_arg), 
     identifier(identifier_arg),
     table_message(table_message_arg), 
@@ -304,19 +303,19 @@ public:
     int ret= engine->doGetTableDefinition(session, identifier, table_message);
 
     if (ret != ENOENT)
-      err= ret;
+      err= static_cast<drizzled::error_t>(ret);
 
-    return err == EEXIST || err != ENOENT;
+    return err == static_cast<drizzled::error_t>(EEXIST) or err != static_cast<drizzled::error_t>(ENOENT);
   }
 };
 
-class StorageEngineDoesTableExist: public unary_function<StorageEngine *, bool>
+class StorageEngineDoesTableExist: public std::unary_function<StorageEngine *, bool>
 {
   Session& session;
-  const TableIdentifier &identifier;
+  const identifier::Table &identifier;
 
 public:
-  StorageEngineDoesTableExist(Session& session_arg, const TableIdentifier &identifier_arg) :
+  StorageEngineDoesTableExist(Session& session_arg, const identifier::Table &identifier_arg) :
     session(session_arg), 
     identifier(identifier_arg) 
   { }
@@ -331,7 +330,7 @@ public:
   Utility method which hides some of the details of getTableDefinition()
 */
 bool plugin::StorageEngine::doesTableExist(Session &session,
-                                           const TableIdentifier &identifier,
+                                           const identifier::Table &identifier,
                                            bool include_temporary_tables)
 {
   if (include_temporary_tables)
@@ -341,8 +340,8 @@ bool plugin::StorageEngine::doesTableExist(Session &session,
   }
 
   EngineVector::iterator iter=
-    find_if(vector_of_engines.begin(), vector_of_engines.end(),
-            StorageEngineDoesTableExist(session, identifier));
+    std::find_if(vector_of_engines.begin(), vector_of_engines.end(),
+                 StorageEngineDoesTableExist(session, identifier));
 
   if (iter == vector_of_engines.end())
   {
@@ -352,41 +351,49 @@ bool plugin::StorageEngine::doesTableExist(Session &session,
   return true;
 }
 
-bool plugin::StorageEngine::doDoesTableExist(Session&, const drizzled::TableIdentifier&)
+bool plugin::StorageEngine::doDoesTableExist(Session&, const drizzled::identifier::Table&)
 {
-  cerr << " Engine was called for doDoesTableExist() and does not implement it: " << this->getName() << "\n";
+  std::cerr << " Engine was called for doDoesTableExist() and does not implement it: " << this->getName() << "\n";
   assert(0);
   return false;
 }
 
-/**
-  Call this function in order to give the Cursor the possiblity
-  to ask engine if there are any new tables that should be written to disk
-  or any dropped tables that need to be removed from disk
-*/
-int StorageEngine::getTableDefinition(Session& session,
-                                      const TableIdentifier &identifier,
-                                      message::Table &table_message,
-                                      bool include_temporary_tables)
+message::table::shared_ptr StorageEngine::getTableMessage(Session& session,
+                                                          identifier::Table::const_reference identifier,
+                                                          bool include_temporary_tables)
 {
-  int err= ENOENT;
+  drizzled::error_t error;
+  error= static_cast<drizzled::error_t>(ENOENT);
 
   if (include_temporary_tables)
   {
-    if (session.doGetTableDefinition(identifier, table_message) == EEXIST)
-      return EEXIST;
+    Table *table= session.find_temporary_table(identifier);
+    if (table)
+    {
+      return message::table::shared_ptr(new message::Table(*table->getShare()->getTableMessage()));
+    }
   }
 
+  drizzled::message::table::shared_ptr table_ptr;
+  if ((table_ptr= drizzled::message::Cache::singleton().find(identifier)))
+  {
+    (void)table_ptr;
+  }
+
+  message::Table message;
   EngineVector::iterator iter=
-    find_if(vector_of_engines.begin(), vector_of_engines.end(),
-            StorageEngineGetTableDefinition(session, identifier, table_message, err));
+    std::find_if(vector_of_engines.begin(), vector_of_engines.end(),
+                 StorageEngineGetTableDefinition(session, identifier, message, error));
 
   if (iter == vector_of_engines.end())
   {
-    return ENOENT;
+    return message::table::shared_ptr();
   }
+  message::table::shared_ptr table_message(new message::Table(message));
 
-  return err;
+  drizzled::message::Cache::singleton().insert(identifier, table_message);
+
+  return table_message;
 }
 
 /**
@@ -399,7 +406,7 @@ class Ha_delete_table_error_handler: public Internal_error_handler
 {
 public:
   Ha_delete_table_error_handler() : Internal_error_handler() {}
-  virtual bool handle_error(uint32_t sql_errno,
+  virtual bool handle_error(drizzled::error_t sql_errno,
                             const char *message,
                             DRIZZLE_ERROR::enum_warning_level level,
                             Session *session);
@@ -409,7 +416,7 @@ public:
 
 bool
 Ha_delete_table_error_handler::
-handle_error(uint32_t ,
+handle_error(drizzled::error_t ,
              const char *message,
              DRIZZLE_ERROR::enum_warning_level ,
              Session *)
@@ -419,56 +426,94 @@ handle_error(uint32_t ,
   return true;
 }
 
-/**
-   returns ENOENT if the file doesn't exists.
-*/
-int StorageEngine::dropTable(Session& session,
-                             const TableIdentifier &identifier)
+class DropTableByIdentifier: public std::unary_function<EngineVector::value_type, bool>
 {
-  int error= 0;
-  int error_proto;
-  message::Table src_proto;
-  StorageEngine *engine;
+  Session::reference session;
+  identifier::Table::const_reference identifier;
+  drizzled::error_t &error;
 
-  error_proto= StorageEngine::getTableDefinition(session, identifier, src_proto);
+public:
 
-  if (error_proto == ER_CORRUPT_TABLE_DEFINITION)
+  DropTableByIdentifier(Session::reference session_arg,
+                        identifier::Table::const_reference identifier_arg,
+                        drizzled::error_t &error_arg) :
+    session(session_arg),
+    identifier(identifier_arg),
+    error(error_arg)
+  { }
+
+  result_type operator() (argument_type engine)
   {
-    string error_message;
+    if (not engine->doDoesTableExist(session, identifier))
+      return false;
 
-    error_message.append(const_cast<TableIdentifier &>(identifier).getSQLPath());
-    error_message.append(" : ");
-    error_message.append(src_proto.InitializationErrorString());
+    int local_error= engine->doDropTable(session, identifier);
 
-    my_error(ER_CORRUPT_TABLE_DEFINITION, MYF(0), error_message.c_str());
 
-    return ER_CORRUPT_TABLE_DEFINITION;
+    if (not local_error)
+      return true;
+
+    switch (local_error)
+    {
+    case HA_ERR_NO_SUCH_TABLE:
+    case ENOENT:
+      error= static_cast<drizzled::error_t>(HA_ERR_NO_SUCH_TABLE);
+      return false;
+
+    default:
+      error= static_cast<drizzled::error_t>(local_error);
+      return true;
+    }
+  } 
+};
+
+
+bool StorageEngine::dropTable(Session::reference session,
+                              identifier::Table::const_reference identifier,
+                              drizzled::error_t &error)
+{
+  error= EE_OK;
+
+  EngineVector::const_iterator iter= std::find_if(vector_of_engines.begin(), vector_of_engines.end(),
+                                                  DropTableByIdentifier(session, identifier, error));
+
+  if (error)
+  {
+    return false;
+  }
+  else if (iter == vector_of_engines.end())
+  {
+    error= ER_BAD_TABLE_ERROR;
+    return false;
   }
 
-  engine= StorageEngine::findByName(session, src_proto.engine().name());
+  drizzled::message::Cache::singleton().erase(identifier);
 
-  if (not engine)
-  {
-    my_error(ER_CORRUPT_TABLE_DEFINITION, MYF(0), const_cast<TableIdentifier &>(identifier).getSQLPath().c_str());
-
-    return ER_CORRUPT_TABLE_DEFINITION;
-  }
-
-  error= StorageEngine::dropTable(session, *engine, identifier);
-
-  if (error_proto && error == 0)
-    return 0;
-
-  return error;
+  return true;
 }
 
-int StorageEngine::dropTable(Session& session,
-                             StorageEngine &engine,
-                             const TableIdentifier &identifier)
+bool StorageEngine::dropTable(Session& session,
+                              const identifier::Table &identifier)
 {
-  int error;
+  drizzled::error_t error;
 
+  if (not dropTable(session, identifier, error))
+  {
+    return false;
+  }
+
+  return true;
+}
+
+bool StorageEngine::dropTable(Session::reference session,
+                              StorageEngine &engine,
+                              identifier::Table::const_reference identifier,
+                              drizzled::error_t &error)
+{
+  error= EE_OK;
   engine.setTransactionReadWrite(session);
+
+  assert(identifier.isTmp());
   
   if (unlikely(plugin::EventObserver::beforeDropTable(session, identifier)))
   {
@@ -476,15 +521,22 @@ int StorageEngine::dropTable(Session& session,
   }
   else
   {
-    error= engine.doDropTable(session, identifier);
+    error= static_cast<drizzled::error_t>(engine.doDropTable(session, identifier));
+
     if (unlikely(plugin::EventObserver::afterDropTable(session, identifier, error)))
     {
       error= ER_EVENT_OBSERVER_PLUGIN;
     }
   }
 
+  drizzled::message::Cache::singleton().erase(identifier);
 
-  return error;
+  if (error)
+  {
+    return false;
+  }
+
+  return true;
 }
 
 
@@ -496,18 +548,24 @@ int StorageEngine::dropTable(Session& session,
   @retval
    1  error
 */
-int StorageEngine::createTable(Session &session,
-                               const TableIdentifier &identifier,
-                               message::Table& table_message)
+bool StorageEngine::createTable(Session &session,
+                                const identifier::Table &identifier,
+                                message::Table& table_message)
 {
-  int error= 1;
-  Table table;
+  drizzled::error_t error= EE_OK;
+
   TableShare share(identifier);
+  table::Shell table(share);
   message::Table tmp_proto;
 
   if (share.parse_table_proto(session, table_message) || share.open_table_from_share(&session, identifier, "", 0, 0, table))
   { 
     // @note Error occured, we should probably do a little more here.
+    // ER_CORRUPT_TABLE_DEFINITION,ER_CORRUPT_TABLE_DEFINITION_ENUM 
+    
+    my_error(ER_CORRUPT_TABLE_DEFINITION_UNKNOWN, identifier);
+
+    return false;
   }
   else
   {
@@ -526,38 +584,44 @@ int StorageEngine::createTable(Session &session,
     {
       share.storage_engine->setTransactionReadWrite(session);
 
-      error= share.storage_engine->doCreateTable(session,
-                                                 table,
-                                                 identifier,
-                                                 table_message);
+      error= static_cast<drizzled::error_t>(share.storage_engine->doCreateTable(session,
+                                                                                table,
+                                                                                identifier,
+                                                                                table_message));
     }
 
-    if (error)
+    if (error == ER_TABLE_PERMISSION_DENIED)
     {
-      my_error(ER_CANT_CREATE_TABLE, MYF(ME_BELL+ME_WAITTANG), const_cast<TableIdentifier &>(identifier).getSQLPath().c_str(), error);
+      my_error(ER_TABLE_PERMISSION_DENIED, identifier);
+    }
+    else if (error)
+    {
+      std::string path;
+      identifier.getSQLPath(path);
+      my_error(ER_CANT_CREATE_TABLE, MYF(ME_BELL+ME_WAITTANG), path.c_str(), error);
     }
 
     table.delete_table();
   }
 
-  return(error != 0);
+  return(error == EE_OK);
 }
 
-Cursor *StorageEngine::getCursor(TableShare &share)
+Cursor *StorageEngine::getCursor(Table &arg)
 {
-  return create(share);
+  return create(arg);
 }
 
 class AddTableIdentifier : 
-  public unary_function<StorageEngine *, void>
+  public std::unary_function<StorageEngine *, void>
 {
   CachedDirectory &directory;
-  const SchemaIdentifier &identifier;
-  TableIdentifiers &set_of_identifiers;
+  const identifier::Schema &identifier;
+  identifier::Table::vector &set_of_identifiers;
 
 public:
 
-  AddTableIdentifier(CachedDirectory &directory_arg, const SchemaIdentifier &identifier_arg, TableIdentifiers &of_names) :
+  AddTableIdentifier(CachedDirectory &directory_arg, const identifier::Schema &identifier_arg, identifier::Table::vector &of_names) :
     directory(directory_arg),
     identifier(identifier_arg),
     set_of_identifiers(of_names)
@@ -571,11 +635,8 @@ public:
 };
 
 
-void StorageEngine::getIdentifiers(Session &session, const SchemaIdentifier &schema_identifier, TableIdentifiers &set_of_identifiers)
+void StorageEngine::getIdentifiers(Session &session, const identifier::Schema &schema_identifier, identifier::Table::vector &set_of_identifiers)
 {
-  static SchemaIdentifier INFORMATION_SCHEMA_IDENTIFIER("information_schema");
-  static SchemaIdentifier DATA_DICTIONARY_IDENTIFIER("data_dictionary");
-
   CachedDirectory directory(schema_identifier.getPath(), set_of_table_definition_ext);
 
   if (schema_identifier == INFORMATION_SCHEMA_IDENTIFIER)
@@ -588,20 +649,27 @@ void StorageEngine::getIdentifiers(Session &session, const SchemaIdentifier &sch
     {
       errno= directory.getError();
       if (errno == ENOENT)
-        my_error(ER_BAD_DB_ERROR, MYF(ME_BELL+ME_WAITTANG), const_cast<SchemaIdentifier &>(schema_identifier).getSQLPath().c_str());
+      {
+        std::string path;
+        schema_identifier.getSQLPath(path);
+        my_error(ER_BAD_DB_ERROR, MYF(ME_BELL+ME_WAITTANG), path.c_str());
+      }
       else
+      {
         my_error(ER_CANT_READ_DIR, MYF(ME_BELL+ME_WAITTANG), directory.getPath(), errno);
+      }
+
       return;
     }
   }
 
-  for_each(vector_of_engines.begin(), vector_of_engines.end(),
-           AddTableIdentifier(directory, schema_identifier, set_of_identifiers));
+  std::for_each(vector_of_engines.begin(), vector_of_engines.end(),
+                AddTableIdentifier(directory, schema_identifier, set_of_identifiers));
 
   session.doGetTableIdentifiers(directory, schema_identifier, set_of_identifiers);
 }
 
-class DropTable: public unary_function<TableIdentifier&, bool>
+class DropTable: public std::unary_function<identifier::Table&, bool>
 {
   Session &session;
   StorageEngine *engine;
@@ -619,15 +687,15 @@ public:
   } 
 };
 
-/* This will later be converted to TableIdentifiers */
-class DropTables: public unary_function<StorageEngine *, void>
+/* This will later be converted to identifier::Tables */
+class DropTables: public std::unary_function<StorageEngine *, void>
 {
   Session &session;
-  TableIdentifiers &table_identifiers;
+  identifier::Table::vector &table_identifiers;
 
 public:
 
-  DropTables(Session &session_arg, TableIdentifiers &table_identifiers_arg) :
+  DropTables(Session &session_arg, identifier::Table::vector &table_identifiers_arg) :
     session(session_arg),
     table_identifiers(table_identifiers_arg)
   { }
@@ -636,9 +704,9 @@ public:
   {
     // True returning from DropTable means the table has been successfully
     // deleted, so it should be removed from the list of tables to drop
-    table_identifiers.erase(remove_if(table_identifiers.begin(),
-                                      table_identifiers.end(),
-                                      DropTable(session, engine)),
+    table_identifiers.erase(std::remove_if(table_identifiers.begin(),
+                                           table_identifiers.end(),
+                                           DropTable(session, engine)),
                             table_identifiers.end());
   }
 };
@@ -651,7 +719,7 @@ public:
 void StorageEngine::removeLostTemporaryTables(Session &session, const char *directory)
 {
   CachedDirectory dir(directory, set_of_table_definition_ext);
-  TableIdentifiers table_identifiers;
+  identifier::Table::vector table_identifiers;
 
   if (dir.fail())
   {
@@ -667,7 +735,7 @@ void StorageEngine::removeLostTemporaryTables(Session &session, const char *dire
        fileIter != files.end(); fileIter++)
   {
     size_t length;
-    string path;
+    std::string path;
     CachedDirectory::Entry *entry= *fileIter;
 
     /* We remove the file extension. */
@@ -680,21 +748,21 @@ void StorageEngine::removeLostTemporaryTables(Session &session, const char *dire
     message::Table definition;
     if (StorageEngine::readTableFile(path, definition))
     {
-      TableIdentifier identifier(definition.schema(), definition.name(), path);
+      identifier::Table identifier(definition.schema(), definition.name(), path);
       table_identifiers.push_back(identifier);
     }
   }
 
-  for_each(vector_of_engines.begin(), vector_of_engines.end(),
-           DropTables(session, table_identifiers));
-  
+  std::for_each(vector_of_engines.begin(), vector_of_engines.end(),
+                DropTables(session, table_identifiers));
+
   /*
     Now we just clean up anything that might left over.
 
     We rescan because some of what might have been there should
     now be all nice and cleaned up.
   */
-  set<string> all_exts= set_of_table_definition_ext;
+  std::set<std::string> all_exts= set_of_table_definition_ext;
 
   for (EngineVector::iterator iter= vector_of_engines.begin();
        iter != vector_of_engines.end() ; iter++)
@@ -709,7 +777,7 @@ void StorageEngine::removeLostTemporaryTables(Session &session, const char *dire
   for (CachedDirectory::Entries::iterator fileIter= files.begin();
        fileIter != files.end(); fileIter++)
   {
-    string path;
+    std::string path;
     CachedDirectory::Entry *entry= *fileIter;
 
     path+= directory;
@@ -730,14 +798,9 @@ void StorageEngine::removeLostTemporaryTables(Session &session, const char *dire
     - table->getShare()->path
     - table->alias
 */
-void StorageEngine::print_error(int error, myf errflag, Table &table)
+void StorageEngine::print_error(int error, myf errflag, const Table &table) const
 {
-  print_error(error, errflag, &table);
-}
-
-void StorageEngine::print_error(int error, myf errflag, Table *table)
-{
-  int textno= ER_GET_ERRNO;
+  drizzled::error_t textno= ER_GET_ERRNO;
   switch (error) {
   case EACCES:
     textno=ER_OPEN_AS_READONLY;
@@ -758,13 +821,12 @@ void StorageEngine::print_error(int error, myf errflag, Table *table)
     break;
   case HA_ERR_FOUND_DUPP_KEY:
   {
-    assert(table);
-    uint32_t key_nr= table->get_dup_key(error);
+    uint32_t key_nr= table.get_dup_key(error);
     if ((int) key_nr >= 0)
     {
       const char *err_msg= ER(ER_DUP_ENTRY_WITH_KEY_NAME);
 
-      print_keydup_error(key_nr, err_msg, *table);
+      print_keydup_error(key_nr, err_msg, table);
 
       return;
     }
@@ -773,8 +835,7 @@ void StorageEngine::print_error(int error, myf errflag, Table *table)
   }
   case HA_ERR_FOREIGN_DUPLICATE_KEY:
   {
-    assert(table);
-    uint32_t key_nr= table->get_dup_key(error);
+    uint32_t key_nr= table.get_dup_key(error);
     if ((int) key_nr >= 0)
     {
       uint32_t max_length;
@@ -784,7 +845,7 @@ void StorageEngine::print_error(int error, myf errflag, Table *table)
       String str(key,sizeof(key),system_charset_info);
 
       /* Table is opened and defined at this point */
-      key_unpack(&str,table,(uint32_t) key_nr);
+      key_unpack(&str, &table,(uint32_t) key_nr);
       max_length= (DRIZZLE_ERRMSG_SIZE-
                    (uint32_t) strlen(ER(ER_FOREIGN_DUPLICATE_KEY)));
       if (str.length() >= max_length)
@@ -792,7 +853,7 @@ void StorageEngine::print_error(int error, myf errflag, Table *table)
         str.length(max_length-4);
         str.append(STRING_WITH_LEN("..."));
       }
-      my_error(ER_FOREIGN_DUPLICATE_KEY, MYF(0), table->getShare()->getTableName(),
+      my_error(ER_FOREIGN_DUPLICATE_KEY, MYF(0), table.getShare()->getTableName(),
         str.c_ptr(), key_nr+1);
       return;
     }
@@ -815,7 +876,7 @@ void StorageEngine::print_error(int error, myf errflag, Table *table)
     textno=ER_CRASHED_ON_USAGE;
     break;
   case HA_ERR_NOT_A_TABLE:
-    textno= error;
+    textno= static_cast<drizzled::error_t>(error);
     break;
   case HA_ERR_CRASHED_ON_REPAIR:
     textno=ER_CRASHED_ON_REPAIR;
@@ -869,20 +930,20 @@ void StorageEngine::print_error(int error, myf errflag, Table *table)
     textno=ER_TABLE_DEF_CHANGED;
     break;
   case HA_ERR_NO_SUCH_TABLE:
-    assert(table);
-    my_error(ER_NO_SUCH_TABLE, MYF(0), table->getShare()->getSchemaName(),
-             table->getShare()->getTableName());
-    return;
+    {
+      identifier::Table identifier(table.getShare()->getSchemaName(), table.getShare()->getTableName());
+      my_error(ER_TABLE_UNKNOWN, identifier);
+      return;
+    }
   case HA_ERR_RBR_LOGGING_FAILED:
     textno= ER_BINLOG_ROW_LOGGING_FAILED;
     break;
   case HA_ERR_DROP_INDEX_FK:
   {
-    assert(table);
     const char *ptr= "???";
-    uint32_t key_nr= table->get_dup_key(error);
+    uint32_t key_nr= table.get_dup_key(error);
     if ((int) key_nr >= 0)
-      ptr= table->key_info[key_nr].name;
+      ptr= table.key_info[key_nr].name;
     my_error(ER_DROP_INDEX_FK, MYF(0), ptr);
     return;
   }
@@ -927,7 +988,8 @@ void StorageEngine::print_error(int error, myf errflag, Table *table)
       return;
     }
   }
-  my_error(textno, errflag, table->getShare()->getTableName(), error);
+
+  my_error(textno, errflag, table.getShare()->getTableName(), error);
 }
 
 
@@ -940,13 +1002,13 @@ void StorageEngine::print_error(int error, myf errflag, Table *table)
   @return
     Returns true if this is a temporary error
 */
-bool StorageEngine::get_error_message(int , String* )
+bool StorageEngine::get_error_message(int , String* ) const
 {
   return false;
 }
 
 
-void StorageEngine::print_keydup_error(uint32_t key_nr, const char *msg, Table &table)
+void StorageEngine::print_keydup_error(uint32_t key_nr, const char *msg, const Table &table) const
 {
   /* Write the duplicated key in the error message */
   char key[MAX_KEY_LENGTH];
@@ -974,20 +1036,20 @@ void StorageEngine::print_keydup_error(uint32_t key_nr, const char *msg, Table &
 }
 
 
-int StorageEngine::deleteDefinitionFromPath(const TableIdentifier &identifier)
+int StorageEngine::deleteDefinitionFromPath(const identifier::Table &identifier)
 {
-  string path(identifier.getPath());
+  std::string path(identifier.getPath());
 
   path.append(DEFAULT_DEFINITION_FILE_EXT);
 
   return internal::my_delete(path.c_str(), MYF(0));
 }
 
-int StorageEngine::renameDefinitionFromPath(const TableIdentifier &dest, const TableIdentifier &src)
+int StorageEngine::renameDefinitionFromPath(const identifier::Table &dest, const identifier::Table &src)
 {
   message::Table table_message;
-  string src_path(src.getPath());
-  string dest_path(dest.getPath());
+  std::string src_path(src.getPath());
+  std::string dest_path(dest.getPath());
 
   src_path.append(DEFAULT_DEFINITION_FILE_EXT);
   dest_path.append(DEFAULT_DEFINITION_FILE_EXT);
@@ -1012,10 +1074,10 @@ int StorageEngine::renameDefinitionFromPath(const TableIdentifier &dest, const T
   return error;
 }
 
-int StorageEngine::writeDefinitionFromPath(const TableIdentifier &identifier, message::Table &table_message)
+int StorageEngine::writeDefinitionFromPath(const identifier::Table &identifier, const message::Table &table_message)
 {
   char definition_file_tmp[FN_REFLEN];
-  string file_name(identifier.getPath());
+  std::string file_name(identifier.getPath());
 
   file_name.append(DEFAULT_DEFINITION_FILE_EXT);
 
@@ -1034,7 +1096,8 @@ int StorageEngine::writeDefinitionFromPath(const TableIdentifier &identifier, me
 
   bool success;
 
-  try {
+  try
+  {
     success= table_message.SerializeToZeroCopyStream(output);
   }
   catch (...)
@@ -1044,7 +1107,11 @@ int StorageEngine::writeDefinitionFromPath(const TableIdentifier &identifier, me
 
   if (not success)
   {
+    std::string error_message;
+    identifier.getSQLPath(error_message);
+
     my_error(ER_CORRUPT_TABLE_DEFINITION, MYF(0),
+             error_message.c_str(),
              table_message.InitializationErrorString().c_str());
     delete output;
 
@@ -1084,12 +1151,12 @@ int StorageEngine::writeDefinitionFromPath(const TableIdentifier &identifier, me
   return 0;
 }
 
-class CanCreateTable: public unary_function<StorageEngine *, bool>
+class CanCreateTable: public std::unary_function<StorageEngine *, bool>
 {
-  const TableIdentifier &identifier;
+  const identifier::Table &identifier;
 
 public:
-  CanCreateTable(const TableIdentifier &identifier_arg) :
+  CanCreateTable(const identifier::Table &identifier_arg) :
     identifier(identifier_arg)
   { }
 
@@ -1103,11 +1170,11 @@ public:
 /**
   @note on success table can be created.
 */
-bool StorageEngine::canCreateTable(const TableIdentifier &identifier)
+bool StorageEngine::canCreateTable(const identifier::Table &identifier)
 {
   EngineVector::iterator iter=
-    find_if(vector_of_engines.begin(), vector_of_engines.end(),
-            CanCreateTable(identifier));
+    std::find_if(vector_of_engines.begin(), vector_of_engines.end(),
+                 CanCreateTable(identifier));
 
   if (iter == vector_of_engines.end())
   {
@@ -1119,7 +1186,7 @@ bool StorageEngine::canCreateTable(const TableIdentifier &identifier)
 
 bool StorageEngine::readTableFile(const std::string &path, message::Table &table_message)
 {
-  fstream input(path.c_str(), ios::in | ios::binary);
+  std::fstream input(path.c_str(), std::ios::in | std::ios::binary);
 
   if (input.good())
   {
@@ -1132,6 +1199,7 @@ bool StorageEngine::readTableFile(const std::string &path, message::Table &table
     catch (...)
     {
       my_error(ER_CORRUPT_TABLE_DEFINITION, MYF(0),
+               table_message.name().empty() ? path.c_str() : table_message.name().c_str(),
                table_message.InitializationErrorString().empty() ? "": table_message.InitializationErrorString().c_str());
     }
   }
@@ -1143,7 +1211,14 @@ bool StorageEngine::readTableFile(const std::string &path, message::Table &table
   return false;
 }
 
+std::ostream& operator<<(std::ostream& output, const StorageEngine &engine)
+{
+  output << "StorageEngine:(";
+  output <<  engine.getName();
+  output << ")";
 
+  return output;
+}
 
 } /* namespace plugin */
 } /* namespace drizzled */
