@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_RECORDS_H
-#define DRIZZLED_RECORDS_H
+#pragma once
 
 namespace drizzled
 {
@@ -181,11 +180,11 @@ public:
     This is the most basic access method of a table using rnd_init,
     rnd_next and rnd_end. No indexes are used.
 */
-  void init_read_record(Session *session, 
-                        Table *reg_form,
-                        optimizer::SqlSelect *select,
-                        int use_record_cache, 
-                        bool print_errors);
+  int init_read_record(Session *session,
+                       Table *reg_form,
+                       optimizer::SqlSelect *select,
+                       int use_record_cache,
+                       bool print_errors) __attribute__ ((warn_unused_result));
 
   void end_read_record();
 
@@ -205,10 +204,10 @@ public:
                       occurs (except for end-of-records error)
   @param idx          index to scan
                     */
-  void init_read_record_idx(Session *session, 
-                            Table *table,
-                            bool print_error, 
-                            uint32_t idx);
+  int init_read_record_idx(Session *session,
+                           Table *table,
+                           bool print_error,
+                           uint32_t idx) __attribute__ ((warn_unused_result));
 
   void init_reard_record_sequential();
 
@@ -217,4 +216,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_RECORDS_H */
