@@ -1,8 +1,8 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008-2009 Sun Microsystems
- *  Copyright (c) 2009-2010 Jay Pipes <jaypipes@gmail.com>
+ *  Copyright (C) 2008-2009 Sun Microsystems, Inc.
+ *  Copyright (C) 2009-2010 Jay Pipes <jaypipes@gmail.com>
  *
  *  Authors:
  *
@@ -22,16 +22,17 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_REPLICATION_SERVICES_H
-#define DRIZZLED_REPLICATION_SERVICES_H
+#pragma once
 
-#include "drizzled/atomics.h"
-#include "drizzled/plugin/replication.h"
+#include <drizzled/atomics.h>
+#include <drizzled/plugin/replication.h>
 
 #include <string>
 #include <vector>
 #include <utility>
 
+#include <drizzled/visibility.h>
+
 namespace drizzled
 {
 
@@ -54,7 +55,7 @@ namespace message
  * transactional events into GPB messages and sending those
  * events out through registered replicators and appliers.
  */
-class ReplicationServices
+class DRIZZLED_API ReplicationServices
 {
 public:
   typedef uint64_t GlobalTransactionId;
@@ -186,4 +187,3 @@ private:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_REPLICATION_SERVICES_H */
