@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
  */
 
 
-#ifndef DRIZZLED_SELECT_RESULT_INTERCEPTOR_H
-#define DRIZZLED_SELECT_RESULT_INTERCEPTOR_H
+#pragma once
 
 #include <drizzled/select_result.h>
 
@@ -45,4 +44,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_SELECT_RESULT_INTERCEPTOR_H */
