@@ -20,24 +20,34 @@
 
 #pragma once
 
-#include <vector>
-#include <cstring>
-#include <drizzled/util/data_ref.h>
+#include <drizzled/util/string.h>
+#include <boost/unordered_map.hpp>
 
-namespace drizzled {
-namespace session {
-
-class State
+namespace drizzled
 {
+
+class Session;
+
+namespace session
+{
+
+class State {
+  std::vector <char> _query;
+
 public:
-  State(str_ref);
+  typedef boost::shared_ptr<State> shared_ptr;
+  typedef boost::shared_ptr<State> const_shared_ptr;
 
-  const char* query() const;
-  const char* query(size_t&) const;
+  State(const char *in_packet, size_t in_packet_length);
 
-private:
-  std::vector<char> _query;
+  const char *query() const;
+
+  const char *query(size_t &size) const;
+
+protected:
+  friend class Session;
 };
 
 } /* namespace session */
 } /* namespace drizzled */
+
