@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,24 +17,21 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <signal.h>
 
-#include "drizzled/signal_handler.h"
-#include "drizzled/drizzled.h"
-#include "drizzled/session.h"
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/probes.h"
-#include "drizzled/plugin.h"
-#include "drizzled/plugin/scheduler.h"
+#include <drizzled/signal_handler.h>
+#include <drizzled/drizzled.h>
+#include <drizzled/session.h>
+#include <drizzled/session/cache.h>
+#include <drizzled/internal/my_sys.h>
+#include <drizzled/probes.h>
+#include <drizzled/plugin.h>
+#include <drizzled/plugin/scheduler.h>
+#include <drizzled/current_session.h>
 
-#ifdef __GNUC__
-#ifdef HAVE_BACKTRACE
-#include <execinfo.h>
-#include <cxxabi.h>
-#endif // HAVE_BACKTRACE
-#endif // __GNUC__
+#include <drizzled/util/backtrace.h>
 
 using namespace drizzled;
 
@@ -53,7 +50,7 @@ extern "C"
 void drizzled_print_signal_warning(int sig)
 {
   if (global_system_variables.log_warnings)
-    errmsg_printf(ERRMSG_LVL_WARN, _("Got signal %d from thread %"PRIu64),
+    errmsg_printf(error::WARN, _("Got signal %d from thread %"PRIu32),
                   sig, global_thread_id);
 #ifndef HAVE_BSD_SIGNALS
   sigset_t set;
@@ -72,14 +69,19 @@ void drizzled_print_signal_warning(int sig)
 /** Called when a thread is aborted. */
 void drizzled_end_thread_signal(int )
 {
-  Session *session=current_session;
+  Session *session= current_session;
   if (session)
   {
+    Session::shared_ptr session_ptr(session::Cache::singleton().find(session->getSessionId()));
+    if (not session_ptr) // We need to make we have a lock on session before we do anything with it.
+      return;
+
     killed_threads++;
-    session->scheduler->killSessionNow(session);
-    DRIZZLE_CONNECTION_DONE(session->thread_id);
+
+    // We need to get the ID before we kill off the session
+    session_ptr->scheduler->killSessionNow(session_ptr);
+    DRIZZLE_CONNECTION_DONE(session_ptr->getSessionId());
   }
-  return;
 }
 
 static void write_core(int sig)
@@ -101,7 +103,6 @@ static void write_core(int sig)
 #endif
 }
 
-#define BACKTRACE_STACK_SIZE 50
 void drizzled_handle_segfault(int sig)
 {
   time_t curr_time;
@@ -151,65 +152,7 @@ void drizzled_handle_segfault(int sig)
                     "Hope that's ok; if not, decrease some variables in the "
                     "equation.\n\n"));
 
-#ifdef __GNUC__
-#ifdef HAVE_BACKTRACE
-  {
-    void *array[BACKTRACE_STACK_SIZE];
-    size_t size;
-    char **strings;
-
-    size= backtrace(array, BACKTRACE_STACK_SIZE);
-    strings= backtrace_symbols(array, size);
-
-    std::cerr << "Number of stack frames obtained: " << size <<  std::endl;
-
-    for (size_t x= 1; x < size; x++) 
-    {
-      size_t sz= 200;
-      char *function= (char *)malloc(sz);
-      char *begin= 0;
-      char *end= 0;
-
-      for (char *j = strings[x]; *j; ++j)
-      {
-        if (*j == '(') {
-          begin = j;
-        }
-        else if (*j == '+') {
-          end = j;
-        }
-      }
-      if (begin && end)
-      {
-        begin++;
-        *end= NULL;
-
-        int status;
-        char *ret = abi::__cxa_demangle(begin, function, &sz, &status);
-        if (ret) 
-        {
-          function= ret;
-        }
-        else
-        {
-          std::strncpy(function, begin, sz);
-          std::strncat(function, "()", sz);
-          function[sz-1] = NULL;
-        }
-        std::cerr << function << std::endl;
-      }
-      else
-      {
-        std::cerr << strings[x] << std::endl;
-      }
-      free(function);
-    }
-
-
-    free (strings);
-  }
-#endif // HAVE_BACKTRACE
-#endif // __GNUC__
+  drizzled::util::custom_backtrace();
 
   write_core(sig);
 
