@@ -11,12 +11,12 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 
 /* Insert of records */
 
-#include "config.h"
+#include <config.h>
 #include <cstdio>
 #include <drizzled/sql_select.h>
 #include <drizzled/show.h>
@@ -25,12 +25,18 @@
 #include <drizzled/probes.h>
 #include <drizzled/sql_base.h>
 #include <drizzled/sql_load.h>
-#include <drizzled/field/timestamp.h>
+#include <drizzled/field/epoch.h>
 #include <drizzled/lock.h>
-#include "drizzled/sql_table.h"
-#include "drizzled/pthread_globals.h"
-#include "drizzled/transaction_services.h"
-#include "drizzled/plugin/transactional_storage_engine.h"
+#include <drizzled/sql_table.h>
+#include <drizzled/pthread_globals.h>
+#include <drizzled/transaction_services.h>
+#include <drizzled/plugin/transactional_storage_engine.h>
+#include <drizzled/select_insert.h>
+#include <drizzled/select_create.h>
+#include <drizzled/table/shell.h>
+#include <drizzled/alter_info.h>
+#include <drizzled/sql_parse.h>
+#include <drizzled/sql_lex.h>
 
 namespace drizzled
 {
@@ -66,9 +72,9 @@ static int check_insert_fields(Session *session, TableList *table_list,
 {
   Table *table= table_list->table;
 
-  if (fields.elements == 0 && values.elements != 0)
+  if (fields.size() == 0 && values.size() != 0)
   {
-    if (values.elements != table->getShare()->sizeFields())
+    if (values.size() != table->getShare()->sizeFields())
     {
       my_error(ER_WRONG_VALUE_COUNT_ON_ROW, MYF(0), 1L);
       return -1;
@@ -83,12 +89,12 @@ static int check_insert_fields(Session *session, TableList *table_list,
   }
   else
   {						// Part field list
-    Select_Lex *select_lex= &session->lex->select_lex;
+    Select_Lex *select_lex= &session->lex().select_lex;
     Name_resolution_context *context= &select_lex->context;
     Name_resolution_context_state ctx_state;
     int res;
 
-    if (fields.elements != values.elements)
+    if (fields.size() != values.size())
     {
       my_error(ER_WRONG_VALUE_COUNT_ON_ROW, MYF(0), 1L);
       return -1;
@@ -127,7 +133,7 @@ static int check_insert_fields(Session *session, TableList *table_list,
       }
       else
       {
-        table->setWriteSet(table->timestamp_field->field_index);
+        table->setWriteSet(table->timestamp_field->position());
       }
     }
   }
@@ -168,7 +174,8 @@ static int check_update_fields(Session *session, TableList *insert_table_list,
       Unmark the timestamp field so that we can check if this is modified
       by update_fields
     */
-    timestamp_mark= table->write_set->testAndClear(table->timestamp_field->field_index);
+    timestamp_mark= table->write_set->test(table->timestamp_field->position());
+    table->write_set->reset(table->timestamp_field->position());
   }
 
   /* Check the fields we are going to modify */
@@ -186,7 +193,7 @@ static int check_update_fields(Session *session, TableList *insert_table_list,
 
     if (timestamp_mark)
     {
-      table->setWriteSet(table->timestamp_field->field_index);
+      table->setWriteSet(table->timestamp_field->position());
     }
   }
   return 0;
@@ -224,7 +231,7 @@ void upgrade_lock_type(Session *,
   end of dispatch_command().
 */
 
-bool mysql_insert(Session *session,TableList *table_list,
+bool insert_query(Session *session,TableList *table_list,
                   List<Item> &fields,
                   List<List_item> &values_list,
                   List<Item> &update_fields,
@@ -240,7 +247,7 @@ bool mysql_insert(Session *session,TableList *table_list,
   uint64_t id;
   CopyInfo info;
   Table *table= 0;
-  List_iterator_fast<List_item> its(values_list);
+  List<List_item>::iterator its(values_list.begin());
   List_item *values;
   Name_resolution_context *context;
   Name_resolution_context_state ctx_state;
@@ -253,7 +260,7 @@ bool mysql_insert(Session *session,TableList *table_list,
     the current connection mode or table operation.
   */
   upgrade_lock_type(session, &table_list->lock_type, duplic,
-                    values_list.elements > 1);
+                    values_list.size() > 1);
 
   if (session->openTablesLock(table_list))
   {
@@ -266,19 +273,27 @@ bool mysql_insert(Session *session,TableList *table_list,
   session->set_proc_info("init");
   session->used_tables=0;
   values= its++;
-  value_count= values->elements;
+  value_count= values->size();
 
-  if (mysql_prepare_insert(session, table_list, table, fields, values,
+  if (prepare_insert(session, table_list, table, fields, values,
 			   update_fields, update_values, duplic, &unused_conds,
                            false,
-                           (fields.elements || !value_count ||
+                           (fields.size() || !value_count ||
                             (0) != 0), !ignore))
-    goto abort;
+  {
+    if (table != NULL)
+      table->cursor->ha_release_auto_increment();
+    if (!joins_freed)
+      free_underlaid_joins(session, &session->lex().select_lex);
+    session->setAbortOnWarning(false);
+    DRIZZLE_INSERT_DONE(1, 0);
+    return true;
+  }
 
   /* mysql_prepare_insert set table_list->table if it was not set */
   table= table_list->table;
 
-  context= &session->lex->select_lex.context;
+  context= &session->lex().select_lex.context;
   /*
     These three asserts test the hypothesis that the resetting of the name
     resolution context below is not necessary at all since the list of local
@@ -301,15 +316,31 @@ bool mysql_insert(Session *session,TableList *table_list,
   while ((values= its++))
   {
     counter++;
-    if (values->elements != value_count)
+    if (values->size() != value_count)
     {
       my_error(ER_WRONG_VALUE_COUNT_ON_ROW, MYF(0), counter);
-      goto abort;
+
+      if (table != NULL)
+        table->cursor->ha_release_auto_increment();
+      if (!joins_freed)
+        free_underlaid_joins(session, &session->lex().select_lex);
+      session->setAbortOnWarning(false);
+      DRIZZLE_INSERT_DONE(1, 0);
+
+      return true;
     }
     if (setup_fields(session, 0, *values, MARK_COLUMNS_READ, 0, 0))
-      goto abort;
+    {
+      if (table != NULL)
+        table->cursor->ha_release_auto_increment();
+      if (!joins_freed)
+        free_underlaid_joins(session, &session->lex().select_lex);
+      session->setAbortOnWarning(false);
+      DRIZZLE_INSERT_DONE(1, 0);
+      return true;
+    }
   }
-  its.rewind ();
+  its= values_list.begin();
 
   /* Restore the current context. */
   ctx_state.restore_state(context, table_list);
@@ -341,22 +372,22 @@ bool mysql_insert(Session *session,TableList *table_list,
   {
     if (duplic != DUP_ERROR || ignore)
       table->cursor->extra(HA_EXTRA_IGNORE_DUP_KEY);
-    table->cursor->ha_start_bulk_insert(values_list.elements);
+    table->cursor->ha_start_bulk_insert(values_list.size());
   }
 
 
-  session->abort_on_warning= !ignore;
+  session->setAbortOnWarning(not ignore);
 
   table->mark_columns_needed_for_insert();
 
   while ((values= its++))
   {
-    if (fields.elements || !value_count)
+    if (fields.size() || !value_count)
     {
       table->restoreRecordAsDefault();	// Get empty record
       if (fill_record(session, fields, *values))
       {
-	if (values_list.elements != 1 && ! session->is_error())
+	if (values_list.size() != 1 && ! session->is_error())
 	{
 	  info.records++;
 	  continue;
@@ -376,7 +407,7 @@ bool mysql_insert(Session *session,TableList *table_list,
 
       if (fill_record(session, table->getFields(), *values))
       {
-	if (values_list.elements != 1 && ! session->is_error())
+	if (values_list.size() != 1 && ! session->is_error())
 	{
 	  info.records++;
 	  continue;
@@ -395,7 +426,7 @@ bool mysql_insert(Session *session,TableList *table_list,
     session->row_count++;
   }
 
-  free_underlaid_joins(session, &session->lex->select_lex);
+  free_underlaid_joins(session, &session->lex().select_lex);
   joins_freed= true;
 
   /*
@@ -451,12 +482,21 @@ bool mysql_insert(Session *session,TableList *table_list,
     table->cursor->extra(HA_EXTRA_WRITE_CANNOT_REPLACE);
 
   if (error)
-    goto abort;
-  if (values_list.elements == 1 && (!(session->options & OPTION_WARNINGS) ||
+  {
+    if (table != NULL)
+      table->cursor->ha_release_auto_increment();
+    if (!joins_freed)
+      free_underlaid_joins(session, &session->lex().select_lex);
+    session->setAbortOnWarning(false);
+    DRIZZLE_INSERT_DONE(1, 0);
+    return true;
+  }
+
+  if (values_list.size() == 1 && (!(session->options & OPTION_WARNINGS) ||
 				    !session->cuted_fields))
   {
     session->row_count_func= info.copied + info.deleted + info.updated;
-    session->my_ok((ulong) session->row_count_func,
+    session->my_ok((ulong) session->rowCount(),
                    info.copied + info.deleted + info.touched, id);
   }
   else
@@ -469,22 +509,14 @@ bool mysql_insert(Session *session,TableList *table_list,
       snprintf(buff, sizeof(buff), ER(ER_INSERT_INFO), (ulong) info.records,
 	      (ulong) (info.deleted + info.updated), (ulong) session->cuted_fields);
     session->row_count_func= info.copied + info.deleted + info.updated;
-    session->my_ok((ulong) session->row_count_func,
+    session->my_ok((ulong) session->rowCount(),
                    info.copied + info.deleted + info.touched, id, buff);
   }
-  session->status_var.inserted_row_count+= session->row_count_func;
-  session->abort_on_warning= 0;
-  DRIZZLE_INSERT_DONE(0, session->row_count_func);
-  return false;
+  session->status_var.inserted_row_count+= session->rowCount();
+  session->setAbortOnWarning(false);
+  DRIZZLE_INSERT_DONE(0, session->rowCount());
 
-abort:
-  if (table != NULL)
-    table->cursor->ha_release_auto_increment();
-  if (!joins_freed)
-    free_underlaid_joins(session, &session->lex->select_lex);
-  session->abort_on_warning= 0;
-  DRIZZLE_INSERT_DONE(1, 0);
-  return true;
+  return false;
 }
 
 
@@ -492,7 +524,7 @@ abort:
   Check if table can be updated
 
   SYNOPSIS
-     mysql_prepare_insert_check_table()
+     prepare_insert_check_table()
      session		Thread handle
      table_list		Table list
      fields		List of fields to be updated
@@ -504,7 +536,7 @@ abort:
      true  ERROR
 */
 
-static bool mysql_prepare_insert_check_table(Session *session, TableList *table_list,
+static bool prepare_insert_check_table(Session *session, TableList *table_list,
                                              List<Item> &,
                                              bool select_insert)
 {
@@ -517,10 +549,10 @@ static bool mysql_prepare_insert_check_table(Session *session, TableList *table_
      than INSERT.
   */
 
-  if (setup_tables_and_check_access(session, &session->lex->select_lex.context,
-                                    &session->lex->select_lex.top_join_list,
+  if (setup_tables_and_check_access(session, &session->lex().select_lex.context,
+                                    &session->lex().select_lex.top_join_list,
                                     table_list,
-                                    &session->lex->select_lex.leaf_tables,
+                                    &session->lex().select_lex.leaf_tables,
                                     select_insert))
     return(true);
 
@@ -532,7 +564,7 @@ static bool mysql_prepare_insert_check_table(Session *session, TableList *table_
   Prepare items in INSERT statement
 
   SYNOPSIS
-    mysql_prepare_insert()
+    prepare_insert()
     session			Thread handler
     table_list	        Global/local table list
     table		Table to insert into (can be NULL if table should
@@ -559,7 +591,7 @@ static bool mysql_prepare_insert_check_table(Session *session, TableList *table_
     true  error
 */
 
-bool mysql_prepare_insert(Session *session, TableList *table_list,
+bool prepare_insert(Session *session, TableList *table_list,
                           Table *table, List<Item> &fields, List_item *values,
                           List<Item> &update_fields, List<Item> &update_values,
                           enum_duplicates duplic,
@@ -567,7 +599,7 @@ bool mysql_prepare_insert(Session *session, TableList *table_list,
                           bool select_insert,
                           bool check_fields, bool abort_on_warning)
 {
-  Select_Lex *select_lex= &session->lex->select_lex;
+  Select_Lex *select_lex= &session->lex().select_lex;
   Name_resolution_context *context= &select_lex->context;
   Name_resolution_context_state ctx_state;
   bool insert_into_view= (0 != 0);
@@ -582,7 +614,7 @@ bool mysql_prepare_insert(Session *session, TableList *table_list,
     inserting (for INSERT ... SELECT this is done by changing table_list,
     because INSERT ... SELECT share Select_Lex it with SELECT.
   */
-  if (!select_insert)
+  if (not select_insert)
   {
     for (Select_Lex_Unit *un= select_lex->first_inner_unit();
          un;
@@ -604,7 +636,7 @@ bool mysql_prepare_insert(Session *session, TableList *table_list,
       return(true);
   }
 
-  if (mysql_prepare_insert_check_table(session, table_list, fields, select_insert))
+  if (prepare_insert_check_table(session, table_list, fields, select_insert))
     return(true);
 
 
@@ -630,13 +662,14 @@ bool mysql_prepare_insert(Session *session, TableList *table_list,
 
     if (!res && check_fields)
     {
-      bool saved_abort_on_warning= session->abort_on_warning;
-      session->abort_on_warning= abort_on_warning;
+      bool saved_abort_on_warning= session->abortOnWarning();
+
+      session->setAbortOnWarning(abort_on_warning);
       res= check_that_all_fields_are_given_values(session,
                                                   table ? table :
                                                   context->table_list->table,
                                                   context->table_list);
-      session->abort_on_warning= saved_abort_on_warning;
+      session->setAbortOnWarning(saved_abort_on_warning);
     }
 
     if (!res && duplic == DUP_UPDATE)
@@ -647,17 +680,17 @@ bool mysql_prepare_insert(Session *session, TableList *table_list,
     /* Restore the current context. */
     ctx_state.restore_state(context, table_list);
 
-    if (!res)
+    if (not res)
       res= setup_fields(session, 0, update_values, MARK_COLUMNS_READ, 0, 0);
   }
 
   if (res)
     return(res);
 
-  if (!table)
+  if (not table)
     table= table_list->table;
 
-  if (!select_insert)
+  if (not select_insert)
   {
     TableList *duplicate;
     if ((duplicate= unique_table(table_list, table_list->next_global, true)))
@@ -667,6 +700,7 @@ bool mysql_prepare_insert(Session *session, TableList *table_list,
       return true;
     }
   }
+
   if (duplic == DUP_UPDATE || duplic == DUP_REPLACE)
     table->prepare_for_position();
 
@@ -716,7 +750,7 @@ int write_record(Session *session, Table *table,CopyInfo *info)
 {
   int error;
   std::vector<unsigned char> key;
-  MyBitmap *save_read_set, *save_write_set;
+  boost::dynamic_bitset<> *save_read_set, *save_write_set;
   uint64_t prev_insert_id= table->cursor->next_insert_id;
   uint64_t insert_id_for_cur_row= 0;
 
@@ -806,8 +840,8 @@ int write_record(Session *session, Table *table,CopyInfo *info)
 	assert(table->insert_values.size());
         table->storeRecordAsInsert();
         table->restoreRecord();
-        assert(info->update_fields->elements ==
-                    info->update_values->elements);
+        assert(info->update_fields->size() ==
+                    info->update_values->size());
         if (fill_record(session, *info->update_fields,
                                                  *info->update_values,
                                                  info->ignore))
@@ -818,9 +852,8 @@ int write_record(Session *session, Table *table,CopyInfo *info)
           table->cursor->adjust_next_insert_id_after_explicit_value(
             table->next_number_field->val_int());
         info->touched++;
-        if ((table->cursor->getEngine()->check_flag(HTON_BIT_PARTIAL_COLUMN_READ) &&
-             !bitmap_is_subset(table->write_set, table->read_set)) ||
-            table->compare_record())
+
+        if (! table->records_are_comparable() || table->compare_records())
         {
           if ((error=table->cursor->updateRecord(table->getUpdateRecord(),
                                                 table->getInsertRecord())) &&
@@ -841,7 +874,7 @@ int write_record(Session *session, Table *table,CopyInfo *info)
           /*
             If ON DUP KEY UPDATE updates a row instead of inserting one, it's
             like a regular UPDATE statement: it should not affect the value of a
-            next SELECT LAST_INSERT_ID() or mysql_insert_id().
+            next SELECT LAST_INSERT_ID() or insert_id().
             Except if LAST_INSERT_ID(#) was in the INSERT query, which is
             handled separately by Session::arg_of_last_insert_id_function.
           */
@@ -910,7 +943,7 @@ int write_record(Session *session, Table *table,CopyInfo *info)
     */
     if (table->read_set != save_read_set ||
         table->write_set != save_write_set)
-      table->column_bitmaps_set(save_read_set, save_write_set);
+      table->column_bitmaps_set(*save_read_set, *save_write_set);
   }
   else if ((error=table->cursor->insertRecord(table->getInsertRecord())))
   {
@@ -933,14 +966,14 @@ gok_or_after_err:
 err:
   info->last_errno= error;
   /* current_select is NULL if this is a delayed insert */
-  if (session->lex->current_select)
-    session->lex->current_select->no_error= 0;        // Give error
+  if (session->lex().current_select)
+    session->lex().current_select->no_error= 0;        // Give error
   table->print_error(error,MYF(0));
 
 before_err:
   table->cursor->restore_auto_increment(prev_insert_id);
-  table->column_bitmaps_set(save_read_set, save_write_set);
-  return(1);
+  table->column_bitmaps_set(*save_read_set, *save_write_set);
+  return 1;
 }
 
 
@@ -973,7 +1006,7 @@ int check_that_all_fields_are_given_values(Session *session, Table *entry,
     {
       /*
        * However, if an actual NULL value was specified
-       * for the field and the field is a NOT NULL field, 
+       * for the field and the field is a NOT NULL field,
        * throw ER_BAD_NULL_ERROR.
        *
        * Per the SQL standard, inserting NULL into a NOT NULL
@@ -987,7 +1020,7 @@ int check_that_all_fields_are_given_values(Session *session, Table *entry,
       }
     }
   }
-  return session->abort_on_warning ? err : 0;
+  return session->abortOnWarning() ? err : 0;
 }
 
 /***************************************************************************
@@ -999,7 +1032,7 @@ int check_that_all_fields_are_given_values(Session *session, Table *entry,
   make insert specific preparation and checks after opening tables
 
   SYNOPSIS
-    mysql_insert_select_prepare()
+    insert_select_prepare()
     session         thread handler
 
   RETURN
@@ -1007,9 +1040,9 @@ int check_that_all_fields_are_given_values(Session *session, Table *entry,
     true  Error
 */
 
-bool mysql_insert_select_prepare(Session *session)
+bool insert_select_prepare(Session *session)
 {
-  LEX *lex= session->lex;
+  LEX *lex= &session->lex();
   Select_Lex *select_lex= &lex->select_lex;
 
   /*
@@ -1017,7 +1050,7 @@ bool mysql_insert_select_prepare(Session *session)
     clause if table is VIEW
   */
 
-  if (mysql_prepare_insert(session, lex->query_tables,
+  if (prepare_insert(session, lex->query_tables,
                            lex->query_tables->table, lex->field_list, 0,
                            lex->update_list, lex->value_list,
                            lex->duplicates,
@@ -1056,10 +1089,9 @@ select_insert::select_insert(TableList *table_list_par, Table *table_par,
 int
 select_insert::prepare(List<Item> &values, Select_Lex_Unit *u)
 {
-  LEX *lex= session->lex;
   int res;
   table_map map= 0;
-  Select_Lex *lex_current_select_save= lex->current_select;
+  Select_Lex *lex_current_select_save= session->lex().current_select;
 
 
   unit= u;
@@ -1069,23 +1101,23 @@ select_insert::prepare(List<Item> &values, Select_Lex_Unit *u)
     select, LEX::current_select should point to the first select while
     we are fixing fields from insert list.
   */
-  lex->current_select= &lex->select_lex;
+  session->lex().current_select= &session->lex().select_lex;
   res= check_insert_fields(session, table_list, *fields, values,
                            !insert_into_view, &map) ||
        setup_fields(session, 0, values, MARK_COLUMNS_READ, 0, 0);
 
-  if (!res && fields->elements)
+  if (!res && fields->size())
   {
-    bool saved_abort_on_warning= session->abort_on_warning;
-    session->abort_on_warning= !info.ignore;
+    bool saved_abort_on_warning= session->abortOnWarning();
+    session->setAbortOnWarning(not info.ignore);
     res= check_that_all_fields_are_given_values(session, table_list->table,
                                                 table_list);
-    session->abort_on_warning= saved_abort_on_warning;
+    session->setAbortOnWarning(saved_abort_on_warning);
   }
 
   if (info.handle_duplicates == DUP_UPDATE && !res)
   {
-    Name_resolution_context *context= &lex->select_lex.context;
+    Name_resolution_context *context= &session->lex().select_lex.context;
     Name_resolution_context_state ctx_state;
 
     /* Save the state of the current name resolution context. */
@@ -1103,8 +1135,8 @@ select_insert::prepare(List<Item> &values, Select_Lex_Unit *u)
       We use next_name_resolution_table descructively, so check it first (views?)
     */
     assert (!table_list->next_name_resolution_table);
-    if (lex->select_lex.group_list.elements == 0 &&
-        !lex->select_lex.with_sum_func)
+    if (session->lex().select_lex.group_list.elements == 0 and
+        not session->lex().select_lex.with_sum_func)
       /*
         We must make a single context out of the two separate name resolution contexts :
         the INSERT table and the tables in the SELECT part of INSERT ... SELECT.
@@ -1123,13 +1155,13 @@ select_insert::prepare(List<Item> &values, Select_Lex_Unit *u)
         order to get correct values from those fields when the select
         employs a temporary table.
       */
-      List_iterator<Item> li(*info.update_values);
+      List<Item>::iterator li(info.update_values->begin());
       Item *item;
 
       while ((item= li++))
       {
         item->transform(&Item::update_value_transformer,
-                        (unsigned char*)lex->current_select);
+                        (unsigned char*)session->lex().current_select);
       }
     }
 
@@ -1137,7 +1169,7 @@ select_insert::prepare(List<Item> &values, Select_Lex_Unit *u)
     ctx_state.restore_state(context, table_list);
   }
 
-  lex->current_select= lex_current_select_save;
+  session->lex().current_select= lex_current_select_save;
   if (res)
     return(1);
   /*
@@ -1153,10 +1185,10 @@ select_insert::prepare(List<Item> &values, Select_Lex_Unit *u)
   if (unique_table(table_list, table_list->next_global))
   {
     /* Using same table for INSERT and SELECT */
-    lex->current_select->options|= OPTION_BUFFER_RESULT;
-    lex->current_select->join->select_options|= OPTION_BUFFER_RESULT;
+    session->lex().current_select->options|= OPTION_BUFFER_RESULT;
+    session->lex().current_select->join->select_options|= OPTION_BUFFER_RESULT;
   }
-  else if (!(lex->current_select->options & OPTION_BUFFER_RESULT))
+  else if (not (session->lex().current_select->options & OPTION_BUFFER_RESULT))
   {
     /*
       We must not yet prepare the result table if it is the same as one of the
@@ -1173,13 +1205,17 @@ select_insert::prepare(List<Item> &values, Select_Lex_Unit *u)
   table->next_number_field=table->found_next_number_field;
 
   session->cuted_fields=0;
+
   if (info.ignore || info.handle_duplicates != DUP_ERROR)
     table->cursor->extra(HA_EXTRA_IGNORE_DUP_KEY);
+
   if (info.handle_duplicates == DUP_REPLACE)
     table->cursor->extra(HA_EXTRA_WRITE_CAN_REPLACE);
+
   if (info.handle_duplicates == DUP_UPDATE)
     table->cursor->extra(HA_EXTRA_INSERT_WITH_UPDATE);
-  session->abort_on_warning= !info.ignore;
+
+  session->setAbortOnWarning(not info.ignore);
   table->mark_columns_needed_for_insert();
 
 
@@ -1205,9 +1241,9 @@ select_insert::prepare(List<Item> &values, Select_Lex_Unit *u)
 
 int select_insert::prepare2(void)
 {
-
-  if (session->lex->current_select->options & OPTION_BUFFER_RESULT)
+  if (session->lex().current_select->options & OPTION_BUFFER_RESULT)
     table->cursor->ha_start_bulk_insert((ha_rows) 0);
+
   return(0);
 }
 
@@ -1228,7 +1264,7 @@ select_insert::~select_insert()
     table->cursor->ha_reset();
   }
   session->count_cuted_fields= CHECK_FIELD_IGNORE;
-  session->abort_on_warning= 0;
+  session->setAbortOnWarning(false);
   return;
 }
 
@@ -1236,19 +1272,19 @@ select_insert::~select_insert()
 bool select_insert::send_data(List<Item> &values)
 {
 
-  bool error=0;
+  bool error= false;
 
   if (unit->offset_limit_cnt)
   {						// using limit offset,count
     unit->offset_limit_cnt--;
-    return(0);
+    return false;
   }
 
   session->count_cuted_fields= CHECK_FIELD_WARN;	// Calculate cuted fields
   store_values(values);
   session->count_cuted_fields= CHECK_FIELD_IGNORE;
   if (session->is_error())
-    return(1);
+    return true;
 
   // Release latches in case bulk insert takes a long time
   plugin::TransactionalStorageEngine::releaseTemporaryLatches(session);
@@ -1292,19 +1328,15 @@ bool select_insert::send_data(List<Item> &values)
 
 void select_insert::store_values(List<Item> &values)
 {
-  if (fields->elements)
+  if (fields->size())
     fill_record(session, *fields, values, true);
   else
     fill_record(session, table->getFields(), values, true);
 }
 
-void select_insert::send_error(uint32_t errcode,const char *err)
+void select_insert::send_error(drizzled::error_t errcode,const char *err)
 {
-
-
   my_message(errcode, err, MYF(0));
-
-  return;
 }
 
 
@@ -1353,10 +1385,10 @@ bool select_insert::send_eof()
     (session->arg_of_last_insert_id_function ?
      session->first_successful_insert_id_in_prev_stmt :
      (info.copied ? autoinc_value_of_last_inserted_row : 0));
-  session->my_ok((ulong) session->row_count_func,
+  session->my_ok((ulong) session->rowCount(),
                  info.copied + info.deleted + info.touched, id, buff);
-  session->status_var.inserted_row_count+= session->row_count_func; 
-  DRIZZLE_INSERT_SELECT_DONE(0, session->row_count_func);
+  session->status_var.inserted_row_count+= session->rowCount();
+  DRIZZLE_INSERT_SELECT_DONE(0, session->rowCount());
   return 0;
 }
 
@@ -1458,17 +1490,14 @@ static Table *create_table_from_items(Session *session, HA_CREATE_INFO *create_i
                                       List<Item> *items,
                                       bool is_if_not_exists,
                                       DrizzleLock **lock,
-				      TableIdentifier &identifier)
+				      identifier::Table::const_reference identifier)
 {
-  Table tmp_table;		// Used during 'CreateField()'
   TableShare share(message::Table::INTERNAL);
-  Table *table= 0;
-  uint32_t select_field_count= items->elements;
+  uint32_t select_field_count= items->size();
   /* Add selected items to field list */
-  List_iterator_fast<Item> it(*items);
+  List<Item>::iterator it(items->begin());
   Item *item;
   Field *tmp_field;
-  bool not_used;
 
   if (not (identifier.isTmp()) && create_table->table->db_stat)
   {
@@ -1478,49 +1507,61 @@ static Table *create_table_from_items(Session *session, HA_CREATE_INFO *create_i
       create_info->table_existed= 1;		// Mark that table existed
       push_warning_printf(session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
                           ER_TABLE_EXISTS_ERROR, ER(ER_TABLE_EXISTS_ERROR),
-                          create_table->table_name);
+                          create_table->getTableName());
       return create_table->table;
     }
 
-    my_error(ER_TABLE_EXISTS_ERROR, MYF(0), create_table->table_name);
+    my_error(ER_TABLE_EXISTS_ERROR, MYF(0), create_table->getTableName());
     return NULL;
   }
 
-  tmp_table.timestamp_field= 0;
-  tmp_table.setShare(&share);
-
-  tmp_table.getMutableShare()->db_create_options= 0;
-  tmp_table.getMutableShare()->blob_ptr_size= portable_sizeof_char_ptr;
-
-  if (not table_proto.engine().name().compare("MyISAM"))
-    tmp_table.getMutableShare()->db_low_byte_first= true;
-  else if (not table_proto.engine().name().compare("MEMORY"))
-    tmp_table.getMutableShare()->db_low_byte_first= true;
-
-  tmp_table.null_row= false;
-  tmp_table.maybe_null= false;
-
-  while ((item=it++))
   {
-    CreateField *cr_field;
-    Field *field, *def_field;
-    if (item->type() == Item::FUNC_ITEM)
-      if (item->result_type() != STRING_RESULT)
-        field= item->tmp_table_field(&tmp_table);
+    table::Shell tmp_table(share);		// Used during 'CreateField()'
+
+    if (not table_proto.engine().name().compare("MyISAM"))
+      tmp_table.getMutableShare()->db_low_byte_first= true;
+    else if (not table_proto.engine().name().compare("MEMORY"))
+      tmp_table.getMutableShare()->db_low_byte_first= true;
+
+    tmp_table.in_use= session;
+
+    while ((item=it++))
+    {
+      CreateField *cr_field;
+      Field *field, *def_field;
+      if (item->type() == Item::FUNC_ITEM)
+      {
+        if (item->result_type() != STRING_RESULT)
+        {
+          field= item->tmp_table_field(&tmp_table);
+        }
+        else
+        {
+          field= item->tmp_table_field_from_field_type(&tmp_table, 0);
+        }
+      }
       else
-        field= item->tmp_table_field_from_field_type(&tmp_table, 0);
-    else
-      field= create_tmp_field(session, &tmp_table, item, item->type(),
-                              (Item ***) 0, &tmp_field, &def_field, false,
-                              false, false, 0);
-    if (!field ||
-	!(cr_field=new CreateField(field,(item->type() == Item::FIELD_ITEM ?
-					   ((Item_field *)item)->field :
-					   (Field*) 0))))
-      return NULL;
-    if (item->maybe_null)
-      cr_field->flags &= ~NOT_NULL_FLAG;
-    alter_info->create_list.push_back(cr_field);
+      {
+        field= create_tmp_field(session, &tmp_table, item, item->type(),
+                                (Item ***) 0, &tmp_field, &def_field, false,
+                                false, false, 0);
+      }
+
+      if (!field ||
+          !(cr_field=new CreateField(field,(item->type() == Item::FIELD_ITEM ?
+                                            ((Item_field *)item)->field :
+                                            (Field*) 0))))
+      {
+        return NULL;
+      }
+
+      if (item->maybe_null)
+      {
+        cr_field->flags &= ~NOT_NULL_FLAG;
+      }
+
+      alter_info->create_list.push_back(cr_field);
+    }
   }
 
   /*
@@ -1530,15 +1571,16 @@ static Table *create_table_from_items(Session *session, HA_CREATE_INFO *create_i
     creating base table on which name we have exclusive lock. So code below
     should not cause deadlocks or races.
   */
+  Table *table= 0;
   {
-    if (not mysql_create_table_no_lock(session,
-				       identifier,
-				       create_info,
-				       table_proto,
-				       alter_info,
-				       false,
-				       select_field_count,
-				       is_if_not_exists))
+    if (not create_table_no_lock(session,
+				 identifier,
+				 create_info,
+				 table_proto,
+				 alter_info,
+				 false,
+				 select_field_count,
+				 is_if_not_exists))
     {
       if (create_info->table_existed && not identifier.isTmp())
       {
@@ -1547,20 +1589,32 @@ static Table *create_table_from_items(Session *session, HA_CREATE_INFO *create_i
           or it was created via different mysqld front-end to the
           cluster. We don't have much options but throw an error.
         */
-        my_error(ER_TABLE_EXISTS_ERROR, MYF(0), create_table->table_name);
+        my_error(ER_TABLE_EXISTS_ERROR, MYF(0), create_table->getTableName());
         return NULL;
       }
 
       if (not identifier.isTmp())
       {
-        LOCK_open.lock(); /* CREATE TABLE... has found that the table already exists for insert and is adapting to use it */
-        if (session->reopen_name_locked_table(create_table, false))
+        /* CREATE TABLE... has found that the table already exists for insert and is adapting to use it */
+        boost::mutex::scoped_lock scopedLock(table::Cache::singleton().mutex());
+
+        if (create_table->table)
         {
-          quick_rm_table(*session, identifier);
+          table::Concurrent *concurrent_table= static_cast<table::Concurrent *>(create_table->table);
+
+          if (concurrent_table->reopen_name_locked_table(create_table, session))
+          {
+            (void)plugin::StorageEngine::dropTable(*session, identifier);
+          }
+          else
+          {
+            table= create_table->table;
+          }
         }
         else
-          table= create_table->table;
-        LOCK_open.unlock();
+        {
+          (void)plugin::StorageEngine::dropTable(*session, identifier);
+        }
       }
       else
       {
@@ -1573,26 +1627,26 @@ static Table *create_table_from_items(Session *session, HA_CREATE_INFO *create_i
             it preparable for open. But let us do close_temporary_table() here
             just in case.
           */
-          session->drop_temporary_table(create_table);
+          session->drop_temporary_table(identifier);
         }
       }
     }
-    if (!table)                                   // open failed
+    if (not table)                                   // open failed
       return NULL;
   }
 
   table->reginfo.lock_type=TL_WRITE;
-  if (! ((*lock)= mysql_lock_tables(session, &table, 1,
-                                    DRIZZLE_LOCK_IGNORE_FLUSH, &not_used)))
+  if (not ((*lock)= session->lockTables(&table, 1, DRIZZLE_LOCK_IGNORE_FLUSH)))
   {
     if (*lock)
     {
-      mysql_unlock_tables(session, *lock);
+      session->unlockTables(*lock);
       *lock= 0;
     }
 
     if (not create_info->table_existed)
       session->drop_open_table(table, identifier);
+
     return NULL;
   }
 
@@ -1606,10 +1660,10 @@ select_create::prepare(List<Item> &values, Select_Lex_Unit *u)
   DrizzleLock *extra_lock= NULL;
   /*
     For replication, the CREATE-SELECT statement is written
-    in two pieces: the first transaction messsage contains 
+    in two pieces: the first transaction messsage contains
     the CREATE TABLE statement as a CreateTableStatement message
     necessary to create the table.
-    
+
     The second transaction message contains all the InsertStatement
     and associated InsertRecords that should go into the table.
    */
@@ -1637,18 +1691,20 @@ select_create::prepare(List<Item> &values, Select_Lex_Unit *u)
     *m_plock= extra_lock;
   }
 
-  if (table->getShare()->sizeFields() < values.elements)
+  if (table->getShare()->sizeFields() < values.size())
   {
     my_error(ER_WRONG_VALUE_COUNT_ON_ROW, MYF(0), 1);
     return(-1);
   }
 
  /* First field to copy */
-  field= table->getFields() + table->getShare()->sizeFields() - values.elements;
+  field= table->getFields() + table->getShare()->sizeFields() - values.size();
 
   /* Mark all fields that are given values */
   for (Field **f= field ; *f ; f++)
-    table->setWriteSet((*f)->field_index);
+  {
+    table->setWriteSet((*f)->position());
+  }
 
   /* Don't set timestamp if used */
   table->timestamp_field_type= TIMESTAMP_NO_AUTO_SET;
@@ -1658,14 +1714,18 @@ select_create::prepare(List<Item> &values, Select_Lex_Unit *u)
   session->cuted_fields=0;
   if (info.ignore || info.handle_duplicates != DUP_ERROR)
     table->cursor->extra(HA_EXTRA_IGNORE_DUP_KEY);
+
   if (info.handle_duplicates == DUP_REPLACE)
     table->cursor->extra(HA_EXTRA_WRITE_CAN_REPLACE);
+
   if (info.handle_duplicates == DUP_UPDATE)
     table->cursor->extra(HA_EXTRA_INSERT_WITH_UPDATE);
+
   table->cursor->ha_start_bulk_insert((ha_rows) 0);
-  session->abort_on_warning= !info.ignore;
+  session->setAbortOnWarning(not info.ignore);
   if (check_that_all_fields_are_given_values(session, table, table_list))
     return(1);
+
   table->mark_columns_needed_for_insert();
   table->cursor->extra(HA_EXTRA_WRITE_CACHE);
   return(0);
@@ -1677,7 +1737,7 @@ void select_create::store_values(List<Item> &values)
 }
 
 
-void select_create::send_error(uint32_t errcode,const char *err)
+void select_create::send_error(drizzled::error_t errcode,const char *err)
 {
   /*
     This will execute any rollbacks that are necessary before writing
@@ -1691,8 +1751,6 @@ void select_create::send_error(uint32_t errcode,const char *err)
 
   */
   select_insert::send_error(errcode, err);
-
-  return;
 }
 
 
@@ -1711,7 +1769,7 @@ bool select_create::send_eof()
     if (!table->getShare()->getType())
     {
       TransactionServices &transaction_services= TransactionServices::singleton();
-      transaction_services.autocommitOrRollback(session, 0);
+      transaction_services.autocommitOrRollback(*session, 0);
       (void) session->endActiveTransaction();
     }
 
@@ -1719,7 +1777,7 @@ bool select_create::send_eof()
     table->cursor->extra(HA_EXTRA_WRITE_CANNOT_REPLACE);
     if (m_plock)
     {
-      mysql_unlock_tables(session, *m_plock);
+      session->unlockTables(*m_plock);
       *m_plock= NULL;
       m_plock= NULL;
     }
@@ -1749,7 +1807,7 @@ void select_create::abort()
 
   if (m_plock)
   {
-    mysql_unlock_tables(session, *m_plock);
+    session->unlockTables(*m_plock);
     *m_plock= NULL;
     m_plock= NULL;
   }
