@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,33 +17,28 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_SQL_LEX_H
-#define DRIZZLED_SQL_LEX_H
+#pragma once
 
 /**
   @defgroup Semantic_Analysis Semantic Analysis
 */
 #include <drizzled/message/table.pb.h>
-
-#include "drizzled/plugin/function.h"
-#include "drizzled/name_resolution_context.h"
-#include "drizzled/item/subselect.h"
-#include "drizzled/table_list.h"
-#include "drizzled/function/math/real.h"
-#include "drizzled/alter_drop.h"
-#include "drizzled/alter_column.h"
-#include "drizzled/alter_info.h"
-#include "drizzled/key_part_spec.h"
-#include "drizzled/index_hint.h"
-#include "drizzled/statement.h"
-#include "drizzled/optimizer/explain_plan.h"
+#include <drizzled/name_resolution_context.h>
+#include <drizzled/table_list.h>
+#include <drizzled/function/math/real.h>
+#include <drizzled/key_part_spec.h>
+#include <drizzled/index_hint.h>
+#include <drizzled/optimizer/explain_plan.h>
 
 #include <bitset>
 #include <string>
 
-namespace drizzled
-{
+namespace drizzled {
 
+namespace plugin { class Function; }
+namespace statement { class Statement; }
+
+class st_lex_symbol;
 class select_result_interceptor;
 
 /* YACC and LEX Definitions */
@@ -62,7 +57,8 @@ class Item_outer_ref;
 */
 
 #ifdef DRIZZLE_SERVER
-# include <drizzled/set_var.h>
+/* set_var should change to set_var here ... */
+# include <drizzled/sys_var.h>
 # include <drizzled/item/func.h>
 # ifdef DRIZZLE_YACC
 #  define LEX_YYSTYPE void *
@@ -70,6 +66,7 @@ class Item_outer_ref;
 #  if defined(DRIZZLE_LEX)
 #   include <drizzled/foreign_key.h>
 #   include <drizzled/lex_symbol.h>
+#   include <drizzled/comp_creator.h>
 #   include <drizzled/sql_yacc.h>
 #   define LEX_YYSTYPE YYSTYPE *
 #  else
@@ -248,8 +245,8 @@ public:
       UNCACHEABLE_EXPLAIN
       UNCACHEABLE_PREPARE
   */
-  uint8_t uncacheable;
-  enum sub_select_type linkage;
+  std::bitset<8> uncacheable;
+  sub_select_type linkage;
   bool no_table_names_allowed; /* used for global order by */
   bool no_error; /* suppress error message (convert it to warnings) */
 
@@ -283,18 +280,17 @@ public:
   virtual uint32_t get_in_sum_expr();
   virtual TableList* get_table_list();
   virtual List<Item>* get_item_list();
-  virtual uint32_t get_table_join_options();
   virtual TableList *add_table_to_list(Session *session, Table_ident *table,
-                                        LEX_STRING *alias,
-                                        uint32_t table_options,
-                                        thr_lock_type flags= TL_UNLOCK,
-                                        List<Index_hint> *hints= 0,
-                                        LEX_STRING *option= 0);
+                                       LEX_STRING *alias,
+                                       const std::bitset<NUM_OF_TABLE_OPTIONS>& table_options,
+                                       thr_lock_type flags= TL_UNLOCK,
+                                       List<Index_hint> *hints= 0,
+                                       LEX_STRING *option= 0);
   virtual void set_lock_for_tables(thr_lock_type)
   {}
 
   friend class Select_Lex_Unit;
-  friend bool mysql_new_select(LEX *lex, bool move_down);
+  friend bool new_select(LEX *lex, bool move_down);
 private:
   void fast_exclude();
 };
@@ -382,7 +378,7 @@ public:
   inline void unclean() { cleaned= 0; }
   void reinit_exec_mechanism();
 
-  void print(String *str, enum_query_type query_type);
+  void print(String *str);
 
   bool add_fake_select_lex(Session *session);
   void init_prepare_fake_select_lex(Session *session);
@@ -393,7 +389,6 @@ public:
   inline bool is_union ();
 
   friend void lex_start(Session *session);
-  friend int subselect_union_engine::exec();
 
   List<Item> *get_unit_column_types();
 };
@@ -404,6 +399,65 @@ public:
 class Select_Lex: public Select_Lex_Node
 {
 public:
+
+  Select_Lex() :
+    context(),
+    db(0),
+    where(0),
+    having(0),
+    cond_value(),
+    having_value(),
+    parent_lex(0),
+    olap(UNSPECIFIED_OLAP_TYPE),
+    table_list(),
+    group_list(),
+    item_list(),
+    interval_list(),
+    is_item_list_lookup(false),
+    join(0),
+    top_join_list(),
+    join_list(0),
+    embedding(0),
+    sj_nests(),
+    leaf_tables(0),
+    type(optimizer::ST_PRIMARY),
+    order_list(),
+    gorder_list(0),
+    select_limit(0),
+    offset_limit(0),
+    ref_pointer_array(0),
+    select_n_having_items(0),
+    cond_count(0),
+    between_count(0),
+    max_equal_elems(0),
+    select_n_where_fields(0),
+    parsing_place(NO_MATTER),
+    with_sum_func(0),
+    in_sum_expr(0),
+    select_number(0),
+    nest_level(0),
+    inner_sum_func_list(0),
+    with_wild(0),
+    braces(0),
+    having_fix_field(0),
+    inner_refs_list(),
+    n_sum_items(0),
+    n_child_sum_items(0),
+    explicit_limit(0),
+    is_cross(false),
+    subquery_in_having(0),
+    is_correlated(0),
+    exclude_from_table_unique_test(0),
+    non_agg_fields(),
+    cur_pos_in_select_list(0),
+    prev_join_using(0),
+    full_group_by_flag(),
+    current_index_hint_type(INDEX_HINT_IGNORE),
+    current_index_hint_clause(),
+    index_hints(0)
+  {
+  }
+
   Name_resolution_context context;
   char *db;
   /* An Item representing the WHERE clause */
@@ -415,7 +469,7 @@ public:
   Item::cond_result having_value;
   /* point on lex in which it was created, used in view subquery detection */
   LEX *parent_lex;
-  enum olap_type olap;
+  olap_type olap;
   /* FROM clause - points to the beginning of the TableList::next_local list. */
   SQL_LIST table_list;
   SQL_LIST group_list; /* GROUP BY clause. */
@@ -433,7 +487,7 @@ public:
     by TableList::next_leaf, so leaf_tables points to the left-most leaf.
   */
   TableList *leaf_tables;
-  enum drizzled::optimizer::select_type type; /* type of select for EXPLAIN */
+  drizzled::optimizer::select_type type; /* type of select for EXPLAIN */
 
   SQL_LIST order_list;                /* ORDER clause */
   SQL_LIST *gorder_list;
@@ -458,7 +512,6 @@ public:
   enum_parsing_place parsing_place; /* where we are parsing expression */
   bool with_sum_func;   /* sum function indicator */
 
-  uint32_t table_join_options;
   uint32_t in_sum_expr;
   uint32_t select_number; /* number of select (used for EXPLAIN) */
   int8_t nest_level;     /* nesting level of select */
@@ -476,6 +529,10 @@ public:
 
   /* explicit LIMIT clause was used */
   bool explicit_limit;
+
+  /* explicit CROSS JOIN was used */
+  bool is_cross;
+
   /*
     there are subquery in HAVING clause => we can't close tables before
     query processing end even if we use temporary table
@@ -552,7 +609,7 @@ public:
   TableList* add_table_to_list(Session *session,
                                Table_ident *table,
                                LEX_STRING *alias,
-                               uint32_t table_options,
+                               const std::bitset<NUM_OF_TABLE_OPTIONS>& table_options,
                                thr_lock_type flags= TL_UNLOCK,
                                List<Index_hint> *hints= 0,
                                LEX_STRING *option= 0);
@@ -563,7 +620,6 @@ public:
   void add_joined_table(TableList *table);
   TableList *convert_right_join();
   List<Item>* get_item_list();
-  uint32_t get_table_join_options();
   void set_lock_for_tables(thr_lock_type lock_type);
   inline void init_order()
   {
@@ -572,7 +628,7 @@ public:
     order_list.next= (unsigned char**) &order_list.first;
   }
   /*
-    This method created for reiniting LEX in mysql_admin_table() and can be
+    This method created for reiniting LEX in admin_table() and can be
     used only if you are going remove all Select_Lex & units except belonger
     to LEX (LEX::unit & LEX::select, for other purposes there are
     Select_Lex_Unit::exclude_level & Select_Lex_Unit::exclude_tree
@@ -584,18 +640,16 @@ public:
   bool test_limit();
 
   friend void lex_start(Session *session);
-  Select_Lex() : n_sum_items(0), n_child_sum_items(0) {}
   void make_empty_select()
   {
     init_query();
     init_select();
   }
   bool setup_ref_array(Session *session, uint32_t order_group_num);
-  void print(Session *session, String *str, enum_query_type query_type);
-  static void print_order(String *str,
-                          order_st *order,
-                          enum_query_type query_type);
-  void print_limit(Session *session, String *str, enum_query_type query_type);
+  void print(Session *session, String *str);
+  static void print_order(String *str, Order *order);
+
+  void print_limit(Session *session, String *str);
   void fix_prepare_information(Session *session, Item **conds, Item **having_conds);
   /*
     Destroy the used execution plan (JOIN) of this subtree (this
@@ -608,7 +662,7 @@ public:
   */
   void cleanup_all_joins(bool full);
 
-  void set_index_hint_type(enum index_hint_type type, index_clause_map clause);
+  void set_index_hint_type(index_hint_type type, index_clause_map clause);
 
   /*
    Add a index hint to the tagged list of hints. The type and clause of the
@@ -630,7 +684,7 @@ public:
 
 private:
   /* current index hint kind. used in filling up index_hints */
-  enum index_hint_type current_index_hint_type;
+  index_hint_type current_index_hint_type;
   index_clause_map current_index_hint_clause;
   /* a list of USE/FORCE/IGNORE INDEX */
   List<Index_hint> *index_hints;
@@ -740,7 +794,7 @@ enum enum_comment_state
 
 } /* namespace drizzled */
 
-#include "drizzled/lex_input_stream.h"
+#include <drizzled/lex_input_stream.h>
 
 namespace drizzled
 {
@@ -756,13 +810,13 @@ public:
   /* list of all Select_Lex */
   Select_Lex *all_selects_list;
 
-  /* This is the "scale" for DECIMAL (S,P) notation */ 
+  /* This is the "scale" for DECIMAL (S,P) notation */
   char *length;
   /* This is the decimal precision in DECIMAL(S,P) notation */
   char *dec;
-  
+
   /**
-   * This is used kind of like the "ident" member variable below, as 
+   * This is used kind of like the "ident" member variable below, as
    * a place to store certain names of identifiers.  Unfortunately, it
    * is used differently depending on the Command (SELECT on a derived
    * table vs CREATE)
@@ -778,7 +832,7 @@ public:
    * or a named savepoint.  It should probably be refactored out into
    * the eventual Command class built for the Keycache and Savepoint
    * commands.
-   */ 
+   */
   LEX_STRING ident;
 
   unsigned char* yacc_yyss, *yacc_yyvs;
@@ -795,7 +849,7 @@ public:
   List<Lex_Column>    columns;
   List<Item>	      *insert_list,field_list,value_list,update_list;
   List<List_item>     many_values;
-  List<set_var_base>  var_list;
+  SetVarVector  var_list;
   /*
     A stack of name resolution contexts for the query. This stack is used
     at parse time to set local name resolution contexts for various parts
@@ -875,17 +929,12 @@ public:
      statement in a session. It's re-used by doing lex_end, lex_start
      in sql_lex.cc
   */
-  virtual ~LEX()
-  {
-  }
+  virtual ~LEX();
 
   TableList *unlink_first_table(bool *link_to_local);
   void link_first_table_back(TableList *first, bool link_to_local);
   void first_lists_tables_same();
 
-  bool only_view_structure();
-  bool need_correct_ident();
-
   void cleanup_after_one_table_open();
 
   bool push_context(Name_resolution_context *context)
@@ -902,12 +951,8 @@ public:
 
   Name_resolution_context *current_context()
   {
-    return context_stack.head();
+    return &context_stack.front();
   }
-  /*
-    Restore the LEX and Session in case of a parse error.
-  */
-  static void cleanup_lex_after_parse_error(Session *session);
 
   /**
     @brief check if the statement is a single-level join
@@ -943,6 +988,7 @@ public:
   void reset()
   {
     sum_expr_used= false;
+    _exists= false;
   }
 
   void setSumExprUsed()
@@ -954,16 +1000,53 @@ public:
   {
     return sum_expr_used;
   }
-private: 
+
+  void start(Session *session);
+  void end();
+
+  message::Table *table()
+  {
+    if (not _create_table)
+      _create_table= new message::Table;
+
+    return _create_table;
+  }
+
+  message::Table::Field *field()
+  {
+    return _create_field;
+  }
+
+  void setField(message::Table::Field *arg)
+  {
+    _create_field= arg;
+  }
+
+  void setExists()
+  {
+    _exists= true;
+  }
+
+  bool exists() const
+  {
+    return _exists;
+  }
+
+private:
   bool cacheable;
   bool sum_expr_used;
+  message::Table *_create_table;
+  message::Table::Field *_create_field;
+  bool _exists;
 };
 
 extern void lex_start(Session *session);
-extern void lex_end(LEX *lex);
 extern void trim_whitespace(const CHARSET_INFO * const cs, LEX_STRING *str);
 extern bool is_lex_native_function(const LEX_STRING *name);
 
+bool check_for_sql_keyword(drizzled::st_lex_symbol const&);
+bool check_for_sql_keyword(drizzled::lex_string_t const&);
+
 /**
   @} (End of group Semantic_Analysis)
 */
@@ -971,4 +1054,3 @@ extern bool is_lex_native_function(const LEX_STRING *name);
 } /* namespace drizzled */
 
 #endif /* DRIZZLE_SERVER */
-#endif /* DRIZZLED_SQL_LEX_H */
