@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_SQL_LOAD_H
-#define DRIZZLED_SQL_LOAD_H
+#pragma once
 
 #include <drizzled/definitions.h>
 #include <drizzled/sql_list.h>
@@ -33,7 +32,7 @@ class Session;
 class Table;
 class CopyInfo;
 
-int mysql_load(Session *session, file_exchange *ex, TableList *table_list,
+int load(Session *session, file_exchange *ex, TableList *table_list,
                List<Item> &fields_vars, List<Item> &set_fields,
                List<Item> &set_values_list,
                enum enum_duplicates handle_duplicates, bool ignore);
@@ -42,4 +41,3 @@ int write_record(Session *session, Table *table, CopyInfo *info);
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_SQL_LOAD_H */
