@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,8 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_SQL_LOCALE_H
-#define DRIZZLED_SQL_LOCALE_H
+#pragma once
 
 namespace drizzled
 {
@@ -55,4 +54,3 @@ MY_LOCALE *my_locale_by_number(uint32_t number);
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_SQL_LOCALE_H */
