@@ -11,62 +11,67 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
-#include "config.h"
+#include <config.h>
 
 #define DRIZZLE_LEX 1
 
-#include <drizzled/my_hash.h>
+#include <drizzled/item/num.h>
+#include <drizzled/abort_exception.h>
 #include <drizzled/error.h>
 #include <drizzled/nested_join.h>
 #include <drizzled/query_id.h>
-#include "drizzled/transaction_services.h"
+#include <drizzled/transaction_services.h>
 #include <drizzled/sql_parse.h>
 #include <drizzled/data_home.h>
 #include <drizzled/sql_base.h>
 #include <drizzled/show.h>
-#include <drizzled/db.h>
 #include <drizzled/function/time/unix_timestamp.h>
 #include <drizzled/function/get_system_var.h>
 #include <drizzled/item/cmpfunc.h>
 #include <drizzled/item/null.h>
 #include <drizzled/session.h>
+#include <drizzled/session/cache.h>
 #include <drizzled/sql_load.h>
 #include <drizzled/lock.h>
 #include <drizzled/select_send.h>
 #include <drizzled/plugin/client.h>
 #include <drizzled/statement.h>
 #include <drizzled/statement/alter_table.h>
-#include "drizzled/probes.h"
-#include "drizzled/session_list.h"
-#include "drizzled/global_charset_info.h"
-
-#include "drizzled/plugin/logging.h"
-#include "drizzled/plugin/query_rewrite.h"
-#include "drizzled/plugin/query_cache.h"
-#include "drizzled/plugin/authorization.h"
-#include "drizzled/optimizer/explain_plan.h"
-#include "drizzled/pthread_globals.h"
+#include <drizzled/probes.h>
+#include <drizzled/global_charset_info.h>
+#include <drizzled/plugin/logging.h>
+#include <drizzled/plugin/query_rewrite.h>
+#include <drizzled/plugin/query_cache.h>
+#include <drizzled/plugin/authorization.h>
+#include <drizzled/optimizer/explain_plan.h>
+#include <drizzled/pthread_globals.h>
+#include <drizzled/plugin/event_observer.h>
+#include <drizzled/display.h>
+#include <drizzled/visibility.h>
+#include <drizzled/kill.h>
+#include <drizzled/schema.h>
+#include <drizzled/item/subselect.h>
 
 #include <limits.h>
 
 #include <bitset>
 #include <algorithm>
-
-#include "drizzled/internal/my_sys.h"
+#include <boost/date_time.hpp>
+#include <drizzled/internal/my_sys.h>
 
 using namespace std;
 
-extern int DRIZZLEparse(void *session); // from sql_yacc.cc
+extern int base_sql_parse(drizzled::Session *session); // from sql_yacc.cc
 
 namespace drizzled
 {
 
 /* Prototypes */
-bool my_yyoverflow(short **a, YYSTYPE **b, ulong *yystacksize);
+bool my_yyoverflow(short **a, ParserType **b, ulong *yystacksize);
 static bool parse_sql(Session *session, Lex_input_stream *lip);
-void mysql_parse(Session *session, const char *inBuf, uint32_t length);
+void parse(Session *session, const char *inBuf, uint32_t length);
 
 /**
   @defgroup Runtime_Environment Runtime Environment
@@ -76,17 +81,23 @@ void mysql_parse(Session *session, const char *inBuf, uint32_t length);
 extern size_t my_thread_stack_size;
 extern const CHARSET_INFO *character_set_filesystem;
 
-const LEX_STRING command_name[COM_END+1]={
-  { C_STRING_WITH_LEN("Sleep") },
-  { C_STRING_WITH_LEN("Quit") },
-  { C_STRING_WITH_LEN("Init DB") },
-  { C_STRING_WITH_LEN("Query") },
-  { C_STRING_WITH_LEN("Shutdown") },
-  { C_STRING_WITH_LEN("Connect") },
-  { C_STRING_WITH_LEN("Ping") },
-  { C_STRING_WITH_LEN("Error") }  // Last command number
+namespace
+{
+
+static const std::string command_name[COM_END+1]={
+  "Sleep",
+  "Quit",
+  "Init DB",
+  "Query",
+  "Shutdown",
+  "Connect",
+  "Ping",
+  "Kill",
+  "Error"  // Last command number
 };
 
+}
+
 const char *xa_state_names[]={
   "NON-EXISTING", "ACTIVE", "IDLE", "PREPARED"
 };
@@ -105,6 +116,11 @@ const char *xa_state_names[]={
 */
 bitset<CF_BIT_SIZE> sql_command_flags[SQLCOM_END+1];
 
+const std::string &getCommandName(const enum_server_command& command)
+{
+  return command_name[command];
+}
+
 void init_update_queries(void)
 {
   uint32_t x;
@@ -153,7 +169,7 @@ void init_update_queries(void)
                          can be zero.
 
   @todo
-    set session->lex->sql_command to SQLCOM_END here.
+    set session->lex().sql_command to SQLCOM_END here.
   @todo
     The following has to be changed to an 8 byte integer
 
@@ -163,17 +179,16 @@ void init_update_queries(void)
     1   request of thread shutdown, i. e. if command is
         COM_QUIT/COM_SHUTDOWN
 */
-bool dispatch_command(enum enum_server_command command, Session *session,
+bool dispatch_command(enum_server_command command, Session *session,
                       char* packet, uint32_t packet_length)
 {
   bool error= 0;
   Query_id &query_id= Query_id::get_query_id();
 
-  DRIZZLE_COMMAND_START(session->thread_id,
-                        command);
+  DRIZZLE_COMMAND_START(session->thread_id, command);
 
   session->command= command;
-  session->lex->sql_command= SQLCOM_END; /* to avoid confusing VIEW detectors */
+  session->lex().sql_command= SQLCOM_END; /* to avoid confusing VIEW detectors */
   session->set_time();
   session->setQueryId(query_id.value());
 
@@ -187,12 +202,17 @@ bool dispatch_command(enum enum_server_command command, Session *session,
     query_id.next();
   }
 
-  /* TODO: set session->lex->sql_command to SQLCOM_END here */
+  /* @todo set session->lex().sql_command to SQLCOM_END here */
 
   plugin::Logging::preDo(session);
+  if (unlikely(plugin::EventObserver::beforeStatement(*session)))
+  {
+    // We should do something about an error...
+  }
 
   session->server_status&=
            ~(SERVER_QUERY_NO_INDEX_USED | SERVER_QUERY_NO_GOOD_INDEX_USED);
+
   switch (command) {
   case COM_INIT_DB:
   {
@@ -204,9 +224,9 @@ bool dispatch_command(enum enum_server_command command, Session *session,
 
     string tmp(packet, packet_length);
 
-    SchemaIdentifier identifier(tmp);
+    identifier::Schema identifier(tmp);
 
-    if (not mysql_change_db(session, identifier))
+    if (not schema::change(*session, identifier))
     {
       session->my_ok();
     }
@@ -214,29 +234,46 @@ bool dispatch_command(enum enum_server_command command, Session *session,
   }
   case COM_QUERY:
   {
-    if (! session->readAndStoreQuery(packet, packet_length))
+    if (not session->readAndStoreQuery(packet, packet_length))
       break;					// fatal error is set
-    DRIZZLE_QUERY_START(session->query.c_str(),
+    DRIZZLE_QUERY_START(session->getQueryString()->c_str(),
                         session->thread_id,
-                        const_cast<const char *>(session->db.empty() ? "" : session->db.c_str()));
+                        const_cast<const char *>(session->schema()->c_str()));
 
-    plugin::QueryRewriter::rewriteQuery(session->db, session->query);
-    mysql_parse(session, session->query.c_str(), session->query.length());
+    parse(session, session->getQueryString()->c_str(), session->getQueryString()->length());
 
     break;
   }
   case COM_QUIT:
     /* We don't calculate statistics for this command */
     session->main_da.disable_status();              // Don't send anything back
-    error=true;					// End server
+    error= true;					// End server
     break;
+  case COM_KILL:
+    {
+      if (packet_length != 4)
+      {
+        my_error(ER_NO_SUCH_THREAD, MYF(0), 0);
+        break;
+      }
+      else
+      {
+        uint32_t kill_id;
+        memcpy(&kill_id, packet, sizeof(uint32_t));
+
+        kill_id= ntohl(kill_id);
+        (void)drizzled::kill(*session->user(), kill_id, true);
+      }
+      session->my_ok();
+      break;
+    }
   case COM_SHUTDOWN:
   {
     session->status_var.com_other++;
     session->my_eof();
     session->close_thread_tables();			// Free before kill
     kill_drizzle();
-    error=true;
+    error= true;
     break;
   }
   case COM_PING:
@@ -254,7 +291,7 @@ bool dispatch_command(enum enum_server_command command, Session *session,
   /* If commit fails, we should be able to reset the OK status. */
   session->main_da.can_overwrite_status= true;
   TransactionServices &transaction_services= TransactionServices::singleton();
-  transaction_services.autocommitOrRollback(session, session->is_error());
+  transaction_services.autocommitOrRollback(*session, session->is_error());
   session->main_da.can_overwrite_status= false;
 
   session->transaction.stmt.reset();
@@ -266,9 +303,9 @@ bool dispatch_command(enum enum_server_command command, Session *session,
     if (! session->main_da.is_set())
       session->send_kill_message();
   }
-  if (session->killed == Session::KILL_QUERY || session->killed == Session::KILL_BAD_DATA)
+  if (session->getKilled() == Session::KILL_QUERY || session->getKilled() == Session::KILL_BAD_DATA)
   {
-    session->killed= Session::NOT_KILLED;
+    session->setKilled(Session::NOT_KILLED);
     session->setAbort(false);
   }
 
@@ -279,16 +316,16 @@ bool dispatch_command(enum enum_server_command command, Session *session,
   {
   case Diagnostics_area::DA_ERROR:
     /* The query failed, send error to log and abort bootstrap. */
-    session->client->sendError(session->main_da.sql_errno(),
+    session->getClient()->sendError(session->main_da.sql_errno(),
                                session->main_da.message());
     break;
 
   case Diagnostics_area::DA_EOF:
-    session->client->sendEOF();
+    session->getClient()->sendEOF();
     break;
 
   case Diagnostics_area::DA_OK:
-    session->client->sendOK();
+    session->getClient()->sendOK();
     break;
 
   case Diagnostics_area::DA_DISABLED:
@@ -296,7 +333,7 @@ bool dispatch_command(enum enum_server_command command, Session *session,
 
   case Diagnostics_area::DA_EMPTY:
   default:
-    session->client->sendOK();
+    session->getClient()->sendOK();
     break;
   }
 
@@ -307,12 +344,15 @@ bool dispatch_command(enum enum_server_command command, Session *session,
   session->close_thread_tables();
 
   plugin::Logging::postDo(session);
+  if (unlikely(plugin::EventObserver::afterStatement(*session)))
+  {
+    // We should do something about an error...
+  }
 
   /* Store temp state for processlist */
   session->set_proc_info("cleaning up");
   session->command= COM_SLEEP;
-  memset(session->process_list_info, 0, PROCESS_LIST_WIDTH);
-  session->query.clear();
+  session->resetQueryString();
 
   session->set_proc_info(NULL);
   session->mem_root->free_root(MYF(memory::KEEP_PREALLOC));
@@ -359,6 +399,7 @@ static bool _schema_select(Session *session, Select_Lex *sel,
                            const string& schema_table_name)
 {
   LEX_STRING db, table;
+  bitset<NUM_OF_TABLE_OPTIONS> table_options;
   /*
      We have to make non const db_name & table_name
      because of lower_case_table_names
@@ -367,19 +408,19 @@ static bool _schema_select(Session *session, Select_Lex *sel,
   session->make_lex_string(&table, schema_table_name, false);
 
   if (! sel->add_table_to_list(session, new Table_ident(db, table),
-                               NULL, 0, TL_READ))
+                               NULL, table_options, TL_READ))
   {
     return true;
   }
   return false;
 }
 
-int prepare_new_schema_table(Session *session, LEX *lex,
+int prepare_new_schema_table(Session *session, LEX& lex,
                              const string& schema_table_name)
 {
   Select_Lex *schema_select_lex= NULL;
 
-  Select_Lex *select_lex= lex->current_select;
+  Select_Lex *select_lex= lex.current_select;
   assert(select_lex);
   if (_schema_select(session, select_lex, schema_table_name))
   {
@@ -422,21 +463,15 @@ int prepare_new_schema_table(Session *session, LEX *lex,
     true        Error
 */
 
-static int
-mysql_execute_command(Session *session)
+static int execute_command(Session *session)
 {
   bool res= false;
-  LEX  *lex= session->lex;
+
   /* first Select_Lex (have special meaning for many of non-SELECTcommands) */
-  Select_Lex *select_lex= &lex->select_lex;
+  Select_Lex *select_lex= &session->lex().select_lex;
+
   /* list of all tables in query */
   TableList *all_tables;
-  /* A peek into the query string */
-  size_t proc_info_len= session->query.length() > PROCESS_LIST_WIDTH ?
-                        PROCESS_LIST_WIDTH : session->query.length();
-
-  memcpy(session->process_list_info, session->query.c_str(), proc_info_len);
-  session->process_list_info[proc_info_len]= '\0';
 
   /*
     In many cases first table of main Select_Lex have special meaning =>
@@ -453,13 +488,13 @@ mysql_execute_command(Session *session)
     assert(first_table == all_tables);
     assert(first_table == all_tables && first_table != 0);
   */
-  lex->first_lists_tables_same();
+  session->lex().first_lists_tables_same();
+
   /* should be assigned after making first tables same */
-  all_tables= lex->query_tables;
+  all_tables= session->lex().query_tables;
+
   /* set context for commands which do not use setup_tables */
-  select_lex->
-    context.resolve_in_table_list_only((TableList*)select_lex->
-                                       table_list.first);
+  select_lex->context.resolve_in_table_list_only((TableList*)select_lex->table_list.first);
 
   /*
     Reset warning count for each query that uses tables
@@ -468,15 +503,26 @@ mysql_execute_command(Session *session)
     variables, but for now this is probably good enough.
     Don't reset warnings when executing a stored routine.
   */
-  if (all_tables || ! lex->is_single_level_stmt())
+  if (all_tables || ! session->lex().is_single_level_stmt())
   {
     drizzle_reset_errors(session, 0);
   }
 
   assert(session->transaction.stmt.hasModifiedNonTransData() == false);
 
+  if (! (session->server_status & SERVER_STATUS_AUTOCOMMIT)
+      && ! session->inTransaction()
+      && session->lex().statement->isTransactional())
+  {
+    if (session->startTransaction() == false)
+    {
+      my_error(drizzled::ER_UNKNOWN_ERROR, MYF(0));
+      return true;
+    }
+  }
+
   /* now we are ready to execute the statement */
-  res= lex->statement->execute();
+  res= session->lex().statement->execute();
   session->set_proc_info("query end");
   /*
     The return value for ROW_COUNT() is "implementation dependent" if the
@@ -484,7 +530,7 @@ mysql_execute_command(Session *session)
     wants. We also keep the last value in case of SQLCOM_CALL or
     SQLCOM_EXECUTE.
   */
-  if (! (sql_command_flags[lex->sql_command].test(CF_BIT_HAS_ROW_COUNT)))
+  if (! (sql_command_flags[session->lex().sql_command].test(CF_BIT_HAS_ROW_COUNT)))
   {
     session->row_count_func= -1;
   }
@@ -493,7 +539,7 @@ mysql_execute_command(Session *session)
 }
 bool execute_sqlcom_select(Session *session, TableList *all_tables)
 {
-  LEX	*lex= session->lex;
+  LEX	*lex= &session->lex();
   select_result *result=lex->result;
   bool res= false;
   /* assign global limit variable if limit is not given */
@@ -503,6 +549,19 @@ bool execute_sqlcom_select(Session *session, TableList *all_tables)
       param->select_limit=
         new Item_int((uint64_t) session->variables.select_limit);
   }
+
+  if (all_tables
+      && ! (session->server_status & SERVER_STATUS_AUTOCOMMIT)
+      && ! session->inTransaction()
+      && ! lex->statement->isShow())
+  {
+    if (session->startTransaction() == false)
+    {
+      my_error(drizzled::ER_UNKNOWN_ERROR, MYF(0));
+      return true;
+    }
+  }
+
   if (not (res= session->openTablesLock(all_tables)))
   {
     if (lex->describe)
@@ -517,13 +576,13 @@ bool execute_sqlcom_select(Session *session, TableList *all_tables)
         return true;
       session->send_explain_fields(result);
       optimizer::ExplainPlan planner;
-      res= planner.explainUnion(session, &session->lex->unit, result);
+      res= planner.explainUnion(session, &session->lex().unit, result);
       if (lex->describe & DESCRIBE_EXTENDED)
       {
         char buff[1024];
         String str(buff,(uint32_t) sizeof(buff), system_charset_info);
         str.length(0);
-        session->lex->unit.print(&str, QT_ORDINARY);
+        session->lex().unit.print(&str);
         str.append('\0');
         push_warning(session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
                      ER_YES, str.ptr());
@@ -532,6 +591,7 @@ bool execute_sqlcom_select(Session *session, TableList *all_tables)
         result->abort();
       else
         result->send_eof();
+
       delete result;
     }
     else
@@ -540,10 +600,10 @@ bool execute_sqlcom_select(Session *session, TableList *all_tables)
         return true;
 
       /* Init the Query Cache plugin */
-      plugin::QueryCache::prepareResultset(session); 
+      plugin::QueryCache::prepareResultset(session);
       res= handle_select(session, lex, result, 0);
       /* Send the Resultset to the cache */
-      plugin::QueryCache::setResultset(session); 
+      plugin::QueryCache::setResultset(session);
 
       if (result != lex->result)
         delete result;
@@ -556,9 +616,9 @@ bool execute_sqlcom_select(Session *session, TableList *all_tables)
 #define MY_YACC_INIT 1000			// Start with big alloc
 #define MY_YACC_MAX  32000			// Because of 'short'
 
-bool my_yyoverflow(short **yyss, YYSTYPE **yyvs, ulong *yystacksize)
+bool my_yyoverflow(short **yyss, ParserType **yyvs, ulong *yystacksize)
 {
-  LEX	*lex= current_session->lex;
+  LEX	*lex= &current_session->lex();
   ulong old_info=0;
   if ((uint32_t) *yystacksize >= MY_YACC_MAX)
     return 1;
@@ -581,13 +641,13 @@ bool my_yyoverflow(short **yyss, YYSTYPE **yyvs, ulong *yystacksize)
     memcpy(lex->yacc_yyvs, *yyvs, old_info*sizeof(**yyvs));
   }
   *yyss=(short*) lex->yacc_yyss;
-  *yyvs=(YYSTYPE*) lex->yacc_yyvs;
+  *yyvs=(ParserType*) lex->yacc_yyvs;
   return 0;
 }
 
 
 void
-mysql_init_select(LEX *lex)
+init_select(LEX *lex)
 {
   Select_Lex *select_lex= lex->current_select;
   select_lex->init_select();
@@ -601,23 +661,26 @@ mysql_init_select(LEX *lex)
 
 
 bool
-mysql_new_select(LEX *lex, bool move_down)
+new_select(LEX *lex, bool move_down)
 {
   Select_Lex *select_lex;
   Session *session= lex->session;
 
   if (!(select_lex= new (session->mem_root) Select_Lex()))
-    return(1);
+    return true;
+
   select_lex->select_number= ++session->select_number;
   select_lex->parent_lex= lex; /* Used in init_query. */
   select_lex->init_query();
   select_lex->init_select();
   lex->nest_level++;
+
   if (lex->nest_level > (int) MAX_SELECT_NESTING)
   {
     my_error(ER_TOO_HIGH_LEVEL_OF_NESTING_FOR_SELECT,MYF(0),MAX_SELECT_NESTING);
     return(1);
   }
+
   select_lex->nest_level= lex->nest_level;
   if (move_down)
   {
@@ -645,12 +708,15 @@ mysql_new_select(LEX *lex, bool move_down)
     if (lex->current_select->order_list.first && !lex->current_select->braces)
     {
       my_error(ER_WRONG_USAGE, MYF(0), "UNION", "order_st BY");
-      return(1);
+      return true;
     }
+
     select_lex->include_neighbour(lex->current_select);
     Select_Lex_Unit *unit= select_lex->master_unit();
-    if (!unit->fake_select_lex && unit->add_fake_select_lex(lex->session))
-      return(1);
+
+    if (not unit->fake_select_lex && unit->add_fake_select_lex(lex->session))
+      return true;
+
     select_lex->context.outer_context=
                 unit->first_select()->context.outer_context;
   }
@@ -663,7 +729,8 @@ mysql_new_select(LEX *lex, bool move_down)
     list
   */
   select_lex->context.resolve_in_select_list= true;
-  return(0);
+
+  return false;
 }
 
 /**
@@ -676,18 +743,16 @@ mysql_new_select(LEX *lex, bool move_down)
   @param var_name		Variable name
 */
 
-void create_select_for_variable(const char *var_name)
+void create_select_for_variable(Session *session, const char *var_name)
 {
-  Session *session;
   LEX *lex;
   LEX_STRING tmp, null_lex_string;
   Item *var;
   char buff[MAX_SYS_VAR_LENGTH*2+4+8];
   char *end= buff;
 
-  session= current_session;
-  lex= session->lex;
-  mysql_init_select(lex);
+  lex= &session->lex();
+  init_select(lex);
   lex->sql_command= SQLCOM_SELECT;
   tmp.str= (char*) var_name;
   tmp.length=strlen(var_name);
@@ -702,7 +767,6 @@ void create_select_for_variable(const char *var_name)
     var->set_name(buff, end-buff, system_charset_info);
     session->add_item_to_list(var);
   }
-  return;
 }
 
 
@@ -714,10 +778,10 @@ void create_select_for_variable(const char *var_name)
   @param       length  Length of the query text
 */
 
-void mysql_parse(Session *session, const char *inBuf, uint32_t length)
+void parse(Session *session, const char *inBuf, uint32_t length)
 {
-  uint64_t start_time= my_getsystime();
-  lex_start(session);
+  session->lex().start(session);
+
   session->reset_for_next_command();
   /* Check if the Query is Cached if and return true if yes
    * TODO the plugin has to make sure that the query is cacheble
@@ -732,27 +796,28 @@ void mysql_parse(Session *session, const char *inBuf, uint32_t length)
   {
     return;
   }
-  LEX *lex= session->lex;
+  LEX *lex= &session->lex();
   Lex_input_stream lip(session, inBuf, length);
   bool err= parse_sql(session, &lip);
   if (!err)
   {
     {
-      if (! session->is_error())
+      if (not session->is_error())
       {
-        DRIZZLE_QUERY_EXEC_START(session->query.c_str(),
+        DRIZZLE_QUERY_EXEC_START(session->getQueryString()->c_str(),
                                  session->thread_id,
-                                 const_cast<const char *>(session->db.empty() ? "" : session->db.c_str()));
+                                 const_cast<const char *>(session->schema()->c_str()));
         // Implement Views here --Brian
         /* Actually execute the query */
-        try 
+        try
         {
-          mysql_execute_command(session);
+          execute_command(session);
         }
         catch (...)
         {
           // Just try to catch any random failures that could have come
           // during execution.
+          DRIZZLE_ABORT;
         }
         DRIZZLE_QUERY_EXEC_DONE(0);
       }
@@ -766,7 +831,7 @@ void mysql_parse(Session *session, const char *inBuf, uint32_t length)
   session->set_proc_info("freeing items");
   session->end_statement();
   session->cleanup_after_query();
-  session->status_var.execution_time_nsec+= my_getsystime() - start_time;
+  session->set_end_timer();
 }
 
 
@@ -788,7 +853,7 @@ bool add_field_to_list(Session *session, LEX_STRING *field_name, enum_field_type
                        List<String> *interval_list, const CHARSET_INFO * const cs)
 {
   register CreateField *new_field;
-  LEX  *lex= session->lex;
+  LEX  *lex= &session->lex();
   statement::AlterTable *statement= (statement::AlterTable *)lex->statement;
 
   if (check_identifier_name(field_name, ER_TOO_LONG_IDENT))
@@ -802,7 +867,7 @@ bool add_field_to_list(Session *session, LEX_STRING *field_name, enum_field_type
                       &default_key_create_info,
                       0, lex->col_list);
     statement->alter_info.key_list.push_back(key);
-    lex->col_list.empty();
+    lex->col_list.clear();
   }
   if (type_modifier & (UNIQUE_FLAG | UNIQUE_KEY_FLAG))
   {
@@ -812,7 +877,7 @@ bool add_field_to_list(Session *session, LEX_STRING *field_name, enum_field_type
                  &default_key_create_info, 0,
                  lex->col_list);
     statement->alter_info.key_list.push_back(key);
-    lex->col_list.empty();
+    lex->col_list.clear();
   }
 
   if (default_value)
@@ -826,7 +891,7 @@ bool add_field_to_list(Session *session, LEX_STRING *field_name, enum_field_type
     */
     if (default_value->type() == Item::FUNC_ITEM &&
         !(((Item_func*)default_value)->functype() == Item_func::NOW_FUNC &&
-         type == DRIZZLE_TYPE_TIMESTAMP))
+         (type == DRIZZLE_TYPE_TIMESTAMP or type == DRIZZLE_TYPE_MICROTIME)))
     {
       my_error(ER_INVALID_DEFAULT, MYF(0), field_name->str);
       return true;
@@ -834,8 +899,7 @@ bool add_field_to_list(Session *session, LEX_STRING *field_name, enum_field_type
     else if (default_value->type() == Item::NULL_ITEM)
     {
       default_value= 0;
-      if ((type_modifier & (NOT_NULL_FLAG | AUTO_INCREMENT_FLAG)) ==
-	  NOT_NULL_FLAG)
+      if ((type_modifier & (NOT_NULL_FLAG | AUTO_INCREMENT_FLAG)) == NOT_NULL_FLAG)
       {
 	my_error(ER_INVALID_DEFAULT, MYF(0), field_name->str);
 	return true;
@@ -848,7 +912,7 @@ bool add_field_to_list(Session *session, LEX_STRING *field_name, enum_field_type
     }
   }
 
-  if (on_update_value && type != DRIZZLE_TYPE_TIMESTAMP)
+  if (on_update_value && (type != DRIZZLE_TYPE_TIMESTAMP and type != DRIZZLE_TYPE_MICROTIME))
   {
     my_error(ER_INVALID_ON_UPDATE, MYF(0), field_name->str);
     return true;
@@ -867,13 +931,6 @@ bool add_field_to_list(Session *session, LEX_STRING *field_name, enum_field_type
 }
 
 
-/** Store position for column in ALTER TABLE .. ADD column. */
-
-void store_position_for_column(const char *name)
-{
-  current_session->lex->last_field->after=const_cast<char*> (name);
-}
-
 /**
   Add a table to list of used tables.
 
@@ -894,22 +951,22 @@ void store_position_for_column(const char *name)
 */
 
 TableList *Select_Lex::add_table_to_list(Session *session,
-					     Table_ident *table,
-					     LEX_STRING *alias,
-					     uint32_t table_options,
-					     thr_lock_type lock_type,
-					     List<Index_hint> *index_hints_arg,
-                                             LEX_STRING *option)
+                                         Table_ident *table,
+                                         LEX_STRING *alias,
+                                         const bitset<NUM_OF_TABLE_OPTIONS>& table_options,
+                                         thr_lock_type lock_type,
+                                         List<Index_hint> *index_hints_arg,
+                                         LEX_STRING *option)
 {
-  register TableList *ptr;
+  TableList *ptr;
   TableList *previous_table_ref; /* The table preceding the current one. */
   char *alias_str;
-  LEX *lex= session->lex;
+  LEX *lex= &session->lex();
 
   if (!table)
     return NULL;				// End of memory
   alias_str= alias ? alias->str : table->table.str;
-  if (!test(table_options & TL_OPTION_ALIAS) &&
+  if (! table_options.test(TL_OPTION_ALIAS) &&
       check_table_name(table->table.str, table->table.length))
   {
     my_error(ER_WRONG_TABLE_NAME, MYF(0), table->table.str);
@@ -920,8 +977,8 @@ TableList *Select_Lex::add_table_to_list(Session *session,
   {
     my_casedn_str(files_charset_info, table->db.str);
 
-    SchemaIdentifier schema_identifier(string(table->db.str));
-    if (not check_db_name(session, schema_identifier))
+    identifier::Schema schema_identifier(string(table->db.str));
+    if (not schema::check(*session, schema_identifier))
     {
 
       my_error(ER_WRONG_DB_NAME, MYF(0), table->db.str);
@@ -937,7 +994,7 @@ TableList *Select_Lex::add_table_to_list(Session *session,
                  ER(ER_DERIVED_MUST_HAVE_ALIAS), MYF(0));
       return NULL;
     }
-    if (!(alias_str= (char*) session->memdup(alias_str,table->table.length+1)))
+    if (!(alias_str= (char*) session->getMemRoot()->duplicate(alias_str,table->table.length+1)))
       return NULL;
   }
   if (!(ptr = (TableList *) session->calloc(sizeof(TableList))))
@@ -946,23 +1003,21 @@ TableList *Select_Lex::add_table_to_list(Session *session,
   if (table->db.str)
   {
     ptr->setIsFqtn(true);
-    ptr->db= table->db.str;
+    ptr->setSchemaName(table->db.str);
     ptr->db_length= table->db.length;
   }
-  else if (lex->copy_db_to(&ptr->db, &ptr->db_length))
+  else if (lex->copy_db_to(ptr->getSchemaNamePtr(), &ptr->db_length))
     return NULL;
   else
     ptr->setIsFqtn(false);
 
   ptr->alias= alias_str;
   ptr->setIsAlias(alias ? true : false);
-  if (table->table.length)
-    table->table.length= my_casedn_str(files_charset_info, table->table.str);
-  ptr->table_name=table->table.str;
+  ptr->setTableName(table->table.str);
   ptr->table_name_length=table->table.length;
   ptr->lock_type=   lock_type;
-  ptr->force_index= test(table_options & TL_OPTION_FORCE_INDEX);
-  ptr->ignore_leaves= test(table_options & TL_OPTION_IGNORE_LEAVES);
+  ptr->force_index= table_options.test(TL_OPTION_FORCE_INDEX);
+  ptr->ignore_leaves= table_options.test(TL_OPTION_IGNORE_LEAVES);
   ptr->derived=	    table->sel;
   ptr->select_lex=  lex->current_select;
   ptr->index_hints= index_hints_arg;
@@ -975,8 +1030,8 @@ TableList *Select_Lex::add_table_to_list(Session *session,
 	 tables ;
 	 tables=tables->next_local)
     {
-      if (!my_strcasecmp(table_alias_charset, alias_str, tables->alias) &&
-	  !strcasecmp(ptr->db, tables->db))
+      if (not my_strcasecmp(table_alias_charset, alias_str, tables->alias) &&
+	  not my_strcasecmp(system_charset_info, ptr->getSchemaName(), tables->getSchemaName()))
       {
 	my_error(ER_NONUNIQ_TABLE, MYF(0), alias_str);
 	return NULL;
@@ -984,7 +1039,7 @@ TableList *Select_Lex::add_table_to_list(Session *session,
     }
   }
   /* Store the table reference preceding the current one. */
-  if (table_list.elements > 0)
+  if (table_list.size() > 0)
   {
     /*
       table_list.next points to the last inserted TableList->next_local'
@@ -1040,12 +1095,12 @@ TableList *Select_Lex::add_table_to_list(Session *session,
 bool Select_Lex::init_nested_join(Session *session)
 {
   TableList *ptr;
-  nested_join_st *nested_join;
+  NestedJoin *nested_join;
 
   if (!(ptr= (TableList*) session->calloc(ALIGN_SIZE(sizeof(TableList))+
-                                       sizeof(nested_join_st))))
+                                       sizeof(NestedJoin))))
     return true;
-  ptr->setNestedJoin(((nested_join_st*) ((unsigned char*) ptr + ALIGN_SIZE(sizeof(TableList)))));
+  ptr->setNestedJoin(((NestedJoin*) ((unsigned char*) ptr + ALIGN_SIZE(sizeof(TableList)))));
   nested_join= ptr->getNestedJoin();
   join_list->push_front(ptr);
   ptr->setEmbedding(embedding);
@@ -1053,7 +1108,7 @@ bool Select_Lex::init_nested_join(Session *session)
   ptr->alias= (char*) "(nested_join)";
   embedding= ptr;
   join_list= &nested_join->join_list;
-  join_list->empty();
+  join_list->clear();
   return false;
 }
 
@@ -1075,23 +1130,23 @@ bool Select_Lex::init_nested_join(Session *session)
 TableList *Select_Lex::end_nested_join(Session *)
 {
   TableList *ptr;
-  nested_join_st *nested_join;
+  NestedJoin *nested_join;
 
   assert(embedding);
   ptr= embedding;
   join_list= ptr->getJoinList();
   embedding= ptr->getEmbedding();
   nested_join= ptr->getNestedJoin();
-  if (nested_join->join_list.elements == 1)
+  if (nested_join->join_list.size() == 1)
   {
-    TableList *embedded= nested_join->join_list.head();
+    TableList *embedded= &nested_join->join_list.front();
     join_list->pop();
     embedded->setJoinList(join_list);
     embedded->setEmbedding(embedding);
     join_list->push_front(embedded);
     ptr= embedded;
   }
-  else if (nested_join->join_list.elements == 0)
+  else if (nested_join->join_list.size() == 0)
   {
     join_list->pop();
     ptr= NULL;                                     // return value
@@ -1116,19 +1171,19 @@ TableList *Select_Lex::end_nested_join(Session *)
 TableList *Select_Lex::nest_last_join(Session *session)
 {
   TableList *ptr;
-  nested_join_st *nested_join;
+  NestedJoin *nested_join;
   List<TableList> *embedded_list;
 
   if (!(ptr= (TableList*) session->calloc(ALIGN_SIZE(sizeof(TableList))+
-                                          sizeof(nested_join_st))))
+                                          sizeof(NestedJoin))))
     return NULL;
-  ptr->setNestedJoin(((nested_join_st*) ((unsigned char*) ptr + ALIGN_SIZE(sizeof(TableList)))));
+  ptr->setNestedJoin(((NestedJoin*) ((unsigned char*) ptr + ALIGN_SIZE(sizeof(TableList)))));
   nested_join= ptr->getNestedJoin();
   ptr->setEmbedding(embedding);
   ptr->setJoinList(join_list);
   ptr->alias= (char*) "(nest_last_join)";
   embedded_list= &nested_join->join_list;
-  embedded_list->empty();
+  embedded_list->clear();
 
   for (uint32_t i=0; i < 2; i++)
   {
@@ -1276,7 +1331,7 @@ bool Select_Lex_Unit::add_fake_select_lex(Session *session_arg)
   fake_select_lex->include_standalone(this,
                                       (Select_Lex_Node**)&fake_select_lex);
   fake_select_lex->select_number= INT_MAX;
-  fake_select_lex->parent_lex= session_arg->lex; /* Used in init_query. */
+  fake_select_lex->parent_lex= &session_arg->lex(); /* Used in init_query. */
   fake_select_lex->make_empty_select();
   fake_select_lex->linkage= GLOBAL_OPTIONS_TYPE;
   fake_select_lex->select_limit= 0;
@@ -1296,9 +1351,9 @@ bool Select_Lex_Unit::add_fake_select_lex(Session *session_arg)
     */
     global_parameters= fake_select_lex;
     fake_select_lex->no_table_names_allowed= 1;
-    session_arg->lex->current_select= fake_select_lex;
+    session_arg->lex().current_select= fake_select_lex;
   }
-  session_arg->lex->pop_context();
+  session_arg->lex().pop_context();
   return(0);
 }
 
@@ -1334,7 +1389,7 @@ push_new_name_resolution_context(Session *session,
     left_op->first_leaf_for_name_resolution();
   on_context->last_name_resolution_table=
     right_op->last_leaf_for_name_resolution();
-  return session->lex->push_context(on_context);
+  return session->lex().push_context(on_context);
 }
 
 
@@ -1413,69 +1468,6 @@ void add_join_natural(TableList *a, TableList *b, List<String> *using_fields,
 }
 
 
-/**
-  kill on thread.
-
-  @param session			Thread class
-  @param id			Thread id
-  @param only_kill_query        Should it kill the query or the connection
-
-  @note
-    This is written such that we have a short lock on LOCK_thread_count
-*/
-
-static unsigned int
-kill_one_thread(Session *, ulong id, bool only_kill_query)
-{
-  Session *tmp= NULL;
-  uint32_t error= ER_NO_SUCH_THREAD;
-  LOCK_thread_count.lock(); // For unlink from list
-  
-  for (SessionList::iterator it= getSessionList().begin(); it != getSessionList().end(); ++it )
-  {
-    if ((*it)->thread_id == id)
-    {
-      tmp= *it;
-      tmp->lockForDelete();
-      break;
-    }
-  }
-  LOCK_thread_count.unlock();
-  if (tmp)
-  {
-
-    if (tmp->isViewable())
-    {
-      tmp->awake(only_kill_query ? Session::KILL_QUERY : Session::KILL_CONNECTION);
-      error= 0;
-    }
-
-    tmp->unlockForDelete();
-  }
-  return(error);
-}
-
-
-/*
-  kills a thread and sends response
-
-  SYNOPSIS
-    sql_kill()
-    session			Thread class
-    id			Thread id
-    only_kill_query     Should it kill the query or the connection
-*/
-
-void sql_kill(Session *session, ulong id, bool only_kill_query)
-{
-  uint32_t error;
-  if (!(error= kill_one_thread(session, id, only_kill_query)))
-    session->my_ok();
-  else
-    my_error(error, MYF(0), id);
-}
-
-
 /**
   Check if the select is a simple select (not an union).
 
@@ -1485,11 +1477,9 @@ void sql_kill(Session *session, ulong id, bool only_kill_query)
     1	error	; In this case the error messege is sent to the client
 */
 
-bool check_simple_select()
+bool check_simple_select(Session::pointer session)
 {
-  Session *session= current_session;
-  LEX *lex= session->lex;
-  if (lex->current_select != &lex->select_lex)
+  if (session->lex().current_select != &session->lex().select_lex)
   {
     char command[80];
     Lex_input_stream *lip= session->m_lip;
@@ -1549,18 +1539,17 @@ Item * all_any_subquery_creator(Item *left_expr,
 bool update_precheck(Session *session, TableList *)
 {
   const char *msg= 0;
-  LEX *lex= session->lex;
-  Select_Lex *select_lex= &lex->select_lex;
+  Select_Lex *select_lex= &session->lex().select_lex;
 
-  if (session->lex->select_lex.item_list.elements != session->lex->value_list.elements)
+  if (session->lex().select_lex.item_list.size() != session->lex().value_list.size())
   {
     my_message(ER_WRONG_VALUE_COUNT, ER(ER_WRONG_VALUE_COUNT), MYF(0));
     return(true);
   }
 
-  if (session->lex->select_lex.table_list.elements > 1)
+  if (session->lex().select_lex.table_list.size() > 1)
   {
-    if (select_lex->order_list.elements)
+    if (select_lex->order_list.size())
       msg= "ORDER BY";
     else if (select_lex->select_limit)
       msg= "LIMIT";
@@ -1588,13 +1577,11 @@ bool update_precheck(Session *session, TableList *)
 
 bool insert_precheck(Session *session, TableList *)
 {
-  LEX *lex= session->lex;
-
   /*
     Check that we have modify privileges for the first table and
     select privileges for the rest
   */
-  if (lex->update_list.elements != lex->value_list.elements)
+  if (session->lex().update_list.size() != session->lex().value_list.size())
   {
     my_message(ER_WRONG_VALUE_COUNT, ER(ER_WRONG_VALUE_COUNT), MYF(0));
     return(true);
@@ -1603,37 +1590,6 @@ bool insert_precheck(Session *session, TableList *)
 }
 
 
-/**
-  CREATE TABLE query pre-check.
-
-  @param session			Thread handler
-  @param tables		Global table list
-  @param create_table	        Table which will be created
-
-  @retval
-    false   OK
-  @retval
-    true   Error
-*/
-
-bool create_table_precheck(TableIdentifier &identifier)
-{
-  if (not plugin::StorageEngine::canCreateTable(identifier))
-  {
-    my_error(ER_DBACCESS_DENIED_ERROR, MYF(0), "", "", identifier.getSchemaName().c_str());
-    return true;
-  }
-
-  if (not plugin::StorageEngine::doesSchemaExist(identifier))
-  {
-    my_error(ER_BAD_DB_ERROR, MYF(0), identifier.getSchemaName().c_str());
-    return true;
-  }
-
-  return false;
-}
-
-
 /**
   negate given expression.
 
@@ -1652,7 +1608,7 @@ Item *negate_expression(Session *session, Item *expr)
   {
     /* it is NOT(NOT( ... )) */
     Item *arg= ((Item_func *) expr)->arguments()[0];
-    enum_parsing_place place= session->lex->current_select->parsing_place;
+    enum_parsing_place place= session->lex().current_select->parsing_place;
     if (arg->is_bool_func() || place == IN_WHERE || place == IN_HAVING)
       return arg;
     /*
@@ -1701,7 +1657,7 @@ bool check_string_char_length(LEX_STRING *str, const char *err_msg,
 }
 
 
-bool check_identifier_name(LEX_STRING *str, uint32_t err_code,
+bool check_identifier_name(LEX_STRING *str, error_t err_code,
                            uint32_t max_char_length,
                            const char *param_for_err_msg)
 {
@@ -1727,7 +1683,7 @@ bool check_identifier_name(LEX_STRING *str, uint32_t err_code,
 
   switch (err_code)
   {
-  case 0:
+  case EE_OK:
     break;
   case ER_WRONG_STRING_LENGTH:
     my_error(err_code, MYF(0), str->str, param_for_err_msg, max_char_length);
@@ -1739,6 +1695,7 @@ bool check_identifier_name(LEX_STRING *str, uint32_t err_code,
     assert(0);
     break;
   }
+
   return true;
 }
 
@@ -1759,7 +1716,7 @@ static bool parse_sql(Session *session, Lex_input_stream *lip)
 {
   assert(session->m_lip == NULL);
 
-  DRIZZLE_QUERY_PARSE_START(session->query.c_str());
+  DRIZZLE_QUERY_PARSE_START(session->getQueryString()->c_str());
 
   /* Set Lex_input_stream. */
 
@@ -1767,21 +1724,21 @@ static bool parse_sql(Session *session, Lex_input_stream *lip)
 
   /* Parse the query. */
 
-  bool mysql_parse_status= DRIZZLEparse(session) != 0;
+  bool parse_status= base_sql_parse(session) != 0;
 
   /* Check that if DRIZZLEparse() failed, session->is_error() is set. */
 
-  assert(!mysql_parse_status || session->is_error());
+  assert(!parse_status || session->is_error());
 
   /* Reset Lex_input_stream. */
 
   session->m_lip= NULL;
 
-  DRIZZLE_QUERY_PARSE_DONE(mysql_parse_status || session->is_fatal_error);
+  DRIZZLE_QUERY_PARSE_DONE(parse_status || session->is_fatal_error);
 
   /* That's it. */
 
-  return mysql_parse_status || session->is_fatal_error;
+  return parse_status || session->is_fatal_error;
 }
 
 /**
