@@ -11,18 +11,23 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /*
   UNION  of select's
   UNION's  were introduced by Monty and Sinisa <sinisa@mysql.com>
 */
-#include "config.h"
+#include <config.h>
+
 #include <drizzled/sql_select.h>
 #include <drizzled/error.h>
 #include <drizzled/item/type_holder.h>
 #include <drizzled/sql_base.h>
 #include <drizzled/sql_union.h>
+#include <drizzled/select_union.h>
+#include <drizzled/sql_lex.h>
+#include <drizzled/session.h>
+#include <drizzled/item/subselect.h>
 
 namespace drizzled
 {
@@ -122,10 +127,10 @@ select_union::create_result_table(Session *session_arg, List<Item> *column_types
 {
   assert(table == NULL);
   tmp_table_param.init();
-  tmp_table_param.field_count= column_types->elements;
+  tmp_table_param.field_count= column_types->size();
 
   if (! (table= create_tmp_table(session_arg, &tmp_table_param, *column_types,
-                                 (order_st*) NULL, is_union_distinct, 1,
+                                 (Order*) NULL, is_union_distinct, 1,
                                  options, HA_POS_ERROR, (char*) table_alias)))
   {
     return true;
@@ -168,7 +173,7 @@ void select_union::cleanup()
 void
 Select_Lex_Unit::init_prepare_fake_select_lex(Session *session_arg)
 {
-  session_arg->lex->current_select= fake_select_lex;
+  session_arg->lex().current_select= fake_select_lex;
   fake_select_lex->table_list.link_in_list((unsigned char *)&result_table_list,
 					   (unsigned char **)
 					   &result_table_list.next_local);
@@ -176,12 +181,12 @@ Select_Lex_Unit::init_prepare_fake_select_lex(Session *session_arg)
     fake_select_lex->context.first_name_resolution_table=
     fake_select_lex->get_table_list();
 
-  for (order_st *order= (order_st *) global_parameters->order_list.first;
+  for (Order *order= (Order *) global_parameters->order_list.first;
        order;
        order= order->next)
     order->item= &order->item_ptr;
 
-  for (order_st *order= (order_st *)global_parameters->order_list.first;
+  for (Order *order= (Order *)global_parameters->order_list.first;
        order;
        order=order->next)
   {
@@ -194,7 +199,7 @@ Select_Lex_Unit::init_prepare_fake_select_lex(Session *session_arg)
 bool Select_Lex_Unit::prepare(Session *session_arg, select_result *sel_result,
                               uint64_t additional_options)
 {
-  Select_Lex *lex_select_save= session_arg->lex->current_select;
+  Select_Lex *lex_select_save= session_arg->lex().current_select;
   Select_Lex *sl, *first_sl= first_select();
   select_result *tmp_result;
   bool is_union_select;
@@ -231,7 +236,7 @@ bool Select_Lex_Unit::prepare(Session *session_arg, select_result *sel_result,
   prepared= 1;
   saved_error= false;
 
-  session_arg->lex->current_select= sl= first_sl;
+  session_arg->lex().current_select= sl= first_sl;
   found_rows_for_union= first_sl->options & OPTION_FOUND_ROWS;
   is_union_select= is_union() || fake_select_lex;
 
@@ -266,7 +271,7 @@ bool Select_Lex_Unit::prepare(Session *session_arg, select_result *sel_result,
     if (!join)
       goto err;
 
-    session_arg->lex->current_select= sl;
+    session_arg->lex().current_select= sl;
 
     can_skip_order_by= is_union_select && !(sl->braces && sl->explicit_limit);
 
@@ -275,11 +280,11 @@ bool Select_Lex_Unit::prepare(Session *session_arg, select_result *sel_result,
                                sl->with_wild,
                                sl->where,
                                (can_skip_order_by ? 0 :
-                                sl->order_list.elements) +
-                               sl->group_list.elements,
+                                sl->order_list.size()) +
+                               sl->group_list.size(),
                                can_skip_order_by ?
-                               (order_st*) NULL : (order_st *)sl->order_list.first,
-                               (order_st*) sl->group_list.first,
+                               (Order*) NULL : (Order *)sl->order_list.first,
+                               (Order*) sl->group_list.first,
                                sl->having,
                                sl, this);
     /* There are no * in the statement anymore (for PS) */
@@ -303,8 +308,8 @@ bool Select_Lex_Unit::prepare(Session *session_arg, select_result *sel_result,
       */
       assert(!empty_table);
       empty_table= (Table*) session->calloc(sizeof(Table));
-      types.empty();
-      List_iterator_fast<Item> it(sl->item_list);
+      types.clear();
+      List<Item>::iterator it(sl->item_list.begin());
       Item *item_tmp;
       while ((item_tmp= it++))
       {
@@ -317,14 +322,14 @@ bool Select_Lex_Unit::prepare(Session *session_arg, select_result *sel_result,
     }
     else
     {
-      if (types.elements != sl->item_list.elements)
+      if (types.size() != sl->item_list.size())
       {
 	my_message(ER_WRONG_NUMBER_OF_COLUMNS_IN_SELECT,
 		   ER(ER_WRONG_NUMBER_OF_COLUMNS_IN_SELECT),MYF(0));
 	goto err;
       }
-      List_iterator_fast<Item> it(sl->item_list);
-      List_iterator_fast<Item> tp(types);
+      List<Item>::iterator it(sl->item_list.begin());
+      List<Item>::iterator tp(types.begin());
       Item *type, *item_tmp;
       while ((type= tp++, item_tmp= it++))
       {
@@ -340,7 +345,7 @@ bool Select_Lex_Unit::prepare(Session *session_arg, select_result *sel_result,
       Check that it was possible to aggregate
       all collations together for UNION.
     */
-    List_iterator_fast<Item> tp(types);
+    List<Item>::iterator tp(types.begin());
     Item *type;
     uint64_t create_options;
 
@@ -361,13 +366,13 @@ bool Select_Lex_Unit::prepare(Session *session_arg, select_result *sel_result,
                                           create_options, ""))
       goto err;
     memset(&result_table_list, 0, sizeof(result_table_list));
-    result_table_list.db= (char*) "";
+    result_table_list.setSchemaName((char*) "");
     result_table_list.alias= "union";
-    result_table_list.table_name= (char *) "union";
+    result_table_list.setTableName((char *) "union");
     result_table_list.table= table= union_result->table;
 
-    session_arg->lex->current_select= lex_select_save;
-    if (!item_list.elements)
+    session_arg->lex().current_select= lex_select_save;
+    if (!item_list.size())
     {
       saved_error= table->fill_item_list(&item_list);
       if (saved_error)
@@ -383,28 +388,28 @@ bool Select_Lex_Unit::prepare(Session *session_arg, select_result *sel_result,
     }
   }
 
-  session_arg->lex->current_select= lex_select_save;
+  session_arg->lex().current_select= lex_select_save;
 
   return(saved_error || session_arg->is_fatal_error);
 
 err:
-  session_arg->lex->current_select= lex_select_save;
+  session_arg->lex().current_select= lex_select_save;
   return(true);
 }
 
 
 bool Select_Lex_Unit::exec()
 {
-  Select_Lex *lex_select_save= session->lex->current_select;
+  Select_Lex *lex_select_save= session->lex().current_select;
   Select_Lex *select_cursor=first_select();
   uint64_t add_rows=0;
   ha_rows examined_rows= 0;
 
-  if (executed && !uncacheable && !describe)
-    return(false);
+  if (executed && uncacheable.none() && ! describe)
+    return false;
   executed= 1;
 
-  if (uncacheable || !item || !item->assigned() || describe)
+  if (uncacheable.any() || ! item || ! item->assigned() || describe)
   {
     if (item)
       item->reset_value_registration();
@@ -425,7 +430,7 @@ bool Select_Lex_Unit::exec()
     for (Select_Lex *sl= select_cursor; sl; sl= sl->next_select())
     {
       ha_rows records_at_start= 0;
-      session->lex->current_select= sl;
+      session->lex().current_select= sl;
 
       if (optimized)
 	saved_error= sl->join->reinit();
@@ -473,14 +478,14 @@ bool Select_Lex_Unit::exec()
 	  examined_rows+= session->examined_row_count;
 	  if (union_result->flush())
 	  {
-	    session->lex->current_select= lex_select_save;
+	    session->lex().current_select= lex_select_save;
 	    return(1);
 	  }
 	}
       }
       if (saved_error)
       {
-	session->lex->current_select= lex_select_save;
+	session->lex().current_select= lex_select_save;
 	return(saved_error);
       }
       /* Needed for the following test and for records_at_start in next loop */
@@ -518,8 +523,8 @@ bool Select_Lex_Unit::exec()
       {
 	/*
 	  allocate JOIN for fake select only once (prevent
-	  mysql_select automatic allocation)
-          TODO: The above is nonsense. mysql_select() will not allocate the
+	  select_query automatic allocation)
+          TODO: The above is nonsense. select_query() will not allocate the
           join if one already exists. There must be some other reason why we
           don't let it allocate the join. Perhaps this is because we need
           some special parameter values passed to join constructor?
@@ -527,7 +532,7 @@ bool Select_Lex_Unit::exec()
 	if (!(fake_select_lex->join= new Join(session, item_list,
 					      fake_select_lex->options, result)))
 	{
-	  fake_select_lex->table_list.empty();
+	  fake_select_lex->table_list.clear();
 	  return(true);
 	}
         fake_select_lex->join->no_const_tables= true;
@@ -537,12 +542,12 @@ bool Select_Lex_Unit::exec()
 	  allocation.
 	*/
 	fake_select_lex->item_list= item_list;
-        saved_error= mysql_select(session, &fake_select_lex->ref_pointer_array,
+        saved_error= select_query(session, &fake_select_lex->ref_pointer_array,
                               &result_table_list,
                               0, item_list, NULL,
-                              global_parameters->order_list.elements,
-                              (order_st*)global_parameters->order_list.first,
-                              (order_st*) NULL, NULL,
+                              global_parameters->order_list.size(),
+                              (Order*)global_parameters->order_list.first,
+                              (Order*) NULL, NULL,
                               fake_select_lex->options | SELECT_NO_UNLOCK,
                               result, this, fake_select_lex);
       }
@@ -560,12 +565,12 @@ bool Select_Lex_Unit::exec()
             to reset them back, we re-do all of the actions (yes it is ugly):
           */
 	        join->reset(session, item_list, fake_select_lex->options, result);
-          saved_error= mysql_select(session, &fake_select_lex->ref_pointer_array,
+          saved_error= select_query(session, &fake_select_lex->ref_pointer_array,
                                 &result_table_list,
                                 0, item_list, NULL,
-                                global_parameters->order_list.elements,
-                                (order_st*)global_parameters->order_list.first,
-                                (order_st*) NULL, NULL,
+                                global_parameters->order_list.size(),
+                                (Order*)global_parameters->order_list.first,
+                                (Order*) NULL, NULL,
                                 fake_select_lex->options | SELECT_NO_UNLOCK,
                                 result, this, fake_select_lex);
         }
@@ -577,7 +582,7 @@ bool Select_Lex_Unit::exec()
         }
       }
 
-      fake_select_lex->table_list.empty();
+      fake_select_lex->table_list.clear();
       if (!saved_error)
       {
 	session->limit_found_rows = (uint64_t)table->cursor->stats.records + add_rows;
@@ -589,7 +594,7 @@ bool Select_Lex_Unit::exec()
       */
     }
   }
-  session->lex->current_select= lex_select_save;
+  session->lex().current_select= lex_select_save;
   return(saved_error);
 }
 
@@ -606,8 +611,7 @@ bool Select_Lex_Unit::cleanup()
 
   if (union_result)
   {
-    delete union_result;
-    union_result=0; // Safety
+    safe_delete(union_result);
     table= 0; // Safety
   }
 
@@ -623,10 +627,10 @@ bool Select_Lex_Unit::cleanup()
       join->tables= 0;
     }
     error|= fake_select_lex->cleanup();
-    if (fake_select_lex->order_list.elements)
+    if (fake_select_lex->order_list.size())
     {
-      order_st *ord;
-      for (ord= (order_st*)fake_select_lex->order_list.first; ord; ord= ord->next)
+      Order *ord;
+      for (ord= (Order*)fake_select_lex->order_list.first; ord; ord= ord->next)
         (*ord->item)->cleanup();
     }
   }
@@ -709,16 +713,15 @@ bool Select_Lex::cleanup()
   {
     assert((Select_Lex*)join->select_lex == this);
     error= join->destroy();
-    delete join;
-    join= 0;
+    safe_delete(join);
   }
   for (Select_Lex_Unit *lex_unit= first_inner_unit(); lex_unit ;
        lex_unit= lex_unit->next_unit())
   {
     error= (bool) ((uint32_t) error | (uint32_t) lex_unit->cleanup());
   }
-  non_agg_fields.empty();
-  inner_refs_list.empty();
+  non_agg_fields.clear();
+  inner_refs_list.clear();
   return(error);
 }
 
