@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_STATEMENT_H
-#define DRIZZLED_STATEMENT_H
+#pragma once
 
 #include <drizzled/definitions.h>
 #include <drizzled/error.h>
@@ -27,15 +26,15 @@
 #include <drizzled/sql_base.h>
 #include <drizzled/show.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 class Session;
 class TableList;
 class Item;
 
-namespace statement
-{
+namespace session { class Transactions; }
+
+namespace statement {
 
 /**
  * @class Statement
@@ -44,13 +43,16 @@ namespace statement
 class Statement
 {
 public:
-  Statement(Session *in_session)
-    : 
-      session(in_session)
+  Statement(Session *in_session) :
+    _session(*in_session)
   {}
 
   virtual ~Statement() {}
 
+  void set_command(enum_sql_command);
+  LEX& lex();
+  session::Transactions& transaction();
+
   /**
    * Execute the statement.
    *
@@ -58,16 +60,24 @@ public:
    */
   virtual bool execute()= 0;
 
-protected:
+  /* True if can be in transaction. Currently only DDL is not.
+     This should go away when DDL commands are within transactions. */
+  virtual bool isTransactional()
+  {
+    return false;
+  }
 
-  /**
-   * A session handler.
-   */
-  Session *session;
+  Session& session() const
+  {
+    return _session;
+  }
+
+  virtual bool isShow() { return false; }
+
+private:
+  Session& _session;
 };
 
 } /* namespace statement */
-
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_STATEMENT_H */
