@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_STATEMENT_ALTER_SCHEMA_H
-#define DRIZZLED_STATEMENT_ALTER_SCHEMA_H
+#pragma once
 
 #include <drizzled/statement/create_schema.h>
 
@@ -33,11 +32,10 @@ namespace statement
 class AlterSchema : public CreateSchema
 {
 public:
-  AlterSchema(Session *in_session)
-    :
-      CreateSchema(in_session)
-  { 
-    schema_message.set_update_timestamp(time(NULL));
+  AlterSchema(Session *in_session) :
+    CreateSchema(in_session)
+  {
+    set_command(SQLCOM_ALTER_DB);
   }
 
   bool execute();
@@ -47,4 +45,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_STATEMENT_ALTER_SCHEMA_H */
