@@ -23,10 +23,13 @@
 #include <drizzled/session.h>
 #include <drizzled/statement/catalog.h>
 
-namespace drizzled {
-namespace statement {
+namespace drizzled
+{
 
-Catalog::Catalog(Session *in_session, str_ref arg) :
+namespace statement
+{
+
+Catalog::Catalog(Session *in_session, drizzled::lex_string_t &arg) :
   Statement(in_session),
   _identifier(arg)
 {
