@@ -18,29 +18,33 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+
 #pragma once
 
 #include <drizzled/statement.h>
 
-namespace drizzled {
-namespace statement {
+namespace drizzled
+{
+
+namespace statement
+{
 
 class Catalog : public Statement
 {
+  identifier::Catalog _identifier;
+
 public:
-  Catalog(Session*, str_ref);
+  Catalog(Session *in_session, drizzled::lex_string_t &arg);
 
   virtual bool authorized() const= 0;
   virtual bool perform() const= 0;
 
   bool execute();
 
-  const identifier::Catalog& identifier() const
+  identifier::Catalog::const_reference identifier() const
   {
     return _identifier;
   }
-private:
-  identifier::Catalog _identifier;
 };
 
 } /* namespace statement */
@@ -48,3 +52,4 @@ private:
 
 #include <drizzled/statement/catalog/create.h>
 #include <drizzled/statement/catalog/drop.h>
+
