@@ -21,14 +21,19 @@
 
 #pragma once
 
-namespace drizzled {
-namespace statement {
-namespace catalog {
+namespace drizzled
+{
 
-class Create : public Catalog
+namespace statement
+{
+
+namespace catalog
+{
+
+class Create :public Catalog
 {
 public:
-  Create(Session*, str_ref);
+  Create(Session *in_session, drizzled::lex_string_t &arg);
   bool authorized() const;
   bool perform() const;
 };
