@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,11 +18,12 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 #include <drizzled/show.h>
 #include <drizzled/session.h>
 #include <drizzled/statement/change_schema.h>
-#include <drizzled/db.h>
+#include <drizzled/schema.h>
+#include <drizzled/sql_lex.h>
 
 #include <string>
 
@@ -33,12 +34,12 @@ namespace drizzled
 
 bool statement::ChangeSchema::execute()
 {
-  Select_Lex *select_lex= &session->lex->select_lex;
+  Select_Lex *select_lex= &lex().select_lex;
 
-  SchemaIdentifier identifier(select_lex->db);
-  if (not mysql_change_db(session, identifier))
+  identifier::Schema identifier(select_lex->db);
+  if (not schema::change(session(), identifier))
   {
-    session->my_ok();
+    session().my_ok();
   }
 
   return false;
