@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,9 +18,9 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_STATEMENT_DROP_INDEX_H
-#define DRIZZLED_STATEMENT_DROP_INDEX_H
+#pragma once
 
+#include <drizzled/alter_info.h>
 #include <drizzled/statement.h>
 
 namespace drizzled
@@ -33,10 +33,11 @@ namespace statement
 class DropIndex : public Statement
 {
 public:
-  DropIndex(Session *in_session)
-    :
-      Statement(in_session)
-  {}
+  DropIndex(Session *in_session) :
+    Statement(in_session)
+  {
+    set_command(SQLCOM_DROP_INDEX);
+  }
 
   bool execute();
   message::Table create_table_proto;
@@ -47,4 +48,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_STATEMENT_DROP_INDEX_H */
