@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_STATEMENT_DROP_TABLE_H
-#define DRIZZLED_STATEMENT_DROP_TABLE_H
+#pragma once
 
 #include <drizzled/statement.h>
 
@@ -33,12 +32,14 @@ namespace statement
 class DropTable : public Statement
 {
 public:
-  DropTable(Session *in_session)
-    :
-      Statement(in_session)
-  {}
+  DropTable(Session *in_session) :
+    Statement(in_session)
+  {
+    set_command(SQLCOM_DROP_TABLE);
+  }
 
   bool execute();
+
   /* True if "IF EXISTS" */
   bool drop_if_exists;
 
@@ -50,4 +51,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_STATEMENT_DROP_TABLE_H */
