@@ -22,8 +22,16 @@
 
 #include <drizzled/statement.h>
 
-namespace drizzled {
-namespace statement {
+namespace drizzled
+{
+class Session;
+
+namespace plugin {
+class NullClient;
+}
+
+namespace statement
+{
 
 class Execute : public Statement
 {
@@ -34,7 +42,7 @@ class Execute : public Statement
 
   bool parseVariable(void);
 
-  bool runStatement(plugin::NullClient&, const std::string&);
+  bool runStatement(plugin::NullClient *client, const std::string &arg);
 
   bool execute_shell();
 public:
@@ -47,3 +55,4 @@ public:
 } /* namespace statement */
 
 } /* namespace drizzled */
+
