@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,12 +18,15 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
+
 #include <drizzled/show.h>
 #include <drizzled/session.h>
 #include <drizzled/lock.h>
 #include <drizzled/statement/flush.h>
-#include "drizzled/sql_table.h"
+#include <drizzled/sql_table.h>
+#include <drizzled/plugin/logging.h>
+#include <drizzled/plugin/storage_engine.h>
 
 namespace drizzled
 {
@@ -34,16 +37,9 @@ bool statement::Flush::execute()
    * reloadCache() will tell us if we are allowed to write to the
    * binlog or not.
    */
-  if (! reloadCache())
+  if (not reloadCache())
   {
-    /*
-     * We WANT to write and we CAN write.
-     * ! we write after unlocking the table.
-     *
-     * Presumably, RESET and binlog writing doesn't require synchronization
-     */
-    write_bin_log(session, session->query.c_str());
-    session->my_ok();
+    session().my_ok();
   }
 
   return false;
@@ -52,7 +48,7 @@ bool statement::Flush::execute()
 bool statement::Flush::reloadCache()
 {
   bool result= false;
-  TableList *tables= (TableList *) session->lex->select_lex.table_list.first;
+  TableList *tables= (TableList *) lex().select_lex.table_list.first;
 
   if (flush_log)
   {
@@ -67,33 +63,40 @@ bool statement::Flush::reloadCache()
   */
   if (flush_tables || flush_tables_with_read_lock)
   {
-    if (session && flush_tables_with_read_lock)
+    if (&session() && flush_tables_with_read_lock)
     {
-      if (lock_global_read_lock(session))
+      if (session().lockGlobalReadLock())
       {
         return true; /* Killed */
       }
-      result= session->close_cached_tables(tables, true, true);
+      result= session().close_cached_tables(tables, true, true);
 
-      if (make_global_read_lock_block_commit(session)) /* Killed */
+      if (session().makeGlobalReadLockBlockCommit()) /* Killed */
       {
         /* Don't leave things in a half-locked state */
-        unlock_global_read_lock(session);
+        session().unlockGlobalReadLock();
         return true;
       }
     }
     else
     {
-      result= session->close_cached_tables(tables, true, false);
+      result= session().close_cached_tables(tables, true, false);
     }
   }
 
-  if (session && flush_status)
+  if (&session() && flush_status)
   {
-    session->refresh_status();
+    session().refresh_status();
   }
 
- return result;
+  if (&session() && flush_global_status)
+  {
+    memset(&current_global_counters, 0, sizeof(current_global_counters));
+    plugin::Logging::resetStats(&session());
+    session().refresh_status();
+  }
+
+  return result;
 }
 
 }
