@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_STATEMENT_INSERT_SELECT_H
-#define DRIZZLED_STATEMENT_INSERT_SELECT_H
+#pragma once
 
 #include <drizzled/statement.h>
 
@@ -33,16 +32,20 @@ namespace statement
 class InsertSelect : public Statement
 {
 public:
-  InsertSelect(Session *in_session)
-    :
-      Statement(in_session)
-  {}
+  InsertSelect(Session *in_session) :
+    Statement(in_session)
+  {
+    set_command(SQLCOM_INSERT_SELECT);
+  }
 
   bool execute();
+  bool isTransactional()
+  {
+    return true;
+  }
 };
 
 } /* namespace statement */
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_STATEMENT_INSERT_SELECT_H */
