@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_STATEMENT_SELECT_H
-#define DRIZZLED_STATEMENT_SELECT_H
+#pragma once
 
 #include <drizzled/statement.h>
 
@@ -32,31 +31,8 @@ namespace statement
 
 class Select : public Statement
 {
-  /* These will move out once we have args for table functions */
-  std::string show_schema;
-  std::string show_table;
-
 public:
-  Select(Session *in_session)
-    :
-      Statement(in_session)
-  {}
-
-  void setShowPredicate(const std::string &schema_arg, const std::string &table_arg)
-  {
-    show_schema= schema_arg;
-    show_table= table_arg;
-  }
-
-  const std::string getShowSchema()
-  {
-    return show_schema;
-  }
-
-  const std::string getShowTable()
-  {
-    return show_table;
-  }
+  Select(Session *in_session);
 
   bool execute();
 };
@@ -64,4 +40,3 @@ public:
 } /* namespace statement */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_STATEMENT_SELECT_H */
