@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 #include <drizzled/show.h>
 #include <drizzled/session.h>
 #include <drizzled/statement/truncate.h>
@@ -28,24 +28,15 @@ namespace drizzled
 
 bool statement::Truncate::execute()
 {
-  TableList *first_table= (TableList *) session->lex->select_lex.table_list.first;
-  if (! session->endActiveTransaction())
+  TableList *first_table= (TableList *) lex().select_lex.table_list.first;
+
+  if (session().inTransaction())
   {
-    return true;
-  }
-  /*
-   * Don't allow this within a transaction because we want to use
-   * re-generate table
-   */
-  if (session->inTransaction())
-  {
-    my_message(ER_LOCK_OR_ACTIVE_TRANSACTION, 
-               ER(ER_LOCK_OR_ACTIVE_TRANSACTION), 
-               MYF(0));
+    my_error(ER_TRANSACTIONAL_DDL_NOT_SUPPORTED, MYF(0));
     return true;
   }
 
-  return mysql_truncate(*session, first_table);
+  return truncate(session(), first_table);
 }
 
 } /* namespace drizzled */
