@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *  Copyright (C) 2010 Joseph Daly 
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_STATISTICS_VARIABLES_H
-#define DRIZZLED_STATISTICS_VARIABLES_H
+#pragma once
 
 namespace drizzled
 {
@@ -102,4 +101,3 @@ typedef struct system_status_var
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_STATISTICS_VARIABLES_H */
