@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *  Copyright (C) 2010 Joseph Daly 
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -18,17 +18,25 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
+#include <boost/lexical_cast.hpp>
 #include "status_helper.h"
-#include "drizzled/set_var.h"
-#include "drizzled/drizzled.h"
-#include "plugin/myisam/myisam.h"
+#include <drizzled/set_var.h>
+#include <drizzled/drizzled.h>
+#include <plugin/myisam/myisam.h>
+
+#include <drizzled/refresh_version.h>
 
 #include <sstream>
 
-using namespace drizzled;
 using namespace std;
 
+namespace drizzled
+{
+
+extern time_t server_start_time;
+extern time_t flush_status_time;
+
 static int show_starttime_new(drizzle_show_var *var, char *buff)
 {
   var->type= SHOW_LONG;
@@ -77,23 +85,19 @@ string StatusHelper::fillHelper(system_status_var *status_var, char *value, SHOW
     value= ((char *) status_var + (ulong) value);
     /* fall through */
   case SHOW_LONG:
-    oss << *(long*) value;
-    return_value= oss.str();
+    return_value=boost::lexical_cast<std::string>(*(long*) value);
     break;
   case SHOW_LONGLONG_STATUS:
     value= ((char *) status_var + (uint64_t) value);
     /* fall through */
   case SHOW_LONGLONG:
-    oss << *(int64_t*) value;
-    return_value= oss.str();
+    return_value=boost::lexical_cast<std::string>(*(int64_t*) value);
     break;
   case SHOW_SIZE:
-    oss << *(size_t*) value;
-    return_value= oss.str();
+    return_value=boost::lexical_cast<std::string>(*(size_t*) value);
     break;
   case SHOW_HA_ROWS:
-    oss << (int64_t) *(ha_rows*) value;
-    return_value= oss.str();
+    return_value=boost::lexical_cast<std::string>((int64_t) *(ha_rows*) value);
     break;
   case SHOW_BOOL:
   case SHOW_MY_BOOL:
@@ -101,8 +105,7 @@ string StatusHelper::fillHelper(system_status_var *status_var, char *value, SHOW
     break;
   case SHOW_INT:
   case SHOW_INT_NOFLUSH: // the difference lies in refresh_status()
-    oss << (long) *(uint32_t*) value;
-    return_value= oss.str();
+    return_value=boost::lexical_cast<std::string>((long) *(uint32_t*) value);
     break;
   case SHOW_CHAR:
     {
@@ -160,6 +163,7 @@ drizzle_show_var StatusHelper::status_vars_defs[]=
   {"Select_range",              (char*) offsetof(system_status_var, select_range_count), SHOW_LONGLONG_STATUS},
   {"Select_range_check",        (char*) offsetof(system_status_var, select_range_check_count), SHOW_LONGLONG_STATUS},
   {"Select_scan",               (char*) offsetof(system_status_var, select_scan_count), SHOW_LONGLONG_STATUS},
+  {"Sessions_connected",         (char*) &show_connection_count_cont_new,  SHOW_FUNC},
   {"Slow_queries",              (char*) offsetof(system_status_var, long_query_count), SHOW_LONGLONG_STATUS},
   {"Sort_merge_passes",         (char*) offsetof(system_status_var, filesort_merge_passes), SHOW_LONGLONG_STATUS},
   {"Sort_range",                (char*) offsetof(system_status_var, filesort_range_count), SHOW_LONGLONG_STATUS},
@@ -167,8 +171,9 @@ drizzle_show_var StatusHelper::status_vars_defs[]=
   {"Sort_scan",                 (char*) offsetof(system_status_var, filesort_scan_count), SHOW_LONGLONG_STATUS},
   {"Table_locks_immediate",     (char*) &current_global_counters.locks_immediate,        SHOW_LONGLONG},
   {"Table_locks_waited",        (char*) &current_global_counters.locks_waited,           SHOW_LONGLONG},
-  {"Threads_connected",         (char*) &show_connection_count_cont_new,  SHOW_FUNC},
   {"Uptime",                    (char*) &show_starttime_cont_new,         SHOW_FUNC},
   {"Uptime_since_flush_status", (char*) &show_flushstatustime_cont_new,   SHOW_FUNC},
   {NULL, NULL, SHOW_LONGLONG}
 };
+
+} /* namespace drizzled */
