@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *  Copyright (C) 2010 Joseph Daly 
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -18,16 +18,17 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_STATUS_HELPER_H
-#define DRIZZLED_STATUS_HELPER_H
+#pragma once
 
-#include "drizzled/plugin.h"
-#include "drizzled/statistics_variables.h"
+#include <drizzled/plugin.h>
+#include <drizzled/statistics_variables.h>
+
+#include <drizzled/visibility.h>
 
 namespace drizzled
 {
 
-class StatusHelper 
+class DRIZZLED_API StatusHelper 
 {
 public:
 
@@ -39,4 +40,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_STATUS_HELPER_H */
