@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,36 +20,38 @@
 
 /* Structs that defines the Table */
 
-#ifndef DRIZZLED_TABLE_H
-#define DRIZZLED_TABLE_H
+
+
+#pragma once
 
 #include <string>
+#include <boost/dynamic_bitset.hpp>
 
-#include "drizzled/order.h"
-#include "drizzled/filesort_info.h"
-#include "drizzled/natural_join_column.h"
-#include "drizzled/field_iterator.h"
-#include "drizzled/cursor.h"
-#include "drizzled/lex_string.h"
-#include "drizzled/table_list.h"
-#include "drizzled/table_share.h"
-#include "drizzled/atomics.h"
-#include "drizzled/query_id.h"
+#include <drizzled/order.h>
+#include <drizzled/filesort_info.h>
+#include <drizzled/natural_join_column.h>
+#include <drizzled/field_iterator.h>
+#include <drizzled/cursor.h>
+#include <drizzled/lex_string.h>
+#include <drizzled/table/instance.h>
+#include <drizzled/atomics.h>
+#include <drizzled/query_id.h>
+
+#include <drizzled/visibility.h>
 
 namespace drizzled
 {
 
+class COND_EQUAL;
+class Field_blob;
 class Item;
 class Item_subselect;
-class Select_Lex_Unit;
-class Select_Lex;
-class COND_EQUAL;
 class SecurityContext;
+class Select_Lex;
+class Select_Lex_Unit;
 class TableList;
-class Field_timestamp;
-class Field_blob;
-
-extern uint64_t refresh_version;
+namespace field { class Epoch; }
+namespace plugin { class StorageEngine; }
 
 typedef enum enum_table_category TABLE_CATEGORY;
 typedef struct st_columndef MI_COLUMNDEF;
@@ -58,15 +60,11 @@ typedef struct st_columndef MI_COLUMNDEF;
  * Class representing a set of records, either in a temporary, 
  * normal, or derived table.
  */
-class Table 
+class DRIZZLED_API Table 
 {
-public:
-  TableShare *s; /**< Pointer to the shared metadata about the table */
-
-private:
   Field **field; /**< Pointer to fields collection */
-public:
 
+public:
   Field **getFields() const
   {
     return field;
@@ -88,8 +86,10 @@ public:
   }
 
   Cursor *cursor; /**< Pointer to the storage engine's Cursor managing this table */
+
 private:
   Table *next;
+
 public:
   Table *getNext() const
   {
@@ -130,15 +130,15 @@ public:
     prev= arg;
   }
 
-  MyBitmap *read_set; /* Active column sets */
-  MyBitmap *write_set; /* Active column sets */
+  boost::dynamic_bitset<> *read_set; /* Active column sets */
+  boost::dynamic_bitset<> *write_set; /* Active column sets */
 
   uint32_t tablenr;
   uint32_t db_stat; /**< information about the cursor as in Cursor.h */
 
-  MyBitmap def_read_set; /**< Default read set of columns */
-  MyBitmap def_write_set; /**< Default write set of columns */
-  MyBitmap tmp_set; /* Not sure about this... */
+  boost::dynamic_bitset<> def_read_set; /**< Default read set of columns */
+  boost::dynamic_bitset<> def_write_set; /**< Default write set of columns */
+  boost::dynamic_bitset<> tmp_set; /* Not sure about this... */
 
   Session *in_use; /**< Pointer to the current session using this object */
   Session *getSession()
@@ -146,7 +146,7 @@ public:
     return in_use;
   }
 
-  unsigned char *getInsertRecord()
+  unsigned char *getInsertRecord() const
   {
     return record[0];
   }
@@ -161,17 +161,29 @@ public:
   KeyInfo  *key_info; /**< data of keys in database */
   Field *next_number_field; /**< Set if next_number is activated. @TODO What the heck is the difference between this and the next member? */
   Field *found_next_number_field; /**< Points to the "next-number" field (autoincrement field) */
-  Field_timestamp *timestamp_field; /**< Points to the auto-setting timestamp field, if any */
+  field::Epoch *timestamp_field; /**< Points to the auto-setting timestamp field, if any */
 
   TableList *pos_in_table_list; /* Element referring to this table */
-  order_st *group;
+  Order *group;
   
   const char *getAlias() const
   {
-    return alias;
+    return _alias.c_str();
   }
 
-  const char *alias; /**< alias or table name if no alias */
+  void clearAlias()
+  {
+    _alias.clear();
+  }
+
+  void setAlias(const char *arg)
+  {
+    _alias= arg;
+  }
+
+private:
+  std::string _alias; /**< alias or table name if no alias */
+public:
 
   unsigned char *null_flags;
 
@@ -271,7 +283,7 @@ public:
     statement then the variable contains TIMESTAMP_NO_AUTO_SET (i.e. 0).
 
     Value of this variable is set for each statement in open_table() and
-    if needed cleared later in statement processing code (see mysql_update()
+    if needed cleared later in statement processing code (see update_query()
     as example).
   */
   timestamp_auto_set_type timestamp_field_type;
@@ -299,8 +311,10 @@ public:
     The set is implemented as a bitmap.
   */
   key_map keys_in_use_for_query;
+
   /* Map of keys that can be used to calculate GROUP BY without sorting */
   key_map keys_in_use_for_group_by;
+
   /* Map of keys that can be used to calculate ORDER BY without sorting */
   key_map keys_in_use_for_order_by;
 
@@ -354,10 +368,10 @@ public:
     return mem_root.strmake_root(str_arg, len_arg);
   }
 
-  filesort_info_st sort;
+  filesort_info sort;
 
   Table();
-  virtual ~Table() { };
+  virtual ~Table();
 
   int report_error(int error);
   /**
@@ -371,42 +385,49 @@ public:
   void resetTable(Session *session, TableShare *share, uint32_t db_stat_arg);
 
   /* SHARE methods */
-  inline const TableShare *getShare() const { assert(s); return s; } /* Get rid of this long term */
-  inline bool hasShare() const { return s ? true : false ; } /* Get rid of this long term */
-  inline TableShare *getMutableShare() { assert(s); return s; } /* Get rid of this long term */
-  inline void setShare(TableShare *new_share) { s= new_share; } /* Get rid of this long term */
-  inline uint32_t sizeKeys() { return s->sizeKeys(); }
-  inline uint32_t sizeFields() { return s->sizeFields(); }
-  inline uint32_t getRecordLength() const { return s->getRecordLength(); }
-  inline uint32_t sizeBlobFields() { return s->blob_fields; }
-  inline uint32_t *getBlobField() { return &s->blob_field[0]; }
+  virtual const TableShare *getShare() const= 0; /* Get rid of this long term */
+  virtual TableShare *getMutableShare()= 0; /* Get rid of this long term */
+  virtual bool hasShare() const= 0; /* Get rid of this long term */
+  virtual void setShare(TableShare *new_share)= 0; /* Get rid of this long term */
+
+  virtual void release(void)= 0;
+
+  uint32_t sizeKeys() { return getMutableShare()->sizeKeys(); }
+  uint32_t sizeFields() { return getMutableShare()->sizeFields(); }
+  uint32_t getRecordLength() const { return getShare()->getRecordLength(); }
+  uint32_t sizeBlobFields() { return getMutableShare()->blob_fields; }
+  uint32_t *getBlobField() { return &getMutableShare()->blob_field[0]; }
+
+public:
+  virtual bool hasVariableWidth() const
+  {
+    return getShare()->hasVariableWidth(); // We should calculate this.
+  }
+
+  virtual void setVariableWidth(void);
 
   Field_blob *getBlobFieldAt(uint32_t arg) const
   {
-    if (arg < s->blob_fields)
-      return (Field_blob*) field[s->blob_field[arg]]; /*NOTE: Using 'Table.field' NOT SharedTable.field. */
+    if (arg < getShare()->blob_fields)
+      return (Field_blob*) field[getShare()->blob_field[arg]]; /*NOTE: Using 'Table.field' NOT SharedTable.field. */
 
     return NULL;
   }
-  inline uint8_t getBlobPtrSize() { return s->blob_ptr_size; }
-  inline uint32_t getNullBytes() { return s->null_bytes; }
-  inline uint32_t getNullFields() { return s->null_fields; }
-  inline unsigned char *getDefaultValues() { return  s->getDefaultValues(); }
-  inline const char *getSchemaName()  const { return s->getSchemaName(); }
-  inline const char *getTableName()  const { return s->getTableName(); }
+  inline uint8_t getBlobPtrSize() const { return getShare()->sizeBlobPtr(); }
+  inline uint32_t getNullBytes() const { return getShare()->null_bytes; }
+  inline uint32_t getNullFields() const { return getShare()->null_fields; }
+  inline unsigned char *getDefaultValues() { return  getMutableShare()->getDefaultValues(); }
+  inline const char *getSchemaName()  const { return getShare()->getSchemaName(); }
+  inline const char *getTableName()  const { return getShare()->getTableName(); }
 
-  inline bool isDatabaseLowByteFirst() { return s->db_low_byte_first; } /* Portable row format */
-  inline bool isNameLock() const { return s->isNameLock(); }
-  inline bool isReplaceWithNameLock() { return s->replace_with_name_lock; }
+  inline bool isDatabaseLowByteFirst() const { return getShare()->db_low_byte_first; } /* Portable row format */
+  inline bool isNameLock() const { return open_placeholder; }
 
-  uint32_t index_flags(uint32_t idx) const
-  {
-    return s->storage_engine->index_flags(s->getKeyInfo(idx).algorithm);
-  }
+  uint32_t index_flags(uint32_t idx) const;
 
   inline plugin::StorageEngine *getEngine() const   /* table_type for handler */
   {
-    return s->storage_engine;
+    return getShare()->getEngine();
   }
 
   Cursor &getCursor() const /* table_type for handler */
@@ -415,18 +436,11 @@ public:
     return *cursor;
   }
 
-  /* For TMP tables, should be pulled out as a class */
-  void setup_tmp_table_column_bitmaps(unsigned char *bitmaps);
-  bool create_myisam_tmp_table(KeyInfo *keyinfo,
-                               MI_COLUMNDEF *start_recinfo,
-                               MI_COLUMNDEF **recinfo,
-                               uint64_t options);
-  void free_tmp_table(Session *session);
-  bool open_tmp_table();
   size_t max_row_length(const unsigned char *data);
   uint32_t find_shortest_key(const key_map *usable_keys);
   bool compare_record(Field **ptr);
-  bool compare_record();
+  bool records_are_comparable();
+  bool compare_records();
   /* TODO: the (re)storeRecord's may be able to be further condensed */
   void storeRecord();
   void storeRecordAsInsert();
@@ -435,6 +449,7 @@ public:
   void restoreRecordAsDefault();
   void emptyRecord();
 
+
   /* See if this can be blown away */
   inline uint32_t getDBStat () { return db_stat; }
   inline uint32_t setDBStat () { return db_stat; }
@@ -457,7 +472,7 @@ public:
   bool fill_item_list(List<Item> *item_list) const;
   void clear_column_bitmaps(void);
   void prepare_for_position(void);
-  void mark_columns_used_by_index_no_reset(uint32_t index, MyBitmap *map);
+  void mark_columns_used_by_index_no_reset(uint32_t index, boost::dynamic_bitset<>& bitmap);
   void mark_columns_used_by_index_no_reset(uint32_t index);
   void mark_columns_used_by_index(uint32_t index);
   void restore_column_maps_after_mark_index();
@@ -465,19 +480,15 @@ public:
   void mark_columns_needed_for_update(void);
   void mark_columns_needed_for_delete(void);
   void mark_columns_needed_for_insert(void);
-  inline void column_bitmaps_set(MyBitmap *read_set_arg,
-                                 MyBitmap *write_set_arg)
-  {
-    read_set= read_set_arg;
-    write_set= write_set_arg;
-  }
+  void column_bitmaps_set(boost::dynamic_bitset<>& read_set_arg,
+                          boost::dynamic_bitset<>& write_set_arg);
 
-  void restore_column_map(my_bitmap_map *old);
+  void restore_column_map(const boost::dynamic_bitset<>& old);
 
-  my_bitmap_map *use_all_columns(MyBitmap *bitmap);
+  const boost::dynamic_bitset<> use_all_columns(boost::dynamic_bitset<>& map);
   inline void use_all_columns()
   {
-    column_bitmaps_set(&s->all_set, &s->all_set);
+    column_bitmaps_set(getMutableShare()->all_set, getMutableShare()->all_set);
   }
 
   inline void default_column_bitmaps()
@@ -487,54 +498,54 @@ public:
   }
 
   /* Both of the below should go away once we can move this bit to the field objects */
-  inline bool isReadSet(uint32_t index)
+  inline bool isReadSet(uint32_t index) const
   {
-    return read_set->isBitSet(index);
+    return read_set->test(index);
   }
 
   inline void setReadSet(uint32_t index)
   {
-    read_set->setBit(index);
+    read_set->set(index);
   }
 
   inline void setReadSet()
   {
-    read_set->setAll();
+    read_set->set();
   }
 
   inline void clearReadSet(uint32_t index)
   {
-    read_set->clearBit(index);
+    read_set->reset(index);
   }
 
   inline void clearReadSet()
   {
-    read_set->clearAll();
+    read_set->reset();
   }
 
   inline bool isWriteSet(uint32_t index)
   {
-    return write_set->isBitSet(index);
+    return write_set->test(index);
   }
 
   inline void setWriteSet(uint32_t index)
   {
-    write_set->setBit(index);
+    write_set->set(index);
   }
 
   inline void setWriteSet()
   {
-    write_set->setAll();
+    write_set->set();
   }
 
   inline void clearWriteSet(uint32_t index)
   {
-    write_set->clearBit(index);
+    write_set->reset(index);
   }
 
   inline void clearWriteSet()
   {
-    write_set->clearAll();
+    write_set->reset();
   }
 
   /* Is table open or should be treated as such by name-locking? */
@@ -542,13 +553,11 @@ public:
   {
     return db_stat || open_placeholder;
   }
+
   /*
     Is this instance of the table should be reopen or represents a name-lock?
   */
-  inline bool needs_reopen_or_name_lock()
-  { 
-    return s->getVersion() != refresh_version;
-  }
+  bool needs_reopen_or_name_lock() const;
 
   /**
     clean/setup table fields and map.
@@ -562,23 +571,20 @@ public:
   {
     null_row= 1;
     status|= STATUS_NULL_ROW;
-    memset(null_flags, 255, s->null_bytes);
+    memset(null_flags, 255, getShare()->null_bytes);
   }
 
   void free_io_cache();
   void filesort_free_buffers(bool full= false);
   void intern_close_table();
 
-  void print_error(int error, myf errflag)
-  {
-    s->storage_engine->print_error(error, errflag, *this);
-  }
+  void print_error(int error, myf errflag) const;
 
   /**
     @return
     key if error because of duplicated keys
   */
-  uint32_t get_dup_key(int error)
+  uint32_t get_dup_key(int error) const
   {
     cursor->errkey  = (uint32_t) -1;
     if (error == HA_ERR_FOUND_DUPP_KEY || error == HA_ERR_FOREIGN_DUPLICATE_KEY ||
@@ -594,26 +600,7 @@ public:
   */
   bool operator<(const Table &right) const
   {
-    int result= strcasecmp(this->getShare()->getSchemaName(), right.getShare()->getSchemaName());
-
-    if (result <  0)
-      return true;
-
-    if (result >  0)
-      return false;
-
-    result= strcasecmp(this->getShare()->getTableName(), right.getShare()->getTableName());
-
-    if (result <  0)
-      return true;
-
-    if (result >  0)
-      return false;
-
-    if (this->getShare()->getTableProto()->type()  < right.getShare()->getTableProto()->type())
-      return true;
-
-    return false;
+    return getShare()->getCacheKey() < right.getShare()->getCacheKey();
   }
 
   static bool compare(const Table *a, const Table *b)
@@ -623,24 +610,28 @@ public:
 
   friend std::ostream& operator<<(std::ostream& output, const Table &table)
   {
-    output << "Table:(";
-    output << table.getShare()->getSchemaName();
-    output << ", ";
-    output <<  table.getShare()->getTableName();
-    output << ", ";
-    output <<  table.getShare()->getTableTypeAsString();
-    output << ")";
+    if (table.getShare())
+    {
+      output << "Table:(";
+      output << table.getShare()->getSchemaName();
+      output << ", ";
+      output <<  table.getShare()->getTableName();
+      output << ", ";
+      output <<  table.getShare()->getTableTypeAsString();
+      output << ")";
+    }
+    else
+    {
+      output << "Table:(has no share)";
+    }
 
     return output;  // for multiple << operators.
   }
 
-protected:
-  bool is_placeholder_created;
-
 public:
-  bool isPlaceHolder()
+  virtual bool isPlaceHolder(void) const
   {
-    return is_placeholder_created;
+    return false;
   }
 };
 
@@ -826,20 +817,6 @@ struct st_lex;
 class select_union;
 class Tmp_Table_Param;
 
-struct open_table_list_st
-{
-  std::string   db;
-  std::string   table;
-  uint32_t in_use;
-  uint32_t locked;
-
-  open_table_list_st() :
-    in_use(0),
-    locked(0)
-  { }
-
-};
-
 void free_blobs(Table *table);
 int set_zone(int nr,int min_zone,int max_zone);
 uint32_t convert_period_to_month(uint32_t period);
@@ -850,33 +827,21 @@ void change_byte(unsigned char *,uint,char,char);
 
 namespace optimizer { class SqlSelect; }
 
-ha_rows filesort(Session *session,
-                 Table *form,
-                 SortField *sortorder,
-                 uint32_t s_length,
-                 optimizer::SqlSelect *select,
-                 ha_rows max_rows,
-                 bool sort_positions,
-                 ha_rows *examined_rows);
-
-void filesort_free_buffers(Table *table, bool full);
 void change_double_for_sort(double nr,unsigned char *to);
-double my_double_round(double value, int64_t dec, bool dec_unsigned,
-                       bool truncate);
 int get_quick_record(optimizer::SqlSelect *select);
 
 void find_date(char *pos,uint32_t *vek,uint32_t flag);
 TYPELIB *convert_strings_to_array_type(char * *typelibs, char * *end);
 TYPELIB *typelib(memory::Root *mem_root, List<String> &strings);
 ulong get_form_pos(int file, unsigned char *head, TYPELIB *save_names);
-ulong next_io_size(ulong pos);
 void append_unescaped(String *res, const char *pos, uint32_t length);
 
-int rename_file_ext(const char * from,const char * to,const char * ext);
+DRIZZLED_API int rename_file_ext(const char * from,const char * to,const char * ext);
 bool check_column_name(const char *name);
-bool check_db_name(Session *session, SchemaIdentifier &schema);
 bool check_table_name(const char *name, uint32_t length);
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_TABLE_H */
+#include <drizzled/table/singular.h>
+#include <drizzled/table/concurrent.h>
+
