@@ -24,3 +24,17 @@
 #include <drizzled/table/instance/base.h>
 #include <drizzled/table/instance/shared.h>
 #include <drizzled/table/instance/singular.h>
+
+namespace drizzled
+{
+
+namespace table
+{
+
+namespace instance
+{
+
+} /* namespace instance */
+} /* namespace table */
+} /* namespace drizzled */
+
