@@ -23,9 +23,16 @@
 
 #include <drizzled/table/instance/base.h>
 
-namespace drizzled {
-namespace table {
-namespace instance {
+namespace drizzled
+{
+
+namespace identifier { class Table; }
+
+namespace table
+{
+
+namespace instance
+{
 
 class Singular : public drizzled::TableShare
 {
@@ -33,7 +40,7 @@ public:
 
   Singular(const identifier::Table::Type type_arg,
            const identifier::Table &identifier,
-           const char *path_arg= NULL, uint32_t path_length_arg= 0);
+           char *path_arg= NULL, uint32_t path_length_arg= 0);
 
   ~Singular();
 };
