@@ -16,14 +16,15 @@
 #include <config.h>
 #include <drizzled/error.h>
 #include <drizzled/session.h>
+#include <drizzled/unireg.h>
 #include <drizzled/sql_table.h>
+#include <drizzled/global_charset_info.h>
 #include <drizzled/message/statement_transform.h>
 
 #include <drizzled/plugin/storage_engine.h>
 
 #include <drizzled/internal/my_sys.h>
 #include <drizzled/typelib.h>
-#include <drizzled/util/test.h>
 
 /* For proto */
 #include <string>
@@ -37,7 +38,7 @@
 
 #include <drizzled/table_proto.h>
 #include <drizzled/charset.h>
-#include <drizzled/create_field.h>
+
 #include <drizzled/function/time/typecast.h>
 
 using namespace std;
@@ -45,7 +46,7 @@ using namespace std;
 namespace drizzled {
 
 static
-bool fill_table_proto(const identifier::Table& identifier,
+bool fill_table_proto(identifier::Table::const_reference identifier,
                       message::Table &table_proto,
                       List<CreateField> &create_fields,
                       HA_CREATE_INFO *create_info,
@@ -135,7 +136,6 @@ bool fill_table_proto(const identifier::Table& identifier,
     case message::Table::Field::DATE:
     case message::Table::Field::DATETIME:
     case message::Table::Field::UUID:
-    case message::Table::Field::IPV6:
     case message::Table::Field::TIME:
     case message::Table::Field::BOOLEAN:
       break;
@@ -231,23 +231,27 @@ bool fill_table_proto(const identifier::Table& identifier,
     constraints->set_is_nullable(field_arg->def->null_value);
 #endif
 
-    if (not field_arg->comment.empty())
+    if (field_arg->comment.length)
     {
-      uint32_t tmp_len= system_charset_info->cset->charpos(system_charset_info,
-						  field_arg->comment.begin(),
-						  field_arg->comment.end(),
+      uint32_t tmp_len;
+      tmp_len= system_charset_info->cset->charpos(system_charset_info,
+						  field_arg->comment.str,
+						  field_arg->comment.str +
+						  field_arg->comment.length,
 						  COLUMN_COMMENT_MAXLEN);
 
-      if (tmp_len < field_arg->comment.size())
+      if (tmp_len < field_arg->comment.length)
       {
-        my_error(ER_WRONG_STRING_LENGTH, MYF(0), field_arg->comment.data(), "COLUMN COMMENT", (uint32_t) COLUMN_COMMENT_MAXLEN);
-        return true;
+	my_error(ER_WRONG_STRING_LENGTH, MYF(0),
+		 field_arg->comment.str,"COLUMN COMMENT",
+		 (uint32_t) COLUMN_COMMENT_MAXLEN);
+	return true;
       }
 
-      if (not use_existing_fields)
-        attribute->set_comment(field_arg->comment.data());
+      if (! use_existing_fields)
+        attribute->set_comment(field_arg->comment.str);
 
-      assert(strcmp(attribute->comment().c_str(), field_arg->comment.data())==0);
+      assert(strcmp(attribute->comment().c_str(), field_arg->comment.str)==0);
     }
 
     if (field_arg->unireg_check == Field::NEXT_NUMBER)
@@ -340,10 +344,15 @@ bool fill_table_proto(const identifier::Table& identifier,
           }
         }
 
-	if ((field_arg->sql_type == DRIZZLE_TYPE_VARCHAR && field_arg->charset == &my_charset_bin)
-	   || (field_arg->sql_type == DRIZZLE_TYPE_BLOB && field_arg->charset == &my_charset_bin))
+	if ((field_arg->sql_type==DRIZZLE_TYPE_VARCHAR
+	    && field_arg->charset==&my_charset_bin)
+	   || (field_arg->sql_type==DRIZZLE_TYPE_BLOB
+	    && field_arg->charset==&my_charset_bin))
 	{
-	  field_options->set_default_bin_value(string(default_value->c_ptr(), default_value->length()));
+	  string bin_default;
+	  bin_default.assign(default_value->c_ptr(),
+			     default_value->length());
+	  field_options->set_default_bin_value(bin_default);
 	}
 	else
 	{
@@ -402,13 +411,21 @@ bool fill_table_proto(const identifier::Table& identifier,
 
   for (uint32_t i= 0; i < keys; i++)
   {
-    message::Table::Index *idx= table_proto.add_indexes();
+    message::Table::Index *idx;
 
-    assert(test(key_info[i].flags & HA_USES_COMMENT) == (key_info[i].comment.size() > 0));
+    idx= table_proto.add_indexes();
+
+    assert(test(key_info[i].flags & HA_USES_COMMENT) ==
+           (key_info[i].comment.length > 0));
 
     idx->set_name(key_info[i].name);
+
     idx->set_key_length(key_info[i].key_length);
-    idx->set_is_primary(is_primary_key(key_info[i].name));
+
+    if (is_primary_key_name(key_info[i].name))
+      idx->set_is_primary(true);
+    else
+      idx->set_is_primary(false);
 
     switch(key_info[i].algorithm)
     {
@@ -421,10 +438,11 @@ bool fill_table_proto(const identifier::Table& identifier,
       break;
 
     case HA_KEY_ALG_UNDEF:
-      {
-        idx->set_type(create_info->db_type->default_index_type());
-        break;
-      }
+      idx->set_type(message::Table::Index::UNKNOWN_INDEX);
+      break;
+
+    default:
+      abort(); /* Somebody's brain broke. haven't added index type to proto */
     }
 
     if (key_info[i].flags & HA_NOSAME)
@@ -459,19 +477,20 @@ bool fill_table_proto(const identifier::Table& identifier,
     {
       uint32_t tmp_len;
       tmp_len= system_charset_info->cset->charpos(system_charset_info,
-						  key_info[i].comment.begin(),
-						  key_info[i].comment.end(),
+						  key_info[i].comment.str,
+						  key_info[i].comment.str +
+						  key_info[i].comment.length,
 						  TABLE_COMMENT_MAXLEN);
 
-      if (tmp_len < key_info[i].comment.size())
+      if (tmp_len < key_info[i].comment.length)
       {
 	my_error(ER_WRONG_STRING_LENGTH, MYF(0),
-		 key_info[i].comment.data(), "Index COMMENT",
+		 key_info[i].comment.str,"Index COMMENT",
 		 (uint32_t) TABLE_COMMENT_MAXLEN);
 	return true;
       }
 
-      idx->set_comment(key_info[i].comment.data());
+      idx->set_comment(key_info[i].comment.str);
     }
     static const uint64_t unknown_index_flag= (HA_NOSAME | HA_PACK_KEY |
                                                HA_USES_BLOCK_SIZE | 
@@ -504,7 +523,7 @@ bool fill_table_proto(const identifier::Table& identifier,
         else
           collation_id= table_proto.options().collation_id();
 
-        const charset_info_st *cs= get_charset(collation_id);
+        const CHARSET_INFO *cs= get_charset(collation_id);
 
         mbmaxlen= cs->mbmaxlen;
       }
