@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,9 +17,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-
-#ifndef DRIZZLED_TABLE_PROTO_H
-#define DRIZZLED_TABLE_PROTO_H
+#pragma once
 
 namespace drizzled {
 /*
@@ -32,12 +30,10 @@ namespace drizzled {
 #define INDEX_COMMENT_MAXLEN 1024
 
 bool rea_create_table(Session *session,
-                      TableIdentifier &identifier,
+                      const identifier::Table &identifier,
                       message::Table &table_proto,
                       HA_CREATE_INFO *create_info,
                       List<CreateField> &create_field,
                       uint32_t key_count,KeyInfo *key_info);
 
 } /* namespace drizzled */
-
-#endif /* DRIZZLED_TABLE_PROTO_H */
