@@ -1,7 +1,7 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008-2009 Sun Microsystems
+ *  Copyright (C) 2008-2009 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,11 +25,10 @@
  * used in the nested loops join implementation.
  */
 
-#ifndef DRIZZLED_TABLE_REFERENCE_H
-#define DRIZZLED_TABLE_REFERENCE_H
+#pragma once
 
 #include <drizzled/base.h>
-#include <drizzled/sql_bitmap.h>
+#include <drizzled/definitions.h>
 
 namespace drizzled
 {
@@ -39,6 +38,20 @@ class Item;
 
 struct table_reference_st
 {
+  table_reference_st() :
+    key_err(false),
+    key_parts(0),
+    key_length(0),
+    key(0),
+    key_buff(NULL),
+    key_buff2(NULL),
+    key_copy(NULL),
+    items(NULL),
+    cond_guards(NULL),
+    null_ref_key(NULL),
+    disable_cache(false)
+  { }
+
   bool key_err;
   uint32_t key_parts; /**< num of key parts */
   uint32_t key_length; /**< length of key_buff */
@@ -76,4 +89,3 @@ struct table_reference_st
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_TABLE_REFERENCE_H */
