@@ -1,7 +1,7 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  Authors:
  *
@@ -28,8 +28,7 @@
  * Defines the API for matching datetime formats.
  */
 
-#ifndef DRIZZLED_TEMPORAL_FORMAT_H
-#define DRIZZLED_TEMPORAL_FORMAT_H
+#pragma once
 
 #include PCRE_HEADER
 
@@ -150,4 +149,3 @@ void deinit_temporal_formats();
 
 } /* end namespace drizzled */
 
-#endif /* DRIZZLED_TEMPORAL_FORMAT_H */
