@@ -11,7 +11,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /*
 Read and write locks for Posix threads. All tread must acquire
@@ -52,16 +52,16 @@ TL_WRITE_CONCURRENT_INSERT lock at the same time as multiple read locks.
 
 */
 
-#include "config.h"
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/internal/thread_var.h"
-#include "drizzled/statistics_variables.h"
+#include <config.h>
+#include <drizzled/internal/my_sys.h>
+#include <drizzled/internal/thread_var.h>
+#include <drizzled/statistics_variables.h>
+#include <drizzled/pthread_globals.h>
 
-#include "drizzled/session.h"
-#include "drizzled/current_session.h"
+#include <drizzled/session.h>
 
 #include "thr_lock.h"
-#include "drizzled/internal/m_string.h"
+#include <drizzled/internal/m_string.h>
 #include <errno.h>
 #include <list>
 
@@ -89,7 +89,7 @@ uint64_t table_lock_wait_timeout;
 static enum thr_lock_type thr_upgraded_concurrent_insert_lock = TL_WRITE;
 
 
-uint64_t max_write_lock_count= ~(uint64_t) 0L;
+uint64_t max_write_lock_count= UINT64_MAX;
 
 /*
 ** For the future (now the thread specific cond is alloced by my_pthread.c)
@@ -117,7 +117,6 @@ void thr_lock_init(THR_LOCK *lock)
 void THR_LOCK_INFO::init()
 {
   internal::st_my_thread_var *tmp= my_thread_var;
-  thread= tmp->pthread_self;
   thread_id= tmp->id;
   n_cursors= 0;
 }
@@ -148,16 +147,14 @@ have_old_read_lock(THR_LOCK_DATA *data, THR_LOCK_OWNER *owner)
 static void wake_up_waiters(THR_LOCK *lock);
 
 
-static enum enum_thr_lock_result wait_for_lock(struct st_lock_list *wait, THR_LOCK_DATA *data, bool in_wait_list)
+static enum enum_thr_lock_result wait_for_lock(Session &session, struct st_lock_list *wait, THR_LOCK_DATA *data)
 {
-  Session *session= current_session;
-  internal::st_my_thread_var *thread_var= session->getThreadVar();
+  internal::st_my_thread_var *thread_var= session.getThreadVar();
 
-  boost::condition_variable *cond= &thread_var->suspend;
+  boost::condition_variable_any *cond= &thread_var->suspend;
   enum enum_thr_lock_result result= THR_LOCK_ABORTED;
   bool can_deadlock= test(data->owner->info->n_cursors);
 
-  if (!in_wait_list)
   {
     (*wait->last)=data;				/* Wait for lock */
     data->prev= wait->last;
@@ -171,9 +168,9 @@ static enum enum_thr_lock_result wait_for_lock(struct st_lock_list *wait, THR_LO
   thread_var->current_cond=  &thread_var->suspend;
   data->cond= &thread_var->suspend;;
 
-  while (!thread_var->abort || in_wait_list)
+  while (not thread_var->abort)
   {
-    boost::mutex::scoped_lock scoped(*data->lock->native_handle(), boost::adopt_lock_t());
+    boost_unique_lock_t scoped(*data->lock->native_handle(), boost::adopt_lock_t());
 
     if (can_deadlock)
     {
@@ -230,14 +227,14 @@ static enum enum_thr_lock_result wait_for_lock(struct st_lock_list *wait, THR_LO
   data->lock->unlock();
 
   /* The following must be done after unlock of lock->mutex */
-  boost::mutex::scoped_lock scopedLock(thread_var->mutex);
+  boost_unique_lock_t scopedLock(thread_var->mutex);
   thread_var->current_mutex= NULL;
   thread_var->current_cond= NULL;
   return(result);
 }
 
 
-static enum enum_thr_lock_result thr_lock(THR_LOCK_DATA *data, THR_LOCK_OWNER *owner, enum thr_lock_type lock_type)
+static enum enum_thr_lock_result thr_lock(Session &session, THR_LOCK_DATA *data, THR_LOCK_OWNER *owner, enum thr_lock_type lock_type)
 {
   THR_LOCK *lock= data->lock;
   enum enum_thr_lock_result result= THR_LOCK_SUCCESS;
@@ -385,7 +382,7 @@ static enum enum_thr_lock_result thr_lock(THR_LOCK_DATA *data, THR_LOCK_OWNER *o
   }
 
   /* Can't get lock yet;  Wait for it */
-  return(wait_for_lock(wait_queue, data, 0));
+  return(wait_for_lock(session, wait_queue, data));
 end:
   lock->unlock();
 
@@ -407,7 +404,7 @@ static void free_all_read_locks(THR_LOCK *lock, bool using_concurrent_insert)
 
   do
   {
-    boost::condition_variable *cond= data->cond;
+    boost::condition_variable_any *cond= data->cond;
     if ((int) data->type == (int) TL_READ_NO_INSERT)
     {
       if (using_concurrent_insert)
@@ -505,7 +502,7 @@ static void wake_up_waiters(THR_LOCK *lock)
 	  lock->write.last= &data->next;
 
 	  {
-            boost::condition_variable *cond= data->cond;
+            boost::condition_variable_any *cond= data->cond;
 	    data->cond= NULL;				/* Mark thread free */
             cond->notify_one(); /* Start waiting thred */
 	  }
@@ -532,7 +529,7 @@ static void wake_up_waiters(THR_LOCK *lock)
 	      !lock->read_no_write_count))
     {
       do {
-        boost::condition_variable *cond= data->cond;
+        boost::condition_variable_any *cond= data->cond;
 	if (((*data->prev)=data->next))		/* remove from wait-list */
 	  data->next->prev= data->prev;
 	else
@@ -592,7 +589,7 @@ static void sort_locks(THR_LOCK_DATA **data,uint32_t count)
 
 
 enum enum_thr_lock_result
-thr_multi_lock(THR_LOCK_DATA **data, uint32_t count, THR_LOCK_OWNER *owner)
+thr_multi_lock(Session &session, THR_LOCK_DATA **data, uint32_t count, THR_LOCK_OWNER *owner)
 {
   THR_LOCK_DATA **pos,**end;
   if (count > 1)
@@ -600,7 +597,7 @@ thr_multi_lock(THR_LOCK_DATA **data, uint32_t count, THR_LOCK_OWNER *owner)
   /* lock everything */
   for (pos=data,end=data+count; pos < end ; pos++)
   {
-    enum enum_thr_lock_result result= thr_lock(*pos, owner, (*pos)->type);
+    enum enum_thr_lock_result result= thr_lock(session, *pos, owner, (*pos)->type);
     if (result != THR_LOCK_SUCCESS)
     {						/* Aborted */
       thr_multi_unlock(data,(uint32_t) (pos-data));
@@ -641,6 +638,17 @@ void thr_multi_unlock(THR_LOCK_DATA **data,uint32_t count)
   return;
 }
 
+void DrizzleLock::unlock(uint32_t count)
+{
+  THR_LOCK_DATA **pos,**end;
+
+  for (pos= getLocks(),end= getLocks()+count; pos < end ; pos++)
+  {
+    if ((*pos)->type != TL_UNLOCK)
+      thr_unlock(*pos);
+  }
+}
+
 /*
   Abort all threads waiting for a lock. The lock will be upgraded to
   TL_WRITE_ONLY to abort any new accesses to the lock
@@ -648,7 +656,7 @@ void thr_multi_unlock(THR_LOCK_DATA **data,uint32_t count)
 
 void THR_LOCK::abort_locks()
 {
-  boost::mutex::scoped_lock scopedLock(mutex);
+  boost_unique_lock_t scopedLock(mutex);
 
   for (THR_LOCK_DATA *local_data= read_wait.data; local_data ; local_data= local_data->next)
   {
@@ -681,7 +689,7 @@ bool THR_LOCK::abort_locks_for_thread(uint64_t thread_id_arg)
 {
   bool found= false;
 
-  boost::mutex::scoped_lock scopedLock(mutex);
+  boost_unique_lock_t scopedLock(mutex);
   for (THR_LOCK_DATA *local_data= read_wait.data; local_data ; local_data= local_data->next)
   {
     if (local_data->owner->info->thread_id == thread_id_arg)
