@@ -11,7 +11,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /*
   Code for handling red-black (balanced) binary trees.
@@ -53,12 +53,12 @@
     (*tree->compare)(custom_arg, key, ELEMENT_KEY(tree,element))
 */
 
-#include "config.h"
+#include <config.h>
 
-#include "drizzled/tree.h"
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/internal/m_string.h"
-#include "drizzled/memory/root.h"
+#include <drizzled/tree.h>
+#include <drizzled/internal/my_sys.h>
+#include <drizzled/internal/m_string.h>
+#include <drizzled/memory/root.h>
 
 #define BLACK		1
 #define RED		0
