@@ -20,13 +20,15 @@
 
 #pragma once
 
-namespace drizzled {
-namespace type {
+namespace drizzled
+{
+
+namespace type
+{
 
 bool convert(bool &destination, String &source);
 bool convert(bool &destination, const char *source, const size_t source_length);
-const char* convert(bool source, bool ansi_display);
-void convert(String& destination, bool source, bool ansi_display);
+bool convert(String &destination, const bool source, bool ansi_display);
 
 } /* namespace type */
 } /* namespace drizzled */
