@@ -20,7 +20,7 @@
 #include <drizzled/util/gmtime.h>
 
 #include <drizzled/internal/m_string.h>
-#include <drizzled/charset.h>
+#include <drizzled/charset_info.h>
 #include <drizzled/util/test.h>
 #include <drizzled/definitions.h>
 #include <drizzled/sql_string.h>
@@ -30,7 +30,8 @@
 
 using namespace std;
 
-namespace drizzled {
+namespace drizzled
+{
 
 static int check_time_range(type::Time *my_time, int *warning);
 
@@ -189,10 +190,10 @@ type::timestamp_t Time::store(const char *str, uint32_t length, uint32_t flags,
   was_cut= type::VALID;
 
   /* Skip space at start */
-  for (; str != end && my_charset_utf8_general_ci.isspace(*str) ; str++)
+  for (; str != end && my_isspace(&my_charset_utf8_general_ci, *str) ; str++)
     ;
 
-  if (str == end || not my_charset_utf8_general_ci.isdigit(*str))
+  if (str == end || ! my_isdigit(&my_charset_utf8_general_ci, *str))
   {
     was_cut= type::CUT;
     return(type::DRIZZLE_TIMESTAMP_NONE);
@@ -208,7 +209,7 @@ type::timestamp_t Time::store(const char *str, uint32_t length, uint32_t flags,
     (YYYY-MM-DD,  YYYYMMDD, YYYYYMMDDHHMMSS)
   */
   for (pos=str;
-       pos != end && (my_charset_utf8_general_ci.isdigit(*pos) || *pos == 'T');
+       pos != end && (my_isdigit(&my_charset_utf8_general_ci,*pos) || *pos == 'T');
        pos++)
     ;
 
@@ -233,9 +234,9 @@ type::timestamp_t Time::store(const char *str, uint32_t length, uint32_t flags,
         We do this by checking if there is two numbers separated by
         space in the input.
       */
-      while (pos < end && not my_charset_utf8_general_ci.isspace(*pos))
+      while (pos < end && !my_isspace(&my_charset_utf8_general_ci, *pos))
         pos++;
-      while (pos < end && not my_charset_utf8_general_ci.isdigit(*pos))
+      while (pos < end && !my_isdigit(&my_charset_utf8_general_ci, *pos))
         pos++;
       if (pos == end)
       {
@@ -269,12 +270,12 @@ type::timestamp_t Time::store(const char *str, uint32_t length, uint32_t flags,
   not_zero_date= 0;
   for (i = start_loop;
        i < MAX_DATE_PARTS-1 && str != end &&
-         my_charset_utf8_general_ci.isdigit(*str);
+         my_isdigit(&my_charset_utf8_general_ci,*str);
        i++)
   {
     const char *start= str;
     uint32_t tmp_value= (uint32_t) (unsigned char) (*str++ - '0');
-    while (str != end && my_charset_utf8_general_ci.isdigit(str[0]) &&
+    while (str != end && my_isdigit(&my_charset_utf8_general_ci,str[0]) &&
            (!is_internal_format || --field_length))
     {
       tmp_value=tmp_value*10 + (uint32_t) (unsigned char) (*str - '0');
@@ -313,10 +314,10 @@ type::timestamp_t Time::store(const char *str, uint32_t length, uint32_t flags,
       continue;
     }
     while (str != end &&
-           (my_charset_utf8_general_ci.ispunct(*str) ||
-            my_charset_utf8_general_ci.isspace(*str)))
+           (my_ispunct(&my_charset_utf8_general_ci,*str) ||
+            my_isspace(&my_charset_utf8_general_ci,*str)))
     {
-      if (my_charset_utf8_general_ci.isspace(*str))
+      if (my_isspace(&my_charset_utf8_general_ci,*str))
       {
         if (!(allow_space & (1 << i)))
         {
@@ -342,7 +343,7 @@ type::timestamp_t Time::store(const char *str, uint32_t length, uint32_t flags,
             continue;                           /* Not AM/PM */
           str+= 2;                              /* Skip AM/PM */
           /* Skip space after AM/PM */
-          while (str != end && my_charset_utf8_general_ci.isspace(*str))
+          while (str != end && my_isspace(&my_charset_utf8_general_ci,*str))
             str++;
         }
       }
@@ -425,7 +426,7 @@ type::timestamp_t Time::store(const char *str, uint32_t length, uint32_t flags,
       {
         for (; str != end ; str++)
         {
-          if (not my_charset_utf8_general_ci.isspace(*str))
+          if (!my_isspace(&my_charset_utf8_general_ci, *str))
           {
             not_zero_date= 1;                     /* Give warning */
             break;
@@ -446,7 +447,7 @@ type::timestamp_t Time::store(const char *str, uint32_t length, uint32_t flags,
 
     for (; str != end ; str++)
     {
-      if (not my_charset_utf8_general_ci.isspace(*str))
+      if (!my_isspace(&my_charset_utf8_general_ci,*str))
       {
         was_cut= type::CUT;
         break;
@@ -504,7 +505,7 @@ bool Time::store(const char *str, uint32_t length, int &warning, type::timestamp
 
   this->neg=0;
   warning= 0;
-  for (; str != end && my_charset_utf8_general_ci.isspace(*str) ; str++)
+  for (; str != end && my_isspace(&my_charset_utf8_general_ci,*str) ; str++)
     length--;
   if (str != end && *str == '-')
   {
@@ -530,24 +531,24 @@ bool Time::store(const char *str, uint32_t length, int &warning, type::timestamp
   }
 
   /* Not a timestamp. Try to get this as a DAYS_TO_SECOND string */
-  for (value=0; str != end && my_charset_utf8_general_ci.isdigit(*str) ; str++)
+  for (value=0; str != end && my_isdigit(&my_charset_utf8_general_ci,*str) ; str++)
     value=value*10L + (long) (*str - '0');
 
   /* Skip all space after 'days' */
   end_of_days= str;
-  for (; str != end && my_charset_utf8_general_ci.isspace(str[0]) ; str++)
+  for (; str != end && my_isspace(&my_charset_utf8_general_ci, str[0]) ; str++)
     ;
 
   found_days=found_hours=0;
   if ((uint32_t) (end-str) > 1 && str != end_of_days &&
-      my_charset_utf8_general_ci.isdigit(*str))
+      my_isdigit(&my_charset_utf8_general_ci, *str))
   {                                             /* Found days part */
     date[0]= (uint32_t) value;
     state= 1;                                   /* Assume next is hours */
     found_days= 1;
   }
   else if ((end-str) > 1 &&  *str == time_separator &&
-           my_charset_utf8_general_ci.isdigit(str[1]))
+           my_isdigit(&my_charset_utf8_general_ci, str[1]))
   {
     date[0]= 0;                                 /* Assume we found hours */
     date[1]= (uint32_t) value;
@@ -569,11 +570,11 @@ bool Time::store(const char *str, uint32_t length, int &warning, type::timestamp
   /* Read hours, minutes and seconds */
   for (;;)
   {
-    for (value=0; str != end && my_charset_utf8_general_ci.isdigit(*str) ; str++)
+    for (value=0; str != end && my_isdigit(&my_charset_utf8_general_ci,*str) ; str++)
       value=value*10L + (long) (*str - '0');
     date[state++]= (uint32_t) value;
     if (state == 4 || (end-str) < 2 || *str != time_separator ||
-        !my_charset_utf8_general_ci.isdigit(str[1]))
+        !my_isdigit(&my_charset_utf8_general_ci,str[1]))
       break;
     str++;                                      /* Skip time_separator (':') */
   }
@@ -593,11 +594,11 @@ bool Time::store(const char *str, uint32_t length, int &warning, type::timestamp
 
 fractional:
   /* Get fractional second part */
-  if ((end-str) >= 2 && *str == '.' && my_charset_utf8_general_ci.isdigit(str[1]))
+  if ((end-str) >= 2 && *str == '.' && my_isdigit(&my_charset_utf8_general_ci,str[1]))
   {
     int field_length= 5;
     str++; value=(uint32_t) (unsigned char) (*str - '0');
-    while (++str != end && my_charset_utf8_general_ci.isdigit(*str))
+    while (++str != end && my_isdigit(&my_charset_utf8_general_ci, *str))
     {
       if (field_length-- > 0)
         value= value*10 + (uint32_t) (unsigned char) (*str - '0');
@@ -622,16 +623,16 @@ fractional:
   /* (may occur as result of %g formatting of time value) */
   if ((end - str) > 1 &&
       (*str == 'e' || *str == 'E') &&
-      (my_charset_utf8_general_ci.isdigit(str[1]) ||
+      (my_isdigit(&my_charset_utf8_general_ci, str[1]) ||
        ((str[1] == '-' || str[1] == '+') &&
         (end - str) > 2 &&
-        my_charset_utf8_general_ci.isdigit(str[2]))))
+        my_isdigit(&my_charset_utf8_general_ci, str[2]))))
     return 1;
 
   if (internal_format_positions[7] != 255)
   {
     /* Read a possible AM/PM */
-    while (str != end && my_charset_utf8_general_ci.isspace(*str))
+    while (str != end && my_isspace(&my_charset_utf8_general_ci, *str))
       str++;
     if (str+2 <= end && (str[1] == 'M' || str[1] == 'm'))
     {
@@ -671,7 +672,7 @@ fractional:
   {
     do
     {
-      if (not my_charset_utf8_general_ci.isspace(*str))
+      if (!my_isspace(&my_charset_utf8_general_ci,*str))
       {
         warning|= DRIZZLE_TIME_WARN_TRUNCATED;
         break;
@@ -734,13 +735,15 @@ static int check_time_range(type::Time *my_time, int *warning)
 */
 void init_time(void)
 {
+  time_t seconds;
+  struct tm *l_time,tm_tmp;
   type::Time my_time;
-  type::epoch_t epoch;
+  type::Time::epoch_t epoch;
+  bool not_used;
 
-  time_t seconds= time(NULL);
-  tm tm_tmp;
+  seconds= (time_t) time((time_t*) 0);
   localtime_r(&seconds, &tm_tmp);
-  tm* l_time= &tm_tmp;
+  l_time= &tm_tmp;
   my_time_zone=		3600;		/* Comp. for -3600 in my_gmt_sec */
   my_time.year=		(uint32_t) l_time->tm_year+1900;
   my_time.month=	(uint32_t) l_time->tm_mon+1;
@@ -751,7 +754,7 @@ void init_time(void)
   my_time.time_type=	type::DRIZZLE_TIMESTAMP_NONE;
   my_time.second_part=  0;
   my_time.neg=          false;
-  my_time.convert(epoch, &my_time_zone); /* Init my_time_zone */
+  my_time.convert(epoch, &my_time_zone, &not_used); /* Init my_time_zone */
 }
 
 
@@ -795,7 +798,7 @@ long calc_daynr(uint32_t year,uint32_t month,uint32_t day)
   int temp;
 
   if (year == 0 && month == 0 && day == 0)
-    return 0;				/* Skip errors */
+    return(0);				/* Skip errors */
   delsum= (long) (365L * year+ 31*(month-1) +day);
   if (month <= 2)
       year--;
@@ -829,18 +832,20 @@ namespace type {
   RETURN VALUE
     Time in UTC seconds since Unix Epoch representation.
 */
-void Time::convert(epoch_t &epoch, long *my_timezone) const
+void Time::convert(epoch_t &epoch, long *my_timezone, bool *in_dst_time_gap, bool skip_timezone) const
 {
+  uint32_t loop;
   int shift= 0;
+  type::Time tmp_time;
+  type::Time *t= &tmp_time;
   struct tm *l_time,tm_tmp;
-  long diff;
+  long diff, current_timezone;
 
   /*
     Use temp variable to avoid trashing input data, which could happen in
     case of shift required for boundary dates processing.
   */
-  type::Time tmp_time= *this;
-  type::Time* t= &tmp_time;
+  tmp_time= *this;
 
   if (not t->isValidEpoch())
   {
@@ -927,16 +932,24 @@ void Time::convert(epoch_t &epoch, long *my_timezone) const
   }
 #endif
 
-  epoch= (type::epoch_t) (((calc_daynr((uint32_t) t->year, (uint32_t) t->month, (uint32_t) t->day) -
+  epoch= (type::Time::epoch_t) (((calc_daynr((uint32_t) t->year, (uint32_t) t->month, (uint32_t) t->day) -
                    (long) days_at_timestart)*86400L + (long) t->hour*3600L +
                   (long) (t->minute*60 + t->second)) + (time_t) my_time_zone -
                  3600);
 
-  long current_timezone= my_time_zone;
-  util::gmtime(epoch, &tm_tmp);
+  current_timezone= my_time_zone;
+  if (skip_timezone)
+  {
+    util::gmtime(epoch, &tm_tmp);
+  }
+  else
+  {
+    util::localtime(epoch, &tm_tmp);
+  }
+
   l_time= &tm_tmp;
-  int loop= 0;
-  for (; loop < 2 &&
+  for (loop=0;
+       loop < 2 &&
 	 (t->hour != (uint32_t) l_time->tm_hour ||
 	  t->minute != (uint32_t) l_time->tm_min ||
           t->second != (uint32_t) l_time->tm_sec);
@@ -953,7 +966,14 @@ void Time::convert(epoch_t &epoch, long *my_timezone) const
           (long) ((int) t->second - (int) l_time->tm_sec));
     current_timezone+= diff+3600;		/* Compensate for -3600 above */
     epoch+= (time_t) diff;
-    util::gmtime(epoch, &tm_tmp);
+    if (skip_timezone)
+    {
+      util::gmtime(epoch, &tm_tmp);
+    }
+    else
+    {
+      util::localtime(epoch, &tm_tmp);
+    }
     l_time=&tm_tmp;
   }
   /*
@@ -980,6 +1000,8 @@ void Time::convert(epoch_t &epoch, long *my_timezone) const
       epoch+=3600 - t->minute*60 - t->second;	/* Move to next hour */
     else if (diff == -3600)
       epoch-=t->minute*60 + t->second;		/* Move to previous hour */
+
+    *in_dst_time_gap= true;
   }
   *my_timezone= current_timezone;
 
@@ -1004,6 +1026,7 @@ void Time::convert(epoch_t &epoch, long *my_timezone) const
 
 void Time::store(const struct tm &from)
 {
+  _is_local_time= false;
   neg= 0;
   second_part= 0;
   year=	(int32_t) ((from.tm_year+1900) % 10000);
@@ -1023,15 +1046,24 @@ void Time::store(const struct timeval &from)
 }
 
 
-void Time::store(type::epoch_t from)
+void Time::store(const type::Time::epoch_t &from, bool use_localtime)
 {
-  store(from, 0);
+  store(from, 0, use_localtime);
 }
 
-void Time::store(type::epoch_t from_arg, usec_t from_fractional_seconds)
+void Time::store(const type::Time::epoch_t &from_arg, const usec_t &from_fractional_seconds, bool use_localtime)
 {
   epoch_t from= from_arg;
-  util::gmtime(from, *this);
+
+  if (use_localtime)
+  {
+    util::localtime(from, *this);
+    _is_local_time= true;
+  }
+  else
+  {
+    util::gmtime(from, *this);
+  }
 
   // Since time_t/epoch_t doesn't have fractional seconds, we have to
   // collect them outside of the gmtime function.
