@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,31 +18,21 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_TZTIME_H
-#define DRIZZLED_TZTIME_H
+#pragma once
 
-#if TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# if HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
-#endif
+#include <drizzled/memory/sql_alloc.h>
+#include <drizzled/type/time.h>
 
-#include "drizzled/memory/sql_alloc.h"
+#include <drizzled/type/time.h>
 
 namespace drizzled
 {
 
 class String;
-typedef struct st_drizzle_time DRIZZLE_TIME;
 
 /**
   This class represents abstract time zone and provides
-  basic interface for DRIZZLE_TIME <-> time_t conversion.
+  basic interface for type::Time <-> type::Time::epoch_t conversion.
   Actual time zones which are specified by DB, or via offset
   or use system functions are its descendants.
 */
@@ -51,18 +41,19 @@ class Time_zone: public memory::SqlAlloc
 public:
   Time_zone() {}                              /* Remove gcc warning */
   /**
-    Converts local time in broken down DRIZZLE_TIME representation to
-    time_t (UTC seconds since Epoch) represenation.
+    Converts local time in broken down type::Time representation to
+    type::Time::epoch_t (UTC seconds since Epoch) represenation.
     Returns 0 in case of error. Sets in_dst_time_gap to true if date provided
     falls into spring time-gap (or lefts it untouched otherwise).
   */
-  virtual time_t TIME_to_gmt_sec(const DRIZZLE_TIME *t,
-                                 bool *in_dst_time_gap) const = 0;
+  virtual type::Time::epoch_t TIME_to_gmt_sec(const type::Time &t,
+                                              bool *in_dst_time_gap) const = 0;
   /**
-    Converts time in time_t representation to local time in
-    broken down DRIZZLE_TIME representation.
+    Converts time in type::Time::epoch_t representation to local time in
+    broken down type::Time representation.
   */
-  virtual void   gmt_sec_to_TIME(DRIZZLE_TIME *tmp, time_t t) const = 0;
+  virtual void gmt_sec_to_TIME(type::Time &tmp, type::Time::epoch_t t) const = 0;
+
   /**
     Because of constness of String returned by get_name() time zone name
     have to be already zeroended to be able to use String::ptr() instead
@@ -78,9 +69,7 @@ public:
 };
 
 extern Time_zone * my_tz_SYSTEM;
-extern Time_zone * my_tz_find(Session *session, const String *name);
-extern bool     my_tz_init(Session *org_session, const char *default_tzname);
+bool     my_tz_init(Session *org_session, const char *default_tzname);
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_TZTIME_H */
