@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,15 +20,14 @@
 
 /*  Extra functions used by unireg library */
 
-#ifndef DRIZZLED_UNIREG_H
-#define DRIZZLED_UNIREG_H
+#pragma once
+
+#include <drizzled/visibility.h>
 
 namespace drizzled
 {
 
-void unireg_end(void) __attribute__((noreturn));
-void unireg_abort(int exit_code) __attribute__((noreturn));
+DRIZZLED_API void unireg_abort(int exit_code) __attribute__((noreturn));
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_UNIREG_H */
