@@ -22,8 +22,6 @@
 
 #include <drizzled/visibility.h>
 
-#include <cstddef>
-
 namespace drizzled
 {
 
@@ -31,11 +29,9 @@ namespace util
 {
 
 DRIZZLED_API
-void custom_backtrace(const char *file, int line, const char *func, size_t depth= 0);
+void custom_backtrace(void);
 
 } /* namespace util */
 } /* namespace drizzled */
 
-#define call_backtrace() drizzled::util::custom_backtrace(__FILE__, __LINE__, __func__)
-#define call_backtrace_limit(__limit) drizzled::util::custom_backtrace(__FILE__, __LINE__, __func__, __limit)
 
