@@ -18,29 +18,15 @@
 #pragma once
 
 template <class T, class U>
-typename T::value_type::second_type* find_ptr(T& c, U v)
+typename T::mapped_type* find_ptr(T& c, U v)
 {
 	typename T::iterator i = c.find(v);
 	return i == c.end() ? NULL : &i->second;
 }
 
 template <class T, class U>
-const typename T::value_type::second_type* find_ptr(const T& c, U v)
+const typename T::mapped_type* find_ptr(const T& c, U v)
 {
 	typename T::const_iterator i = c.find(v);
 	return i == c.end() ? NULL : &i->second;
 }
-
-template <class T, class U>
-typename T::value_type::second_type find_ptr2(T& c, U v)
-{
-	typename T::value_type::second_type* i = find_ptr(c, v);
-	return i ? *i : typename T::value_type::second_type();
-}
-
-template <class T, class U>
-const typename T::value_type::second_type find_ptr2(const T& c, U v)
-{
-	const typename T::value_type::second_type* i = find_ptr(c, v);
-	return i ? *i : typename T::value_type::second_type();
-}
