@@ -24,13 +24,18 @@
 
 #pragma once
 
-#include <ctime>
+#include <time.h>
 
-namespace drizzled {
-namespace util {
+namespace drizzled
+{
 
-tm* gmtime(const type::epoch_t&, tm*);
-void gmtime(const type::epoch_t&, type::Time&);
+namespace util
+{
+
+struct tm *gmtime(const type::Time::epoch_t &timer, struct tm *tmbuf);
+void gmtime(const type::Time::epoch_t &timer, type::Time &tmbuf);
+struct tm *localtime(const type::Time::epoch_t &timer, struct tm *tmbuf);
+void localtime(const type::Time::epoch_t &timer,  type::Time &tmbuf);
 
 } /* namespace util */
 } /* namespace drizzled */
