@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef DRIZZLED_UTIL_STORABLE_H
-#define DRIZZLED_UTIL_STORABLE_H
+#pragma once
 
 namespace drizzled
 {
@@ -36,4 +35,3 @@ public:
 } /* namespace util */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_UTIL_STORABLE_H */
