@@ -1,7 +1,7 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- * Copyright (c) 2010, Brian Aker
+ * Copyright (C) 2010 Brian Aker
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,12 +33,15 @@
   Some sections of this code came from the Boost examples.
 */
 
-#ifndef DRIZZLED_UTIL_STRING_H
-#define DRIZZLED_UTIL_STRING_H
+#pragma once
 
+#include <utility>
 #include <string>
+#include <vector>
+
 #include <boost/algorithm/string/predicate.hpp>
 #include <boost/functional/hash.hpp>
+#include <boost/shared_ptr.hpp>
 
 namespace drizzled
 {
@@ -46,6 +49,13 @@ namespace drizzled
 namespace util
 {
 
+
+namespace string {
+typedef boost::shared_ptr<std::string> shared_ptr;
+typedef boost::shared_ptr<const std::string> const_shared_ptr;
+typedef std::vector< std::string > vector;
+}
+
 struct insensitive_equal_to : std::binary_function<std::string, std::string, bool>
 {
   bool operator()(std::string const& x, std::string const& y) const
@@ -70,7 +80,21 @@ struct insensitive_hash : std::unary_function<std::string, std::size_t>
   }
 };
 
+struct sensitive_hash : std::unary_function< std::vector<char>, std::size_t>
+{
+  std::size_t operator()(std::vector<char> const& x) const
+  {
+    std::size_t seed = 0;
+
+    for(std::vector<char>::const_iterator it = x.begin(); it != x.end(); ++it)
+    {
+      boost::hash_combine(seed, *it);
+    }
+
+    return seed;
+  }
+};
+
 } /* namespace util */
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_UTIL_STRING_H */
