@@ -20,10 +20,13 @@
 
 #pragma once
 
-namespace drizzled {
-namespace util {
+namespace drizzled
+{
 
-std::string tablename_to_filename(const std::string&);
+namespace util
+{
+
+bool tablename_to_filename(const std::string &from, std::string &to);
 
 } /* namespace util */
 } /* namespace drizzled */
