@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
  */
 
 
-#ifndef DRIZZLED_VAR_H
-#define DRIZZLED_VAR_H
+#pragma once
 
 namespace drizzled
 {
@@ -38,4 +37,3 @@ public:
 
 } /* namespace drizzled */
 
-#endif /* DRIZZLED_VAR_H */
