@@ -4,8 +4,34 @@
  * Copyright (C) 2008 Eric Day (eday@oddments.org)
  * All rights reserved.
  *
- * Use and distribution licensed under the BSD license.  See
- * the COPYING.BSD file in the root source directory for full text.
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are
+ * met:
+ *
+ *     * Redistributions of source code must retain the above copyright
+ * notice, this list of conditions and the following disclaimer.
+ *
+ *     * Redistributions in binary form must reproduce the above
+ * copyright notice, this list of conditions and the following disclaimer
+ * in the documentation and/or other materials provided with the
+ * distribution.
+ *
+ *     * The names of its contributors may not be used to endorse or
+ * promote products derived from this software without specific prior
+ * written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
  */
 
 /**
@@ -16,31 +42,25 @@
 #ifndef __DRIZZLE_H
 #define __DRIZZLE_H
 
-#if !defined(__cplusplus)
-# include <stdbool.h>
-#endif
 
 #include <inttypes.h>
 #include <sys/types.h>
 
 #ifdef _WIN32
+# define WIN32_LEAN_AND_MEAN
+
+# include <Windows.h>
 # include <winsock2.h>
 # include <ws2tcpip.h>
+# include <io.h>
 
-# include <errno.h>
-# define EINPROGRESS WSAEINPROGRESS
-# define EALREADY WSAEALREADY
-# define EISCONN WSAEISCONN
-# define ENOBUFS WSAENOBUFS
-# define ECONNREFUSED WSAECONNREFUSED
-# define ENETUNREACH WSAENETUNREACH
-# define ETIMEDOUT WSAETIMEDOUT
-# define ECONNRESET WSAECONNRESET 
-# define EADDRINUSE WSAEADDRINUSE
-# define EOPNOTSUPP WSAEOPNOTSUPP
-# define ENOPROTOOPT WSAENOPROTOOPT
-
+# undef close
+# define close _close
 typedef unsigned int in_port_t;
+typedef long ssize_t;
+
+# define snprintf _snprintf
+# define inline __inline
 
 struct sockaddr_un
 {
@@ -48,16 +68,32 @@ struct sockaddr_un
   char sun_path[108];
 };
 
+# define poll WSAPoll
+//# define pollfd WSAPOLLFD
+
+#if defined(__GNUC__)
+# include <stdbool.h>
+#else
+# if !defined(__cplusplus)
+typedef enum { false = 0, true = 1 } _Bool;
+typedef _Bool bool;
+#endif 
+#endif
 
 #else
+# if !defined(__cplusplus)
+#  include <stdbool.h>
+# endif
 # include <sys/socket.h>
 # include <netinet/in.h>
 # include <arpa/inet.h>
 # include <sys/un.h>
 # include <netdb.h>
+# include <poll.h>
 #endif
 
-#include <poll.h>
+#include <assert.h>
+#include <errno.h>
 
 #include <libdrizzle/visibility.h>
 #include <libdrizzle/constants.h>
