@@ -31,7 +31,7 @@ class Filesystem : public drizzled::plugin::Catalog
 
 public:
   Filesystem() :
-    drizzled::plugin::Catalog("filesystem")
+    drizzled::plugin::Catalog("FilesystemCatalog")
   {}
 
   catalog::Engine::shared_ptr engine()
