@@ -36,7 +36,8 @@ int64_t Drop::val_int()
   }
 
   null_value= false;
-  return drizzled::plugin::Catalog::drop(drizzled::identifier::Catalog(*res));
+
+  return drizzled::plugin::Catalog::drop(drizzled::identifier::Catalog(res->c_str()));
 }
 
 } /* namespace functions */
