@@ -37,7 +37,7 @@ int64_t Lock::val_int()
   }
 
   null_value= false;
-  return drizzled::plugin::Catalog::create(drizzled::identifier::Catalog(*res));
+  return drizzled::plugin::Catalog::create(drizzled::identifier::Catalog(res->c_str()));
 }
 
 } /* namespace functions */
