@@ -1,7 +1,7 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2010 Sun Microsystems
+ *  Copyright (C) 2010 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef PLUGIN_COLLATION_DICTIONARY_COLLATIONS_H
-#define PLUGIN_COLLATION_DICTIONARY_COLLATIONS_H
+#pragma once
 
 class CollationsTool : public CharacterSetsTool
 {
@@ -67,4 +66,3 @@ public:
 
 };
 
-#endif /* PLUGIN_COLLATION_DICTIONARY_COLLATIONS_H */
