@@ -13,12 +13,12 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
-#include "config.h"
-#include "drizzled/plugin/function.h"
+#include <config.h>
+#include <drizzled/plugin/function.h>
 
-#include "plugin/compression/compress.h"
-#include "plugin/compression/uncompress.h"
-#include "plugin/compression/uncompressed_length.h"
+#include <plugin/compression/compress.h>
+#include <plugin/compression/uncompress.h>
+#include <plugin/compression/uncompressed_length.h>
 
 using namespace std;
 using namespace drizzled;
@@ -50,7 +50,7 @@ DRIZZLE_DECLARE_PLUGIN
   "UDFs for compression functions",
   PLUGIN_LICENSE_GPL,
   compressionudf_plugin_init, /* Plugin Init */
-  NULL,   /* system variables */
+  NULL,   /* depends */
   NULL    /* config options */
 }
 DRIZZLE_DECLARE_PLUGIN_END;
