@@ -35,10 +35,10 @@ static int init(drizzled::module::Context &context)
 DRIZZLE_DECLARE_PLUGIN
 {
   DRIZZLE_VERSION_ID,
-  "error_dictionary",
+  "Error Dictionary",
   "1.0",
   "Monty Taylor",
-  N_("Dictionary of Drizzle errors codes and messages"),
+  "Data Dictionary for Errors.",
   drizzled::PLUGIN_LICENSE_GPL,
   drizzle_plugin::init,
   NULL,
