@@ -1,7 +1,7 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2010 Sun Microsystems
+ *  Copyright (C) 2010 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <plugin/function_engine/function.h>
 #include <plugin/function_engine/cursor.h>
@@ -28,26 +28,33 @@
 using namespace std;
 using namespace drizzled;
 
-static SchemaIdentifier INFORMATION_SCHEMA_IDENTIFIER("INFORMATION_SCHEMA");
-static SchemaIdentifier DATA_DICTIONARY_IDENTIFIER("DATA_DICTIONARY");
-
 Function::Function(const std::string &name_arg) :
   drizzled::plugin::StorageEngine(name_arg,
                                   HTON_ALTER_NOT_SUPPORTED |
                                   HTON_HAS_SCHEMA_DICTIONARY |
                                   HTON_SKIP_STORE_LOCK |
-                                  HTON_TEMPORARY_NOT_SUPPORTED)
+                                  HTON_TEMPORARY_NOT_SUPPORTED),
+  information_message(new(message::Schema)),
+  data_dictionary_message(new(message::Schema))
+
 {
+  information_message->set_name(INFORMATION_SCHEMA_IDENTIFIER.getSchemaName());
+  information_message->set_collation("utf8_general_ci");
+  message::set_is_replicated(*information_message, false);
+
+  data_dictionary_message->set_name(DATA_DICTIONARY_IDENTIFIER.getSchemaName());
+  data_dictionary_message->set_collation("utf8_general_ci");
+  message::set_is_replicated(*data_dictionary_message, false);
 }
 
 
-Cursor *Function::create(TableShare &table)
+Cursor *Function::create(Table &table)
 {
   return new FunctionCursor(*this, table);
 }
 
 int Function::doGetTableDefinition(Session &,
-                                   const TableIdentifier &identifier,
+                                   const identifier::Table &identifier,
                                    message::Table &table_proto)
 {
   drizzled::plugin::TableFunction *function= getFunction(identifier.getPath());
@@ -62,40 +69,40 @@ int Function::doGetTableDefinition(Session &,
   return EEXIST;
 }
 
-void Function::doGetSchemaIdentifiers(SchemaIdentifiers& schemas)
+void Function::doGetSchemaIdentifiers(identifier::Schema::vector& schemas)
 {
   schemas.push_back(INFORMATION_SCHEMA_IDENTIFIER);
   schemas.push_back(DATA_DICTIONARY_IDENTIFIER);
 }
 
-bool Function::doGetSchemaDefinition(const SchemaIdentifier &schema_identifier, message::Schema &schema_message)
+drizzled::message::schema::shared_ptr Function::doGetSchemaDefinition(const identifier::Schema &schema_identifier)
 {
+  drizzled::message::schema::shared_ptr schema_message;
+
   if (schema_identifier == INFORMATION_SCHEMA_IDENTIFIER)
   {
-    schema_message.set_name("information_schema");
-    schema_message.set_collation("utf8_general_ci");
+    schema_message= information_message;
   }
   else if (schema_identifier == DATA_DICTIONARY_IDENTIFIER)
   {
-    schema_message.set_name("data_dictionary");
-    schema_message.set_collation("utf8_general_ci");
+    schema_message= data_dictionary_message;
   }
   else
   {
-    return false;
+    return drizzled::message::schema::shared_ptr();
   }
 
-  return true;
+  return schema_message;
 }
 
-bool Function::doCanCreateTable(const drizzled::TableIdentifier &table_identifier)
+bool Function::doCanCreateTable(const drizzled::identifier::Table &table_identifier)
 {
-  if (static_cast<const SchemaIdentifier&>(table_identifier) == INFORMATION_SCHEMA_IDENTIFIER)
+  if (static_cast<const identifier::Schema&>(table_identifier) == INFORMATION_SCHEMA_IDENTIFIER)
   {
     return false;
   }
 
-  else if (static_cast<const SchemaIdentifier&>(table_identifier) == DATA_DICTIONARY_IDENTIFIER)
+  else if (static_cast<const identifier::Schema&>(table_identifier) == DATA_DICTIONARY_IDENTIFIER)
   {
     return false;
   }
@@ -103,7 +110,7 @@ bool Function::doCanCreateTable(const drizzled::TableIdentifier &table_identifie
   return true;
 }
 
-bool Function::doDoesTableExist(Session&, const TableIdentifier &identifier)
+bool Function::doDoesTableExist(Session&, const identifier::Table &identifier)
 {
   drizzled::plugin::TableFunction *function= getFunction(identifier.getPath());
 
@@ -115,15 +122,15 @@ bool Function::doDoesTableExist(Session&, const TableIdentifier &identifier)
 
 
 void Function::doGetTableIdentifiers(drizzled::CachedDirectory&,
-                                     const drizzled::SchemaIdentifier &schema_identifier,
-                                     drizzled::TableIdentifiers &set_of_identifiers)
+                                     const drizzled::identifier::Schema &schema_identifier,
+                                     drizzled::identifier::Table::vector &set_of_identifiers)
 {
-  set<string> set_of_names;
+  set<std::string> set_of_names;
   drizzled::plugin::TableFunction::getNames(schema_identifier.getSchemaName(), set_of_names);
 
-  for (set<string>::iterator iter= set_of_names.begin(); iter != set_of_names.end(); iter++)
+  for (set<std::string>::iterator iter= set_of_names.begin(); iter != set_of_names.end(); iter++)
   {
-    set_of_identifiers.push_back(TableIdentifier(schema_identifier, *iter, drizzled::message::Table::FUNCTION));
+    set_of_identifiers.push_back(identifier::Table(schema_identifier, *iter, drizzled::message::Table::FUNCTION));
   }
 }
 
@@ -143,7 +150,7 @@ DRIZZLE_DECLARE_PLUGIN
   "Function Engine provides the infrastructure for Table Functions,etc.",
   PLUGIN_LICENSE_GPL,
   init,     /* Plugin Init */
-  NULL,               /* system variables */
+  NULL,               /* depends */
   NULL                /* config options   */
 }
 DRIZZLE_DECLARE_PLUGIN_END;
