@@ -18,8 +18,8 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
-#include "plugin/information_schema_dictionary/dictionary.h"
+#include <config.h>
+#include <plugin/information_schema_dictionary/dictionary.h>
 
 using namespace std;
 using namespace drizzled;
