@@ -248,78 +248,74 @@ buf_LRU_drop_page_hash_for_tablespace(
 		sizeof(ulint) * BUF_LRU_DROP_SEARCH_HASH_SIZE));
 
 	buf_pool_mutex_enter(buf_pool);
-	num_entries = 0;
 
 scan_again:
+	num_entries = 0;
 	bpage = UT_LIST_GET_LAST(buf_pool->LRU);
 
 	while (bpage != NULL) {
+		mutex_t*	block_mutex = buf_page_get_mutex(bpage);
 		buf_page_t*	prev_bpage;
-		ibool		is_fixed;
 
+		mutex_enter(block_mutex);
 		prev_bpage = UT_LIST_GET_PREV(LRU, bpage);
 
 		ut_a(buf_page_in_file(bpage));
 
 		if (buf_page_get_state(bpage) != BUF_BLOCK_FILE_PAGE
 		    || bpage->space != id
+		    || bpage->buf_fix_count > 0
 		    || bpage->io_fix != BUF_IO_NONE) {
-			/* Compressed pages are never hashed.
-			Skip blocks of other tablespaces.
-			Skip I/O-fixed blocks (to be dealt with later). */
+			/* We leave the fixed pages as is in this scan.
+			To be dealt with later in the final scan. */
+			mutex_exit(block_mutex);
+			goto next_page;
+		}
+
+		if (((buf_block_t*) bpage)->is_hashed) {
+
+			/* Store the offset(i.e.: page_no) in the array
+			so that we can drop hash index in a batch
+			later. */
+			page_arr[num_entries] = bpage->offset;
+			mutex_exit(block_mutex);
+			ut_a(num_entries < BUF_LRU_DROP_SEARCH_HASH_SIZE);
+			++num_entries;
+
+			if (num_entries < BUF_LRU_DROP_SEARCH_HASH_SIZE) {
+				goto next_page;
+			}
+
+			/* Array full. We release the buf_pool->mutex to
+			obey the latching order. */
+			buf_pool_mutex_exit(buf_pool);
+
+			buf_LRU_drop_page_hash_batch(
+				id, zip_size, page_arr, num_entries);
+
+			num_entries = 0;
+
+			buf_pool_mutex_enter(buf_pool);
+		} else {
+			mutex_exit(block_mutex);
+		}
+
 next_page:
-			bpage = prev_bpage;
-			continue;
-		}
-
-		mutex_enter(&((buf_block_t*) bpage)->mutex);
-		is_fixed = bpage->buf_fix_count > 0
-			|| !((buf_block_t*) bpage)->is_hashed;
-		mutex_exit(&((buf_block_t*) bpage)->mutex);
-
-		if (is_fixed) {
-			goto next_page;
-		}
-
-		/* Store the page number so that we can drop the hash
-		index in a batch later. */
-		page_arr[num_entries] = bpage->offset;
-		ut_a(num_entries < BUF_LRU_DROP_SEARCH_HASH_SIZE);
-		++num_entries;
-
-		if (num_entries < BUF_LRU_DROP_SEARCH_HASH_SIZE) {
-			goto next_page;
-		}
-
-		/* Array full. We release the buf_pool->mutex to obey
-		the latching order. */
-		buf_pool_mutex_exit(buf_pool);
-
-		buf_LRU_drop_page_hash_batch(
-			id, zip_size, page_arr, num_entries);
-
-		num_entries = 0;
-
-		buf_pool_mutex_enter(buf_pool);
-
-		/* Note that we released the buf_pool mutex above
-		after reading the prev_bpage during processing of a
-		page_hash_batch (i.e.: when the array was full).
-		Because prev_bpage could belong to a compressed-only
-		block, it may have been relocated, and thus the
-		pointer cannot be trusted. Because bpage is of type
-		buf_block_t, it is safe to dereference.
-
-		bpage can change in the LRU list. This is OK because
-		this function is a 'best effort' to drop as many
-		search hash entries as possible and it does not
-		guarantee that ALL such entries will be dropped. */
+		/* Note that we may have released the buf_pool mutex
+		above after reading the prev_bpage during processing
+		of a page_hash_batch (i.e.: when the array was full).
+		This means that prev_bpage can change in LRU list.
+		This is OK because this function is a 'best effort'
+		to drop as many search hash entries as possible and
+		it does not guarantee that ALL such entries will be
+		dropped. */
+		bpage = prev_bpage;
 
 		/* If, however, bpage has been removed from LRU list
 		to the free list then we should restart the scan.
 		bpage->state is protected by buf_pool mutex. */
-		if (bpage
-		    && buf_page_get_state(bpage) != BUF_BLOCK_FILE_PAGE) {
+		if (bpage && !buf_page_in_file(bpage)) {
+			ut_a(num_entries == 0);
 			goto scan_again;
 		}
 	}
@@ -608,7 +604,7 @@ buf_LRU_free_from_unzip_LRU_list(
 		ut_ad(block->page.in_LRU_list);
 
 		mutex_enter(&block->mutex);
-		freed = buf_LRU_free_block(&block->page, FALSE);
+		freed = buf_LRU_free_block(&block->page, FALSE, NULL);
 		mutex_exit(&block->mutex);
 
 		switch (freed) {
@@ -671,7 +667,7 @@ buf_LRU_free_from_common_LRU_list(
 
 		mutex_enter(block_mutex);
 		accessed = buf_page_is_accessed(bpage);
-		freed = buf_LRU_free_block(bpage, TRUE);
+		freed = buf_LRU_free_block(bpage, TRUE, NULL);
 		mutex_exit(block_mutex);
 
 		switch (freed) {
@@ -863,7 +859,9 @@ UNIV_INTERN
 buf_block_t*
 buf_LRU_get_free_block(
 /*===================*/
-	buf_pool_t*	buf_pool)	/*!< in/out: buffer pool instance */
+	buf_pool_t*	buf_pool,	/*!< in: buffer pool instance */
+	ulint		zip_size)	/*!< in: compressed page size in bytes,
+					or 0 if uncompressed tablespace */
 {
 	buf_block_t*	block		= NULL;
 	ibool		freed;
@@ -939,11 +937,31 @@ loop:
 
 	/* If there is a block in the free list, take it */
 	block = buf_LRU_get_free_only(buf_pool);
-	buf_pool_mutex_exit(buf_pool);
-
 	if (block) {
+
 		ut_ad(buf_pool_from_block(block) == buf_pool);
-		memset(&block->page.zip, 0, sizeof block->page.zip);
+
+#ifdef UNIV_DEBUG
+		block->page.zip.m_start =
+#endif /* UNIV_DEBUG */
+			block->page.zip.m_end =
+			block->page.zip.m_nonempty =
+			block->page.zip.n_blobs = 0;
+
+		if (UNIV_UNLIKELY(zip_size)) {
+			ibool	lru;
+			page_zip_set_size(&block->page.zip, zip_size);
+
+			block->page.zip.data = static_cast<unsigned char *>(buf_buddy_alloc(
+				buf_pool, zip_size, &lru));
+
+			UNIV_MEM_DESC(block->page.zip.data, zip_size, block);
+		} else {
+			page_zip_set_size(&block->page.zip, 0);
+			block->page.zip.data = NULL;
+		}
+
+		buf_pool_mutex_exit(buf_pool);
 
 		if (started_monitor) {
 			srv_print_innodb_monitor = mon_value_was;
@@ -955,6 +973,8 @@ loop:
 	/* If no block was in the free list, search from the end of the LRU
 	list and try to free a block there */
 
+	buf_pool_mutex_exit(buf_pool);
+
 	freed = buf_LRU_search_and_free_block(buf_pool, n_iterations);
 
 	if (freed > 0) {
@@ -1437,8 +1457,12 @@ enum buf_lru_free_block_status
 buf_LRU_free_block(
 /*===============*/
 	buf_page_t*	bpage,	/*!< in: block to be freed */
-	ibool		zip)	/*!< in: TRUE if should remove also the
+	ibool		zip,	/*!< in: TRUE if should remove also the
 				compressed page of an uncompressed page */
+	ibool*		buf_pool_mutex_released)
+				/*!< in: pointer to a variable that will
+				be assigned TRUE if buf_pool_mutex
+				was temporarily released, or NULL */
 {
 	buf_page_t*	b = NULL;
 	buf_pool_t*	buf_pool = buf_pool_from_bpage(bpage);
@@ -1615,6 +1639,10 @@ alloc:
 			b->io_fix = BUF_IO_READ;
 		}
 
+		if (buf_pool_mutex_released) {
+			*buf_pool_mutex_released = TRUE;
+		}
+
 		buf_pool_mutex_exit(buf_pool);
 		mutex_exit(block_mutex);
 
@@ -1894,7 +1922,6 @@ buf_LRU_block_remove_hashed_page(
 			buf_pool, bpage->zip.data,
 			page_zip_get_size(&bpage->zip));
 
-		bpage->state = BUF_BLOCK_ZIP_FREE;
 		buf_buddy_free(buf_pool, bpage, sizeof(*bpage));
 		buf_pool_mutex_exit_allow(buf_pool);
 
@@ -2050,7 +2077,6 @@ buf_LRU_stat_update(void)
 	buf_LRU_stat_t*	item;
 	buf_pool_t*	buf_pool;
 	ibool		evict_started = FALSE;
-	buf_LRU_stat_t	cur_stat;
 
 	/* If we haven't started eviction yet then don't update stats. */
 	for (i = 0; i < srv_buf_pool_instances; i++) {
@@ -2072,303 +2098,18 @@ buf_LRU_stat_update(void)
 	buf_LRU_stat_arr_ind++;
 	buf_LRU_stat_arr_ind %= BUF_LRU_STAT_N_INTERVAL;
 
-	/* Add the current value and subtract the obsolete entry.
-	Since buf_LRU_stat_cur is not protected by any mutex,
-	it can be changing between adding to buf_LRU_stat_sum
-	and copying to item. Assign it to local variables to make
-	sure the same value assign to the buf_LRU_stat_sum
-	and item */
-	cur_stat = buf_LRU_stat_cur;
-
-	buf_LRU_stat_sum.io += cur_stat.io - item->io;
-	buf_LRU_stat_sum.unzip += cur_stat.unzip - item->unzip;
+	/* Add the current value and subtract the obsolete entry. */
+	buf_LRU_stat_sum.io += buf_LRU_stat_cur.io - item->io;
+	buf_LRU_stat_sum.unzip += buf_LRU_stat_cur.unzip - item->unzip;
 
 	/* Put current entry in the array. */
-	memcpy(item, &cur_stat, sizeof *item);
+	memcpy(item, &buf_LRU_stat_cur, sizeof *item);
 
 func_exit:
 	/* Clear the current entry. */
 	memset(&buf_LRU_stat_cur, 0, sizeof buf_LRU_stat_cur);
 }
 
-/********************************************************************//**
-Dump the LRU page list to the specific file. */
-#define LRU_DUMP_FILE "ib_lru_dump"
-
-UNIV_INTERN
-bool
-buf_LRU_file_dump(void)
-/*===================*/
-{
-	os_file_t	dump_file = -1;
-	ibool		success;
-	byte*		buffer_base = NULL;
-	byte*		buffer = NULL;
-	buf_page_t*	bpage;
-	ulint		buffers;
-	ulint		offset;
-	bool		ret = false;
-	ulint		i;
-
-	for (i = 0; i < srv_n_data_files; i++) {
-		if (strstr(srv_data_file_names[i], LRU_DUMP_FILE) != NULL) {
-			fprintf(stderr,
-				" InnoDB: The name '%s' seems to be used for"
-				" innodb_data_file_path. For safety, dumping of the LRU list"
-				" is not being done.\n", LRU_DUMP_FILE);
-			goto end;
-		}
-	}
-
-	buffer_base = static_cast<byte *>(ut_malloc(2 * UNIV_PAGE_SIZE));
-	buffer = static_cast<byte *>(ut_align(buffer_base, UNIV_PAGE_SIZE));
-	if (buffer == NULL) {
-		fprintf(stderr,
-			" InnoDB: cannot allocate buffer.\n");
-		goto end;
-	}
-
-	dump_file = os_file_create(innodb_file_temp_key, LRU_DUMP_FILE, OS_FILE_OVERWRITE,
-				   OS_FILE_NORMAL, OS_DATA_FILE, &success);
-	if (success == FALSE) {
-		os_file_get_last_error(TRUE);
-		fprintf(stderr,
-			" InnoDB: cannot open %s\n", LRU_DUMP_FILE);
-		goto end;
-	}
-
-	buffers = offset = 0;
-
-	for (i = 0; i < srv_buf_pool_instances; i++) {
-		buf_pool_t*	buf_pool;
-
-		buf_pool = buf_pool_from_array(i);
-
-		buf_pool_mutex_enter(buf_pool);
-		bpage = UT_LIST_GET_LAST(buf_pool->LRU);
-
-		while (bpage != NULL) {
-			if (offset == 0) {
-				memset(buffer, 0, UNIV_PAGE_SIZE);
-			}
-
-			mach_write_to_4(buffer + offset * 4, bpage->space);
-			offset++;
-			mach_write_to_4(buffer + offset * 4, bpage->offset);
-			offset++;
-
-			if (offset == UNIV_PAGE_SIZE/4) {
-				success = os_file_write(LRU_DUMP_FILE, dump_file, buffer,
-							(buffers << UNIV_PAGE_SIZE_SHIFT) & 0xFFFFFFFFUL,
-							(buffers >> (32 - UNIV_PAGE_SIZE_SHIFT)),
-							UNIV_PAGE_SIZE);
-				if (success == FALSE) {
-					buf_pool_mutex_exit(buf_pool);
-					fprintf(stderr,
-						" InnoDB: cannot write page %lu of %s\n",
-						buffers, LRU_DUMP_FILE);
-					goto end;
-				}
-				buffers++;
-				offset = 0;
-			}
-
-			bpage = UT_LIST_GET_PREV(LRU, bpage);
-		}
-		buf_pool_mutex_exit(buf_pool);
-	}
-
-	if (offset == 0) {
-		memset(buffer, 0, UNIV_PAGE_SIZE);
-	}
-
-	mach_write_to_4(buffer + offset * 4, 0xFFFFFFFFUL);
-	offset++;
-	mach_write_to_4(buffer + offset * 4, 0xFFFFFFFFUL);
-	offset++;
-
-	success = os_file_write(LRU_DUMP_FILE, dump_file, buffer,
-				(buffers << UNIV_PAGE_SIZE_SHIFT) & 0xFFFFFFFFUL,
-				(buffers >> (32 - UNIV_PAGE_SIZE_SHIFT)),
-				UNIV_PAGE_SIZE);
-	if (success == FALSE) {
-		goto end;
-	}
-
-	ret = true;
-end:
-	if (dump_file != -1)
-		os_file_close(dump_file);
-	if (buffer_base)
-		ut_free(buffer_base);
-
-	return(ret);
-}
-
-typedef struct {
-	ib_uint32_t space_id;
-	ib_uint32_t page_no;
-} dump_record_t;
-
-static int dump_record_cmp(const void *a, const void *b)
-{
-	const dump_record_t *rec1 = (dump_record_t *) a;
-	const dump_record_t *rec2 = (dump_record_t *) b;
-
-	if (rec1->space_id < rec2->space_id)
-		return -1;
-	if (rec1->space_id > rec2->space_id)
-		return 1;
-	if (rec1->page_no < rec2->page_no)
-		return -1;
-	return rec1->page_no > rec2->page_no;
-}
-
-/********************************************************************//**
-Read the pages based on the specific file.*/
-UNIV_INTERN
-bool
-buf_LRU_file_restore(void)
-/*======================*/
-{
-	os_file_t	dump_file = -1;
-	ibool		success;
-	byte*		buffer_base = NULL;
-	byte*		buffer = NULL;
-	ulint		buffers;
-	ulint		offset;
-	ulint		reads = 0;
-	ulint		req = 0;
-	bool		terminated = false;
-	bool		ret = false;
-	dump_record_t*	records = NULL;
-	ulint		size;
-	ulint		size_high;
-	ulint		length;
-
-	dump_file = os_file_create_simple_no_error_handling(innodb_file_temp_key,
-							    LRU_DUMP_FILE, OS_FILE_OPEN, OS_FILE_READ_ONLY, &success);
-	if (success == FALSE || !os_file_get_size(dump_file, &size, &size_high)) {
-		os_file_get_last_error(TRUE);
-		fprintf(stderr,
-			" InnoDB: cannot open %s\n", LRU_DUMP_FILE);
-		goto end;
-	}
-	if (size == 0 || size_high > 0 || size % 8) {
-		fprintf(stderr, " InnoDB: broken LRU dump file\n");
-		goto end;
-	}
-	buffer_base = static_cast<byte *>(ut_malloc(2 * UNIV_PAGE_SIZE));
-	buffer = static_cast<byte *>(ut_align(buffer_base, UNIV_PAGE_SIZE));
-	records = static_cast<dump_record_t *>(ut_malloc(size));
-	if (buffer == NULL || records == NULL) {
-		fprintf(stderr,
-			" InnoDB: cannot allocate buffer.\n");
-		goto end;
-	}
-
-	buffers = 0;
-	length = 0;
-	while (!terminated) {
-		success = os_file_read(dump_file, buffer,
-				       (buffers << UNIV_PAGE_SIZE_SHIFT) & 0xFFFFFFFFUL,
-				       (buffers >> (32 - UNIV_PAGE_SIZE_SHIFT)),
-				       UNIV_PAGE_SIZE);
-		if (success == FALSE) {
-			fprintf(stderr,
-				" InnoDB: either could not read page %lu of %s,"
-				" or terminated unexpectedly.\n",
-				buffers, LRU_DUMP_FILE);
-			goto end;
-		}
-
-		for (offset = 0; offset < UNIV_PAGE_SIZE/4; offset += 2) {
-			ulint	space_id;
-			ulint	page_no;
-
-			space_id = mach_read_from_4(buffer + offset * 4);
-			page_no = mach_read_from_4(buffer + (offset + 1) * 4);
-			if (space_id == 0xFFFFFFFFUL
-			    || page_no == 0xFFFFFFFFUL) {
-				terminated = true;
-				break;
-			}
-
-			records[length].space_id = space_id;
-			records[length].page_no = page_no;
-			length++;
-			if (length * 8 >= size) {
-				fprintf(stderr,
-					" InnoDB: could not find the "
-					"end-of-file marker after reading "
-					"the expected %lu bytes from the "
-					"LRU dump file.\n"
-					" InnoDB: this could be caused by a "
-					"broken or incomplete file.\n"
-					" InnoDB: trying to process what has "
-					"been read so far.\n",
-					size);
-				terminated = true;
-				break;
-			}
-		}
-		buffers++;
-	}
-
-	qsort(records, length, sizeof(dump_record_t), dump_record_cmp);
-
-	for (offset = 0; offset < length; offset++) {
-		ulint	space_id;
-		ulint	page_no;
-		ulint	zip_size;
-		ulint	err;
-		int64_t	tablespace_version;
-
-		space_id = records[offset].space_id;
-		page_no = records[offset].page_no;
-
-		if (offset % 16 == 15) {
-			os_aio_simulated_wake_handler_threads();
-			buf_flush_free_margins();
-		}
-
-		zip_size = fil_space_get_zip_size(space_id);
-		if (UNIV_UNLIKELY(zip_size == ULINT_UNDEFINED)) {
-			continue;
-		}
-
-		if (fil_is_exist(space_id, page_no)) {
-
-			tablespace_version = fil_space_get_version(space_id);
-
-			req++;
-			reads += buf_read_page_low(&err, FALSE, BUF_READ_ANY_PAGE
-						   | OS_AIO_SIMULATED_WAKE_LATER,
-						   space_id, zip_size, TRUE,
-						   tablespace_version, page_no);
-			buf_LRU_stat_inc_io();
-		}
-	}
-
-	os_aio_simulated_wake_handler_threads();
-	buf_flush_free_margins();
-
-	ut_print_timestamp(stderr);
-	fprintf(stderr,
-		" InnoDB: reading pages based on the dumped LRU list was done."
-		" (requested: %lu, read: %lu)\n", req, reads);
-	ret = true;
-end:
-	if (dump_file != -1)
-		os_file_close(dump_file);
-	if (buffer_base)
-		ut_free(buffer_base);
-	if (records)
-		ut_free(records);
-
-	return(ret);
-}
-
 #if defined UNIV_DEBUG || defined UNIV_BUF_DEBUG
 /**********************************************************************//**
 Validates the LRU list for one buffer pool instance. */
