@@ -44,7 +44,6 @@ Created 4/24/1996 Heikki Tuuri
 #include "rem0cmp.h"
 #include "srv0start.h"
 #include "srv0srv.h"
-#include "ha_prototypes.h" /* innobase_casedn_str() */
 
 
 /** Following are six InnoDB system tables */
@@ -443,11 +442,10 @@ dict_process_sys_fields_rec(
 	return(err_msg);
 
 }
-
 /********************************************************************//**
 This function parses a SYS_FOREIGN record and populate a dict_foreign_t
 structure with the information from the record. For detail information
-about SYS_FOREIGN fields, please refer to dict_load_foreign() function.
+about SYS_FOREIGN fields, please refer to dict_load_foreign() function
 @return error message, or NULL on success */
 UNIV_INTERN
 const char*
@@ -475,11 +473,6 @@ dict_process_sys_foreign_rec(
 err_len:
 		return("incorrect column length in SYS_FOREIGN");
 	}
-	
-	/* This recieves a dict_foreign_t* that points to a stack variable.
-	So mem_heap_free(foreign->heap) is not used as elsewhere.
-	Since the heap used here is freed elsewhere, foreign->heap
-	is not assigned. */
 	foreign->id = mem_heap_strdupl(heap, (const char*) field, len);
 
 	rec_get_nth_field_offs_old(rec, 1/*DB_TRX_ID*/, &len);
@@ -491,9 +484,6 @@ err_len:
 		goto err_len;
 	}
 
-	/* The _lookup versions of the referenced and foreign table names
-	 are not assigned since they are not used in this dict_foreign_t */
-
 	field = rec_get_nth_field_old(rec, 3/*FOR_NAME*/, &len);
 	if (UNIV_UNLIKELY(len < 1 || len == UNIV_SQL_NULL)) {
 		goto err_len;
@@ -519,7 +509,6 @@ err_len:
 
 	return(NULL);
 }
-
 /********************************************************************//**
 This function parses a SYS_FOREIGN_COLS record and extract necessary
 information from the record and return to caller.
@@ -1401,10 +1390,7 @@ ulint
 dict_load_indexes(
 /*==============*/
 	dict_table_t*	table,	/*!< in/out: table */
-	mem_heap_t*	heap,	/*!< in: memory heap for temporary storage */
-	dict_err_ignore_t ignore_err)
-				/*!< in: error to be ignored when
-				loading the index definition */
+	mem_heap_t*	heap)	/*!< in: memory heap for temporary storage */
 {
 	dict_table_t*	sys_indexes;
 	dict_index_t*	sys_index;
@@ -1487,22 +1473,10 @@ dict_load_indexes(
 				"InnoDB: but the index tree has been freed!\n",
 				index->name, table->name);
 
-			if (ignore_err & DICT_ERR_IGNORE_INDEX_ROOT) {
-				/* If caller can tolerate this error,
-				we will continue to load the index and
-				let caller deal with this error. However
-				mark the index and table corrupted */
-				index->corrupted = TRUE;
-				table->corrupted = TRUE;
-				fprintf(stderr,
-					"InnoDB: Index is corrupt but forcing"
-					" load into data dictionary\n");
-			} else {
 corrupted:
-				dict_mem_index_free(index);
-				error = DB_CORRUPTION;
-				goto func_exit;
-			}
+			dict_mem_index_free(index);
+			error = DB_CORRUPTION;
+			goto func_exit;
 		} else if (!dict_index_is_clust(index)
 			   && NULL == dict_table_get_first_index(table)) {
 
@@ -1645,7 +1619,7 @@ err_len:
 				"InnoDB: in InnoDB data dictionary"
 				" has unknown type %lx.\n",
 				(ulong) flags);
-			return("incorrect flags in SYS_TABLES");
+			return(NULL);
 		}
 	} else {
 		flags = 0;
@@ -1711,10 +1685,7 @@ dict_load_table(
 /*============*/
 	const char*	name,	/*!< in: table name in the
 				databasename/tablename format */
-	ibool		cached,	/*!< in: TRUE=add to cache, FALSE=do not */
-	dict_err_ignore_t ignore_err)
-				/*!< in: error to be ignored when loading
-				table and its indexes' definition */
+	ibool		cached)	/*!< in: TRUE=add to cache, FALSE=do not */
 {
 	dict_table_t*	table;
 	dict_table_t*	sys_tables;
@@ -1829,7 +1800,7 @@ err_exit:
 
 	mem_heap_empty(heap);
 
-	err = dict_load_indexes(table, heap, ignore_err);
+	err = dict_load_indexes(table, heap);
 
 	/* Initialize table foreign_child value. Its value could be
 	changed when dict_load_foreigns() is called below */
@@ -1908,8 +1879,6 @@ dict_load_table_on_id(
 
 	table = NULL;
 
-	table = NULL;
-
 	/* NOTE that the operation of this function is protected by
 	the dictionary mutex, and therefore no deadlocks can occur
 	with other dictionary operations. */
@@ -1966,7 +1935,7 @@ dict_load_table_on_id(
 	field = rec_get_nth_field_old(rec, 1, &len);
 	/* Load the table definition to memory */
 	table = dict_load_table(mem_heap_strdupl(heap, (char*) field, len),
-				TRUE, DICT_ERR_IGNORE_NONE);
+				TRUE);
 func_exit:
 	btr_pcur_close(&pcur);
 	mtr_commit(&mtr);
@@ -1991,7 +1960,7 @@ dict_load_sys_table(
 
 	heap = mem_heap_create(1000);
 
-	dict_load_indexes(table, heap, DICT_ERR_IGNORE_NONE);
+	dict_load_indexes(table, heap);
 
 	mem_heap_free(heap);
 }
@@ -2170,15 +2139,12 @@ dict_load_foreign(
 	foreign->id = mem_heap_strdup(foreign->heap, id);
 
 	field = rec_get_nth_field_old(rec, 3, &len);
-
 	foreign->foreign_table_name = mem_heap_strdupl(
 		foreign->heap, (char*) field, len);
-	dict_mem_foreign_table_name_lookup_set(foreign, TRUE);
 
 	field = rec_get_nth_field_old(rec, 4, &len);
 	foreign->referenced_table_name = mem_heap_strdupl(
 		foreign->heap, (char*) field, len);
-	dict_mem_referenced_table_name_lookup_set(foreign, TRUE);
 
 	btr_pcur_close(&pcur);
 	mtr_commit(&mtr);
@@ -2186,7 +2152,7 @@ dict_load_foreign(
 	dict_load_foreign_cols(id, foreign);
 
 	ref_table = dict_table_check_if_in_cache_low(
-			foreign->referenced_table_name_lookup);
+			foreign->referenced_table_name);
 
 	/* We could possibly wind up in a deep recursive calls if
 	we call dict_table_get_low() again here if there
@@ -2219,7 +2185,7 @@ dict_load_foreign(
 		have to load it so that we are able to make type comparisons
 		in the next function call. */
 
-		for_table = dict_table_get_low(foreign->foreign_table_name_lookup);
+		for_table = dict_table_get_low(foreign->foreign_table_name);
 
 		if (for_table && ref_table && check_recursive) {
 			/* This is to record the longest chain of ancesters
@@ -2339,12 +2305,10 @@ loop:
 	/* Since table names in SYS_FOREIGN are stored in a case-insensitive
 	order, we have to check that the table name matches also in a binary
 	string comparison. On Unix, MySQL allows table names that only differ
-	in character case.  If lower_case_table_names=2 then what is stored
-	may not be the same case, but the previous comparison showed that they
-	match with no-case.  */
+	in character case. */
+
+	if (0 != ut_memcmp(field, table_name, len)) {
 
-	if ((srv_lower_case_table_names != 2)
-	    && (0 != ut_memcmp(field, table_name, len))) {
 		goto next_rec;
 	}
 
