@@ -1,6 +1,6 @@
 /*****************************************************************************
 
-Copyright (c) 2007, 2009, Innobase Oy. All Rights Reserved.
+Copyright (C) 2007, 2009, Innobase Oy. All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
@@ -11,18 +11,17 @@ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along with
-this program; if not, write to the Free Software Foundation, Inc., 59 Temple
-Place, Suite 330, Boston, MA 02111-1307 USA
+this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+St, Fifth Floor, Boston, MA 02110-1301 USA
 
 *****************************************************************************/
 
-#include "config.h"
+#include <config.h>
 
 #include "internal_dictionary.h"
 
-#include "drizzled/current_session.h"
+#include <drizzled/current_session.h>
 
-extern "C" {
 #include "univ.i"
 #include "btr0sea.h"
 #include "os0file.h"
@@ -52,8 +51,6 @@ extern "C" {
 #include "ha_prototypes.h"
 #include "ut0mem.h"
 #include "ibuf0ibuf.h"
-#include "mysql_addons.h"
-}
 #include "handler0vars.h"
 
 using namespace drizzled;
@@ -68,11 +65,7 @@ InnodbInternalTables::InnodbInternalTables() :
   add_field("TABLE_NAME");
 }
 
-extern "C" {
-  void my_dict_print_callback(void *ptr, const char *);
-}
-
-void my_dict_print_callback(void *ptr, const char *table_name)
+static void my_dict_print_callback(void *ptr, const char *table_name)
 {
   Recorder *myrec= static_cast<Recorder *>(ptr);
 
