@@ -27,10 +27,13 @@
 class ReplicationLog :
   public drizzled::plugin::TransactionApplier 
 {
+  ReplicationLog(const ReplicationLog&);
+  ReplicationLog& operator=(const ReplicationLog&);
 public:
   ReplicationLog();
 
-  static void setup(ReplicationLog*, const std::string&);
-  drizzled::plugin::ReplicationReturnCode apply(drizzled::Session&, const drizzled::message::Transaction &to_apply);
+  static void setup(ReplicationLog *logger);
+  drizzled::plugin::ReplicationReturnCode apply(drizzled::Session &session,
+                                                const drizzled::message::Transaction &to_apply);
 };
 
