@@ -641,15 +641,7 @@ fil_io(
 				appropriately aligned */
 	void*	message);	/*!< in: message for aio handler if non-sync
 				aio used, else ignored */
-/********************************************************************//**
-Confirm whether the parameters are valid or not */
-UNIV_INTERN
-bool
-fil_is_exist(
-/*=========*/
-	ulint	space_id,	/*!< in: space id */
-	ulint	block_offset);	/*!< in: offset in number of blocks */
-				/**********************************************************************//**
+/**********************************************************************//**
 Waits for an aio operation to complete. This function is used to write the
 handler for completed requests. The aio array of pending requests is divided
 into segments (see os0file.c for more info). The thread specifies which
