@@ -164,11 +164,11 @@ static
 ibool
 page_dir_slot_check(
 /*================*/
-	const page_dir_slot_t*	slot)	/*!< in: slot */
+	page_dir_slot_t*	slot)	/*!< in: slot */
 {
-	const page_t*	page;
-	ulint		n_slots;
-	ulint		n_owned;
+	page_t*	page;
+	ulint	n_slots;
+	ulint	n_owned;
 
 	ut_a(slot);
 
@@ -683,16 +683,12 @@ page_copy_rec_list_end(
 			if (UNIV_UNLIKELY
 			    (!page_zip_reorganize(new_block, index, mtr))) {
 
-				btr_blob_dbg_remove(new_page, index,
-						    "copy_end_reorg_fail");
 				if (UNIV_UNLIKELY
 				    (!page_zip_decompress(new_page_zip,
 							  new_page, FALSE))) {
 					ut_error;
 				}
 				ut_ad(page_validate(new_page, index));
-				btr_blob_dbg_add(new_page, index,
-						 "copy_end_reorg_fail");
 				return(NULL);
 			} else {
 				/* The page was reorganized:
@@ -805,16 +801,12 @@ page_copy_rec_list_start(
 			if (UNIV_UNLIKELY
 			    (!page_zip_reorganize(new_block, index, mtr))) {
 
-				btr_blob_dbg_remove(new_page, index,
-						    "copy_start_reorg_fail");
 				if (UNIV_UNLIKELY
 				    (!page_zip_decompress(new_page_zip,
 							  new_page, FALSE))) {
 					ut_error;
 				}
 				ut_ad(page_validate(new_page, index));
-				btr_blob_dbg_add(new_page, index,
-						 "copy_start_reorg_fail");
 				return(NULL);
 			} else {
 				/* The page was reorganized:
@@ -1086,9 +1078,6 @@ page_delete_rec_list_end(
 	/* Remove the record chain segment from the record chain */
 	page_rec_set_next(prev_rec, page_get_supremum_rec(page));
 
-	btr_blob_dbg_op(page, rec, index, "delete_end",
-			btr_blob_dbg_remove_rec);
-
 	/* Catenate the deleted chain segment to the page free list */
 
 	page_rec_set_next(last_rec, page_header_get_ptr(page, PAGE_FREE));
@@ -1801,12 +1790,12 @@ UNIV_INTERN
 ibool
 page_rec_validate(
 /*==============*/
-	const rec_t*	rec,	/*!< in: physical record */
+	rec_t*		rec,	/*!< in: physical record */
 	const ulint*	offsets)/*!< in: array returned by rec_get_offsets() */
 {
-	ulint		n_owned;
-	ulint		heap_no;
-	const page_t*	page;
+	ulint	n_owned;
+	ulint	heap_no;
+	page_t*	page;
 
 	page = page_align(rec);
 	ut_a(!page_is_comp(page) == !rec_offs_comp(offsets));
@@ -1887,16 +1876,16 @@ UNIV_INTERN
 ibool
 page_simple_validate_old(
 /*=====================*/
-	const page_t*	page)	/*!< in: index page in ROW_FORMAT=REDUNDANT */
+	page_t*	page)	/*!< in: old-style index page */
 {
-	const page_dir_slot_t*	slot;
-	ulint			slot_no;
-	ulint			n_slots;
-	const rec_t*		rec;
-	const byte*		rec_heap_top;
-	ulint			count;
-	ulint			own_count;
-	ibool			ret	= FALSE;
+	page_dir_slot_t* slot;
+	ulint		slot_no;
+	ulint		n_slots;
+	rec_t*		rec;
+	byte*		rec_heap_top;
+	ulint		count;
+	ulint		own_count;
+	ibool		ret	= FALSE;
 
 	ut_a(!page_is_comp(page));
 
@@ -2009,7 +1998,7 @@ page_simple_validate_old(
 			goto func_exit;
 		}
 
-		rec = page_rec_get_next_const(rec);
+		rec = page_rec_get_next(rec);
 		own_count++;
 	}
 
@@ -2070,7 +2059,7 @@ page_simple_validate_old(
 			goto func_exit;
 		}
 
-		rec = page_rec_get_next_const(rec);
+		rec = page_rec_get_next(rec);
 	}
 
 	if (UNIV_UNLIKELY(page_dir_get_n_heap(page) != count + 1)) {
@@ -2097,16 +2086,16 @@ UNIV_INTERN
 ibool
 page_simple_validate_new(
 /*=====================*/
-	const page_t*	page)	/*!< in: index page in ROW_FORMAT!=REDUNDANT */
+	page_t*	page)	/*!< in: new-style index page */
 {
-	const page_dir_slot_t*	slot;
-	ulint			slot_no;
-	ulint			n_slots;
-	const rec_t*		rec;
-	const byte*		rec_heap_top;
-	ulint			count;
-	ulint			own_count;
-	ibool			ret	= FALSE;
+	page_dir_slot_t* slot;
+	ulint		slot_no;
+	ulint		n_slots;
+	rec_t*		rec;
+	byte*		rec_heap_top;
+	ulint		count;
+	ulint		own_count;
+	ibool		ret	= FALSE;
 
 	ut_a(page_is_comp(page));
 
@@ -2219,7 +2208,7 @@ page_simple_validate_new(
 			goto func_exit;
 		}
 
-		rec = page_rec_get_next_const(rec);
+		rec = page_rec_get_next(rec);
 		own_count++;
 	}
 
@@ -2281,7 +2270,7 @@ page_simple_validate_new(
 			goto func_exit;
 		}
 
-		rec = page_rec_get_next_const(rec);
+		rec = page_rec_get_next(rec);
 	}
 
 	if (UNIV_UNLIKELY(page_dir_get_n_heap(page) != count + 1)) {
@@ -2306,26 +2295,26 @@ UNIV_INTERN
 ibool
 page_validate(
 /*==========*/
-	const page_t*	page,	/*!< in: index page */
+	page_t*		page,	/*!< in: index page */
 	dict_index_t*	index)	/*!< in: data dictionary index containing
 				the page record type definition */
 {
-	const page_dir_slot_t*	slot;
-	mem_heap_t*		heap;
-	byte*			buf;
-	ulint			count;
-	ulint			own_count;
-	ulint			rec_own_count;
-	ulint			slot_no;
-	ulint			data_size;
-	const rec_t*		rec;
-	const rec_t*		old_rec		= NULL;
-	ulint			offs;
-	ulint			n_slots;
-	ibool			ret		= FALSE;
-	ulint			i;
-	ulint*			offsets		= NULL;
-	ulint*			old_offsets	= NULL;
+	page_dir_slot_t*slot= NULL;
+	mem_heap_t*	heap= NULL;
+	byte*		buf= NULL;
+	ulint		count= 0;
+	ulint		own_count= 0;
+	ulint		rec_own_count= 0;
+	ulint		slot_no= 0;
+	ulint		data_size= 0;
+	rec_t*		rec= NULL;
+	rec_t*		old_rec		= NULL;
+	ulint		offs= 0;
+	ulint		n_slots= 0;
+	ibool		ret		= FALSE;
+	ulint		i= 0;
+	ulint*		offsets		= NULL;
+	ulint*		old_offsets	= NULL;
         void* buf_ptr= NULL;
 
 	if (UNIV_UNLIKELY((ibool) !!page_is_comp(page)
@@ -2482,7 +2471,7 @@ page_validate(
 		count++;
 		own_count++;
 		old_rec = rec;
-		rec = page_rec_get_next_const(rec);
+		rec = page_rec_get_next(rec);
 
 		/* set old_offsets to offsets; recycle offsets */
 		{
@@ -2556,7 +2545,7 @@ n_owned_zero:
 			buf[offs + i] = 1;
 		}
 
-		rec = page_rec_get_next_const(rec);
+		rec = page_rec_get_next(rec);
 	}
 
 	if (UNIV_UNLIKELY(page_dir_get_n_heap(page) != count + 1)) {
