@@ -98,7 +98,7 @@ This buffer is used for writing or reading a record that spans two
 row_merge_block_t.  Thus, it must be able to hold one merge record,
 whose maximum size is the same as the minimum size of
 row_merge_block_t. */
-typedef byte	mrec_buf_t[UNIV_PAGE_SIZE_MAX];
+typedef byte	mrec_buf_t[UNIV_PAGE_SIZE];
 
 /** @brief Merge record in row_merge_block_t.
 
@@ -2193,15 +2193,13 @@ row_merge_drop_temp_indexes(void)
 }
 
 /*********************************************************************//**
-Creates temperary merge files, and if UNIV_PFS_IO defined, register
-the file descriptor with Performance Schema.
-@return File descriptor */
-UNIV_INLINE
-int
-row_merge_file_create_low(void)
-/*===========================*/
+Create a merge file. */
+static
+void
+row_merge_file_create(
+/*==================*/
+	merge_file_t*	merge_file)	/*!< out: merge file structure */
 {
-	int	fd;
 #ifdef UNIV_PFS_IO
 	/* This temp file open does not go through normal
 	file APIs, add instrumentation to register with
@@ -2213,46 +2211,14 @@ row_merge_file_create_low(void)
 				     "Innodb Merge Temp File",
 				     __FILE__, __LINE__);
 #endif
-	fd = innobase_mysql_tmpfile();
-#ifdef UNIV_PFS_IO
-        register_pfs_file_open_end(locker, fd);
-#endif
-	return(fd);
-}
-/*********************************************************************//**
-Create a merge file. */
-static
-void
-row_merge_file_create(
-/*==================*/
-	merge_file_t*	merge_file)	/*!< out: merge file structure */
-{
-	merge_file->fd = row_merge_file_create_low();
+	merge_file->fd = innobase_mysql_tmpfile();
 	merge_file->offset = 0;
 	merge_file->n_rec = 0;
+#ifdef UNIV_PFS_IO
+        register_pfs_file_open_end(locker, merge_file->fd);
+#endif
 }
 
-/*********************************************************************//**
-Destroy a merge file. And de-register the file from Performance Schema
-if UNIV_PFS_IO is defined. */
-UNIV_INLINE
-void
-row_merge_file_destroy_low(
-/*=======================*/
-	int		fd)	/*!< in: merge file descriptor */
-{
-#ifdef UNIV_PFS_IO
-	struct PSI_file_locker*	locker = NULL;
-	PSI_file_locker_state	state;
-	register_pfs_file_io_begin(&state, locker,
-				   fd, 0, PSI_FILE_CLOSE,
-				   __FILE__, __LINE__);
-#endif
-	close(fd);
-#ifdef UNIV_PFS_IO
-	register_pfs_file_io_end(locker, 0);
-#endif
-}
 /*********************************************************************//**
 Destroy a merge file. */
 static
@@ -2261,10 +2227,20 @@ row_merge_file_destroy(
 /*===================*/
 	merge_file_t*	merge_file)	/*!< out: merge file structure */
 {
+#ifdef UNIV_PFS_IO
+	struct PSI_file_locker*	locker = NULL;
+	PSI_file_locker_state	state;
+	register_pfs_file_io_begin(&state, locker, merge_file->fd, 0, PSI_FILE_CLOSE,
+				   __FILE__, __LINE__);
+#endif
 	if (merge_file->fd != -1) {
-		row_merge_file_destroy_low(merge_file->fd);
+		close(merge_file->fd);
 		merge_file->fd = -1;
 	}
+
+#ifdef UNIV_PFS_IO
+	register_pfs_file_io_end(locker, 0);
+#endif
 }
 
 /*********************************************************************//**
@@ -2423,7 +2399,7 @@ row_merge_rename_tables(
 {
 	ulint		err	= DB_ERROR;
 	pars_info_t*	info;
-	char		old_name[MAX_FULL_NAME_LEN + 1];
+	char		old_name[MAX_TABLE_NAME_LEN + 1];
 
 	ut_ad(trx->mysql_thread_id == os_thread_get_curr_id());
 	ut_ad(old_table != new_table);
@@ -2438,7 +2414,7 @@ row_merge_rename_tables(
 		ut_print_timestamp(stderr);
 		fprintf(stderr, "InnoDB: too long table name: '%s', "
 			"max length is %d\n", old_table->name,
-			MAX_FULL_NAME_LEN);
+			MAX_TABLE_NAME_LEN);
 		ut_error;
 	}
 
@@ -2670,7 +2646,7 @@ row_merge_build_indexes(
 		row_merge_file_create(&merge_files[i]);
 	}
 
-	tmpfd = row_merge_file_create_low();
+	tmpfd = innobase_mysql_tmpfile();
 
 	/* Reset the MySQL row buffer that is used when reporting
 	duplicate keys. */
@@ -2712,7 +2688,7 @@ row_merge_build_indexes(
 	}
 
 func_exit:
-	row_merge_file_destroy_low(tmpfd);
+	close(tmpfd);
 
 	for (i = 0; i < n_indexes; i++) {
 		row_merge_file_destroy(&merge_files[i]);
