@@ -499,11 +499,8 @@ Purges an update of an existing record. Also purges an update of a delete
 marked record if that record contained an externally stored field. */
 static
 void
-row_purge_upd_exist_or_extern_func(
-/*===============================*/
-#ifdef UNIV_DEBUG
-	const que_thr_t*thr,	/*!< in: query thread */
-#endif /* UNIV_DEBUG */
+row_purge_upd_exist_or_extern(
+/*==========================*/
 	purge_node_t*	node)	/*!< in: row purge node */
 {
 	mem_heap_t*	heap;
@@ -528,8 +525,8 @@ row_purge_upd_exist_or_extern_func(
 	while (node->index != NULL) {
 		index = node->index;
 
-		if (row_upd_changes_ord_field_binary(node->index, node->update,
-						     thr, NULL, NULL)) {
+		if (row_upd_changes_ord_field_binary(NULL, node->index,
+						     node->update)) {
 			/* Build the older version of the index entry */
 			entry = row_build_index_entry(node->row, NULL,
 						      index, heap);
@@ -611,14 +608,6 @@ skip_secondaries:
 	}
 }
 
-#ifdef UNIV_DEBUG
-# define row_purge_upd_exist_or_extern(thr,node)	\
-	row_purge_upd_exist_or_extern_func(thr,node)
-#else /* UNIV_DEBUG */
-# define row_purge_upd_exist_or_extern(thr,node)	\
-	row_purge_upd_exist_or_extern_func(node)
-#endif /* UNIV_DEBUG */
-
 /***********************************************************//**
 Parses the row reference and other info in a modify undo log record.
 @return TRUE if purge operation required: NOTE that then the CALLER
@@ -725,32 +714,47 @@ err_exit:
 /***********************************************************//**
 Fetches an undo log record and does the purge for the recorded operation.
 If none left, or the current purge completed, returns the control to the
-parent node, which is always a query thread node. */
-static __attribute__((nonnull))
-void
+parent node, which is always a query thread node.
+@return	DB_SUCCESS if operation successfully completed, else error code */
+static
+ulint
 row_purge(
 /*======*/
 	purge_node_t*	node,	/*!< in: row purge node */
 	que_thr_t*	thr)	/*!< in: query thread */
 {
+	roll_ptr_t	roll_ptr;
+	ibool		purge_needed;
 	ibool		updated_extern;
+	trx_t*		trx;
 
-	ut_ad(node);
-	ut_ad(thr);
+	ut_ad(node && thr);
 
-	node->undo_rec = trx_purge_fetch_next_rec(&node->roll_ptr,
-						  &node->reservation,
+	trx = thr_get_trx(thr);
+
+	node->undo_rec = trx_purge_fetch_next_rec(&roll_ptr,
+						  &(node->reservation),
 						  node->heap);
 	if (!node->undo_rec) {
 		/* Purge completed for this query thread */
 
 		thr->run_node = que_node_get_parent(node);
 
-		return;
+		return(DB_SUCCESS);
 	}
 
-	if (node->undo_rec != &trx_purge_dummy_rec
-	    && row_purge_parse_undo_rec(node, &updated_extern, thr)) {
+	node->roll_ptr = roll_ptr;
+
+	if (node->undo_rec == &trx_purge_dummy_rec) {
+		purge_needed = FALSE;
+	} else {
+		purge_needed = row_purge_parse_undo_rec(node, &updated_extern,
+							thr);
+		/* If purge_needed == TRUE, we must also remember to unfreeze
+		data dictionary! */
+	}
+
+	if (purge_needed) {
 		node->found_clust = FALSE;
 
 		node->index = dict_table_get_next_index(
@@ -762,14 +766,14 @@ row_purge(
 		} else if (updated_extern
 			   || node->rec_type == TRX_UNDO_UPD_EXIST_REC) {
 
-			row_purge_upd_exist_or_extern(thr, node);
+			row_purge_upd_exist_or_extern(node);
 		}
 
 		if (node->found_clust) {
 			btr_pcur_close(&(node->pcur));
 		}
 
-		row_mysql_unfreeze_data_dictionary(thr_get_trx(thr));
+		row_mysql_unfreeze_data_dictionary(trx);
 	}
 
 	/* Do some cleanup */
@@ -777,6 +781,8 @@ row_purge(
 	mem_heap_empty(node->heap);
 
 	thr->run_node = node;
+
+	return(DB_SUCCESS);
 }
 
 /***********************************************************//**
@@ -790,6 +796,9 @@ row_purge_step(
 	que_thr_t*	thr)	/*!< in: query thread */
 {
 	purge_node_t*	node;
+#ifdef UNIV_DEBUG
+	ulint		err;
+#endif /* UNIV_DEBUG */
 
 	ut_ad(thr);
 
@@ -797,7 +806,14 @@ row_purge_step(
 
 	ut_ad(que_node_get_type(node) == QUE_NODE_PURGE);
 
+#ifdef UNIV_DEBUG
+	err =
+#endif /* UNIV_DEBUG */
 	row_purge(node, thr);
 
+#ifdef UNIV_DEBUG
+	ut_a(err == DB_SUCCESS);
+#endif /* UNIV_DEBUG */
+
 	return(thr);
 }
