@@ -85,9 +85,9 @@ Created 2/16/1996 Heikki Tuuri
 # include "row0row.h"
 # include "row0mysql.h"
 # include "btr0pcur.h"
+# include "thr0loc.h"
 # include "os0sync.h" /* for INNODB_RW_LOCKS_USE_ATOMICS */
 # include "zlib.h" /* for ZLIB_VERSION */
-#include "xtrabackup_api.h"
 
 #include <errno.h>
 #include <unistd.h>
@@ -127,9 +127,9 @@ UNIV_INTERN enum srv_shutdown_state	srv_shutdown_state = SRV_SHUTDOWN_NONE;
 static os_file_t	files[1000];
 
 /** io_handler_thread parameters for thread identification */
-static ulint		n[SRV_MAX_N_IO_THREADS + 7];
+static ulint		n[SRV_MAX_N_IO_THREADS + 6];
 /** io_handler_thread identifiers */
-static os_thread_id_t	thread_ids[SRV_MAX_N_IO_THREADS + 7];
+static os_thread_id_t	thread_ids[SRV_MAX_N_IO_THREADS + 6];
 
 /** We use this mutex to test the return value of pthread_mutex_trylock
    on successful locking. HP-UX does NOT return 0, though Linux et al do. */
@@ -555,6 +555,7 @@ srv_calc_high32(
 /*********************************************************************//**
 Creates or opens the log files and closes them.
 @return	DB_SUCCESS or error code */
+static
 ulint
 open_or_create_log_file(
 /*====================*/
@@ -707,6 +708,7 @@ open_or_create_log_file(
 /*********************************************************************//**
 Creates or opens database data files and closes them.
 @return	DB_SUCCESS or error code */
+static
 ulint
 open_or_create_data_files(
 /*======================*/
@@ -1040,12 +1042,6 @@ innobase_start_or_create_for_mysql(void)
 		));
 #endif
 
-#ifdef UNIV_BLOB_DEBUG
-	fprintf(stderr,
-		"InnoDB: !!!!!!!! UNIV_BLOB_DEBUG switched on !!!!!!!!!\n"
-		"InnoDB: Server restart may fail with UNIV_BLOB_DEBUG\n");
-#endif /* UNIV_BLOB_DEBUG */
-
 #ifdef UNIV_SYNC_DEBUG
         drizzled::errmsg_printf(drizzled::error::INFO,
                                 _("InnoDB: !!!!!!!! UNIV_SYNC_DEBUG switched on !!!!!!!!!\n"));
@@ -1157,9 +1153,6 @@ innobase_start_or_create_for_mysql(void)
 	} else if (0 == ut_strcmp(srv_file_flush_method_str, "O_DIRECT")) {
 		srv_unix_file_flush_method = SRV_UNIX_O_DIRECT;
 
-	} else if (0 == ut_strcmp(srv_file_flush_method_str, "ALL_O_DIRECT")) {
-		srv_unix_file_flush_method = SRV_UNIX_ALL_O_DIRECT;
-
 	} else if (0 == ut_strcmp(srv_file_flush_method_str, "littlesync")) {
 		srv_unix_file_flush_method = SRV_UNIX_LITTLESYNC;
 
@@ -1266,16 +1259,13 @@ innobase_start_or_create_for_mysql(void)
 
 	ut_a(srv_n_file_io_threads <= SRV_MAX_N_IO_THREADS);
 
-	io_limit = 8 * SRV_N_PENDING_IOS_PER_THREAD;
-
-	/* On Windows when using native aio the number of aio requests
-	that a thread can handle at a given time is limited to 32
-	i.e.: SRV_N_PENDING_IOS_PER_THREAD */
-# ifdef __WIN__
-	if (srv_use_native_aio) {
+	/* TODO: Investigate if SRV_N_PENDING_IOS_PER_THREAD (32) limit
+	still applies to windows. */
+	if (!srv_use_native_aio) {
+		io_limit = 8 * SRV_N_PENDING_IOS_PER_THREAD;
+	} else {
 		io_limit = SRV_N_PENDING_IOS_PER_THREAD;
 	}
-# endif /* __WIN__ */
 
 	os_aio_init(io_limit,
 		    srv_n_read_io_threads,
@@ -1300,7 +1290,7 @@ innobase_start_or_create_for_mysql(void)
         drizzled::errmsg_printf(drizzled::error::INFO, "InnoDB: Completed initialization of buffer pool");
 
 	if (err != DB_SUCCESS) {
-          drizzled::errmsg_printf(drizzled::error::ERROR, "InnoDB: Fatal error: cannot allocate memory for the buffer pool");
+          drizzled::errmsg_printf(drizzled::error::ERROR, "InnoDB: Fatal error: cannot allocate the memory for the buffer pool");
 
           return(DB_ERROR);
 	}
@@ -1340,11 +1330,9 @@ innobase_start_or_create_for_mysql(void)
 	}
 #endif /* UNIV_LOG_ARCHIVE */
 
-	if (sizeof(ulint) == 4
-	    && srv_n_log_files * srv_log_file_size
-	    >= (1UL << (32 - UNIV_PAGE_SIZE_SHIFT))) {
-		drizzled::errmsg_printf(drizzled::error::ERROR,
-				  "InnoDB: Error: combined size of log files must be < 4 GB on 32-bit systems\n");
+	if (srv_n_log_files * srv_log_file_size >= 262144) {
+          drizzled::errmsg_printf(drizzled::error::ERROR,
+                                  "InnoDB: Error: combined size of log files must be < 4 GB");
 
 		return(DB_ERROR);
 	}
@@ -1353,7 +1341,7 @@ innobase_start_or_create_for_mysql(void)
 
 	for (i = 0; i < srv_n_data_files; i++) {
 #ifndef __WIN__
-		if (sizeof(off_t) < 5 && srv_data_file_sizes[i] >= (1UL << (32 - UNIV_PAGE_SIZE_SHIFT))) {
+		if (sizeof(off_t) < 5 && srv_data_file_sizes[i] >= 262144) {
                   drizzled::errmsg_printf(drizzled::error::ERROR,
                                           "InnoDB: Error: file size must be < 4 GB with this MySQL binary and operating system combination,"
                                           " in some OS's < 2 GB\n");
@@ -1570,10 +1558,6 @@ innobase_start_or_create_for_mysql(void)
 		are initialized in trx_sys_init_at_db_start(). */
 
 		recv_recovery_from_checkpoint_finish();
-
-                if (srv_apply_log_only)
-                  goto skip_processes;
-
 		if (srv_force_recovery < SRV_FORCE_NO_IBUF_MERGE) {
 			/* The following call is necessary for the insert
 			buffer to work with multiple tablespaces. We must
@@ -1678,10 +1662,6 @@ innobase_start_or_create_for_mysql(void)
 	os_thread_create(&srv_monitor_thread, NULL,
 			 thread_ids + 4 + SRV_MAX_N_IO_THREADS);
 
-	/* Create the thread which automaticaly dumps/restore buffer pool */
-	os_thread_create(&srv_LRU_dump_restore_thread, NULL,
-			 thread_ids + 5 + SRV_MAX_N_IO_THREADS);
-
 	srv_is_being_started = FALSE;
 
 	err = dict_create_or_check_foreign_constraint_tables();
@@ -1705,24 +1685,6 @@ innobase_start_or_create_for_mysql(void)
 		os_thread_create(&srv_purge_thread, NULL, NULL);
 	}
 
-	/* Wait for the purge and master thread to startup. */
-
-	while (srv_shutdown_state == SRV_SHUTDOWN_NONE) {
-		if (srv_thread_has_reserved_slot(SRV_MASTER) == ULINT_UNDEFINED
-		    || (srv_n_purge_threads == 1
-			&& srv_thread_has_reserved_slot(SRV_WORKER)
-			== ULINT_UNDEFINED)) {
-
-			ut_print_timestamp(stderr);
-			fprintf(stderr, "  InnoDB: "
-				"Waiting for the background threads to "
-				"start\n");
-			os_thread_sleep(1000000);
-		} else {
-			break;
-		}
-	}
-
 #ifdef UNIV_DEBUG
 	/* buf_debug_prints = TRUE; */
 #endif /* UNIV_DEBUG */
@@ -1862,7 +1824,6 @@ innobase_start_or_create_for_mysql(void)
 		ibuf_update_max_tablespace_id();
 	}
 
-skip_processes:
 	srv_file_per_table = srv_file_per_table_original_value;
 
 	srv_was_started = TRUE;
@@ -1999,6 +1960,7 @@ innobase_shutdown_for_mysql(void)
 	ibuf_close();
 	log_shutdown();
 	lock_sys_close();
+	thr_local_close();
 	trx_sys_file_format_close();
 	trx_sys_close();
 
