@@ -1,6 +1,6 @@
 /*****************************************************************************
 
-Copyright (c) 1995, 2011, Oracle and/or its affiliates. All Rights Reserved.
+Copyright (C) 1995, 2009, Innobase Oy. All Rights Reserved.
 Copyright (C) 2008, Google Inc.
 
 Portions of this file contain modifications contributed and copyrighted by
@@ -40,7 +40,6 @@ Created 9/5/1995 Heikki Tuuri
 #include "os0sync.h"
 #include "os0file.h"
 #include "srv0srv.h"
-#include "ha_prototypes.h"
 
 /*
 			WAIT ARRAY
@@ -479,8 +478,8 @@ sync_array_cell_print(
 	fprintf(file,
 		"--Thread %lu has waited at %s line %lu"
 		" for %.2f seconds the semaphore:\n",
-		(ulong) os_thread_pf(cell->thread),
-		innobase_basename(cell->file), (ulong) cell->line,
+		(ulong) os_thread_pf(cell->thread), cell->file,
+		(ulong) cell->line,
 		difftime(time(NULL), cell->reservation_time));
 
 	if (type == SYNC_MUTEX) {
@@ -494,8 +493,7 @@ sync_array_cell_print(
 			"Last time reserved in file %s line %lu, "
 #endif /* UNIV_SYNC_DEBUG */
 			"waiters flag %lu\n",
-			(void*) mutex, innobase_basename(mutex->cfile_name),
-			(ulong) mutex->cline,
+			(void*) mutex, mutex->cfile_name, (ulong) mutex->cline,
 			(ulong) mutex->lock_word,
 #ifdef UNIV_SYNC_DEBUG
 			mutex->file_name, (ulong) mutex->line,
@@ -514,7 +512,7 @@ sync_array_cell_print(
 
 		fprintf(file,
 			" RW-latch at %p created in file %s line %lu\n",
-			(void*) rwlock, innobase_basename(rwlock->cfile_name),
+			(void*) rwlock, rwlock->cfile_name,
 			(ulong) rwlock->cline);
 		writer = rw_lock_get_writer(rwlock);
 		if (writer != RW_LOCK_NOT_LOCKED) {
@@ -535,7 +533,7 @@ sync_array_cell_print(
 			(ulong) rw_lock_get_reader_count(rwlock),
 			(ulong) rwlock->waiters,
 			rwlock->lock_word,
-			innobase_basename(rwlock->last_s_file_name),
+			rwlock->last_s_file_name,
 			(ulong) rwlock->last_s_line,
 			rwlock->last_x_file_name,
 			(ulong) rwlock->last_x_line);
@@ -592,6 +590,9 @@ sync_array_deadlock_step(
 	ulint		depth)	/*!< in: recursion depth */
 {
 	sync_cell_t*	new;
+	ibool		ret;
+
+	depth++;
 
 	if (pass != 0) {
 		/* If pass != 0, then we do not know which threads are
@@ -603,7 +604,7 @@ sync_array_deadlock_step(
 
 	new = sync_array_find_thread(arr, thread);
 
-	if (UNIV_UNLIKELY(new == start)) {
+	if (new == start) {
 		/* Stop running of other threads */
 
 		ut_dbg_stop_threads = TRUE;
@@ -615,7 +616,11 @@ sync_array_deadlock_step(
 		return(TRUE);
 
 	} else if (new) {
-		return(sync_array_detect_deadlock(arr, start, new, depth + 1));
+		ret = sync_array_detect_deadlock(arr, start, new, depth);
+
+		if (ret) {
+			return(TRUE);
+		}
 	}
 	return(FALSE);
 }
@@ -716,7 +721,7 @@ print:
 					fprintf(stderr, "rw-lock %p ",
 						(void*) lock);
 					sync_array_cell_print(stderr, cell);
-					rw_lock_debug_print(stderr, debug);
+					rw_lock_debug_print(debug);
 					return(TRUE);
 				}
 			}
@@ -915,10 +920,8 @@ Prints warnings of long semaphore waits to stderr.
 @return	TRUE if fatal semaphore wait threshold was exceeded */
 UNIV_INTERN
 ibool
-sync_array_print_long_waits(
-/*========================*/
-	os_thread_id_t*	waiter,	/*!< out: longest waiting thread */
-	const void**	sema)	/*!< out: longest-waited-for semaphore */
+sync_array_print_long_waits(void)
+/*=============================*/
 {
 	sync_cell_t*	cell;
 	ibool		old_val;
@@ -926,52 +929,24 @@ sync_array_print_long_waits(
 	ulint		i;
 	ulint		fatal_timeout = srv_fatal_semaphore_wait_threshold;
 	ibool		fatal = FALSE;
-	double		longest_diff = 0;
-
-#ifdef UNIV_DEBUG_VALGRIND
-	/* Increase the timeouts if running under valgrind because it executes
-	extremely slowly. UNIV_DEBUG_VALGRIND does not necessary mean that
-	we are running under valgrind but we have no better way to tell.
-	See Bug#58432 innodb.innodb_bug56143 fails under valgrind
-	for an example */
-# define SYNC_ARRAY_TIMEOUT	2400
-	fatal_timeout *= 10;
-#else
-# define SYNC_ARRAY_TIMEOUT	240
-#endif
 
 	for (i = 0; i < sync_primary_wait_array->n_cells; i++) {
 
-		double	diff;
-		void*	wait_object;
-
 		cell = sync_array_get_nth_cell(sync_primary_wait_array, i);
 
-		wait_object = cell->wait_object;
-
-		if (wait_object == NULL || !cell->waiting) {
-
-			continue;
-		}
-
-		diff = difftime(time(NULL), cell->reservation_time);
-
-		if (diff > SYNC_ARRAY_TIMEOUT) {
+		if (cell->wait_object != NULL && cell->waiting
+		    && difftime(time(NULL), cell->reservation_time) > 240) {
 			fputs("InnoDB: Warning: a long semaphore wait:\n",
 			      stderr);
 			sync_array_cell_print(stderr, cell);
 			noticed = TRUE;
 		}
 
-		if (diff > fatal_timeout) {
+		if (cell->wait_object != NULL && cell->waiting
+		    && difftime(time(NULL), cell->reservation_time)
+		    > fatal_timeout) {
 			fatal = TRUE;
 		}
-
-		if (diff > longest_diff) {
-			longest_diff = diff;
-			*sema = wait_object;
-			*waiter = cell->thread;
-		}
 	}
 
 	if (noticed) {
@@ -1002,8 +977,6 @@ sync_array_print_long_waits(
 			" to the standard error stream\n");
 	}
 
-#undef SYNC_ARRAY_TIMEOUT
-
 	return(fatal);
 }
 
