@@ -1,6 +1,6 @@
 /*****************************************************************************
 
-Copyright (c) 1995, 2011, Innobase Oy. All Rights Reserved.
+Copyright (C) 1995, 2010, Innobase Oy. All Rights Reserved.
 Copyright (C) 2008, Google Inc.
 
 Portions of this file contain modifications contributed and copyrighted by
@@ -43,7 +43,6 @@ Created 9/5/1995 Heikki Tuuri
 #ifdef UNIV_SYNC_DEBUG
 # include "srv0start.h" /* srv_is_being_started */
 #endif /* UNIV_SYNC_DEBUG */
-#include "ha_prototypes.h"
 
 /*
 	REASONS FOR IMPLEMENTING THE SPIN LOCK MUTEX
@@ -195,7 +194,6 @@ typedef struct sync_level_struct	sync_level_t;
 typedef struct sync_thread_struct	sync_thread_t;
 
 #ifdef UNIV_SYNC_DEBUG
-
 /** The latch levels currently owned by threads are stored in this data
 structure; the size of this array is OS_THREAD_MAX_N */
 
@@ -224,40 +222,21 @@ UNIV_INTERN mysql_pfs_key_t	mutex_list_mutex_key;
 UNIV_INTERN ibool	sync_order_checks_on	= FALSE;
 #endif /* UNIV_SYNC_DEBUG */
 
-/** Number of slots reserved for each OS thread in the sync level array */
-static const ulint SYNC_THREAD_N_LEVELS = 10000;
-
-typedef struct sync_arr_struct sync_arr_t;
-
-/** Array for tracking sync levels per thread. */
-struct sync_arr_struct {
-	ulint		in_use;		/*!< Number of active cells */
-	ulint		n_elems;	/*!< Number of elements in the array */
-	ulint		max_elems;	/*!< Maximum elements */
-	ulint		next_free;	/*!< ULINT_UNDEFINED or index of next
-					free slot */
-	sync_level_t*	elems;		/*!< Array elements */
-};
-
 /** Mutexes or rw-locks held by a thread */
 struct sync_thread_struct{
-	os_thread_id_t	id;		/*!< OS thread id */
-	sync_arr_t*	levels;		/*!< level array for this thread; if
-					this is NULL this slot is unused */
+	os_thread_id_t	id;	/*!< OS thread id */
+	sync_level_t*	levels;	/*!< level array for this thread; if
+				this is NULL this slot is unused */
 };
 
+/** Number of slots reserved for each OS thread in the sync level array */
+#define SYNC_THREAD_N_LEVELS	10000
+
 /** An acquired mutex or rw-lock and its level in the latching order */
 struct sync_level_struct{
-	void*		latch;		/*!< pointer to a mutex or an
-					rw-lock; NULL means that
-					the slot is empty */
-	ulint		level;		/*!< level of the latch in the
-					latching order. This field is
-					overloaded to serve as a node in a
-					linked list of free nodes too. When
-					latch == NULL then this will contain
-					the ordinal value of the next free
-					element */
+	void*	latch;	/*!< pointer to a mutex or an rw-lock; NULL means that
+			the slot is empty */
+	ulint	level;	/*!< level of the latch in the latching order */
 };
 
 /******************************************************************//**
@@ -545,8 +524,7 @@ spin_loop:
 		"Thread %lu spin wait mutex at %p"
 		" cfile %s cline %lu rnds %lu\n",
 		(ulong) os_thread_pf(os_thread_get_curr_id()), (void*) mutex,
-		innobase_basename(mutex->cfile_name),
-		(ulong) mutex->cline, (ulong) i);
+		mutex->cfile_name, (ulong) mutex->cline, (ulong) i);
 #endif
 
 	mutex_spin_round_count += i;
@@ -623,8 +601,7 @@ spin_loop:
 	fprintf(stderr,
 		"Thread %lu OS wait mutex at %p cfile %s cline %lu rnds %lu\n",
 		(ulong) os_thread_pf(os_thread_get_curr_id()), (void*) mutex,
-		innobase_basename(mutex->cfile_name),
-		(ulong) mutex->cline, (ulong) i);
+		mutex->cfile_name, (ulong) mutex->cline, (ulong) i);
 #endif
 
 	mutex_os_wait_count++;
@@ -768,28 +745,27 @@ mutex_n_reserved(void)
 /*==================*/
 {
 	mutex_t*	mutex;
-	ulint		count	= 0;
+	ulint		count		= 0;
 
 	mutex_enter(&mutex_list_mutex);
 
-	for (mutex = UT_LIST_GET_FIRST(mutex_list);
-	     mutex != NULL;
-	     mutex = UT_LIST_GET_NEXT(list, mutex)) {
+	mutex = UT_LIST_GET_FIRST(mutex_list);
 
+	while (mutex != NULL) {
 		if (mutex_get_lock_word(mutex) != 0) {
 
 			count++;
 		}
+
+		mutex = UT_LIST_GET_NEXT(list, mutex);
 	}
 
 	mutex_exit(&mutex_list_mutex);
 
 	ut_a(count >= 1);
 
-	/* Subtract one, because this function itself was holding
-	one mutex (mutex_list_mutex) */
-
-	return(count - 1);
+	return(count - 1); /* Subtract one, because this function itself
+			   was holding one mutex (mutex_list_mutex) */
 }
 
 /******************************************************************//**
@@ -804,6 +780,20 @@ sync_all_freed(void)
 	return(mutex_n_reserved() + rw_lock_n_locked() == 0);
 }
 
+/******************************************************************//**
+Gets the value in the nth slot in the thread level arrays.
+@return	pointer to thread slot */
+static
+sync_thread_t*
+sync_thread_level_arrays_get_nth(
+/*=============================*/
+	ulint	n)	/*!< in: slot number */
+{
+	ut_ad(n < OS_THREAD_MAX_N);
+
+	return(sync_thread_level_arrays + n);
+}
+
 /******************************************************************//**
 Looks for the thread slot for the calling thread.
 @return	pointer to thread slot, NULL if not found */
@@ -813,15 +803,15 @@ sync_thread_level_arrays_find_slot(void)
 /*====================================*/
 
 {
-	ulint		i;
+	sync_thread_t*	slot;
 	os_thread_id_t	id;
+	ulint		i;
 
 	id = os_thread_get_curr_id();
 
 	for (i = 0; i < OS_THREAD_MAX_N; i++) {
-		sync_thread_t*	slot;
 
-		slot = &sync_thread_level_arrays[i];
+		slot = sync_thread_level_arrays_get_nth(i);
 
 		if (slot->levels && os_thread_eq(slot->id, id)) {
 
@@ -841,12 +831,12 @@ sync_thread_level_arrays_find_free(void)
 /*====================================*/
 
 {
+	sync_thread_t*	slot;
 	ulint		i;
 
 	for (i = 0; i < OS_THREAD_MAX_N; i++) {
-		sync_thread_t*	slot;
 
-		slot = &sync_thread_level_arrays[i];
+		slot = sync_thread_level_arrays_get_nth(i);
 
 		if (slot->levels == NULL) {
 
@@ -859,45 +849,18 @@ sync_thread_level_arrays_find_free(void)
 
 /******************************************************************//**
 Gets the value in the nth slot in the thread level array.
-Print warning. */
+@return	pointer to level slot */
 static
-void
-sync_print_warning(
-/*===============*/
-	const sync_level_t*	slot)	/*!< in: slot for which to
-					print warning */
+sync_level_t*
+sync_thread_levels_get_nth(
+/*=======================*/
+	sync_level_t*	arr,	/*!< in: pointer to level array for an OS
+				thread */
+	ulint		n)	/*!< in: slot number */
 {
-	mutex_t*	mutex;
+	ut_ad(n < SYNC_THREAD_N_LEVELS);
 
-	mutex = slot->latch;
-
-	if (mutex->magic_n == MUTEX_MAGIC_N) {
-		fprintf(stderr,
-			"Mutex created at %s %lu\n",
-			innobase_basename(mutex->cfile_name),
-			(ulong) mutex->cline);
-
-		if (mutex_get_lock_word(mutex) != 0) {
-			ulint		line;
-			const char*	file_name;
-			os_thread_id_t	thread_id;
-
-			mutex_get_debug_info(
-				mutex, &file_name, &line, &thread_id);
-
-			fprintf(stderr,
-				"InnoDB: Locked mutex:"
-				" addr %p thread %ld file %s line %ld\n",
-				(void*) mutex, os_thread_pf(thread_id),
-				file_name, (ulong) line);
-		} else {
-			fputs("Not locked\n", stderr);
-		}
-	} else {
-		rw_lock_t*	lock = slot->latch;
-
-		rw_lock_print(lock);
-	}
+	return(arr + n);
 }
 
 /******************************************************************//**
@@ -908,29 +871,69 @@ static
 ibool
 sync_thread_levels_g(
 /*=================*/
-	sync_arr_t*	arr,	/*!< in: pointer to level array for an OS
+	sync_level_t*	arr,	/*!< in: pointer to level array for an OS
 				thread */
 	ulint		limit,	/*!< in: level limit */
 	ulint		warn)	/*!< in: TRUE=display a diagnostic message */
 {
+	sync_level_t*	slot;
+	rw_lock_t*	lock;
+	mutex_t*	mutex;
 	ulint		i;
 
-	for (i = 0; i < arr->n_elems; i++) {
-		const sync_level_t*	slot;
+	for (i = 0; i < SYNC_THREAD_N_LEVELS; i++) {
 
-		slot = &arr->elems[i];
+		slot = sync_thread_levels_get_nth(arr, i);
+
+		if (slot->latch != NULL) {
+			if (slot->level <= limit) {
+
+				if (!warn) {
+
+					return(FALSE);
+				}
+
+				lock = slot->latch;
+				mutex = slot->latch;
 
-		if (slot->latch != NULL && slot->level <= limit) {
-			if (warn) {
 				fprintf(stderr,
 					"InnoDB: sync levels should be"
 					" > %lu but a level is %lu\n",
 					(ulong) limit, (ulong) slot->level);
-				sync_print_warning(slot);
+
+				if (mutex->magic_n == MUTEX_MAGIC_N) {
+					fprintf(stderr,
+						"Mutex created at %s %lu\n",
+						mutex->cfile_name,
+						(ulong) mutex->cline);
+
+					if (mutex_get_lock_word(mutex) != 0) {
+						const char*	file_name;
+						ulint		line;
+						os_thread_id_t	thread_id;
+
+						mutex_get_debug_info(
+							mutex, &file_name,
+							&line, &thread_id);
+
+						fprintf(stderr,
+							"InnoDB: Locked mutex:"
+							" addr %p thread %ld"
+							" file %s line %ld\n",
+							(void*) mutex,
+							os_thread_pf(
+								thread_id),
+							file_name,
+							(ulong) line);
+					} else {
+						fputs("Not locked\n", stderr);
+					}
+				} else {
+					rw_lock_print(lock);
+				}
+
+				return(FALSE);
 			}
-
-			return(FALSE);
-
 		}
 	}
 
@@ -939,28 +942,31 @@ sync_thread_levels_g(
 
 /******************************************************************//**
 Checks if the level value is stored in the level array.
-@return	slot if found or NULL */
+@return	TRUE if stored */
 static
-const sync_level_t*
+ibool
 sync_thread_levels_contain(
 /*=======================*/
-	sync_arr_t*	arr,	/*!< in: pointer to level array for an OS
+	sync_level_t*	arr,	/*!< in: pointer to level array for an OS
 				thread */
 	ulint		level)	/*!< in: level */
 {
+	sync_level_t*	slot;
 	ulint		i;
 
-	for (i = 0; i < arr->n_elems; i++) {
-		const sync_level_t*	slot;
+	for (i = 0; i < SYNC_THREAD_N_LEVELS; i++) {
 
-		slot = &arr->elems[i];
+		slot = sync_thread_levels_get_nth(arr, i);
 
-		if (slot->latch != NULL && slot->level == level) {
-			return(slot);
+		if (slot->latch != NULL) {
+			if (slot->level == level) {
+
+				return(TRUE);
+			}
 		}
 	}
 
-	return(NULL);
+	return(FALSE);
 }
 
 /******************************************************************//**
@@ -974,9 +980,10 @@ sync_thread_levels_contains(
 	ulint	level)			/*!< in: latching order level
 					(SYNC_DICT, ...)*/
 {
-	ulint		i;
-	sync_arr_t*	arr;
+	sync_level_t*	arr;
 	sync_thread_t*	thread_slot;
+	sync_level_t*	slot;
+	ulint		i;
 
 	if (!sync_order_checks_on) {
 
@@ -996,10 +1003,9 @@ sync_thread_levels_contains(
 
 	arr = thread_slot->levels;
 
-	for (i = 0; i < arr->n_elems; i++) {
-		sync_level_t*	slot;
+	for (i = 0; i < SYNC_THREAD_N_LEVELS; i++) {
 
-		slot = &arr->elems[i];
+		slot = sync_thread_levels_get_nth(arr, i);
 
 		if (slot->latch != NULL && slot->level == level) {
 
@@ -1025,9 +1031,10 @@ sync_thread_levels_nonempty_gen(
 					also purge_is_running mutex is
 					allowed */
 {
-	ulint		i;
-	sync_arr_t*	arr;
+	sync_level_t*	arr;
 	sync_thread_t*	thread_slot;
+	sync_level_t*	slot;
+	ulint		i;
 
 	if (!sync_order_checks_on) {
 
@@ -1047,10 +1054,9 @@ sync_thread_levels_nonempty_gen(
 
 	arr = thread_slot->levels;
 
-	for (i = 0; i < arr->n_elems; ++i) {
-		const sync_level_t*	slot;
+	for (i = 0; i < SYNC_THREAD_N_LEVELS; i++) {
 
-		slot = &arr->elems[i];
+		slot = sync_thread_levels_get_nth(arr, i);
 
 		if (slot->latch != NULL
 		    && (!dict_mutex_allowed
@@ -1092,10 +1098,10 @@ sync_thread_add_level(
 	ulint	level)	/*!< in: level in the latching order; if
 			SYNC_LEVEL_VARYING, nothing is done */
 {
-	ulint		i;
- 	sync_level_t*	slot;
-	sync_arr_t*	array;
+	sync_level_t*	array;
+	sync_level_t*	slot;
 	sync_thread_t*	thread_slot;
+	ulint		i;
 
 	if (!sync_order_checks_on) {
 
@@ -1120,22 +1126,20 @@ sync_thread_add_level(
 	thread_slot = sync_thread_level_arrays_find_slot();
 
 	if (thread_slot == NULL) {
-		ulint	sz;
-
-		sz = sizeof(*array)
-		   + (sizeof(*array->elems) * SYNC_THREAD_N_LEVELS);
-
 		/* We have to allocate the level array for a new thread */
-		array = calloc(sz, sizeof(char));
-		ut_a(array != NULL);
-
-		array->next_free = ULINT_UNDEFINED;
-		array->max_elems = SYNC_THREAD_N_LEVELS;
-		array->elems = (sync_level_t*) &array[1];
+		array = ut_malloc(sizeof(sync_level_t) * SYNC_THREAD_N_LEVELS);
 
 		thread_slot = sync_thread_level_arrays_find_free();
-		thread_slot->levels = array;
+
 		thread_slot->id = os_thread_get_curr_id();
+		thread_slot->levels = array;
+
+		for (i = 0; i < SYNC_THREAD_N_LEVELS; i++) {
+
+			slot = sync_thread_levels_get_nth(array, i);
+
+			slot->latch = NULL;
+		}
 	}
 
 	array = thread_slot->levels;
@@ -1176,7 +1180,7 @@ sync_thread_add_level(
 	case SYNC_RSEG:
 	case SYNC_TRX_UNDO:
 	case SYNC_PURGE_LATCH:
-	case SYNC_PURGE_QUEUE:
+	case SYNC_PURGE_SYS:
 	case SYNC_DICT_AUTOINC_MUTEX:
 	case SYNC_DICT_OPERATION:
 	case SYNC_DICT_HEADER:
@@ -1243,16 +1247,10 @@ sync_thread_add_level(
 		     || sync_thread_levels_g(array, SYNC_FSP, TRUE));
 		break;
 	case SYNC_TRX_UNDO_PAGE:
-		/* Purge is allowed to read in as many UNDO pages as it likes,
-		there was a bogus rule here earlier that forced the caller to
-		acquire the purge_sys_t::mutex. The purge mutex did not really
-		protect anything because it was only ever acquired by the
-		single purge thread. The purge thread can read the UNDO pages
-		without any covering mutex. */
-
 		ut_a(sync_thread_levels_contain(array, SYNC_TRX_UNDO)
 		     || sync_thread_levels_contain(array, SYNC_RSEG)
-		     || sync_thread_levels_g(array, level - 1, TRUE));
+		     || sync_thread_levels_contain(array, SYNC_PURGE_SYS)
+		     || sync_thread_levels_g(array, SYNC_TRX_UNDO_PAGE, TRUE));
 		break;
 	case SYNC_RSEG_HEADER:
 		ut_a(sync_thread_levels_contain(array, SYNC_RSEG));
@@ -1305,26 +1303,19 @@ sync_thread_add_level(
 		ut_error;
 	}
 
-	if (array->next_free == ULINT_UNDEFINED) {
-		ut_a(array->n_elems < array->max_elems);
+	for (i = 0; i < SYNC_THREAD_N_LEVELS; i++) {
 
-		i = array->n_elems++;
-	} else {
-		i = array->next_free;
-		array->next_free = array->elems[i].level;
+		slot = sync_thread_levels_get_nth(array, i);
+
+		if (slot->latch == NULL) {
+			slot->latch = latch;
+			slot->level = level;
+
+			break;
+		}
 	}
 
-	ut_a(i < array->n_elems);
-	ut_a(i != ULINT_UNDEFINED);
-
-	++array->in_use;
-
-	slot = &array->elems[i];
-
-	ut_a(slot->latch == NULL);
-
-	slot->latch = latch;
-	slot->level = level;
+	ut_a(i < SYNC_THREAD_N_LEVELS);
 
 	mutex_exit(&sync_thread_mutex);
 }
@@ -1340,7 +1331,8 @@ sync_thread_reset_level(
 /*====================*/
 	void*	latch)	/*!< in: pointer to a mutex or an rw-lock */
 {
-	sync_arr_t*	array;
+	sync_level_t*	array;
+	sync_level_t*	slot;
 	sync_thread_t*	thread_slot;
 	ulint		i;
 
@@ -1371,37 +1363,17 @@ sync_thread_reset_level(
 
 	array = thread_slot->levels;
 
-	for (i = 0; i < array->n_elems; i++) {
-		sync_level_t*	slot;
+	for (i = 0; i < SYNC_THREAD_N_LEVELS; i++) {
 
-		slot = &array->elems[i];
+		slot = sync_thread_levels_get_nth(array, i);
 
-		if (slot->latch != latch) {
-			continue;
+		if (slot->latch == latch) {
+			slot->latch = NULL;
+
+			mutex_exit(&sync_thread_mutex);
+
+			return(TRUE);
 		}
-
-		slot->latch = NULL;
-
-		/* Update the free slot list. See comment in sync_level_t
-		for the level field. */
-		slot->level = array->next_free;
-		array->next_free = i;
-
-		ut_a(array->in_use >= 1);
-		--array->in_use;
-
-		/* If all cells are idle then reset the free
-		list. The assumption is that this will save
-		time when we need to scan up to n_elems. */
-
-		if (array->in_use == 0) {
-			array->n_elems = 0;
-			array->next_free = ULINT_UNDEFINED;
-		}
-
-		mutex_exit(&sync_thread_mutex);
-
-		return(TRUE);
 	}
 
 	if (((mutex_t*) latch)->magic_n != MUTEX_MAGIC_N) {
@@ -1431,6 +1403,11 @@ void
 sync_init(void)
 /*===========*/
 {
+#ifdef UNIV_SYNC_DEBUG
+	sync_thread_t*	thread_slot;
+	ulint		i;
+#endif /* UNIV_SYNC_DEBUG */
+
 	ut_a(sync_initialized == FALSE);
 
 	sync_initialized = TRUE;
@@ -1444,10 +1421,13 @@ sync_init(void)
 	/* Create the thread latch level array where the latch levels
 	are stored for each OS thread */
 
-	sync_thread_level_arrays = calloc(
-		sizeof(sync_thread_t), OS_THREAD_MAX_N);
-	ut_a(sync_thread_level_arrays != NULL);
+	sync_thread_level_arrays = ut_malloc(OS_THREAD_MAX_N
+					     * sizeof(sync_thread_t));
+	for (i = 0; i < OS_THREAD_MAX_N; i++) {
 
+		thread_slot = sync_thread_level_arrays_get_nth(i);
+		thread_slot->levels = NULL;
+	}
 #endif /* UNIV_SYNC_DEBUG */
 	/* Init the mutex list and create the mutex to protect it. */
 
@@ -1474,34 +1454,6 @@ sync_init(void)
 #endif /* UNIV_SYNC_DEBUG */
 }
 
-#ifdef UNIV_SYNC_DEBUG
-/******************************************************************//**
-Frees all debug memory. */
-static
-void
-sync_thread_level_arrays_free(void)
-/*===============================*/
-
-{
-	ulint	i;
-
-	for (i = 0; i < OS_THREAD_MAX_N; i++) {
-		sync_thread_t*	slot;
-
-		slot = &sync_thread_level_arrays[i];
-
-		/* If this slot was allocated then free the slot memory too. */
-		if (slot->levels != NULL) {
-			free(slot->levels);
-			slot->levels = NULL;
-		}
-	}
-
-	free(sync_thread_level_arrays);
-	sync_thread_level_arrays = NULL;
-}
-#endif /* UNIV_SYNC_DEBUG */
-
 /******************************************************************//**
 Frees the resources in InnoDB's own synchronization data structures. Use
 os_sync_free() after calling this. */
@@ -1514,20 +1466,17 @@ sync_close(void)
 
 	sync_array_free(sync_primary_wait_array);
 
-	for (mutex = UT_LIST_GET_FIRST(mutex_list);
-	     mutex != NULL;
-	     /* No op */) {
+	mutex = UT_LIST_GET_FIRST(mutex_list);
 
+	while (mutex) {
 #ifdef UNIV_MEM_DEBUG
 		if (mutex == &mem_hash_mutex) {
 			mutex = UT_LIST_GET_NEXT(list, mutex);
 			continue;
 		}
 #endif /* UNIV_MEM_DEBUG */
-
 		mutex_free(mutex);
-
-	        mutex = UT_LIST_GET_FIRST(mutex_list);
+		mutex = UT_LIST_GET_FIRST(mutex_list);
 	}
 
 	mutex_free(&mutex_list_mutex);
@@ -1536,8 +1485,6 @@ sync_close(void)
 
 	/* Switch latching order checks on in sync0sync.c */
 	sync_order_checks_on = FALSE;
-
-	sync_thread_level_arrays_free();
 #endif /* UNIV_SYNC_DEBUG */
 
 	sync_initialized = FALSE;	
