@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, Joseph Daly <skinny.moey@gmail.com>
+ * Copyright (C) 2010 Joseph Daly <skinny.moey@gmail.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -84,7 +84,7 @@
  * 
  */
 
-#include "config.h"
+#include <config.h>
 #include "user_commands.h"
 #include "status_vars.h"
 #include "global_stats.h"
@@ -94,6 +94,7 @@
 #include <boost/program_options.hpp>
 #include <drizzled/module/option_map.h>
 #include <drizzled/session.h>
+#include <drizzled/sql_lex.h>
 
 namespace po= boost::program_options;
 using namespace drizzled;
@@ -102,11 +103,14 @@ using namespace std;
 
 static bool sysvar_logging_stats_enabled= true;
 
-static uint32_t sysvar_logging_stats_scoreboard_size= 2000;
+typedef constrained_check<uint32_t, 50000, 10> scoreboard_size_constraint;
+static scoreboard_size_constraint sysvar_logging_stats_scoreboard_size;
 
-static uint32_t sysvar_logging_stats_max_user_count= 500;
+typedef constrained_check<uint32_t, 50000, 100> max_user_count_constraint;
+static max_user_count_constraint sysvar_logging_stats_max_user_count;
 
-static uint32_t sysvar_logging_stats_bucket_count= 10;
+typedef constrained_check<uint32_t, 500, 5> bucket_count_constraint;
+static bucket_count_constraint sysvar_logging_stats_bucket_count;
 
 LoggingStats::LoggingStats(string name_arg) : Logging(name_arg)
 {
@@ -125,7 +129,7 @@ LoggingStats::~LoggingStats()
 void LoggingStats::updateCurrentScoreboard(ScoreboardSlot *scoreboard_slot,
                                            Session *session)
 {
-  enum_sql_command sql_command= session->lex->sql_command;
+  enum_sql_command sql_command= session->lex().sql_command;
 
   scoreboard_slot->getUserCommands()->logCommand(sql_command);
 
@@ -137,6 +141,35 @@ void LoggingStats::updateCurrentScoreboard(ScoreboardSlot *scoreboard_slot,
   scoreboard_slot->getStatusVars()->logStatusVar(session);
 }
 
+bool LoggingStats::resetGlobalScoreboard()
+{
+  cumulative_stats->getGlobalStatusVars()->reset();
+  cumulative_stats->getGlobalStats()->getUserCommands()->reset();
+
+  ScoreBoardVectors *vector_of_scoreboard_vectors=
+    current_scoreboard->getVectorOfScoreboardVectors();
+
+  ScoreBoardVectors::iterator v_of_scoreboard_v_begin_it= vector_of_scoreboard_vectors->begin();
+
+  ScoreBoardVectors::iterator v_of_scoreboard_v_end_it= vector_of_scoreboard_vectors->end();
+
+  for (; v_of_scoreboard_v_begin_it != v_of_scoreboard_v_end_it; ++v_of_scoreboard_v_begin_it)
+  {
+    std::vector<ScoreboardSlot* > *scoreboard_vector= *v_of_scoreboard_v_begin_it;
+
+    std::vector<ScoreboardSlot* >::iterator scoreboard_vector_it= scoreboard_vector->begin();
+    std::vector<ScoreboardSlot* >::iterator scoreboard_vector_end= scoreboard_vector->end();
+    for (; scoreboard_vector_it != scoreboard_vector_end; ++scoreboard_vector_it)
+    {
+      ScoreboardSlot *scoreboard_slot= *scoreboard_vector_it;
+      scoreboard_slot->getStatusVars()->reset();
+      scoreboard_slot->getUserCommands()->reset();
+    }
+  }
+
+  return false;
+}
+
 bool LoggingStats::post(Session *session)
 {
   if (! isEnabled() || (session->getSessionId() == 0))
@@ -178,12 +211,12 @@ bool LoggingStats::postEnd(Session *session)
        the scoreboard would be filled up quickly with invalid users. 
     */
     scoreboard_slot= new ScoreboardSlot();
-    scoreboard_slot->setUser(session->getSecurityContext().getUser());
-    scoreboard_slot->setIp(session->getSecurityContext().getIp());
+    scoreboard_slot->setUser(session->user()->username());
+    scoreboard_slot->setIp(session->user()->address());
   }
 
   scoreboard_slot->getStatusVars()->logStatusVar(session);
-  scoreboard_slot->getStatusVars()->getStatusVarCounters()->connection_time= time(NULL) - session->start_time; 
+  scoreboard_slot->getStatusVars()->getStatusVarCounters()->connection_time= session->getConnectSeconds(); 
 
   cumulative_stats->logUserStats(scoreboard_slot, isInScoreboard);
   cumulative_stats->logGlobalStats(scoreboard_slot);
@@ -221,22 +254,17 @@ static CumulativeUserStatsTool *cumulative_user_stats_tool= NULL;
 
 static ScoreboardStatsTool *scoreboard_stats_tool= NULL;
 
-static void enable(Session *,
-                   drizzle_sys_var *,
-                   void *var_ptr,
-                   const void *save)
+static void enable(Session *, sql_var_t)
 {
   if (logging_stats)
   {
-    if (*(bool *)save != false)
+    if (sysvar_logging_stats_enabled)
     {
       logging_stats->enable();
-      *(bool *) var_ptr= (bool) true;
     }
     else
     {
       logging_stats->disable();
-      *(bool *) var_ptr= (bool) false;
     }
   }
 }
@@ -308,34 +336,6 @@ static int init(drizzled::module::Context &context)
 
   sysvar_logging_stats_enabled= (vm.count("disable")) ? false : true;
 
-  if (vm.count("max-user-count"))
-  {
-    if (sysvar_logging_stats_max_user_count < 100 || sysvar_logging_stats_max_user_count > 50000)
-    {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid value for max-user-count\n"));
-      exit(-1);
-    }
-  }
-  if (vm.count("bucket-count"))
-  {
-    if (sysvar_logging_stats_bucket_count < 5 || sysvar_logging_stats_bucket_count > 500)
-    {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid value for bucket-count\n"));
-      exit(-1);
-    }
-  }
-
-  if (vm.count("scoreboard-size"))
-  {
-    if (sysvar_logging_stats_scoreboard_size < 10 || sysvar_logging_stats_scoreboard_size > 50000)
-    {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid value for scoreboard-size\n"));
-      exit(-1);
-    }
-    else
-      sysvar_logging_stats_scoreboard_size= vm["scoreboard-size"].as<uint32_t>(); 
-  }
-
   logging_stats= new LoggingStats("logging_stats");
 
   if (initTable())
@@ -358,72 +358,29 @@ static int init(drizzled::module::Context &context)
     logging_stats->enable();
   }
 
+  context.registerVariable(new sys_var_constrained_value_readonly<uint32_t>("max_user_count", sysvar_logging_stats_max_user_count));
+  context.registerVariable(new sys_var_constrained_value_readonly<uint32_t>("bucket_count", sysvar_logging_stats_bucket_count));
+  context.registerVariable(new sys_var_constrained_value_readonly<uint32_t>("scoreboard_size", sysvar_logging_stats_scoreboard_size));
+  context.registerVariable(new sys_var_bool_ptr("enable", &sysvar_logging_stats_enabled, enable));
+
   return 0;
 }
 
-static DRIZZLE_SYSVAR_UINT(max_user_count,
-                           sysvar_logging_stats_max_user_count,
-                           PLUGIN_VAR_RQCMDARG,
-                           N_("Max number of users that will be logged"),
-                           NULL, /* check func */
-                           NULL, /* update func */
-                           500, /* default */
-                           100, /* minimum */
-                           50000,
-                           0);
-
-static DRIZZLE_SYSVAR_UINT(bucket_count,
-                           sysvar_logging_stats_bucket_count,
-                           PLUGIN_VAR_RQCMDARG,
-                           N_("Max number of range locks to use for Scoreboard"),
-                           NULL, /* check func */
-                           NULL, /* update func */
-                           10, /* default */
-                           5, /* minimum */
-                           500,
-                           0);
-
-static DRIZZLE_SYSVAR_UINT(scoreboard_size,
-                           sysvar_logging_stats_scoreboard_size,
-                           PLUGIN_VAR_RQCMDARG,
-                           N_("Max number of concurrent sessions that will be logged"),
-                           NULL, /* check func */
-                           NULL, /* update func */
-                           2000, /* default */
-                           10, /* minimum */
-                           50000, 
-                           0);
-
-static DRIZZLE_SYSVAR_BOOL(enable,
-                           sysvar_logging_stats_enabled,
-                           PLUGIN_VAR_NOCMDARG,
-                           N_("Enable Logging Statistics Collection"),
-                           NULL, /* check func */
-                           enable, /* update func */
-                           true /* default */);
 
 static void init_options(drizzled::module::option_context &context)
 {
   context("max-user-count",
-          po::value<uint32_t>(&sysvar_logging_stats_max_user_count)->default_value(500),
-          N_("Max number of users that will be logged"));
+          po::value<max_user_count_constraint>(&sysvar_logging_stats_max_user_count)->default_value(500),
+          _("Max number of users that will be logged"));
   context("bucket-count",
-          po::value<uint32_t>(&sysvar_logging_stats_bucket_count)->default_value(10),
-          N_("Max number of range locks to use for Scoreboard"));
+          po::value<bucket_count_constraint>(&sysvar_logging_stats_bucket_count)->default_value(10),
+          _("Max number of range locks to use for Scoreboard"));
   context("scoreboard-size",
-          po::value<uint32_t>(&sysvar_logging_stats_scoreboard_size)->default_value(2000),
-          N_("Max number of concurrent sessions that will be logged"));
-  context("disable", N_("Enable Logging Statistics Collection"));
+          po::value<scoreboard_size_constraint>(&sysvar_logging_stats_scoreboard_size)->default_value(2000),
+          _("Max number of concurrent sessions that will be logged"));
+  context("disable", _("Enable Logging Statistics Collection"));
 }
 
-static drizzle_sys_var* system_var[]= {
-  DRIZZLE_SYSVAR(max_user_count),
-  DRIZZLE_SYSVAR(bucket_count),
-  DRIZZLE_SYSVAR(scoreboard_size),
-  DRIZZLE_SYSVAR(enable),
-  NULL
-};
-
 DRIZZLE_DECLARE_PLUGIN
 {
   DRIZZLE_VERSION_ID,
@@ -433,7 +390,7 @@ DRIZZLE_DECLARE_PLUGIN
   N_("User Statistics as DATA_DICTIONARY tables"),
   PLUGIN_LICENSE_BSD,
   init,   /* Plugin Init      */
-  system_var, /* system variables */
+  NULL, /* depends */
   init_options    /* config options   */
 }
 DRIZZLE_DECLARE_PLUGIN_END;
