@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, Joseph Daly <skinny.moey@gmail.com>
+ * Copyright (C) 2010 Joseph Daly <skinny.moey@gmail.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -27,10 +27,13 @@
  * THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef PLUGIN_LOGGING_STATS_STATUS_VARS_H
-#define PLUGIN_LOGGING_STATS_STATUS_VARS_H
+#pragma once
 
-#include <drizzled/session.h>
+namespace drizzled 
+{ 
+  class Session;
+  class system_status_var;
+}
 
 class StatusVars
 {
@@ -66,4 +69,3 @@ private:
 
 };
 
-#endif /* PLUGIN_LOGGING_STATS_STATUS_VARS_H */
