@@ -11,14 +11,13 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 
 
 /* class for the the heap Cursor */
 
-#ifndef PLUGIN_MEMORY_HA_HEAP_H
-#define PLUGIN_MEMORY_HA_HEAP_H
+#pragma once
 
 #include <drizzled/cursor.h>
 #include <drizzled/thr_lock.h>
@@ -35,7 +34,7 @@ class ha_heap: public drizzled::Cursor
   uint32_t    key_stat_version;
   bool internal_table;
 public:
-  ha_heap(drizzled::plugin::StorageEngine &engine, drizzled::TableShare &table);
+  ha_heap(drizzled::plugin::StorageEngine &engine, drizzled::Table &table);
   ~ha_heap() {}
   Cursor *clone(drizzled::memory::Root *mem_root);
 
@@ -47,7 +46,7 @@ public:
                    drizzled::ha_rows rows)
   { return (double) rows /  20.0+1; }
 
-  int doOpen(const drizzled::TableIdentifier &identifier, int mode, uint32_t test_if_locked);
+  int doOpen(const drizzled::identifier::Table &identifier, int mode, uint32_t test_if_locked);
   int close(void);
   void set_keys_for_scanning(void);
   int doInsertRecord(unsigned char * buf);
@@ -96,4 +95,3 @@ private:
   void update_key_stats();
 };
 
-#endif /* PLUGIN_MEMORY_HA_HEAP_H */
