@@ -11,7 +11,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 #include "heap_priv.h"
 
@@ -27,12 +27,12 @@ using namespace drizzled;
 static void init_block(HP_BLOCK *block,uint32_t chunk_length, uint32_t min_records,
                         uint32_t max_records);
 
-#define FIXED_REC_OVERHEAD (sizeof(unsigned char))
-#define VARIABLE_REC_OVERHEAD (sizeof(unsigned char**) + ALIGN_SIZE(sizeof(unsigned char)))
+static const int FIXED_REC_OVERHEAD = (sizeof(unsigned char));
+static const int VARIABLE_REC_OVERHEAD = (sizeof(unsigned char**) + ALIGN_SIZE(sizeof(unsigned char)));
 
 /* Minimum size that a chunk can take, 12 bytes on 32bit, 24 bytes on 64bit */
-#define VARIABLE_MIN_CHUNK_SIZE \
-        ((sizeof(unsigned char**) + VARIABLE_REC_OVERHEAD + sizeof(unsigned char**) - 1) & ~(sizeof(unsigned char**) - 1))
+static const int VARIABLE_MIN_CHUNK_SIZE =
+        ((sizeof(unsigned char**) + VARIABLE_REC_OVERHEAD + sizeof(unsigned char**) - 1) & ~(sizeof(unsigned char**) - 1));
 
 
 /* Create a heap table */
