@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002, 2004-200 MySQL AB
+/* Copyright (C) 2000-2002, 2004-2006 MySQL AB
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /* remove current record in heap-database */
 
@@ -26,7 +26,7 @@ int heap_delete(HP_INFO *info, const unsigned char *record)
   test_active(info);
 
   if (info->opt_flag & READ_CHECK_USED)
-    return(errno);			/* Record changed */
+    return(errno);   /* Record changed */
   share->changed=1;
 
   if ( --(share->records) < share->blength >> 1) share->blength>>=1;
@@ -97,7 +97,7 @@ int hp_delete_key(HP_INFO *info, register HP_KEYDEF *keyinfo,
     gpos=pos;
     if (!(pos=pos->next_key))
     {
-      return(errno=HA_ERR_CRASHED);	/* This shouldn't happend */
+      return(errno= drizzled::HA_ERR_CRASHED);	/* This shouldn't happend */
     }
   }
 
