@@ -11,13 +11,13 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /* The hash functions used for saveing keys */
 
 #include "heap_priv.h"
 
-#include "drizzled/charset_info.h"
+#include <drizzled/charset_info.h>
 #include <drizzled/util/test.h>
 
 #include <math.h>
