@@ -11,7 +11,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /* Read a record from a random position */
 
@@ -32,13 +32,13 @@ int heap_rrnd(register HP_INFO *info, unsigned char *record, unsigned char *pos)
   if (!(info->current_ptr= pos))
   {
     info->update= 0;
-    return(errno= HA_ERR_END_OF_FILE);
+    return(errno=  drizzled::HA_ERR_END_OF_FILE);
   }
   if (get_chunk_status(&share->recordspace, info->current_ptr) != CHUNK_STATUS_ACTIVE)
   {
     /* treat deleted and linked chunks as deleted */
     info->update= HA_STATE_PREV_FOUND | HA_STATE_NEXT_FOUND;
-    return(errno=HA_ERR_RECORD_DELETED);
+    return(errno= drizzled::HA_ERR_RECORD_DELETED);
   }
   info->update=HA_STATE_PREV_FOUND | HA_STATE_NEXT_FOUND | HA_STATE_AKTIV;
   hp_extract_record(share, record, info->current_ptr);
