@@ -11,7 +11,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /* re-read current record */
 
@@ -34,7 +34,7 @@ int heap_rsame(register HP_INFO *info, unsigned char *record, int inx)
   {
     if (inx < -1 || inx >= (int) share->keys)
     {
-      return(errno=HA_ERR_WRONG_INDEX);
+      return(errno= drizzled::HA_ERR_WRONG_INDEX);
     }
     else if (inx != -1)
     {
@@ -51,5 +51,5 @@ int heap_rsame(register HP_INFO *info, unsigned char *record, int inx)
   }
   info->update=0;
 
-  return(errno=HA_ERR_RECORD_DELETED);
+  return(errno= drizzled::HA_ERR_RECORD_DELETED);
 }
