@@ -11,37 +11,40 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 
 
-#include "config.h"
-#include "drizzled/internal/my_bit.h"
+#include <config.h>
+#include <drizzled/internal/my_bit.h>
 #include "myisampack.h"
 #include "ha_myisam.h"
 #include "myisam_priv.h"
-#include "drizzled/option.h"
-#include "drizzled/internal/my_bit.h"
-#include "drizzled/internal/m_string.h"
-#include "drizzled/util/test.h"
-#include "drizzled/error.h"
-#include "drizzled/errmsg_print.h"
-#include "drizzled/gettext.h"
-#include "drizzled/session.h"
-#include "drizzled/set_var.h"
+#include <drizzled/option.h>
+#include <drizzled/internal/my_bit.h>
+#include <drizzled/internal/m_string.h>
+#include <drizzled/util/test.h>
+#include <drizzled/error.h>
+#include <drizzled/errmsg_print.h>
+#include <drizzled/gettext.h>
+#include <drizzled/session.h>
 #include <drizzled/plugin.h>
-#include "drizzled/plugin/client.h"
-#include "drizzled/table.h"
-#include "drizzled/field/timestamp.h"
-#include "drizzled/memory/multi_malloc.h"
-#include "drizzled/plugin/daemon.h"
+#include <drizzled/plugin/client.h>
+#include <drizzled/table.h>
+#include <drizzled/memory/multi_malloc.h>
+#include <drizzled/plugin/daemon.h>
+
+#include <drizzled/plugin/storage_engine.h>
+#include <drizzled/key.h>
 
 #include <boost/algorithm/string.hpp>
+#include <boost/scoped_ptr.hpp>
 
 #include <string>
 #include <sstream>
 #include <map>
 #include <algorithm>
+#include <memory>
 #include <boost/program_options.hpp>
 #include <drizzled/module/option_map.h>
 
@@ -59,7 +62,8 @@ static uint32_t myisam_key_cache_size;
 static uint32_t myisam_key_cache_division_limit;
 static uint32_t myisam_key_cache_age_threshold;
 static uint64_t max_sort_file_size;
-static uint64_t sort_buffer_size;
+typedef constrained_check<size_t, SIZE_MAX, 1024, 1024> sort_buffer_constraint;
+static sort_buffer_constraint sort_buffer_size;
 
 void st_mi_isam_share::setKeyCache()
 {
@@ -104,7 +108,7 @@ public:
     mi_panic(HA_PANIC_CLOSE);
   }
 
-  virtual Cursor *create(TableShare &table)
+  virtual Cursor *create(Table &table)
   {
     return new ha_myisam(*this, table);
   }
@@ -115,15 +119,15 @@ public:
 
   int doCreateTable(Session&,
                     Table& table_arg,
-                    const TableIdentifier &identifier,
-                    message::Table&);
+                    const identifier::Table &identifier,
+                    const message::Table&);
 
-  int doRenameTable(Session&, const TableIdentifier &from, const TableIdentifier &to);
+  int doRenameTable(Session&, const identifier::Table &from, const identifier::Table &to);
 
-  int doDropTable(Session&, const TableIdentifier &identifier);
+  int doDropTable(Session&, const identifier::Table &identifier);
 
   int doGetTableDefinition(Session& session,
-                           const TableIdentifier &identifier,
+                           const identifier::Table &identifier,
                            message::Table &table_message);
 
   uint32_t max_supported_keys()          const { return MI_MAX_KEY; }
@@ -138,11 +142,11 @@ public:
             HA_READ_ORDER |
             HA_KEYREAD_ONLY);
   }
-  bool doDoesTableExist(Session& session, const TableIdentifier &identifier);
+  bool doDoesTableExist(Session& session, const identifier::Table &identifier);
 
   void doGetTableIdentifiers(drizzled::CachedDirectory &directory,
-                             const drizzled::SchemaIdentifier &schema_identifier,
-                             drizzled::TableIdentifiers &set_of_identifiers);
+                             const drizzled::identifier::Schema &schema_identifier,
+                             drizzled::identifier::Table::vector &set_of_identifiers);
   bool validateCreateTableOption(const std::string &key, const std::string &state)
   {
     (void)state;
@@ -156,21 +160,21 @@ public:
 };
 
 void MyisamEngine::doGetTableIdentifiers(drizzled::CachedDirectory&,
-                                         const drizzled::SchemaIdentifier&,
-                                         drizzled::TableIdentifiers&)
+                                         const drizzled::identifier::Schema&,
+                                         drizzled::identifier::Table::vector&)
 {
 }
 
-bool MyisamEngine::doDoesTableExist(Session &session, const TableIdentifier &identifier)
+bool MyisamEngine::doDoesTableExist(Session &session, const identifier::Table &identifier)
 {
-  return session.doesTableMessageExist(identifier);
+  return session.getMessageCache().doesTableMessageExist(identifier);
 }
 
 int MyisamEngine::doGetTableDefinition(Session &session,
-                                       const TableIdentifier &identifier,
+                                       const identifier::Table &identifier,
                                        message::Table &table_message)
 {
-  if (session.getTableMessage(identifier, table_message))
+  if (session.getMessageCache().getTableMessage(identifier, table_message))
     return EEXIST;
   return ENOENT;
 }
@@ -283,7 +287,7 @@ static int table2myisam(Table *table_arg, MI_KEYDEF **keydef_out,
         keydef[i].seg[j].flag|= HA_BLOB_PART;
         /* save number of bytes used to pack length */
         keydef[i].seg[j].bit_start= (uint) (field->pack_length() -
-                                            share->blob_ptr_size);
+                                            share->sizeBlobPtr());
       }
     }
     keyseg+= pos->key_parts;
@@ -293,7 +297,8 @@ static int table2myisam(Table *table_arg, MI_KEYDEF **keydef_out,
   record= table_arg->getInsertRecord();
   recpos= 0;
   recinfo_pos= recinfo;
-  while (recpos < (uint) share->stored_rec_length)
+
+  while (recpos < (uint) share->sizeStoredRecord())
   {
     Field **field, *found= 0;
     minpos= share->getRecordLength();
@@ -307,6 +312,7 @@ static int table2myisam(Table *table_arg, MI_KEYDEF **keydef_out,
         /* skip null fields */
         if (!(temp_length= (*field)->pack_length_in_rec()))
           continue; /* Skip null-fields */
+
         if (! found || fieldpos < minpos ||
             (fieldpos == minpos && temp_length < length))
         {
@@ -477,7 +483,7 @@ static int check_definition(MI_KEYDEF *t1_keyinfo, MI_COLUMNDEF *t1_recinfo,
 volatile int *killed_ptr(MI_CHECK *param)
 {
   /* In theory Unsafe conversion, but should be ok for now */
-  return (int*) &(((Session *)(param->session))->killed);
+  return (int*) (((Session *)(param->session))->getKilledPtr());
 }
 
 void mi_check_print_error(MI_CHECK *param, const char *fmt,...)
@@ -528,23 +534,29 @@ void _mi_report_crashed(MI_INFO *file, const char *message,
 {
   Session *cur_session;
   if ((cur_session= file->in_use))
-    errmsg_printf(ERRMSG_LVL_ERROR, _("Got an error from thread_id=%"PRIu64", %s:%d"),
+  {
+    errmsg_printf(error::ERROR, _("Got an error from thread_id=%"PRIu64", %s:%d"),
                     cur_session->thread_id,
                     sfile, sline);
+  }
   else
-    errmsg_printf(ERRMSG_LVL_ERROR, _("Got an error from unknown thread, %s:%d"), sfile, sline);
+  {
+    errmsg_printf(error::ERROR, _("Got an error from unknown thread, %s:%d"), sfile, sline);
+  }
+
   if (message)
-    errmsg_printf(ERRMSG_LVL_ERROR, "%s", message);
+    errmsg_printf(error::ERROR, "%s", message);
+
   list<Session *>::iterator it= file->s->in_use->begin();
   while (it != file->s->in_use->end())
   {
-    errmsg_printf(ERRMSG_LVL_ERROR, "%s", _("Unknown thread accessing table"));
+    errmsg_printf(error::ERROR, "%s", _("Unknown thread accessing table"));
     ++it;
   }
 }
 
 ha_myisam::ha_myisam(plugin::StorageEngine &engine_arg,
-                     TableShare &table_arg)
+                     Table &table_arg)
   : Cursor(engine_arg, table_arg),
   file(0),
   can_enable_indexes(true),
@@ -565,7 +577,7 @@ const char *ha_myisam::index_type(uint32_t )
 }
 
 /* Name is here without an extension */
-int ha_myisam::doOpen(const drizzled::TableIdentifier &identifier, int mode, uint32_t test_if_locked)
+int ha_myisam::doOpen(const drizzled::identifier::Table &identifier, int mode, uint32_t test_if_locked)
 {
   MI_KEYDEF *keyinfo;
   MI_COLUMNDEF *recinfo= 0;
@@ -590,13 +602,13 @@ int ha_myisam::doOpen(const drizzled::TableIdentifier &identifier, int mode, uin
   if (!(file= mi_open(identifier, mode, test_if_locked)))
     return (errno ? errno : -1);
 
-  if (!table->getShare()->getType()) /* No need to perform a check for tmp table */
+  if (!getTable()->getShare()->getType()) /* No need to perform a check for tmp table */
   {
-    if ((errno= table2myisam(table, &keyinfo, &recinfo, &recs)))
+    if ((errno= table2myisam(getTable(), &keyinfo, &recinfo, &recs)))
     {
       goto err;
     }
-    if (check_definition(keyinfo, recinfo, table->getShare()->sizeKeys(), recs,
+    if (check_definition(keyinfo, recinfo, getTable()->getShare()->sizeKeys(), recs,
                          file->s->keyinfo, file->s->rec,
                          file->s->base.keys, file->s->base.fields, true))
     {
@@ -612,17 +624,17 @@ int ha_myisam::doOpen(const drizzled::TableIdentifier &identifier, int mode, uin
   info(HA_STATUS_NO_LOCK | HA_STATUS_VARIABLE | HA_STATUS_CONST);
   if (!(test_if_locked & HA_OPEN_WAIT_IF_LOCKED))
     mi_extra(file, HA_EXTRA_WAIT_LOCK, 0);
-  if (!table->getShare()->db_record_offset)
+  if (!getTable()->getShare()->db_record_offset)
     is_ordered= false;
 
 
   keys_with_parts.reset();
-  for (i= 0; i < table->getShare()->sizeKeys(); i++)
+  for (i= 0; i < getTable()->getShare()->sizeKeys(); i++)
   {
-    table->key_info[i].block_size= file->s->keyinfo[i].block_length;
+    getTable()->key_info[i].block_size= file->s->keyinfo[i].block_length;
 
-    KeyPartInfo *kp= table->key_info[i].key_part;
-    KeyPartInfo *kp_end= kp + table->key_info[i].key_parts;
+    KeyPartInfo *kp= getTable()->key_info[i].key_part;
+    KeyPartInfo *kp_end= kp + getTable()->key_info[i].key_parts;
     for (; kp != kp_end; kp++)
     {
       if (!kp->field->part_of_key.test(i))
@@ -659,7 +671,7 @@ int ha_myisam::doInsertRecord(unsigned char *buf)
     If we have an auto_increment column and we are writing a changed row
     or a new row, then update the auto_increment value in the record.
   */
-  if (table->next_number_field && buf == table->getInsertRecord())
+  if (getTable()->next_number_field && buf == getTable()->getInsertRecord())
   {
     int error;
     if ((error= update_auto_increment()))
@@ -689,23 +701,23 @@ int ha_myisam::repair(Session *session, MI_CHECK &param, bool do_optimize)
   */
   if (file->dfile == -1)
   {
-    errmsg_printf(ERRMSG_LVL_INFO, "Retrying repair of: '%s' failed. "
-                          "Please try REPAIR EXTENDED or myisamchk",
-                          table->getShare()->getPath());
+    errmsg_printf(error::INFO, "Retrying repair of: '%s' failed. "
+		  "Please try REPAIR EXTENDED or myisamchk",
+		  getTable()->getShare()->getPath());
     return(HA_ADMIN_FAILED);
   }
 
-  param.db_name=    table->getShare()->getSchemaName();
-  param.table_name= table->getAlias();
+  param.db_name=    getTable()->getShare()->getSchemaName();
+  param.table_name= getTable()->getAlias();
   param.tmpfile_createflag = O_RDWR | O_TRUNC;
   param.using_global_keycache = 1;
   param.session= session;
   param.out_flag= 0;
-  param.sort_buffer_length= (size_t)sort_buffer_size;
+  param.sort_buffer_length= static_cast<size_t>(sort_buffer_size);
   strcpy(fixed_name,file->filename);
 
   // Don't lock tables if we have used LOCK Table
-  if (mi_lock_database(file, table->getShare()->getType() ? F_EXTRA_LCK : F_WRLCK))
+  if (mi_lock_database(file, getTable()->getShare()->getType() ? F_EXTRA_LCK : F_WRLCK))
   {
     mi_check_print_error(&param,ER(ER_CANT_LOCK),errno);
     return(HA_ADMIN_FAILED);
@@ -902,8 +914,9 @@ int ha_myisam::enable_indexes(uint32_t mode)
   }
   else if (mode == HA_KEY_SWITCH_NONUNIQ_SAVE)
   {
-    Session *session= table->in_use;
-    MI_CHECK param;
+    Session *session= getTable()->in_use;
+    boost::scoped_ptr<MI_CHECK> param_ap(new MI_CHECK);
+    MI_CHECK &param= *param_ap.get();
     const char *save_proc_info= session->get_proc_info();
     session->set_proc_info("Creating index");
     myisamchk_init(&param);
@@ -911,11 +924,11 @@ int ha_myisam::enable_indexes(uint32_t mode)
     param.testflag= (T_SILENT | T_REP_BY_SORT | T_QUICK |
                      T_CREATE_MISSING_KEYS);
     param.myf_rw&= ~MY_WAIT_IF_FULL;
-    param.sort_buffer_length=  (size_t)sort_buffer_size;
+    param.sort_buffer_length=  static_cast<size_t>(sort_buffer_size);
     param.stats_method= MI_STATS_METHOD_NULLS_NOT_EQUAL;
     if ((error= (repair(session,param,0) != HA_ADMIN_OK)) && param.retry_repair)
     {
-      errmsg_printf(ERRMSG_LVL_WARN, "Warning: Enabling keys got errno %d on %s.%s, retrying",
+      errmsg_printf(error::WARN, "Warning: Enabling keys got errno %d on %s.%s, retrying",
                         errno, param.db_name, param.table_name);
       /* Repairing by sort failed. Now try standard repair method. */
       param.testflag&= ~(T_REP_BY_SORT | T_QUICK);
@@ -925,7 +938,7 @@ int ha_myisam::enable_indexes(uint32_t mode)
         might have been set by the first repair. They can still be seen
         with SHOW WARNINGS then.
       */
-      if (! error)
+      if (not error)
         session->clear_error();
     }
     info(HA_STATUS_CONST);
@@ -978,7 +991,7 @@ int ha_myisam::indexes_are_disabled(void)
 
 void ha_myisam::start_bulk_insert(ha_rows rows)
 {
-  Session *session= table->in_use;
+  Session *session= getTable()->in_use;
   ulong size= session->variables.read_buff_size;
 
   /* don't enable row cache if too few rows */
@@ -1063,7 +1076,7 @@ int ha_myisam::index_read_map(unsigned char *buf, const unsigned char *key,
   assert(inited==INDEX);
   ha_statistic_increment(&system_status_var::ha_read_key_count);
   int error=mi_rkey(file, buf, active_index, key, keypart_map, find_flag);
-  table->status=error ? STATUS_NOT_FOUND: 0;
+  getTable()->status=error ? STATUS_NOT_FOUND: 0;
   return error;
 }
 
@@ -1073,7 +1086,7 @@ int ha_myisam::index_read_idx_map(unsigned char *buf, uint32_t index, const unsi
 {
   ha_statistic_increment(&system_status_var::ha_read_key_count);
   int error=mi_rkey(file, buf, index, key, keypart_map, find_flag);
-  table->status=error ? STATUS_NOT_FOUND: 0;
+  getTable()->status=error ? STATUS_NOT_FOUND: 0;
   return error;
 }
 
@@ -1084,7 +1097,7 @@ int ha_myisam::index_read_last_map(unsigned char *buf, const unsigned char *key,
   ha_statistic_increment(&system_status_var::ha_read_key_count);
   int error=mi_rkey(file, buf, active_index, key, keypart_map,
                     HA_READ_PREFIX_LAST);
-  table->status=error ? STATUS_NOT_FOUND: 0;
+  getTable()->status=error ? STATUS_NOT_FOUND: 0;
   return(error);
 }
 
@@ -1093,7 +1106,7 @@ int ha_myisam::index_next(unsigned char *buf)
   assert(inited==INDEX);
   ha_statistic_increment(&system_status_var::ha_read_next_count);
   int error=mi_rnext(file,buf,active_index);
-  table->status=error ? STATUS_NOT_FOUND: 0;
+  getTable()->status=error ? STATUS_NOT_FOUND: 0;
   return error;
 }
 
@@ -1102,7 +1115,7 @@ int ha_myisam::index_prev(unsigned char *buf)
   assert(inited==INDEX);
   ha_statistic_increment(&system_status_var::ha_read_prev_count);
   int error=mi_rprev(file,buf, active_index);
-  table->status=error ? STATUS_NOT_FOUND: 0;
+  getTable()->status=error ? STATUS_NOT_FOUND: 0;
   return error;
 }
 
@@ -1111,7 +1124,7 @@ int ha_myisam::index_first(unsigned char *buf)
   assert(inited==INDEX);
   ha_statistic_increment(&system_status_var::ha_read_first_count);
   int error=mi_rfirst(file, buf, active_index);
-  table->status=error ? STATUS_NOT_FOUND: 0;
+  getTable()->status=error ? STATUS_NOT_FOUND: 0;
   return error;
 }
 
@@ -1120,7 +1133,7 @@ int ha_myisam::index_last(unsigned char *buf)
   assert(inited==INDEX);
   ha_statistic_increment(&system_status_var::ha_read_last_count);
   int error=mi_rlast(file, buf, active_index);
-  table->status=error ? STATUS_NOT_FOUND: 0;
+  getTable()->status=error ? STATUS_NOT_FOUND: 0;
   return error;
 }
 
@@ -1135,7 +1148,7 @@ int ha_myisam::index_next_same(unsigned char *buf,
   {
     error= mi_rnext_same(file,buf);
   } while (error == HA_ERR_RECORD_DELETED);
-  table->status=error ? STATUS_NOT_FOUND: 0;
+  getTable()->status=error ? STATUS_NOT_FOUND: 0;
   return error;
 }
 
@@ -1176,7 +1189,7 @@ int ha_myisam::rnd_next(unsigned char *buf)
 {
   ha_statistic_increment(&system_status_var::ha_read_rnd_next_count);
   int error=mi_scan(file, buf);
-  table->status=error ? STATUS_NOT_FOUND: 0;
+  getTable()->status=error ? STATUS_NOT_FOUND: 0;
   return error;
 }
 
@@ -1184,7 +1197,7 @@ int ha_myisam::rnd_pos(unsigned char *buf, unsigned char *pos)
 {
   ha_statistic_increment(&system_status_var::ha_read_rnd_count);
   int error=mi_rrnd(file, buf, internal::my_get_ptr(pos,ref_length));
-  table->status=error ? STATUS_NOT_FOUND: 0;
+  getTable()->status=error ? STATUS_NOT_FOUND: 0;
   return error;
 }
 
@@ -1213,7 +1226,7 @@ int ha_myisam::info(uint32_t flag)
   }
   if (flag & HA_STATUS_CONST)
   {
-    TableShare *share= table->getMutableShare();
+    TableShare *share= getTable()->getMutableShare();
     stats.max_data_file_length=  misam_info.max_data_file_length;
     stats.max_index_file_length= misam_info.max_index_file_length;
     stats.create_time= misam_info.create_time;
@@ -1270,9 +1283,9 @@ int ha_myisam::info(uint32_t flag)
     share->keys_for_keyread&= share->keys_in_use;
     share->db_record_offset= misam_info.record_offset;
     if (share->key_parts)
-      memcpy(table->key_info[0].rec_per_key,
+      memcpy(getTable()->key_info[0].rec_per_key,
 	     misam_info.rec_per_key,
-	     sizeof(table->key_info[0].rec_per_key)*share->key_parts);
+	     sizeof(getTable()->key_info[0].rec_per_key)*share->key_parts);
     assert(share->getType() != message::Table::STANDARD);
 
    /*
@@ -1326,9 +1339,9 @@ int ha_myisam::delete_all_rows()
 }
 
 int MyisamEngine::doDropTable(Session &session,
-                              const TableIdentifier &identifier)
+                              const identifier::Table &identifier)
 {
-  session.removeTableMessage(identifier);
+  session.getMessageCache().removeTableMessage(identifier);
 
   return mi_delete_table(identifier.getPath().c_str());
 }
@@ -1337,15 +1350,15 @@ int MyisamEngine::doDropTable(Session &session,
 int ha_myisam::external_lock(Session *session, int lock_type)
 {
   file->in_use= session;
-  return mi_lock_database(file, !table->getShare()->getType() ?
+  return mi_lock_database(file, !getTable()->getShare()->getType() ?
 			  lock_type : ((lock_type == F_UNLCK) ?
 				       F_UNLCK : F_EXTRA_LCK));
 }
 
 int MyisamEngine::doCreateTable(Session &session,
                                 Table& table_arg,
-                                const TableIdentifier &identifier,
-                                message::Table& create_proto)
+                                const identifier::Table &identifier,
+                                const message::Table& create_proto)
 {
   int error;
   uint32_t create_flags= 0, create_records;
@@ -1384,15 +1397,15 @@ int MyisamEngine::doCreateTable(Session &session,
                    &create_info, create_flags);
   free((unsigned char*) recinfo);
 
-  session.storeTableMessage(identifier, create_proto);
+  session.getMessageCache().storeTableMessage(identifier, create_proto);
 
   return error;
 }
 
 
-int MyisamEngine::doRenameTable(Session &session, const TableIdentifier &from, const TableIdentifier &to)
+int MyisamEngine::doRenameTable(Session &session, const identifier::Table &from, const identifier::Table &to)
 {
-  session.renameTableMessage(from, to);
+  session.getMessageCache().renameTableMessage(from, to);
 
   return mi_rename(from.getPath().c_str(), to.getPath().c_str());
 }
@@ -1408,7 +1421,7 @@ void ha_myisam::get_auto_increment(uint64_t ,
   int error;
   unsigned char key[MI_MAX_KEY_LENGTH];
 
-  if (!table->getShare()->next_number_key_offset)
+  if (!getTable()->getShare()->next_number_key_offset)
   {						// Autoincrement at key-start
     ha_myisam::info(HA_STATUS_AUTO);
     *first_value= stats.auto_increment_value;
@@ -1418,22 +1431,22 @@ void ha_myisam::get_auto_increment(uint64_t ,
   }
 
   /* it's safe to call the following if bulk_insert isn't on */
-  mi_flush_bulk_insert(file, table->getShare()->next_number_index);
+  mi_flush_bulk_insert(file, getTable()->getShare()->next_number_index);
 
   (void) extra(HA_EXTRA_KEYREAD);
-  key_copy(key, table->getInsertRecord(),
-           &table->key_info[table->getShare()->next_number_index],
-           table->getShare()->next_number_key_offset);
-  error= mi_rkey(file, table->getUpdateRecord(), (int) table->getShare()->next_number_index,
-                 key, make_prev_keypart_map(table->getShare()->next_number_keypart),
+  key_copy(key, getTable()->getInsertRecord(),
+           &getTable()->key_info[getTable()->getShare()->next_number_index],
+           getTable()->getShare()->next_number_key_offset);
+  error= mi_rkey(file, getTable()->getUpdateRecord(), (int) getTable()->getShare()->next_number_index,
+                 key, make_prev_keypart_map(getTable()->getShare()->next_number_keypart),
                  HA_READ_PREFIX_LAST);
   if (error)
     nr= 1;
   else
   {
     /* Get data from getUpdateRecord() */
-    nr= ((uint64_t) table->next_number_field->
-         val_int_offset(table->getShare()->rec_buff_length)+1);
+    nr= ((uint64_t) getTable()->next_number_field->
+         val_int_offset(getTable()->getShare()->rec_buff_length)+1);
   }
   extra(HA_EXTRA_NO_KEYREAD);
   *first_value= nr;
@@ -1484,63 +1497,29 @@ uint32_t ha_myisam::checksum() const
   return (uint)file->state->checksum;
 }
 
-static MyisamEngine *engine= NULL;
-
 static int myisam_init(module::Context &context)
 { 
-  const module::option_map &vm= context.getOptions();
-
-  if (vm.count("max-sort-file-size"))
-  {
-    if (max_sort_file_size > UINT64_MAX)
-    {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid value for max-sort-file-size\n"));
-      exit(-1);
-    }
-  }
-
-  if (vm.count("sort-buffer-size"))
-  {
-    if (sort_buffer_size < 1024 || sort_buffer_size > SIZE_MAX)
-    {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid value for sort-buffer-size\n"));
-      exit(-1);
-    }
-  }
-
-  engine= new MyisamEngine(engine_name);
-  context.add(engine);
+  context.add(new MyisamEngine(engine_name));
+  context.registerVariable(new sys_var_constrained_value<size_t>("sort-buffer-size",
+                                                                 sort_buffer_size));
+  context.registerVariable(new sys_var_uint64_t_ptr("max_sort_file_size",
+                                                    &max_sort_file_size,
+                                                    context.getOptions()["max-sort-file-size"].as<uint64_t>()));
 
   return 0;
 }
 
 
-static DRIZZLE_SYSVAR_ULONGLONG(max_sort_file_size, max_sort_file_size,
-                                PLUGIN_VAR_RQCMDARG,
-                                N_("Don't use the fast sort index method to created index if the temporary file would get bigger than this."),
-                                NULL, NULL, INT32_MAX, 0, UINT64_MAX, 0);
-
-static DRIZZLE_SYSVAR_ULONGLONG(sort_buffer_size, sort_buffer_size,
-                                PLUGIN_VAR_RQCMDARG,
-                                N_("The buffer that is allocated when sorting the index when doing a REPAIR or when creating indexes with CREATE INDEX or ALTER TABLE."),
-                                NULL, NULL, 8192*1024, 1024, SIZE_MAX, 0);
-
 static void init_options(drizzled::module::option_context &context)
 {
   context("max-sort-file-size",
           po::value<uint64_t>(&max_sort_file_size)->default_value(INT32_MAX),
-          N_("Don't use the fast sort index method to created index if the temporary file would get bigger than this."));
+          _("Don't use the fast sort index method to created index if the temporary file would get bigger than this."));
   context("sort-buffer-size",
-          po::value<uint64_t>(&sort_buffer_size)->default_value(8192*1024),
-          N_("The buffer that is allocated when sorting the index when doing a REPAIR or when creating indexes with CREATE INDEX or ALTER TABLE."));
+          po::value<sort_buffer_constraint>(&sort_buffer_size)->default_value(8192*1024),
+          _("The buffer that is allocated when sorting the index when doing a REPAIR or when creating indexes with CREATE INDEX or ALTER TABLE."));
 }
 
-static drizzle_sys_var* sys_variables[]= {
-  DRIZZLE_SYSVAR(max_sort_file_size),
-  DRIZZLE_SYSVAR(sort_buffer_size),
-  NULL
-};
-
 
 DRIZZLE_DECLARE_PLUGIN
 {
@@ -1551,7 +1530,7 @@ DRIZZLE_DECLARE_PLUGIN
   "Default engine as of MySQL 3.23 with great performance",
   PLUGIN_LICENSE_GPL,
   myisam_init, /* Plugin Init */
-  sys_variables,           /* system variables */
+  NULL,           /* depends */
   init_options                        /* config options                  */
 }
 DRIZZLE_DECLARE_PLUGIN_END;
