@@ -11,12 +11,11 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /* Key cache variable structures */
 
-#ifndef PLUGIN_MYISAM_KEYCACHE_H
-#define PLUGIN_MYISAM_KEYCACHE_H
+#pragma once
 
 enum flush_type
 {
@@ -134,4 +133,3 @@ static inline uint32_t my_round_up_to_next_power(uint32_t v)
 }
 
 
-#endif /* PLUGIN_MYISAM_KEYCACHE_H */
