@@ -11,12 +11,12 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /* Functions to handle keys */
 
 #include "myisam_priv.h"
-#include "drizzled/charset_info.h"
+#include <drizzled/charset_info.h>
 #ifdef HAVE_IEEEFP_H
 #include <ieeefp.h>
 #endif
