@@ -11,7 +11,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /* open a isam-database */
 
@@ -19,13 +19,16 @@
 
 #include <string.h>
 #include <algorithm>
+#include <memory>
+#include <boost/scoped_ptr.hpp>
+#include <boost/scoped_array.hpp>
 
-#include "drizzled/charset_info.h"
-#include "drizzled/internal/m_string.h"
-#include "drizzled/util/test.h"
-#include "drizzled/global_charset_info.h"
-#include "drizzled/charset.h"
-#include "drizzled/memory/multi_malloc.h"
+#include <drizzled/charset_info.h>
+#include <drizzled/internal/m_string.h>
+#include <drizzled/util/test.h>
+#include <drizzled/global_charset_info.h>
+#include <drizzled/charset.h>
+#include <drizzled/memory/multi_malloc.h>
 
 
 using namespace std;
@@ -76,7 +79,7 @@ MI_INFO *test_if_reopen(char *filename)
   have an open count of 0.
 ******************************************************************************/
 
-MI_INFO *mi_open(const drizzled::TableIdentifier &identifier, int mode, uint32_t open_flags)
+MI_INFO *mi_open(const drizzled::identifier::Table &identifier, int mode, uint32_t open_flags)
 {
   int lock_error,kfile,open_mode,save_errno,have_rtree=0;
   uint32_t i,j,len,errpos,head_length,base_pos,offset,info_length,keys,
@@ -86,8 +89,11 @@ MI_INFO *mi_open(const drizzled::TableIdentifier &identifier, int mode, uint32_t
   unsigned char *disk_cache= NULL;
   unsigned char *disk_pos, *end_pos;
   MI_INFO info,*m_info,*old_info;
-  MYISAM_SHARE share_buff,*share;
-  ulong rec_per_key_part[HA_MAX_POSSIBLE_KEY*MI_MAX_KEY_SEG];
+  boost::scoped_ptr<MYISAM_SHARE> share_buff_ap(new MYISAM_SHARE);
+  MYISAM_SHARE &share_buff= *share_buff_ap.get();
+  MYISAM_SHARE *share;
+  boost::scoped_array<ulong> rec_per_key_part_ap(new ulong[HA_MAX_POSSIBLE_KEY*MI_MAX_KEY_SEG]);
+  ulong *rec_per_key_part= rec_per_key_part_ap.get();
   internal::my_off_t key_root[HA_MAX_POSSIBLE_KEY],key_del[MI_MAX_KEY_BLOCK_SIZE];
   uint64_t max_key_file_length, max_data_file_length;
 
@@ -137,12 +143,12 @@ MI_INFO *mi_open(const drizzled::TableIdentifier &identifier, int mode, uint32_t
       goto err;
     }
     share->options= mi_uint2korr(share->state.header.options);
-    if (share->options &
-	~(HA_OPTION_PACK_RECORD | HA_OPTION_PACK_KEYS |
-	  HA_OPTION_COMPRESS_RECORD | HA_OPTION_READ_ONLY_DATA |
-	  HA_OPTION_TEMP_COMPRESS_RECORD |
-          HA_OPTION_TMP_TABLE
-          ))
+    static const uint64_t OLD_FILE_OPTIONS= HA_OPTION_PACK_RECORD |
+	    HA_OPTION_PACK_KEYS |
+	    HA_OPTION_COMPRESS_RECORD | HA_OPTION_READ_ONLY_DATA |
+	    HA_OPTION_TEMP_COMPRESS_RECORD |
+	    HA_OPTION_TMP_TABLE;
+    if (share->options & ~OLD_FILE_OPTIONS)
     {
       errno=HA_ERR_OLD_FILE;
       goto err;
@@ -489,7 +495,7 @@ MI_INFO *mi_open(const drizzled::TableIdentifier &identifier, int mode, uint32_t
   /* Allocate buffer for one record */
 
   /* prerequisites: memset(info, 0) && info->s=share; are met. */
-  if (!mi_alloc_rec_buff(&info, -1, &info.rec_buff))
+  if (!mi_alloc_rec_buff(&info, SIZE_MAX, &info.rec_buff))
     goto err;
   memset(info.rec_buff, 0, mi_get_rec_buff_len(&info, info.rec_buff));
 
@@ -544,7 +550,7 @@ unsigned char *mi_alloc_rec_buff(MI_INFO *info, size_t length, unsigned char **b
     unsigned char *newptr = *buf;
 
     /* to simplify initial init of info->rec_buf in mi_open and mi_extra */
-    if (length == (ulong) -1)
+    if (length == SIZE_MAX)
     {
       if (info->s->options & HA_OPTION_COMPRESS_RECORD)
         length= max(info->s->base.pack_reclength, info->s->max_pack_length);
