@@ -11,26 +11,25 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /* This file should be included when using myisam_funktions */
 
-#ifndef PLUGIN_MYISAM_MYISAM_H
-#define PLUGIN_MYISAM_MYISAM_H
+#pragma once
 
-#include "drizzled/identifier/table.h"
+#include <drizzled/identifier.h>
 
 #include <drizzled/key_map.h>
 
 #include <drizzled/base.h>
 #ifndef _m_ctype_h
-#include "drizzled/charset_info.h"
+#include <drizzled/charset_info.h>
 #endif
 #ifndef _keycache_h
 #include "keycache.h"
 #endif
 #include <plugin/myisam/my_handler.h>
-#include "drizzled/internal/iocache.h"
+#include <drizzled/internal/iocache.h>
 
 /*
   Limit max keys according to HA_MAX_POSSIBLE_KEY
@@ -277,7 +276,7 @@ extern uint32_t data_pointer_size;
 
 extern int mi_close(struct st_myisam_info *file);
 extern int mi_delete(struct st_myisam_info *file,const unsigned char *buff);
-extern struct st_myisam_info *mi_open(const drizzled::TableIdentifier &identifier,
+extern struct st_myisam_info *mi_open(const drizzled::identifier::Table &identifier,
                                       int mode,
 				      uint32_t wait_if_locked);
 extern int mi_panic(enum drizzled::ha_panic_function function);
@@ -489,4 +488,3 @@ void mi_flush_bulk_insert(MI_INFO *info, uint32_t inx);
 void mi_end_bulk_insert(MI_INFO *info);
 int mi_preload(MI_INFO *info, uint64_t key_map, bool ignore_leaves);
 
-#endif /* PLUGIN_MYISAM_MYISAM_H */
