@@ -11,20 +11,22 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /* This file is included by all internal myisam files */
 
-#ifndef PLUGIN_MYISAM_MYISAM_PRIV_H
-#define PLUGIN_MYISAM_MYISAM_PRIV_H
+#pragma once
+
+#include <config.h>
 
-#include "config.h"
 #include "myisam.h"			/* Structs & some defines */
 #include "myisampack.h"			/* packing of keys */
-#include "drizzled/tree.h"
-#include "drizzled/internal/my_pthread.h"
+#include <drizzled/tree.h>
+#include <drizzled/internal/my_pthread.h>
 #include <drizzled/thr_lock.h>
 #include <drizzled/common.h>
+#include <drizzled/enum.h>
+#include <drizzled/dynamic_array.h>
 
 #include <assert.h>
 #include <fcntl.h>
@@ -212,7 +214,7 @@ public:
   ulong this_process;			/* processid */
   ulong last_process;			/* For table-change-check */
   ulong last_version;			/* Version on start */
-  ulong options;			/* Options used */
+  uint64_t options;			/* Options used */
   ulong min_pack_length;		/* Theese are used by packed data */
   ulong max_pack_length;
   ulong state_diff_length;
@@ -686,6 +688,7 @@ extern uint32_t _mi_pack_get_block_info(MI_INFO *myisam, MI_BIT_BUFF *bit_buff,
                                     int file, drizzled::internal::my_off_t filepos);
 extern void _my_store_blob_length(unsigned char *pos,uint32_t pack_length,uint32_t length);
 extern void mi_report_error(int errcode, const char *file_name);
+extern void mi_report_error(drizzled::error_t errcode, const char *file_name);
 extern size_t mi_mmap_pread(MI_INFO *info, unsigned char *Buffer,
                             size_t Count, drizzled::internal::my_off_t offset, drizzled::myf MyFlags);
 extern size_t mi_mmap_pwrite(MI_INFO *info, const unsigned char *Buffer,
@@ -753,4 +756,3 @@ void mi_disable_non_unique_index(MI_INFO *info, drizzled::ha_rows rows);
 void _mi_report_crashed(MI_INFO *file, const char *message, const char *sfile,
                         uint32_t sline);
 
-#endif /* PLUGIN_MYISAM_MYISAM_PRIV_H */
