@@ -11,7 +11,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 /*
   Creates a index for a database by reading keys, sorting them and outputing
@@ -199,17 +199,15 @@ int _create_index_by_sort(MI_SORT_PARAM *info,bool no_messages,
     {
       if (!no_messages)
 	printf("  - Merging %u keys\n", (uint32_t) records);
-      if (merge_many_buff(info,keys,sort_keys,
-                  dynamic_element(&buffpek,0,BUFFPEK *),&maxbuffer,&tempfile))
+      if (merge_many_buff(info,keys,sort_keys, (BUFFPEK*)buffpek.buffer, &maxbuffer, &tempfile))
 	goto err;
     }
     if (internal::flush_io_cache(&tempfile) ||
-	internal::reinit_io_cache(&tempfile,internal::READ_CACHE,0L,0,0))
+	tempfile.reinit_io_cache(internal::READ_CACHE,0L,0,0))
       goto err;
     if (!no_messages)
       printf("  - Last merge and dumping keys\n");
-    if (merge_index(info,keys,sort_keys,dynamic_element(&buffpek,0,BUFFPEK *),
-                    maxbuffer,&tempfile))
+    if (merge_index(info,keys,sort_keys, (BUFFPEK*)buffpek.buffer, maxbuffer, &tempfile))
       goto err;
   }
 
@@ -222,11 +220,13 @@ int _create_index_by_sort(MI_SORT_PARAM *info,bool no_messages,
     uint32_t     keyno=info->key;
     uint32_t     key_length, ref_length=idx->s->rec_reflength;
 
-    if (!no_messages)
+    if (not no_messages)
       printf("  - Adding exceptions\n");
-    if (flush_io_cache(&tempfile_for_exceptions) ||
-	reinit_io_cache(&tempfile_for_exceptions,internal::READ_CACHE,0L,0,0))
+
+    if (flush_io_cache(&tempfile_for_exceptions) || tempfile_for_exceptions.reinit_io_cache(internal::READ_CACHE,0L,0,0))
+    {
       goto err;
+    }
 
     while (!my_b_read(&tempfile_for_exceptions,(unsigned char*)&key_length,
 		      sizeof(key_length))
@@ -244,8 +244,8 @@ err:
   if (sort_keys)
     free((unsigned char*) sort_keys);
   delete_dynamic(&buffpek);
-  close_cached_file(&tempfile);
-  close_cached_file(&tempfile_for_exceptions);
+  tempfile.close_cached_file();
+  tempfile_for_exceptions.close_cached_file();
 
   return(error ? -1 : 0);
 } /* _create_index_by_sort */
@@ -288,12 +288,12 @@ static ha_rows  find_all_keys(MI_SORT_PARAM *info, uint32_t keys,
   }
   if (error > 0)
     return(HA_POS_ERROR);
-  if (buffpek->elements)
+  if (buffpek->size())
   {
     if (info->write_keys(info,sort_keys,idx,(BUFFPEK *)alloc_dynamic(buffpek),
 		   tempfile))
       return(HA_POS_ERROR);
-    *maxbuffer=buffpek->elements-1;
+    *maxbuffer=buffpek->size() - 1;
   }
   else
     *maxbuffer=0;
@@ -330,7 +330,7 @@ int thr_write_keys(MI_SORT_PARAM *sort_param)
     if (!got_error)
     {
       mi_set_key_active(share->state.key_map, sinfo->key);
-      if (!sinfo->buffpek.elements)
+      if (!sinfo->buffpek.size())
       {
         if (param->testflag & T_VERBOSE)
         {
@@ -357,8 +357,8 @@ int thr_write_keys(MI_SORT_PARAM *sort_param)
        i < sort_info->total_keys ;
        i++,
 	 delete_dynamic(&sinfo->buffpek),
-	 close_cached_file(&sinfo->tempfile),
-	 close_cached_file(&sinfo->tempfile_for_exceptions),
+	 sinfo->tempfile.close_cached_file(),
+	 sinfo->tempfile_for_exceptions.close_cached_file(),
 	 sinfo++)
   {
     if (got_error)
@@ -375,9 +375,9 @@ int thr_write_keys(MI_SORT_PARAM *sort_param)
       sinfo->read_to_buffer=read_to_buffer;
       sinfo->write_key=write_merge_key;
     }
-    if (sinfo->buffpek.elements)
+    if (sinfo->buffpek.size())
     {
-      size_t maxbuffer=sinfo->buffpek.elements-1;
+      size_t maxbuffer=sinfo->buffpek.size() - 1;
       if (!mergebuf)
       {
         length=param->sort_buffer_length;
@@ -398,24 +398,21 @@ int thr_write_keys(MI_SORT_PARAM *sort_param)
       {
         if (param->testflag & T_VERBOSE)
           printf("Key %d  - Merging %u keys\n",sinfo->key+1, sinfo->keys);
-        if (merge_many_buff(sinfo, keys, (unsigned char **)mergebuf,
-			    dynamic_element(&sinfo->buffpek, 0, BUFFPEK *),
+        if (merge_many_buff(sinfo, keys, (unsigned char **)mergebuf, (BUFFPEK*)sinfo->buffpek.buffer,
 			    &maxbuffer, &sinfo->tempfile))
         {
           got_error=1;
           continue;
         }
       }
-      if (flush_io_cache(&sinfo->tempfile) ||
-          reinit_io_cache(&sinfo->tempfile,internal::READ_CACHE,0L,0,0))
+      if (flush_io_cache(&sinfo->tempfile) || sinfo->tempfile.reinit_io_cache(internal::READ_CACHE,0L,0,0))
       {
         got_error=1;
         continue;
       }
       if (param->testflag & T_VERBOSE)
         printf("Key %d  - Last merge and dumping keys\n", sinfo->key+1);
-      if (merge_index(sinfo, keys, (unsigned char **)mergebuf,
-                      dynamic_element(&sinfo->buffpek,0,BUFFPEK *),
+      if (merge_index(sinfo, keys, (unsigned char **)mergebuf, (BUFFPEK*)sinfo->buffpek.buffer,
                       maxbuffer,&sinfo->tempfile) ||
 	  flush_pending_blocks(sinfo))
       {
@@ -430,8 +427,7 @@ int thr_write_keys(MI_SORT_PARAM *sort_param)
       if (param->testflag & T_VERBOSE)
         printf("Key %d  - Dumping 'long' keys\n", sinfo->key+1);
 
-      if (flush_io_cache(&sinfo->tempfile_for_exceptions) ||
-          reinit_io_cache(&sinfo->tempfile_for_exceptions,internal::READ_CACHE,0L,0,0))
+      if (flush_io_cache(&sinfo->tempfile_for_exceptions) || sinfo->tempfile_for_exceptions.reinit_io_cache(internal::READ_CACHE,0L,0,0))
       {
         got_error=1;
         continue;
@@ -465,9 +461,7 @@ static int  write_keys(MI_SORT_PARAM *info, register unsigned char **sort_keys,
 
   internal::my_qsort2((unsigned char*) sort_keys,count,sizeof(unsigned char*),(qsort2_cmp) info->key_cmp,
             info);
-  if (!my_b_inited(tempfile) &&
-      open_cached_file(tempfile, P_tmpdir, "ST",
-                       DISK_BUFFER_SIZE, info->sort_info->param->myf_rw))
+  if (!my_b_inited(tempfile) && tempfile->open_cached_file(P_tmpdir, "ST", DISK_BUFFER_SIZE, info->sort_info->param->myf_rw))
     return(1);
 
   buffpek->file_pos=my_b_tell(tempfile);
@@ -507,9 +501,7 @@ static int  write_keys_varlen(MI_SORT_PARAM *info,
 
   internal::my_qsort2((unsigned char*) sort_keys,count,sizeof(unsigned char*),(qsort2_cmp) info->key_cmp,
             info);
-  if (!my_b_inited(tempfile) &&
-      open_cached_file(tempfile, P_tmpdir, "ST",
-                       DISK_BUFFER_SIZE, info->sort_info->param->myf_rw))
+  if (!my_b_inited(tempfile) && tempfile->open_cached_file(P_tmpdir, "ST", DISK_BUFFER_SIZE, info->sort_info->param->myf_rw))
     return(1);
 
   buffpek->file_pos=my_b_tell(tempfile);
@@ -528,9 +520,7 @@ static int  write_key(MI_SORT_PARAM *info, unsigned char *key,
 {
   uint32_t key_length=info->real_key_length;
 
-  if (!my_b_inited(tempfile) &&
-      open_cached_file(tempfile, P_tmpdir, "ST",
-                       DISK_BUFFER_SIZE, info->sort_info->param->myf_rw))
+  if (!my_b_inited(tempfile) && tempfile->open_cached_file(P_tmpdir, "ST", DISK_BUFFER_SIZE, info->sort_info->param->myf_rw))
     return(1);
 
   if (my_b_write(tempfile,(unsigned char*)&key_length,sizeof(key_length)) ||
@@ -568,16 +558,15 @@ static int  merge_many_buff(MI_SORT_PARAM *info, uint32_t keys,
 
   if (*maxbuffer < MERGEBUFF2)
     return(0);
-  if (flush_io_cache(t_file) ||
-      open_cached_file(&t_file2, P_tmpdir, "ST",
+  if (flush_io_cache(t_file) || t_file2.open_cached_file(P_tmpdir, "ST",
                        DISK_BUFFER_SIZE, info->sort_info->param->myf_rw))
     return(1);
 
   from_file= t_file ; to_file= &t_file2;
   while (*maxbuffer >= MERGEBUFF2)
   {
-    reinit_io_cache(from_file,internal::READ_CACHE,0L,0,0);
-    reinit_io_cache(to_file,internal::WRITE_CACHE,0L,0,0);
+    from_file->reinit_io_cache(internal::READ_CACHE,0L,0,0);
+    to_file->reinit_io_cache(internal::WRITE_CACHE,0L,0,0);
     lastbuff=buffpek;
     for (i=0 ; i <= *maxbuffer-MERGEBUFF*3/2 ; i+=MERGEBUFF)
     {
@@ -594,7 +583,7 @@ static int  merge_many_buff(MI_SORT_PARAM *info, uint32_t keys,
     *maxbuffer= (int) (lastbuff-buffpek)-1;
   }
 cleanup:
-  close_cached_file(to_file);                   /* This holds old result */
+  to_file->close_cached_file();                   /* This holds old result */
   if (to_file == t_file)
     *t_file=t_file2;                            /* Copy result file */
 
