@@ -13,13 +13,15 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
-#include "config.h"
+#include <config.h>
 #include "mysql_password.h"
-#include "drizzled/algorithm/sha1.h"
-#include "drizzled/util/convert.h"
+#include <drizzled/algorithm/sha1.h>
+#include <drizzled/util/convert.h>
 
 using namespace std;
-using namespace drizzled;
+
+namespace drizzle_plugin
+{
 
 const char* MySQLPasswordName = "mysql_password";
 
@@ -42,27 +44,30 @@ bool MySQLPassword::check_argument_count(int n)
   return (n == 1);
 }
 
-String *MySQLPassword::val_str(String *str)
+drizzled::String *MySQLPassword::val_str(drizzled::String *str)
 {
-  String argument;
-  String *password= args[0]->val_str(&argument);
-  SHA1_CTX ctx;
+  drizzled::String argument;
+  drizzled::String *password= args[0]->val_str(&argument);
+  drizzled::SHA1_CTX ctx;
   uint8_t hash_tmp1[SHA1_DIGEST_LENGTH];
   uint8_t hash_tmp2[SHA1_DIGEST_LENGTH];
 
-  SHA1Init(&ctx);
-  SHA1Update(&ctx, reinterpret_cast<uint8_t *>(password->ptr()),
-             password->length());
-  SHA1Final(hash_tmp1, &ctx);
+  drizzled::SHA1Init(&ctx);
+  drizzled::SHA1Update(&ctx, reinterpret_cast<uint8_t *>(password->ptr()),
+                       password->length());
+  drizzled::SHA1Final(hash_tmp1, &ctx);
 
-  SHA1Init(&ctx);
-  SHA1Update(&ctx, hash_tmp1, SHA1_DIGEST_LENGTH);
-  SHA1Final(hash_tmp2, &ctx);
+  drizzled::SHA1Init(&ctx);
+  drizzled::SHA1Update(&ctx, hash_tmp1, SHA1_DIGEST_LENGTH);
+  drizzled::SHA1Final(hash_tmp2, &ctx);
 
   str->realloc(SHA1_DIGEST_LENGTH * 2);
-  drizzled_string_to_hex(str->ptr(), reinterpret_cast<const char*>(hash_tmp2),
-                         SHA1_DIGEST_LENGTH);
+  drizzled::drizzled_string_to_hex(str->ptr(),
+                                   reinterpret_cast<const char*>(hash_tmp2),
+                                   SHA1_DIGEST_LENGTH);
   str->length(SHA1_DIGEST_LENGTH * 2);
 
   return str;
 }
+
+} /* namespace drizzle_plugin */
