@@ -13,16 +13,15 @@
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
-#ifndef PLUGIN_MYSQL_PROTOCOL_MYSQL_PASSWORD_H
-#define PLUGIN_MYSQL_PROTOCOL_MYSQL_PASSWORD_H
+#pragma once
 
 #include <drizzled/item/func.h>
 #include <drizzled/function/str/strfunc.h>
 
-namespace drizzled
+namespace drizzle_plugin
 {
 
-extern "C" const char* MySQLPasswordName;
+extern const char* MySQLPasswordName;
 
 class MySQLPassword: public drizzled::Item_str_func
 {
@@ -34,6 +33,5 @@ public:
   drizzled::String *val_str(drizzled::String *);
 };
 
-} /* namespace drizzled */
+} /* namespace drizzle_plugin */
 
-#endif /* PLUGIN_MYSQL_PROTOCOL_MYSQL_PASSWORD_H */
