@@ -1,7 +1,7 @@
 /* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008 Sun Microsystems
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,60 +14,73 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 #include <drizzled/gettext.h>
 #include <drizzled/error.h>
 #include <drizzled/query_id.h>
-#include <drizzled/sql_state.h>
+#include <drizzled/error/sql_state.h>
 #include <drizzled/session.h>
-#include "drizzled/internal/m_string.h"
+#include <drizzled/internal/m_string.h>
 #include <algorithm>
 #include <boost/program_options.hpp>
 #include <drizzled/module/option_map.h>
+#include <drizzled/util/tokenize.h>
 #include "errmsg.h"
 #include "mysql_protocol.h"
 #include "mysql_password.h"
 #include "options.h"
-#include "table_function.h"
+#include <drizzled/identifier.h>
+#include <drizzled/plugin/function.h>
+#include <libdrizzle/constants.h>
+
+#define PROTOCOL_VERSION 10
 
 namespace po= boost::program_options;
 using namespace std;
 using namespace drizzled;
 
-#define PROTOCOL_VERSION 10
+namespace drizzle_plugin
+{
 
+std::vector<std::string> ClientMySQLProtocol::mysql_admin_ip_addresses;
 static const unsigned int PACKET_BUFFER_EXTRA_ALLOC= 1024;
-static uint32_t port;
-static uint32_t connect_timeout;
-static uint32_t read_timeout;
-static uint32_t write_timeout;
-static uint32_t retry_count;
-static uint32_t buffer_length;
-static char* bind_address;
+
+static port_constraint port;
+static timeout_constraint connect_timeout;
+static timeout_constraint read_timeout;
+static timeout_constraint write_timeout;
+static retry_constraint retry_count;
+static buffer_constraint buffer_length;
+
 static uint32_t random_seed1;
 static uint32_t random_seed2;
 static const uint32_t random_max= 0x3FFFFFFF;
 static const double random_max_double= (double)0x3FFFFFFF;
 
-static plugin::TableFunction* mysql_status_table_function_ptr= NULL;
+
+ProtocolCounters *ListenMySQLProtocol::mysql_counters= new ProtocolCounters();
 
 ListenMySQLProtocol::~ListenMySQLProtocol()
+{ }
+
+void ListenMySQLProtocol::addCountersToTable()
 {
-  /* This is strdup'd from the options */
-  free(bind_address);
+  counters.push_back(new drizzled::plugin::ListenCounter(new std::string("connection_count"), &getCounters()->connectionCount));
+  counters.push_back(new drizzled::plugin::ListenCounter(new std::string("connected"), &getCounters()->connected));
+  counters.push_back(new drizzled::plugin::ListenCounter(new std::string("failed_connections"), &getCounters()->failedConnections));
 }
 
-const char* ListenMySQLProtocol::getHost(void) const
+const std::string ListenMySQLProtocol::getHost(void) const
 {
-  return bind_address;
+  return _hostname;
 }
 
 in_port_t ListenMySQLProtocol::getPort(void) const
 {
-  return (in_port_t) port;
+  return port.get();
 }
 
 plugin::Client *ListenMySQLProtocol::getClient(int fd)
@@ -77,33 +90,33 @@ plugin::Client *ListenMySQLProtocol::getClient(int fd)
   if (new_fd == -1)
     return NULL;
 
-  return new (nothrow) ClientMySQLProtocol(new_fd, using_mysql41_protocol);
+  return new ClientMySQLProtocol(new_fd, _using_mysql41_protocol, getCounters());
 }
 
-drizzled::atomic<uint64_t> ClientMySQLProtocol::connectionCount;
-drizzled::atomic<uint64_t> ClientMySQLProtocol::failedConnections;
-drizzled::atomic<uint64_t> ClientMySQLProtocol::connected;
-
-ClientMySQLProtocol::ClientMySQLProtocol(int fd, bool using_mysql41_protocol_arg):
-  using_mysql41_protocol(using_mysql41_protocol_arg)
+ClientMySQLProtocol::ClientMySQLProtocol(int fd, bool using_mysql41_protocol, ProtocolCounters *set_counters):
+  is_admin_connection(false),
+  _using_mysql41_protocol(using_mysql41_protocol),
+  _is_interactive(false),
+  counters(set_counters)
 {
+  
   net.vio= 0;
 
   if (fd == -1)
     return;
 
-  if (drizzleclient_net_init_sock(&net, fd, buffer_length))
+  if (drizzleclient_net_init_sock(&net, fd, buffer_length.get()))
     throw bad_alloc();
 
-  drizzleclient_net_set_read_timeout(&net, read_timeout);
-  drizzleclient_net_set_write_timeout(&net, write_timeout);
-  net.retry_count=retry_count;
+  drizzleclient_net_set_read_timeout(&net, read_timeout.get());
+  drizzleclient_net_set_write_timeout(&net, write_timeout.get());
+  net.retry_count=retry_count.get();
 }
 
 ClientMySQLProtocol::~ClientMySQLProtocol()
 {
   if (net.vio)
-    vio_close(net.vio);
+    net.vio->close();
 }
 
 int ClientMySQLProtocol::getFileDescriptor(void)
@@ -142,34 +155,60 @@ void ClientMySQLProtocol::close(void)
   { 
     drizzleclient_net_close(&net);
     drizzleclient_net_end(&net);
-    connected.decrement();
+    if (is_admin_connection)
+    {
+      counters->adminConnected.decrement();
+    }
+    else
+    {
+      counters->connected.decrement();
+    }
   }
 }
 
 bool ClientMySQLProtocol::authenticate()
 {
   bool connection_is_valid;
-
-  connectionCount.increment();
-  connected.increment();
+  if (is_admin_connection)
+  {
+    counters->adminConnectionCount.increment();
+    counters->adminConnected.increment();
+  }
+  else
+  {
+    counters->connectionCount.increment();
+    counters->connected.increment();
+  }
 
   /* Use "connect_timeout" value during connection phase */
-  drizzleclient_net_set_read_timeout(&net, connect_timeout);
-  drizzleclient_net_set_write_timeout(&net, connect_timeout);
+  drizzleclient_net_set_read_timeout(&net, connect_timeout.get());
+  drizzleclient_net_set_write_timeout(&net, connect_timeout.get());
 
   connection_is_valid= checkConnection();
 
   if (connection_is_valid)
-    sendOK();
+  {
+    if (not is_admin_connection and (counters->connected > counters->max_connections))
+    {
+      std::string errmsg(ER(ER_CON_COUNT_ERROR));
+      sendError(ER_CON_COUNT_ERROR, errmsg.c_str());
+      counters->failedConnections.increment();
+    }
+    else
+    {
+      sendOK();
+    }
+  }
   else
   {
     sendError(session->main_da.sql_errno(), session->main_da.message());
-    failedConnections.increment();
+    counters->failedConnections.increment();
     return false;
   }
+
   /* Connect completed, set read/write timeouts back to default */
-  drizzleclient_net_set_read_timeout(&net, read_timeout);
-  drizzleclient_net_set_write_timeout(&net, write_timeout);
+  drizzleclient_net_set_read_timeout(&net, read_timeout.get());
+  drizzleclient_net_set_write_timeout(&net, write_timeout.get());
   return true;
 }
 
@@ -206,8 +245,6 @@ bool ClientMySQLProtocol::readCommand(char **l_packet, uint32_t *packet_length)
       return false;                       // We have to close it.
 
     net.error= 0;
-    *packet_length= 0;
-    return true;
   }
 
   *l_packet= (char*) net.read_pos;
@@ -227,7 +264,7 @@ bool ClientMySQLProtocol::readCommand(char **l_packet, uint32_t *packet_length)
     (*l_packet)[0]= (unsigned char) COM_SLEEP;
     *packet_length= 1;
   }
-  else if (using_mysql41_protocol)
+  else if (_using_mysql41_protocol)
   {
     /* Map from MySQL commands to Drizzle commands. */
     switch ((int)(*l_packet)[0])
@@ -242,6 +279,10 @@ bool ClientMySQLProtocol::readCommand(char **l_packet, uint32_t *packet_length)
       (*l_packet)[0]= (unsigned char) COM_SHUTDOWN;
       break;
 
+    case 12: /* KILL */
+      (*l_packet)[0]= (unsigned char) COM_KILL;
+      break;
+
     case 14: /* PING */
       (*l_packet)[0]= (unsigned char) COM_PING;
       break;
@@ -367,11 +408,11 @@ void ClientMySQLProtocol::sendEOF()
     drizzleclient_net_flush(&net);
     session->main_da.can_overwrite_status= false;
   }
-  packet.shrink(buffer_length);
+  packet.shrink(buffer_length.get());
 }
 
 
-void ClientMySQLProtocol::sendError(uint32_t sql_errno, const char *err)
+void ClientMySQLProtocol::sendError(drizzled::error_t sql_errno, const char *err)
 {
   uint32_t length;
   /*
@@ -379,7 +420,7 @@ void ClientMySQLProtocol::sendError(uint32_t sql_errno, const char *err)
   */
   unsigned char buff[2+1+SQLSTATE_LENGTH+DRIZZLE_ERRMSG_SIZE], *pos;
 
-  assert(sql_errno);
+  assert(sql_errno != EE_OK);
   assert(err && err[0]);
 
   /*
@@ -404,13 +445,13 @@ void ClientMySQLProtocol::sendError(uint32_t sql_errno, const char *err)
     return;
   }
 
-  int2store(buff,sql_errno);
+  int2store(buff, static_cast<uint16_t>(sql_errno));
   pos= buff+2;
 
   /* The first # is to make the client backward compatible */
   buff[2]= '#';
-  pos= (unsigned char*) strcpy((char*) buff+3, drizzle_errno_to_sqlstate(sql_errno));
-  pos+= strlen(drizzle_errno_to_sqlstate(sql_errno));
+  pos= (unsigned char*) strcpy((char*) buff+3, error::convert_to_sqlstate(sql_errno));
+  pos+= strlen(error::convert_to_sqlstate(sql_errno));
 
   char *tmp= strncpy((char*)pos, err, DRIZZLE_ERRMSG_SIZE-1);
   tmp+= strlen((char*)pos);
@@ -420,6 +461,8 @@ void ClientMySQLProtocol::sendError(uint32_t sql_errno, const char *err)
 
   drizzleclient_net_write_command(&net,(unsigned char) 255, (unsigned char*) "", 0, (unsigned char*) err, length);
 
+  drizzleclient_net_flush(&net);
+
   session->main_da.can_overwrite_status= false;
 }
 
@@ -443,12 +486,12 @@ void ClientMySQLProtocol::sendError(uint32_t sql_errno, const char *err)
 */
 bool ClientMySQLProtocol::sendFields(List<Item> *list)
 {
-  List_iterator_fast<Item> it(*list);
+  List<Item>::iterator it(list->begin());
   Item *item;
   unsigned char buff[80];
   String tmp((char*) buff,sizeof(buff),&my_charset_bin);
 
-  unsigned char *row_pos= storeLength(buff, list->elements);
+  unsigned char *row_pos= storeLength(buff, list->size());
   (void) drizzleclient_net_write(&net, buff, (size_t) (row_pos-buff));
 
   while ((item=it++))
@@ -475,53 +518,69 @@ bool ClientMySQLProtocol::sendFields(List<Item> *list)
     int2store(pos, field.charsetnr);
     int4store(pos+2, field.length);
 
-    if (using_mysql41_protocol)
+    if (_using_mysql41_protocol)
     {
       /* Switch to MySQL field numbering. */
       switch (field.type)
       {
       case DRIZZLE_TYPE_LONG:
-        pos[6]= 3;
+        pos[6]= DRIZZLE_COLUMN_TYPE_LONG;
         break;
 
       case DRIZZLE_TYPE_DOUBLE:
-        pos[6]= 5;
+        pos[6]= DRIZZLE_COLUMN_TYPE_DOUBLE;
         break;
 
       case DRIZZLE_TYPE_NULL:
-        pos[6]= 6;
+        pos[6]= DRIZZLE_COLUMN_TYPE_NULL;
         break;
 
       case DRIZZLE_TYPE_TIMESTAMP:
-        pos[6]= 7;
+        pos[6]= DRIZZLE_COLUMN_TYPE_TIMESTAMP;
         break;
 
       case DRIZZLE_TYPE_LONGLONG:
-        pos[6]= 8;
+        pos[6]= DRIZZLE_COLUMN_TYPE_LONGLONG;
         break;
 
       case DRIZZLE_TYPE_DATETIME:
-        pos[6]= 12;
+        pos[6]= DRIZZLE_COLUMN_TYPE_DATETIME;
+        break;
+
+      case DRIZZLE_TYPE_TIME:
+        pos[6]= DRIZZLE_COLUMN_TYPE_TIME;
         break;
 
       case DRIZZLE_TYPE_DATE:
-        pos[6]= 14;
+        pos[6]= DRIZZLE_COLUMN_TYPE_DATE;
         break;
 
       case DRIZZLE_TYPE_VARCHAR:
-        pos[6]= 15;
+        pos[6]= DRIZZLE_COLUMN_TYPE_VARCHAR;
+        break;
+
+      case DRIZZLE_TYPE_MICROTIME:
+        pos[6]= DRIZZLE_COLUMN_TYPE_VARCHAR;
+        break;
+
+      case DRIZZLE_TYPE_UUID:
+        pos[6]= DRIZZLE_COLUMN_TYPE_VARCHAR;
+        break;
+
+      case DRIZZLE_TYPE_BOOLEAN:
+        pos[6]= DRIZZLE_COLUMN_TYPE_TINY;
         break;
 
       case DRIZZLE_TYPE_DECIMAL:
-        pos[6]= (char)246;
+        pos[6]= (char)DRIZZLE_COLUMN_TYPE_NEWDECIMAL;
         break;
 
       case DRIZZLE_TYPE_ENUM:
-        pos[6]= (char)247;
+        pos[6]= (char)DRIZZLE_COLUMN_TYPE_ENUM;
         break;
 
       case DRIZZLE_TYPE_BLOB:
-        pos[6]= (char)252;
+        pos[6]= (char)DRIZZLE_COLUMN_TYPE_BLOB;
         break;
       }
     }
@@ -560,10 +619,15 @@ bool ClientMySQLProtocol::store(Field *from)
 {
   if (from->is_null())
     return store();
+  if (from->type() == DRIZZLE_TYPE_BOOLEAN)
+  {
+    return store(from->val_int());
+  }
+
   char buff[MAX_FIELD_WIDTH];
   String str(buff,sizeof(buff), &my_charset_bin);
 
-  from->val_str(&str);
+  from->val_str_internal(&str);
 
   return netStoreData((const unsigned char *)str.ptr(), str.length());
 }
@@ -634,6 +698,7 @@ bool ClientMySQLProtocol::checkConnection(void)
   uint32_t pkt_len= 0;
   char *end;
   char scramble[SCRAMBLE_LENGTH];
+  identifier::User::shared_ptr user_identifier= identifier::User::make_shared();
 
   makeScramble(scramble);
 
@@ -644,11 +709,11 @@ bool ClientMySQLProtocol::checkConnection(void)
 
     if (drizzleclient_net_peer_addr(&net, ip, &peer_port, NI_MAXHOST))
     {
-      my_error(ER_BAD_HOST_ERROR, MYF(0), session->getSecurityContext().getIp().c_str());
+      my_error(ER_BAD_HOST_ERROR, MYF(0), ip);
       return false;
     }
 
-    session->getSecurityContext().setIp(ip);
+    user_identifier->setAddress(ip);
   }
   drizzleclient_net_keepalive(&net, true);
 
@@ -659,8 +724,10 @@ bool ClientMySQLProtocol::checkConnection(void)
 
     server_capabilites= CLIENT_BASIC_FLAGS;
 
-    if (using_mysql41_protocol)
+    if (_using_mysql41_protocol)
+    {
       server_capabilites|= CLIENT_PROTOCOL_MYSQL41;
+    }
 
 #ifdef HAVE_COMPRESS
     server_capabilites|= CLIENT_COMPRESS;
@@ -703,17 +770,17 @@ bool ClientMySQLProtocol::checkConnection(void)
         ||    (pkt_len= drizzleclient_net_read(&net)) == packet_error 
         || pkt_len < MIN_HANDSHAKE_SIZE)
     {
-      my_error(ER_HANDSHAKE_ERROR, MYF(0), session->getSecurityContext().getIp().c_str());
+      my_error(ER_HANDSHAKE_ERROR, MYF(0), user_identifier->address().c_str());
       return false;
     }
   }
-  if (packet.alloc(buffer_length))
+  if (packet.alloc(buffer_length.get()))
     return false; /* The error is set by alloc(). */
 
   client_capabilities= uint2korr(net.read_pos);
   if (!(client_capabilities & CLIENT_PROTOCOL_MYSQL41))
   {
-    my_error(ER_HANDSHAKE_ERROR, MYF(0), session->getSecurityContext().getIp().c_str());
+    my_error(ER_HANDSHAKE_ERROR, MYF(0), user_identifier->address().c_str());
     return false;
   }
 
@@ -729,7 +796,7 @@ bool ClientMySQLProtocol::checkConnection(void)
 
   if (end >= (char*) net.read_pos + pkt_len + 2)
   {
-    my_error(ER_HANDSHAKE_ERROR, MYF(0), session->getSecurityContext().getIp().c_str());
+    my_error(ER_HANDSHAKE_ERROR, MYF(0), user_identifier->address().c_str());
     return false;
   }
 
@@ -751,14 +818,20 @@ bool ClientMySQLProtocol::checkConnection(void)
       passwd < (char *) net.read_pos + pkt_len)
   {
     passwd_len= (unsigned char)(*passwd++);
-    if (passwd_len > 0)
+    if (passwd_len > 0 and client_capabilities & CLIENT_CAPABILITIES_PLUGIN_AUTH)
     {
-      session->getSecurityContext().setPasswordType(SecurityContext::MYSQL_HASH);
-      session->getSecurityContext().setPasswordContext(scramble, SCRAMBLE_LENGTH);
+      user_identifier->setPasswordType(identifier::User::PLAIN_TEXT);
+    }
+    else if (passwd_len > 0)
+    {
+      user_identifier->setPasswordType(identifier::User::MYSQL_HASH);
+      user_identifier->setPasswordContext(scramble, SCRAMBLE_LENGTH);
     }
   }
   else
+  {
     passwd_len= 0;
+  }
 
   if (client_capabilities & CLIENT_CONNECT_WITH_DB &&
       passwd < (char *) net.read_pos + pkt_len)
@@ -766,14 +839,16 @@ bool ClientMySQLProtocol::checkConnection(void)
     l_db= l_db + passwd_len + 1;
   }
   else
+  {
     l_db= NULL;
+  }
 
   /* strlen() can't be easily deleted without changing client */
   uint32_t db_len= l_db ? strlen(l_db) : 0;
 
   if (passwd + passwd_len + db_len > (char *) net.read_pos + pkt_len)
   {
-    my_error(ER_HANDSHAKE_ERROR, MYF(0), session->getSecurityContext().getIp().c_str());
+    my_error(ER_HANDSHAKE_ERROR, MYF(0), user_identifier->address().c_str());
     return false;
   }
 
@@ -785,9 +860,43 @@ bool ClientMySQLProtocol::checkConnection(void)
     user_len-= 2;
   }
 
-  session->getSecurityContext().setUser(user);
+  if (client_capabilities & CLIENT_ADMIN)
+  {
+    if ((strncmp(user, "root", 4) == 0) and isAdminAllowed())
+    {
+      is_admin_connection= true;
+    }
+    else
+    {
+      my_error(ER_ADMIN_ACCESS, MYF(0));
+      return false;
+    }
+  }
 
-  return session->checkUser(passwd, passwd_len, l_db);
+  if (client_capabilities & CLIENT_INTERACTIVE)
+  {
+    _is_interactive= true;
+  }
+
+  if (client_capabilities & CLIENT_CAPABILITIES_PLUGIN_AUTH)
+  {
+    passwd_len= strlen(passwd);
+  }
+
+  user_identifier->setUser(user);
+  session->setUser(user_identifier);
+
+  return session->checkUser(string(passwd, passwd_len),
+                            string(l_db ? l_db : ""));
+
+}
+
+bool ClientMySQLProtocol::isAdminAllowed(void)
+{
+  if (std::find(mysql_admin_ip_addresses.begin(), mysql_admin_ip_addresses.end(), session->user()->address()) != mysql_admin_ip_addresses.end())
+    return true;
+
+  return false;
 }
 
 bool ClientMySQLProtocol::netStoreData(const unsigned char *from, size_t length)
@@ -882,7 +991,7 @@ void ClientMySQLProtocol::makeScramble(char *scramble)
   uint32_t pointer_seed;
   memcpy(&pointer_seed, &pointer, 4);
   uint32_t random1= (seed + pointer_seed) % random_max;
-  uint32_t random2= (seed + session->variables.pseudo_thread_id + net.vio->sd) % random_max;
+  uint32_t random2= (seed + session->variables.pseudo_thread_id + net.vio->get_fd()) % random_max;
 
   for (char *end= scramble + SCRAMBLE_LENGTH; scramble != end; scramble++)
   {
@@ -892,245 +1001,81 @@ void ClientMySQLProtocol::makeScramble(char *scramble)
   }
 }
 
+void ClientMySQLProtocol::mysql_compose_ip_addresses(vector<string> options)
+{
+  for (vector<string>::iterator it= options.begin();
+       it != options.end();
+       ++it)
+  {
+    tokenize(*it, mysql_admin_ip_addresses, ",", true);
+  }
+}
+
 static ListenMySQLProtocol *listen_obj= NULL;
 plugin::Create_function<MySQLPassword> *mysql_password= NULL;
 
 static int init(drizzled::module::Context &context)
 {  
-  mysql_status_table_function_ptr= new MysqlProtocolStatus;
-
-  context.add(mysql_status_table_function_ptr);
   /* Initialize random seeds for the MySQL algorithm with minimal changes. */
   time_t seed_time= time(NULL);
   random_seed1= seed_time % random_max;
   random_seed2= (seed_time / 2) % random_max;
 
   const module::option_map &vm= context.getOptions();
-  if (vm.count("port"))
-  { 
-    if (port > 65535)
-    {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid value of port\n"));
-      exit(-1);
-    }
-  }
-
-  if (vm.count("connect-timeout"))
-  {
-    if (connect_timeout < 1 || connect_timeout > 300)
-    {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid value for connect_timeout\n"));
-      exit(-1);
-    }
-  }
-
-  if (vm.count("read-timeout"))
-  {
-    if (read_timeout < 1 || read_timeout > 300)
-    {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid value for read_timeout\n"));
-      exit(-1);
-    }
-  }
-
-  if (vm.count("write-timeout"))
-  {
-    if (write_timeout < 1 || write_timeout > 300)
-    {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid value for write_timeout\n"));
-      exit(-1);
-    }
-  }
-
-  if (vm.count("retry-count"))
-  {
-    if (retry_count < 1 || retry_count > 100)
-    {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid value for retry_count"));
-      exit(-1);
-    }
-  }
-
-  if (vm.count("buffer-length"))
-  {
-    if (buffer_length < 1024 || buffer_length > 1024*1024)
-    {
-      errmsg_printf(ERRMSG_LVL_ERROR, _("Invalid value for buffer_length\n"));
-      exit(-1);
-    }
-  }
-
-  if (vm.count("bind-address"))
-  {
-    bind_address= strdup(vm["bind-address"].as<string>().c_str());
-  }
-
-  else
-  {
-    bind_address= NULL;
-  }
 
   mysql_password= new plugin::Create_function<MySQLPassword>(MySQLPasswordName);
   context.add(mysql_password);
 
-  listen_obj= new ListenMySQLProtocol("mysql_protocol", true);
+  listen_obj= new ListenMySQLProtocol("mysql_protocol", vm["bind-address"].as<std::string>(), true);
+  listen_obj->addCountersToTable();
   context.add(listen_obj); 
+  context.registerVariable(new sys_var_constrained_value_readonly<in_port_t>("port", port));
+  context.registerVariable(new sys_var_constrained_value<uint32_t>("connect_timeout", connect_timeout));
+  context.registerVariable(new sys_var_constrained_value<uint32_t>("read_timeout", read_timeout));
+  context.registerVariable(new sys_var_constrained_value<uint32_t>("write_timeout", write_timeout));
+  context.registerVariable(new sys_var_constrained_value<uint32_t>("retry_count", retry_count));
+  context.registerVariable(new sys_var_constrained_value<uint32_t>("buffer_length", buffer_length));
+  context.registerVariable(new sys_var_const_string_val("bind_address",
+                                                        vm["bind-address"].as<std::string>()));
+
+  context.registerVariable(new sys_var_uint32_t_ptr("max-connections", &ListenMySQLProtocol::mysql_counters->max_connections));
 
   return 0;
 }
 
-static DRIZZLE_SYSVAR_UINT(port, port, PLUGIN_VAR_RQCMDARG,
-                           N_("Port number to use for connection or 0 for default to with MySQL "
-                              "protocol."),
-                           NULL, NULL, 3306, 0, 65535, 0);
-static DRIZZLE_SYSVAR_UINT(connect_timeout, connect_timeout,
-                           PLUGIN_VAR_RQCMDARG, N_("Connect Timeout."),
-                           NULL, NULL, 10, 1, 300, 0);
-static DRIZZLE_SYSVAR_UINT(read_timeout, read_timeout, PLUGIN_VAR_RQCMDARG,
-                           N_("Read Timeout."), NULL, NULL, 30, 1, 300, 0);
-static DRIZZLE_SYSVAR_UINT(write_timeout, write_timeout, PLUGIN_VAR_RQCMDARG,
-                           N_("Write Timeout."), NULL, NULL, 60, 1, 300, 0);
-static DRIZZLE_SYSVAR_UINT(retry_count, retry_count, PLUGIN_VAR_RQCMDARG,
-                           N_("Retry Count."), NULL, NULL, 10, 1, 100, 0);
-static DRIZZLE_SYSVAR_UINT(buffer_length, buffer_length, PLUGIN_VAR_RQCMDARG,
-                           N_("Buffer length."), NULL, NULL, 16384, 1024,
-                           1024*1024, 0);
-static DRIZZLE_SYSVAR_STR(bind_address, bind_address, PLUGIN_VAR_READONLY,
-                          N_("Address to bind to."), NULL, NULL, NULL);
-
 static void init_options(drizzled::module::option_context &context)
 {
   context("port",
-          po::value<uint32_t>(&port)->default_value(3306),
-          N_("Port number to use for connection or 0 for default to with MySQL "
+          po::value<port_constraint>(&port)->default_value(3306),
+          _("Port number to use for connection or 0 for default to with MySQL "
                               "protocol."));
   context("connect-timeout",
-          po::value<uint32_t>(&connect_timeout)->default_value(10),
-          N_("Connect Timeout."));
+          po::value<timeout_constraint>(&connect_timeout)->default_value(10),
+          _("Connect Timeout."));
   context("read-timeout",
-          po::value<uint32_t>(&read_timeout)->default_value(30),
-          N_("Read Timeout."));
+          po::value<timeout_constraint>(&read_timeout)->default_value(30),
+          _("Read Timeout."));
   context("write-timeout",
-          po::value<uint32_t>(&write_timeout)->default_value(60),
-          N_("Write Timeout."));
+          po::value<timeout_constraint>(&write_timeout)->default_value(60),
+          _("Write Timeout."));
   context("retry-count",
-          po::value<uint32_t>(&retry_count)->default_value(10),
-          N_("Retry Count."));
+          po::value<retry_constraint>(&retry_count)->default_value(10),
+          _("Retry Count."));
   context("buffer-length",
-          po::value<uint32_t>(&buffer_length)->default_value(16384),
-          N_("Buffer length."));
+          po::value<buffer_constraint>(&buffer_length)->default_value(16384),
+          _("Buffer length."));
   context("bind-address",
-          po::value<string>(),
-          N_("Address to bind to."));
+          po::value<string>()->default_value("localhost"),
+          _("Address to bind to."));
+  context("max-connections",
+          po::value<uint32_t>(&ListenMySQLProtocol::mysql_counters->max_connections)->default_value(1000),
+          _("Maximum simultaneous connections."));
+  context("admin-ip-addresses",
+          po::value<vector<string> >()->composing()->notifier(&ClientMySQLProtocol::mysql_compose_ip_addresses),
+          _("A restrictive IP address list for incoming admin connections."));
 }
 
-static drizzle_sys_var* sys_variables[]= {
-  DRIZZLE_SYSVAR(port),
-  DRIZZLE_SYSVAR(connect_timeout),
-  DRIZZLE_SYSVAR(read_timeout),
-  DRIZZLE_SYSVAR(write_timeout),
-  DRIZZLE_SYSVAR(retry_count),
-  DRIZZLE_SYSVAR(buffer_length),
-  DRIZZLE_SYSVAR(bind_address),
-  NULL
-};
-
-static int mysql_protocol_connection_count_func(drizzle_show_var *var, char *buff)
-{
-  var->type= SHOW_LONGLONG;
-  var->value= buff;
-  *((uint64_t *)buff)= ClientMySQLProtocol::connectionCount;
-  return 0;
-}
-
-static int mysql_protocol_connected_count_func(drizzle_show_var *var, char *buff)
-{
-  var->type= SHOW_LONGLONG;
-  var->value= buff;
-  *((uint64_t *)buff)= ClientMySQLProtocol::connected;
-  return 0;
-}
-
-static int mysql_protocol_failed_count_func(drizzle_show_var *var, char *buff)
-{
-  var->type= SHOW_LONGLONG;
-  var->value= buff;
-  *((uint64_t *)buff)= ClientMySQLProtocol::failedConnections;
-  return 0;
-}
-
-static st_show_var_func_container mysql_protocol_connection_count=
-  { &mysql_protocol_connection_count_func };
-
-static st_show_var_func_container mysql_protocol_connected_count=
-  { &mysql_protocol_connected_count_func };
-
-static st_show_var_func_container mysql_protocol_failed_count=
-  { &mysql_protocol_failed_count_func };
-
-static drizzle_show_var mysql_protocol_status_variables[]= {
-  {"Connections",
-  (char*) &mysql_protocol_connection_count, SHOW_FUNC},
-  {"Connected",
-  (char*) &mysql_protocol_connected_count, SHOW_FUNC},
-  {"Failed_connections",
-  (char*) &mysql_protocol_failed_count, SHOW_FUNC},
-  {NULL, NULL, SHOW_LONGLONG}
-};
-
-MysqlProtocolStatus::Generator::Generator(drizzled::Field **fields) :
-  plugin::TableFunction::Generator(fields)
-{
-  status_var_ptr= mysql_protocol_status_variables;
-}
-
-bool MysqlProtocolStatus::Generator::populate()
-{
-  MY_ALIGNED_BYTE_ARRAY(buff_data, SHOW_VAR_FUNC_BUFF_SIZE, int64_t);
-  char * const buff= (char *) &buff_data;
-  drizzle_show_var tmp;
-
-  if (status_var_ptr->name)
-  {
-    std::ostringstream oss;
-    string return_value;
-    const char *value;
-    int type;
-
-    push(status_var_ptr->name);
-
-    if (status_var_ptr->type == SHOW_FUNC)
-    {
-      ((mysql_show_var_func)((st_show_var_func_container *)status_var_ptr->value)->func)(&tmp, buff);
-      value= buff;
-      type= tmp.type;
-    }
-    else
-    {
-      value= status_var_ptr->value;
-      type= status_var_ptr->type;
-    }
-
-    switch(type)
-    {
-    case SHOW_LONGLONG:
-      oss << *(uint64_t*) value;
-      return_value= oss.str();
-      break;
-    default:
-      assert(0);
-    }
-    if (return_value.length())
-      push(return_value);
-    else
-      push(" ");
-
-    status_var_ptr++;
-
-    return true;
-  }
-  return false;
-}
+} /* namespace drizzle_plugin */
 
 DRIZZLE_DECLARE_PLUGIN
 {
@@ -1140,8 +1085,8 @@ DRIZZLE_DECLARE_PLUGIN
   "Eric Day",
   "MySQL Protocol Module",
   PLUGIN_LICENSE_GPL,
-  init,             /* Plugin Init */
-  sys_variables, /* system variables */
-  init_options    /* config options */
+  drizzle_plugin::init,             /* Plugin Init */
+  NULL, /* depends */
+  drizzle_plugin::init_options    /* config options */
 }
 DRIZZLE_DECLARE_PLUGIN_END;
