@@ -17,12 +17,10 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef PLUGIN_MYSQL_PROTOCOL_OPTIONS_H
-#define PLUGIN_MYSQL_PROTOCOL_OPTIONS_H
+#pragma once
 
-#ifdef  __cplusplus
-extern "C" {
-#endif
+namespace drizzle_plugin
+{
 
 enum drizzle_option
 {
@@ -72,13 +70,6 @@ struct st_drizzleclient_options {
 };
 
 
-#ifdef  __cplusplus
-}
-#endif
-
-#define CLIENT_NET_READ_TIMEOUT    365*24*3600  /* Timeout on read */
-#define CLIENT_NET_WRITE_TIMEOUT  365*24*3600  /* Timeout on write */
-
 #define CLIENT_LONG_PASSWORD    1       /* new more secure passwords */
 #define CLIENT_FOUND_ROWS       2       /* Found instead of affected rows */
 #define CLIENT_LONG_FLAG        4       /* Get all column flags */
@@ -88,12 +79,17 @@ struct st_drizzleclient_options {
 #define CLIENT_ODBC             64      /* Odbc client */
 #define CLIENT_IGNORE_SPACE     256     /* Ignore spaces before '(' */
 #define CLIENT_PROTOCOL_MYSQL41 512     /* New 4.1 protocol */
+#define CLIENT_INTERACTIVE      1024
 #define CLIENT_SSL              2048    /* Switch to SSL after handshake */
 #define CLIENT_IGNORE_SIGPIPE   4096    /* IGNORE sigpipes */
+#define CLIENT_TRANSACTIONS     8192    /* Support transactions */
 #define CLIENT_RESERVED         16384   /* Old flag for 4.1 protocol  */
 #define CLIENT_SECURE_CONNECTION 32768  /* New 4.1 authentication */
 #define CLIENT_MULTI_STATEMENTS (1UL << 16) /* Enable/disable multi-stmt support */
 #define CLIENT_MULTI_RESULTS    (1UL << 17) /* Enable/disable multi-results */
+#define CLIENT_CAPABILITIES_PLUGIN_AUTH (1 << 19)
+
+#define CLIENT_ADMIN            (1UL << 25) /* Admin client connection */
 
 #define CLIENT_SSL_VERIFY_SERVER_CERT (1UL << 30)
 #define CLIENT_REMEMBER_OPTIONS (1UL << 31)
@@ -107,12 +103,16 @@ struct st_drizzleclient_options {
                            CLIENT_COMPRESS | \
                            CLIENT_ODBC | \
                            CLIENT_IGNORE_SPACE | \
+                           CLIENT_INTERACTIVE | \
                            CLIENT_SSL | \
                            CLIENT_IGNORE_SIGPIPE | \
+                           CLIENT_TRANSACTIONS | \
                            CLIENT_RESERVED | \
                            CLIENT_SECURE_CONNECTION | \
                            CLIENT_MULTI_STATEMENTS | \
                            CLIENT_MULTI_RESULTS | \
+                           CLIENT_CAPABILITIES_PLUGIN_AUTH | \
+                           CLIENT_ADMIN | \
                            CLIENT_SSL_VERIFY_SERVER_CERT | \
                            CLIENT_REMEMBER_OPTIONS)
 
@@ -125,4 +125,5 @@ struct st_drizzleclient_options {
                                                & ~CLIENT_COMPRESS) \
                                                & ~CLIENT_SSL_VERIFY_SERVER_CERT)
 
-#endif /* PLUGIN_MYSQL_PROTOCOL_OPTIONS_H */
+} /* namespace drizzle_plugin */
+
