@@ -1,4 +1,4 @@
-/* Copyright (c) 2008 PrimeBase Technologies GmbH, Germany
+/* Copyright (C) 2008 PrimeBase Technologies GmbH, Germany
  *
  * PrimeBase Media Stream for MySQL
  *
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * Original author: Paul McCullagh
  * Continued development: Barry Leslie
@@ -28,12 +28,12 @@
  */
  
 #ifdef DRIZZLED
-#include "config.h"
+#include <config.h>
 #include <drizzled/common.h>
 #include <drizzled/session.h>
 #include <drizzled/table.h>
 #include <drizzled/message/table.pb.h>
-#include "drizzled/charset_info.h"
+#include <drizzled/charset_info.h>
 #include <drizzled/table_proto.h>
 #include <drizzled/field.h>
 #endif
@@ -529,8 +529,7 @@ MSRepoFile *MSDatabase::getRepoFileFromPool(uint32_t repo_id, bool missing_ok)
 	if (!file) {
 		file = repo->openRepoFile();
 		lock_(myRepostoryList);
-		repo->addRepoFile(file);
-		file->retain();
+		repo->addRepoFile(RETAIN(file));
 		unlock_(myRepostoryList);
 	}
 	return_(file);
@@ -545,11 +544,11 @@ void MSDatabase::returnRepoFileToPool(MSRepoFile *file)
 	push_(file);
 	if ((repo = file->myRepo)) {
 		if (repo->isRemovingFP) {
-			repo->removeRepoFile(file);
+			repo->removeRepoFile(file); // No retain expected
 			myRepostoryList->wakeup();
 		}
 		else
-			repo->returnRepoFile(file);
+			repo->returnRepoFile(file); // No retain expected
 		repo->release(); /* [++] here is the release.  */
 	}
 	release_(file);
@@ -1047,7 +1046,7 @@ MSDatabase *MSDatabase::getDatabase(const char *db_name, bool create)
 	return getDatabase(CSString::newString(db_name), create);
 }
 
-MSDatabase *MSDatabase::getDatabase(uint32_t db_id)
+MSDatabase *MSDatabase::getDatabase(uint32_t db_id, bool missing_ok)
 {
 	MSDatabase *db;
 	
@@ -1076,7 +1075,7 @@ MSDatabase *MSDatabase::getDatabase(uint32_t db_id)
 						int len = ptr - dir_name;
 						ptr++;
 						if ((strtoul(ptr, NULL, 10) == db_id) && len) {
-							db = getDatabase(CSCString::newString(dir_name, len), true);
+							db = getDatabase(CSString::newString(dir_name, len), true);
 							ASSERT(db->myDatabaseID == db_id);
 						}
 					}
@@ -1088,7 +1087,7 @@ MSDatabase *MSDatabase::getDatabase(uint32_t db_id)
 	}
 	unlock_(gDatabaseList);
 	
-	if (!db) {
+	if ((!db) && !missing_ok) {
 		char buffer[CS_EXC_MESSAGE_SIZE];
 
 		cs_strcpy(CS_EXC_MESSAGE_SIZE, buffer, "Unknown database #");
@@ -1597,7 +1596,7 @@ void MSDatabase::dropDatabase(MSDatabase *doomedDatabase, const char *db_name )
 			gDatabaseList->remove(doomedDatabase->getKey());
 		if (!self->myMustQuit) 
 			unlock_(gDatabaseList); 
-		ASSERT(doomedDatabase->iRefCount == 1);
+		ASSERT(doomedDatabase->getRefCount() == 1);
 		release_(doomedDatabase);
 		
 	} else {
