@@ -1,4 +1,4 @@
-/* Copyright (c) 2008 PrimeBase Technologies GmbH, Germany
+/* Copyright (C) 2008 PrimeBase Technologies GmbH, Germany
  * Derived from code Copyright (C) 2000-2004 MySQL AB
  *
  * PrimeBase MS
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  *
  *  Created by Barry Leslie on 8/27/08.
  *
@@ -212,8 +212,8 @@ mysql_prepare_create_table(THD *thd, HA_CREATE_INFO *create_info,
   int		timestamps= 0, timestamps_with_niladic= 0;
   int		field_no,dup_no;
   int		select_field_pos,auto_increment=0;
-  List_iterator<Create_field> it(alter_info->create_list);
-  List_iterator<Create_field> it2(alter_info->create_list);
+  List<Create_field>::iterator it(alter_info->create_list);
+  List<Create_field>::iterator it2(alter_info->create_list);
   uint total_uneven_bit_length= 0;
   DBUG_ENTER("mysql_prepare_create_table");
 
@@ -307,7 +307,7 @@ mysql_prepare_create_table(THD *thd, HA_CREATE_INFO *create_info,
         */
         interval= sql_field->interval= typelib(thd->mem_root,
                                                sql_field->interval_list);
-        List_iterator<String> int_it(sql_field->interval_list);
+        List<String>::iterator int_it(sql_field->interval_list);
         String conv, *tmp;
         char comma_buf[2];
         int comma_length= cs->cset->wc_mb(cs, ',', (uchar*) comma_buf,
@@ -487,14 +487,14 @@ mysql_prepare_create_table(THD *thd, HA_CREATE_INFO *create_info,
 	sql_field->sql_type == MYSQL_TYPE_VARCHAR &&
 	create_info->row_type != ROW_TYPE_FIXED)
       (*db_options)|= HA_OPTION_PACK_RECORD;
-    it2.rewind();
+    it2= alter_info->create_list;
   }
 
   /* record_offset will be increased with 'length-of-null-bits' later */
   record_offset= 0;
   null_fields+= total_uneven_bit_length;
 
-  it.rewind();
+  it= alter_info->create_list;
   while ((sql_field=it++))
   {
     DBUG_ASSERT(sql_field->charset != 0);
@@ -538,8 +538,8 @@ mysql_prepare_create_table(THD *thd, HA_CREATE_INFO *create_info,
 
   /* Create keys */
 
-  List_iterator<Key> key_iterator(alter_info->key_list);
-  List_iterator<Key> key_iterator2(alter_info->key_list);
+  List<Key>::iterator key_iterator(alter_info->key_list);
+  List<Key>::iterator key_iterator2(alter_info->key_list);
   uint key_parts=0, fk_key_count=0;
   bool primary_key=0,unique_key=0;
   Key *key, *key2;
@@ -584,7 +584,7 @@ mysql_prepare_create_table(THD *thd, HA_CREATE_INFO *create_info,
       my_error(ER_TOO_LONG_IDENT, MYF(0), key->DOT_STR(name));
       DBUG_RETURN(TRUE);
     }
-    key_iterator2.rewind ();
+    key_iterator2= alter_info->key_list;
     if (key->type != Key::FOREIGN_KEY)
     {
       while ((key2 = key_iterator2++) != key)
@@ -637,7 +637,7 @@ mysql_prepare_create_table(THD *thd, HA_CREATE_INFO *create_info,
   if (!*key_info_buffer || ! key_part_info)
     DBUG_RETURN(TRUE);				// Out of memory
 
-  key_iterator.rewind();
+  key_iterator= alter_info->key_list;
   key_number=0;
   for (; (key=key_iterator++) ; key_number++)
   {
@@ -751,14 +751,15 @@ mysql_prepare_create_table(THD *thd, HA_CREATE_INFO *create_info,
     if (key_info->block_size)
       key_info->flags|= HA_USES_BLOCK_SIZE;
 
-    List_iterator<Key_part_spec> cols(key->columns), cols2(key->columns);
+    List<Key_part_spec>::iterator cols(key->columns);
+    List<Key_part_spec>::iterator cols2(key->columns);
     CHARSET_INFO *ft_key_charset=0;  // for FULLTEXT
     for (uint column_nr=0 ; (column=cols++) ; column_nr++)
     {
       uint length;
       Key_part_spec *dup_column;
 
-      it.rewind();
+      it= alter_info->create_list;
       field=0;
       while ((sql_field=it++) &&
 	     my_strcasecmp(system_charset_info,
@@ -781,7 +782,7 @@ mysql_prepare_create_table(THD *thd, HA_CREATE_INFO *create_info,
 	  DBUG_RETURN(TRUE);
 	}
       }
-      cols2.rewind();
+      cols2= key->columns;
       if (key->type == Key::FULLTEXT)
       {
 	if ((sql_field->sql_type != MYSQL_TYPE_STRING &&
@@ -1024,7 +1025,7 @@ mysql_prepare_create_table(THD *thd, HA_CREATE_INFO *create_info,
   create_info->null_bits= null_fields;
 
   /* Check fields. */
-  it.rewind();
+  it= alter_info->create_list;
   while ((sql_field=it++))
   {
     Field::utype type= (Field::utype) MTYP_TYPENR(sql_field->unireg_check);
@@ -1148,7 +1149,7 @@ static bool mysql_create_table_no_lock(THD *thd,
     goto err;
   }
 
-  LOCK_open.lock;
+  pthread_mutex_lock(&LOCK_open);
   if (!internal_tmp_table && !(create_info->options & HA_LEX_CREATE_TMP_TABLE))
   {
     if (!access(path,F_OK))
@@ -1256,7 +1257,7 @@ static bool mysql_create_table_no_lock(THD *thd,
 #endif
   error= FALSE;
 unlock_and_end:
-  LOCK_open.unlock;
+  pthread_mutex_unlock(&LOCK_open);
 
 err:
   thd_proc_info(thd, "After create");
