@@ -1,4 +1,4 @@
-/* Copyright (c) 2010 PrimeBase Technologies GmbH, Germany
+/* Copyright (C) 2010 PrimeBase Technologies GmbH, Germany
  *
  * PrimeBase Media Stream for MySQL
  *
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * Barry Leslie
  *
@@ -25,13 +25,13 @@
  */
 
 #ifdef DRIZZLED
-#include "config.h"
+#include <config.h>
 #include <set>
 #include <drizzled/common.h>
 #include <drizzled/plugin.h>
 #include <drizzled/session.h>
-using namespace drizzled;
-using namespace drizzled::plugin;
+#include <drizzled/sql_lex.h>
+
 
 #define my_strdup(a,b) strdup(a)
 
@@ -44,6 +44,7 @@ using namespace drizzled::plugin;
 #endif 
 
 #include <inttypes.h>
+#include <string.h>
 
 #include "cslib/CSDefs.h"
 #include "cslib/CSObject.h"
@@ -57,12 +58,39 @@ using namespace drizzled::plugin;
 #include "database_ms.h"
 #include "parameters_ms.h"
 
+using namespace std;
+using namespace drizzled;
+using namespace drizzled::plugin;
+
+#include <drizzled/module/option_map.h>
+#include <boost/program_options.hpp>
+namespace po= boost::program_options;
 #ifndef PBMS_PORT
 #define PBMS_PORT 8080
 #endif
 
+/* Note: 'new' used here is NOT CSObject::new which is a DEBUG define*/
+#ifdef new
+#undef new
+#endif
 
-static int my_port_number = PBMS_PORT;
+
+#ifdef DRIZZLED
+static port_constraint pbms_port_number;
+
+static std::string my_repository_threshold;
+static std::string my_temp_log_threshold;
+static std::string my_http_metadata_headers;
+
+typedef drizzled::constrained_check<uint32_t, 100, 0> percent_constraint;
+static percent_constraint my_garbage_threshold;
+static uint32_nonzero_constraint my_temp_blob_timeout;
+static uint32_nonzero_constraint my_max_keep_alive;
+static uint32_nonzero_constraint my_backup_db_id;
+
+static uint32_t my_server_id = 1;
+#else
+uint32_t pbms_port_number;
 
 static char		*my_repository_threshold = NULL;
 static char		*my_temp_log_threshold = NULL;
@@ -74,6 +102,7 @@ static u_long	my_max_keep_alive = MS_DEFAULT_KEEP_ALIVE;
 
 static u_long	my_backup_db_id = 1;
 static uint32_t my_server_id = 1;
+#endif
 
 #ifdef DRIZZLED
 static set<string> my_black_list;
@@ -81,13 +110,13 @@ static bool my_events_enabled = true;
 static CSMutex my_table_list_lock;
 
 typedef enum {MATCH_ALL, MATCH_DBS, MATCH_SOME, MATCH_NONE, MATCH_UNKNOWN, MATCH_ERROR} TableMatchState;
-static char *my_table_list = NULL;
-static const char *dflt_my_table_list = "*";
+static std::string my_table_list;
 
 static TableMatchState my_table_match = MATCH_UNKNOWN;
 
-static int32_t my_before_insert_position= 1;      // Call this event observer first.
-static int32_t my_before_update_position= 1;
+typedef constrained_check<int32_t, INT32_MAX-1, 1> before_position_constraint;
+static before_position_constraint my_before_insert_position;      // Call this event observer first.
+static before_position_constraint my_before_update_position;
 
 using namespace drizzled;
 using namespace drizzled::plugin;
@@ -121,7 +150,7 @@ struct st_mysql_sys_var
 #endif
 
 //--------------
-uint32_t PBMSParameters::getPortNumber(){ return my_port_number;}
+uint32_t PBMSParameters::getPortNumber(){ return pbms_port_number;}
 
 //--------------
 uint32_t PBMSParameters::getServerID(){ return my_server_id;}
@@ -129,41 +158,53 @@ uint32_t PBMSParameters::getServerID(){ return my_server_id;}
 //--------------
 uint64_t PBMSParameters::getRepoThreshold()
 {
+#ifdef DRIZZLED
+  return (uint64_t) cs_byte_size_to_int8(my_repository_threshold.c_str());
+#else
 	if (my_repository_threshold)
 		return((uint64_t) cs_byte_size_to_int8(my_repository_threshold));
 
 	return((uint64_t) cs_byte_size_to_int8(MS_REPO_THRESHOLD_DEF));
+#endif
 }
 
 //--------------
 uint64_t PBMSParameters::getTempLogThreshold()
 {
+#ifdef DRIZZLED
+  return (uint64_t) cs_byte_size_to_int8(my_temp_log_threshold.c_str());
+#else
 	if (my_temp_log_threshold)
 		return((uint64_t) cs_byte_size_to_int8(my_temp_log_threshold));
 
 	return((uint64_t) cs_byte_size_to_int8(MS_TEMP_LOG_THRESHOLD_DEF));
+#endif
 }
 
 //--------------
-uint32_t PBMSParameters::getTempBlobTimeout(){ return my_temp_blob_timeout;}
+uint32_t PBMSParameters::getTempBlobTimeout(){ return static_cast<uint32_t>(my_temp_blob_timeout);}
 
 //--------------
-uint32_t PBMSParameters::getGarbageThreshold(){ return my_garbage_threshold;}
+uint32_t PBMSParameters::getGarbageThreshold(){ return static_cast<uint32_t>(my_garbage_threshold);}
 
 //--------------
-uint32_t PBMSParameters::getMaxKeepAlive(){ return my_max_keep_alive;}
+uint32_t PBMSParameters::getMaxKeepAlive(){ return static_cast<uint32_t>(my_max_keep_alive);}
 
 //--------------
 const char * PBMSParameters::getDefaultMetaDataHeaders()
 {
+#ifdef DRIZZLED
+        return my_http_metadata_headers.c_str();
+#else
 	if (my_http_metadata_headers)
 		return my_http_metadata_headers; 
 		
 	return MS_HTTP_METADATA_HEADERS_DEF; 
+#endif
 }
 
 //-----------------
-uint32_t PBMSParameters::getBackupDatabaseID() { return my_backup_db_id;}
+uint32_t PBMSParameters::getBackupDatabaseID() { return static_cast<uint32_t>(my_backup_db_id);}
 
 //-----------------
 void PBMSParameters::setBackupDatabaseID(uint32_t id) { my_backup_db_id = id;}
@@ -292,14 +333,137 @@ static const char* locate_db(const char *list, const char *db, int len)
 	return NULL;
 }
 
+#ifdef DRIZZLED
+static void temp_blob_timeout_update(Session*, sql_var_t)
+{
+	CSThread		*self;
+	PBMSResultRec	result;
+	
+	if (MSEngine::enterConnectionNoThd(&self, &result))
+		return;
+	try_(a) {
+		MSDatabase::wakeTempLogThreads();
+	}
+	
+	catch_(a);
+	cont_(a);
+}
+//----------
+static int table_list_validate(Session*, set_var *var)
+{
+	const char *list= var->value->str_value.ptr();
+	if (list == NULL)
+		return 1;
+
+	TableMatchState state = set_match_type(list);
+	if (state == MATCH_ERROR)
+		return 1;
+		
+	std::string new_list(list);
+
+	my_table_list_lock.lock();
+	my_table_list.swap(new_list);
+	my_table_match = state;
+	my_table_list_lock.unlock();
+
+	return 0;
+}
+
+//----------
+#endif
+
 //--------------
 // Parameter update functions are not called for parameters that are set on
 // the command line. PBMSParameters::startUp() will perform any initialization required.
-void PBMSParameters::startUp()
+#ifdef DRIZZLED
+void PBMSParameters::startUp(drizzled::module::Context &context)
+#else
+void PBMSParameters::startup()
+#endif
 { 
+
+#ifdef DRIZZLED
+	my_table_match = set_match_type(my_table_list.c_str());
+        const module::option_map &vm= context.getOptions();
+	my_events_enabled= (vm.count("watch-disable")) ? false : true;
+
+        context.registerVariable(new sys_var_constrained_value_readonly<in_port_t>("port",
+                                                                         pbms_port_number));
+        context.registerVariable(new sys_var_std_string("repository_threshold",
+                                                        my_repository_threshold));
+        context.registerVariable(new sys_var_std_string("temp_log_threshold",
+                                                        my_temp_log_threshold));
+        context.registerVariable(new sys_var_const_string("http_metadata_headers",
+                                                          my_http_metadata_headers));
+        context.registerVariable(new sys_var_constrained_value_readonly<uint32_t>("garbage_threshold", my_garbage_threshold));
+	context.registerVariable(new sys_var_constrained_value<uint32_t>("temp_blob_timeout",
+									 my_temp_blob_timeout,
+									 temp_blob_timeout_update));
+	context.registerVariable(new sys_var_constrained_value<uint32_t>("max_keep_alive",
+									 my_max_keep_alive));
+	context.registerVariable(new sys_var_constrained_value<uint32_t>("next_backup_db_id",
+									 my_backup_db_id));
+	context.registerVariable(new sys_var_std_string("watch_tables",
+							my_table_list,
+							table_list_validate));
+	context.registerVariable(new sys_var_bool_ptr("watch_enable",
+						      &my_events_enabled));
+	context.registerVariable(new sys_var_constrained_value<int32_t>("before_insert_position",
+									my_before_insert_position));
+	context.registerVariable(new sys_var_constrained_value<int32_t>("before_update_position",
+									my_before_update_position));
+
+#else
 	my_table_match = set_match_type(my_table_list);
+#endif
 }
 
+
+#ifdef DRIZZLED
+void PBMSParameters::initOptions(drizzled::module::option_context &context)
+{
+	context("port",
+                po::value<port_constraint>(&pbms_port_number)->default_value(DEFAULT_PBMS_PORT),
+                _("Port number to use for connection or 0 for default PBMS port "));
+        context("repository-threshold",
+                po::value<std::string>(&my_repository_threshold)->default_value(MS_REPO_THRESHOLD_DEF),
+                _("The maximum size of a BLOB repository file."));
+        context("temp-log-threshold",
+                po::value<std::string>(&my_temp_log_threshold)->default_value(MS_TEMP_LOG_THRESHOLD_DEF),
+                _("The maximum size of a temorary BLOB log file."));
+        context("http-metadata-headers",
+                po::value<std::string>(&my_http_metadata_headers)->default_value(MS_HTTP_METADATA_HEADERS_DEF),
+                _("A ':' delimited list of metadata header names to be used to initialize "
+                   "the pbms_metadata_header table when a database is created."));
+        context("garbage-threshold",
+                po::value<percent_constraint>(&my_garbage_threshold)->default_value(MS_DEFAULT_GARBAGE_LEVEL),
+                _("The percentage of garbage in a repository file before it is compacted."));
+	context("temp-blob-timeout",
+		po::value<uint32_nonzero_constraint>(&my_temp_blob_timeout)->default_value(MS_DEFAULT_TEMP_LOG_WAIT),
+		_("The timeout, in seconds, for temporary BLOBs. Uploaded blob data is removed after this time, unless committed to the database."));
+	context("max-keep-alive",
+		po::value<uint32_nonzero_constraint>(&my_temp_blob_timeout)->default_value(MS_DEFAULT_KEEP_ALIVE),
+		_("The timeout, in milli-seconds, before the HTTP server will close an inactive HTTP connection."));
+	context("next-backup-db-id",
+		po::value<uint32_nonzero_constraint>(&my_backup_db_id)->default_value(1),
+		_("The next backup ID to use when backing up a PBMS database."));
+	context("watch-tables",
+		po::value<std::string>(&my_table_list)->default_value("*"),
+		_("A comma delimited list of tables to watch of the format: <database>.<table>, ..."));
+	context("watch-disable",
+		_("Enable PBMS daemon Insert/Update/Delete event scanning"));
+
+	context("before-insert-position",
+		po::value<before_position_constraint>(&my_before_insert_position)->default_value(1),
+		_("Before insert row event observer call position"));
+
+	context("before-update-position",
+		po::value<before_position_constraint>(&my_before_update_position)->default_value(1),
+		_("Before update row event observer call position"));
+
+}
+#endif
+
 //-----------------
 bool PBMSParameters::isBlackListedDB(const char *db)
 {
@@ -315,10 +479,29 @@ void PBMSParameters::blackListedDB(const char *db)
 	my_black_list.insert(string(db));
 }		
 
+//-----------------
+bool PBMSParameters::try_LocateDB(CSThread *self, const char *db, bool *found)
+{
+	volatile bool rtc = true;
+	try_(a) {
+		lock_(&my_table_list_lock);	
+		
+			
+		*found = (locate_db(my_table_list.c_str(), db, strlen(db)) != NULL);
+			
+		unlock_(&my_table_list_lock);
+		rtc = false;
+	}
+	
+	catch_(a)
+	cont_(a);
+	return rtc;
+}
+
 //-----------------
 bool PBMSParameters::isBLOBDatabase(const char *db)
 {
-	CSThread *self;
+	CSThread *self= NULL;
 	int		err;
 	PBMSResultRec result;
 	bool found = false;
@@ -327,7 +510,16 @@ bool PBMSParameters::isBLOBDatabase(const char *db)
 		return false;
 		
 	if (my_table_match == MATCH_UNKNOWN)
-		my_table_match = set_match_type(my_table_list);
+	{
+		try_(a) {
+			lock_(&my_table_list_lock);	
+			my_table_match = set_match_type(my_table_list.c_str());
+			unlock_(&my_table_list_lock);
+		}
+
+		catch_(a)
+		cont_(a);
+	}
 
 	if (my_table_match == MATCH_NONE)
 		return false;
@@ -338,19 +530,9 @@ bool PBMSParameters::isBLOBDatabase(const char *db)
 	if ((err = MSEngine::enterConnectionNoThd(&self, &result)) == 0) {
 
 		inner_();
-		try_(a) {
-			lock_(&my_table_list_lock);	
-			
-				
-			found = (locate_db(my_table_list, db, strlen(db)) != NULL);
-				
-			unlock_(&my_table_list_lock);
-		}
-		
-		catch_(a) {
+		if (try_LocateDB(self, db, &found)) {
 			err = MSEngine::exceptionToResult(&self->myException, &result);
-		}
-		cont_(a);
+		}		
 		outer_();
 	
 	}
@@ -363,21 +545,71 @@ bool PBMSParameters::isBLOBDatabase(const char *db)
 	return found;
 }
 	
+//-----------------
+bool PBMSParameters::try_LocateTable(CSThread *self, const char *db, const char *table, bool *found)
+{
+	volatile bool rtc = true;
+	try_(a) {
+		int db_len, table_len, match_len;
+		
+		lock_(&my_table_list_lock);	
+				
+		db_len = strlen(db);
+		table_len = strlen(table);
+		
+		const char *ptr = my_table_list.c_str();
+		while (ptr) {
+			ptr = locate_db(ptr, db, db_len);
+			if (ptr) {
+				match_len = 0;
+				if (*ptr == '*')
+					match_len = 1;
+				else if (strncmp(ptr, table, table_len) == 0)
+					match_len = table_len;
+					
+				if (match_len) {
+					ptr += match_len;
+					if ((!*ptr) || (*ptr == ',') || isspace(*ptr)) {
+						*found = true;
+						break;
+					}
+				}
+				
+				NEXT_IN_TABLE_LIST(ptr);
+			}
+		}
+			
+		unlock_(&my_table_list_lock);
+		rtc = false;
+	}
+	
+	catch_(a)
+	cont_(a);
+	return rtc;
+}
+
 //-----------------
 bool PBMSParameters::isBLOBTable(const char *db, const char *table)
 {
-	CSThread *self;
+	CSThread *self= NULL;
 	int		err;
 	PBMSResultRec result;
 	bool found = false;
-	const char *ptr;
-	int db_len, table_len, match_len;
 	
 	if (isBlackListedDB(db))
 		return false;
 		
 	if (my_table_match == MATCH_UNKNOWN)
-		my_table_match = set_match_type(my_table_list);
+	{
+		try_(a) {
+			lock_(&my_table_list_lock);	
+			my_table_match = set_match_type(my_table_list.c_str());
+			unlock_(&my_table_list_lock);
+		}
+
+		catch_(a)
+		cont_(a);
+	}
 
 	if (my_table_match == MATCH_NONE)
 		return false;
@@ -388,40 +620,9 @@ bool PBMSParameters::isBLOBTable(const char *db, const char *table)
 	if ((err = MSEngine::enterConnectionNoThd(&self, &result)) == 0) {
 
 		inner_();
-		try_(a) {
-			lock_(&my_table_list_lock);	
-					
-			db_len = strlen(db);
-			table_len = strlen(table);
-			
-			ptr = my_table_list;
-			while (ptr) {
-				ptr = locate_db(ptr, db, db_len);
-				if (ptr) {
-					match_len = 0;
-					if (*ptr == '*')
-						match_len = 1;
-					else if (strncmp(ptr, table, table_len) == 0)
-						match_len = table_len;
-						
-					if (match_len) {
-						ptr += match_len;
-						if ((!*ptr) || (*ptr == ',') || isspace(*ptr)) {
-							found = true;
-							break;
-						}
-					}
-					
-					NEXT_IN_TABLE_LIST(ptr);
-				}
-			}
-				
-			unlock_(&my_table_list_lock);
-		}
-		catch_(a) {
+		if (try_LocateTable(self, db, table, &found)) {
 			err = MSEngine::exceptionToResult(&self->myException, &result);
-		}
-		cont_(a);
+		}		
 		outer_();
 	
 	}
@@ -436,13 +637,14 @@ bool PBMSParameters::isBLOBTable(const char *db, const char *table)
 
 
 //-----------------
-int32_t PBMSParameters::getBeforeUptateEventPosition() { return my_before_update_position;}
+int32_t PBMSParameters::getBeforeUptateEventPosition() { return static_cast<int32_t>(my_before_update_position);}
 
 //-----------------
-int32_t PBMSParameters::getBeforeInsertEventPosition() { return my_before_insert_position;}
+int32_t PBMSParameters::getBeforeInsertEventPosition() { return static_cast<int32_t>(my_before_insert_position);}
 #endif // DRIZZLED
 
 //-----------------
+#ifndef DRIZZLED
 static void pbms_temp_blob_timeout_func(THD *thd, struct st_mysql_sys_var *var, void *trg, CONST_SAVE void *save)
 {
 	CSThread		*self;
@@ -462,11 +664,14 @@ static void pbms_temp_blob_timeout_func(THD *thd, struct st_mysql_sys_var *var,
 	catch_(a);
 	cont_(a);
 }
+#endif
+//-----------------
+//-----------------
 
-//-----------------
-//-----------------
-static MYSQL_SYSVAR_INT(port, my_port_number,
-	PLUGIN_VAR_OPCMDARG | PLUGIN_VAR_READONLY,
+#ifndef DRIZZLED
+
+static MYSQL_SYSVAR_UINT(port, pbms_port_number,
+	PLUGIN_VAR_READONLY,
 	"The port for the server stream-based communications.",
 	NULL, NULL, PBMS_PORT, 0, 64*1024, 1);
 
@@ -506,86 +711,6 @@ static MYSQL_SYSVAR_ULONG(next_backup_db_id, my_backup_db_id,
 	"The next backup ID to use when backing up a PBMS database.",
 	NULL, NULL, 1, 1, UINT32_MAX, 1);
 
-
-#ifdef DRIZZLED
-
-//----------
-static int check_table_list(THD *, struct st_mysql_sys_var *, void *save, drizzle_value *value)
-{
-	char buffer[100];
-	int len = 100;
-	const char *list = value->val_str(value, buffer, &len);
-	TableMatchState state;
-	
-	state = set_match_type(list);
-	if (state == MATCH_ERROR)
-		return 1;
-		
-	char *new_list = strdup(list);
-	if (!new_list)
-		return 1;
-	
-	my_table_list_lock.lock();
-	if (my_table_list && (my_table_list != dflt_my_table_list)) free(my_table_list);
-	my_table_list = new_list;
-	
-	my_table_match = state;
-	my_table_list_lock.unlock();
-
-   *static_cast<const char**>(save)= my_table_list;
-
-	return 0;
-}
-
-//----------
-static void set_table_list(THD *, struct st_mysql_sys_var *, void *var_ptr, CONST_SAVE void *)
-{
-	// Everything was done in check_table_list()
-  *static_cast<const char**>(var_ptr)= my_table_list;
-}
-
-//----------
-
-static MYSQL_SYSVAR_STR(watch_tables,
-                           my_table_list,
-                           PLUGIN_VAR_OPCMDARG | PLUGIN_VAR_MEMALLOC,
-                           N_("A comma delimited list of tables to watch of the format: <database>.<table>, ..."),
-                           check_table_list, /* check func */
-                           set_table_list, /* update func */
-                           dflt_my_table_list /* default */);
-
-static MYSQL_SYSVAR_BOOL(watch_enable,
-                           my_events_enabled,
-                           PLUGIN_VAR_OPCMDARG,
-                           N_("Enable PBMS daemon Insert/Update/Delete event scanning"),
-                           NULL, /* check func */
-                           NULL, /* update func */
-                           true /* default */);
-
-static MYSQL_SYSVAR_INT(before_insert_position,
-                           my_before_insert_position,
-                           PLUGIN_VAR_OPCMDARG,
-                           N_("Before insert row event observer call position"),
-                           NULL, /* check func */
-                           NULL, /* update func */
-                           1, /* default */
-                           1, /* min */
-                           INT32_MAX -1, /* max */
-                           0 /* blk */);
-
-static MYSQL_SYSVAR_INT(before_update_position,
-                           my_before_update_position,
-                           PLUGIN_VAR_OPCMDARG,
-                           N_("Before update row event observer call position"),
-                           NULL, /* check func */
-                           NULL, /* update func */
-                           1, /* default */
-                           1, /* min */
-                           INT32_MAX -1, /* max */
-                           0 /* blk */);
-
-#endif // DRIZZLED
-
 struct st_mysql_sys_var* pbms_system_variables[] = {
 	MYSQL_SYSVAR(port),
 	MYSQL_SYSVAR(repository_threshold),
@@ -595,19 +720,10 @@ struct st_mysql_sys_var* pbms_system_variables[] = {
 	MYSQL_SYSVAR(http_metadata_headers),
 	MYSQL_SYSVAR(max_keep_alive),
 	MYSQL_SYSVAR(next_backup_db_id),
-	
-#ifdef DRIZZLED
-	MYSQL_SYSVAR(watch_tables),
-	MYSQL_SYSVAR(watch_enable),
-	
-	MYSQL_SYSVAR(before_insert_position),
-	MYSQL_SYSVAR(before_update_position),
-#endif
-  
 	NULL
 };
 
+#endif // !DRIZZLED
 
 
-
-
+// vim:noexpandtab:sts=8:sw=8:tabstop=8:smarttab:
