@@ -1,4 +1,4 @@
-/* Copyright (c) 2008 PrimeBase Technologies GmbH, Germany
+/* Copyright (C) 2008 PrimeBase Technologies GmbH, Germany
  *
  * PrimeBase Media Stream for MySQL
  *
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * Original author: Paul McCullagh
  * Continued development: Barry Leslie
@@ -28,7 +28,7 @@
  */
 
 #ifdef DRIZZLED
-#include "config.h"
+#include <config.h>
 #include <drizzled/common.h>
 #include <drizzled/session.h>
 #include <drizzled/table.h>
@@ -36,7 +36,7 @@
 #include <drizzled/field/blob.h>
 
 #include <drizzled/message/table.pb.h>
-#include "drizzled/charset_info.h"
+#include <drizzled/charset_info.h>
 #include <drizzled/table_proto.h>
 #endif
 
@@ -93,17 +93,17 @@ static DT_FIELD_INFO pbms_repository_info[]=
 #ifdef HAVE_ALIAS_SUPPORT
 	{"Blob_alias",			BLOB_ALIAS_LENGTH, NULL, MYSQL_TYPE_VARCHAR,		&my_charset_utf8_bin,	0,								"The BLOB alias"},
 #endif
-	{"Repository_id",		NULL, NULL, MYSQL_TYPE_LONG,		NULL,					NOT_NULL_FLAG,					"The repository file number"},
-	{"Repo_blob_offset",	NULL, NULL, MYSQL_TYPE_LONGLONG,	NULL,					NOT_NULL_FLAG,					"The offset of the BLOB in the repository file"},
-	{"Blob_size",			NULL, NULL, MYSQL_TYPE_LONGLONG,	NULL,					NOT_NULL_FLAG,					"The size of the BLOB in bytes"},
+	{"Repository_id",		NOVAL, NULL, MYSQL_TYPE_LONG,		NULL,					NOT_NULL_FLAG,					"The repository file number"},
+	{"Repo_blob_offset",	NOVAL, NULL, MYSQL_TYPE_LONGLONG,	NULL,					NOT_NULL_FLAG,					"The offset of the BLOB in the repository file"},
+	{"Blob_size",			NOVAL, NULL, MYSQL_TYPE_LONGLONG,	NULL,					NOT_NULL_FLAG,					"The size of the BLOB in bytes"},
 	{"MD5_Checksum",		32,   NULL,	MYSQL_TYPE_VARCHAR,		system_charset_info,	0,								"The MD5 Digest of the BLOB data."},
-	{"Head_size",			NULL, NULL, MYSQL_TYPE_SHORT,		NULL,					NOT_NULL_FLAG | UNSIGNED_FLAG,	"The size of the BLOB header - proceeds the BLOB data"},
-	{"Access_code",			NULL, NULL, MYSQL_TYPE_LONG,		NULL,					NOT_NULL_FLAG,					"The 4-byte authorisation code required to access the BLOB - part of the BLOB URL"},
-	{"Creation_time",		NULL, NULL, MYSQL_TYPE_TIMESTAMP,	NULL,					NOT_NULL_FLAG,					"The time the BLOB was created"},
-	{"Last_ref_time",		NULL, NULL, MYSQL_TYPE_TIMESTAMP,	NULL,					0,								"The last time the BLOB was referenced"},
-	{"Last_access_time",	NULL, NULL, MYSQL_TYPE_TIMESTAMP,	NULL,					0,								"The last time the BLOB was accessed (read)"},
-	{"Access_count",		NULL, NULL, MYSQL_TYPE_LONG,		NULL,					NOT_NULL_FLAG,					"The count of the number of times the BLOB has been read"},
-	{NULL,NULL, NULL, MYSQL_TYPE_STRING,NULL, 0, NULL}
+	{"Head_size",			NOVAL, NULL, MYSQL_TYPE_SHORT,		NULL,					NOT_NULL_FLAG | UNSIGNED_FLAG,	"The size of the BLOB header - proceeds the BLOB data"},
+	{"Access_code",			NOVAL, NULL, MYSQL_TYPE_LONG,		NULL,					NOT_NULL_FLAG,					"The 4-byte authorisation code required to access the BLOB - part of the BLOB URL"},
+	{"Creation_time",		NOVAL, NULL, MYSQL_TYPE_TIMESTAMP,	NULL,					NOT_NULL_FLAG,					"The time the BLOB was created"},
+	{"Last_ref_time",		NOVAL, NULL, MYSQL_TYPE_TIMESTAMP,	NULL,					0,								"The last time the BLOB was referenced"},
+	{"Last_access_time",	NOVAL, NULL, MYSQL_TYPE_TIMESTAMP,	NULL,					0,								"The last time the BLOB was accessed (read)"},
+	{"Access_count",		NOVAL, NULL, MYSQL_TYPE_LONG,		NULL,					NOT_NULL_FLAG,					"The count of the number of times the BLOB has been read"},
+	{NULL,NOVAL, NULL, MYSQL_TYPE_STRING,NULL, 0, NULL}
 };
 
 #ifdef PBMS_HAS_KEYS
@@ -116,11 +116,11 @@ static DT_KEY_INFO pbms_repository_keys[]=
 
 static DT_FIELD_INFO pbms_metadata_info[]=
 {
-	{"Repository_id",		NULL,					NULL, MYSQL_TYPE_LONG,		NULL,							NOT_NULL_FLAG,	"The repository file number"},
-	{"Repo_blob_offset",	NULL,					NULL, MYSQL_TYPE_LONGLONG,	NULL,							NOT_NULL_FLAG,	"The offset of the BLOB in the repository file"},
+	{"Repository_id",		NOVAL,					NULL, MYSQL_TYPE_LONG,		NULL,							NOT_NULL_FLAG,	"The repository file number"},
+	{"Repo_blob_offset",	NOVAL,					NULL, MYSQL_TYPE_LONGLONG,	NULL,							NOT_NULL_FLAG,	"The offset of the BLOB in the repository file"},
 	{"Name",				MS_META_NAME_SIZE,	NULL, MYSQL_TYPE_VARCHAR,	&UTF8_CHARSET,	NOT_NULL_FLAG,	"Metadata name"},
 	{"Value",				MS_META_VALUE_SIZE,	NULL, MYSQL_TYPE_VARCHAR,	&UTF8_CHARSET,			NOT_NULL_FLAG,	"Metadata value"},
-	{NULL,					NULL,					NULL, MYSQL_TYPE_STRING,	NULL, 0, NULL}
+	{NULL,					NOVAL,					NULL, MYSQL_TYPE_STRING,	NULL, 0, NULL}
 };
 
 #ifdef PBMS_HAS_KEYS
@@ -135,10 +135,10 @@ static DT_KEY_INFO pbms_metadata_keys[]=
 #ifdef HAVE_ALIAS_SUPPORT
 static DT_FIELD_INFO pbms_alias_info[]=
 {
-	{"Repository_id",		NULL, NULL, MYSQL_TYPE_LONG,		NULL,				NOT_NULL_FLAG,	"The repository file number"},
-	{"Repo_blob_offset",	NULL, NULL, MYSQL_TYPE_LONGLONG,	NULL,				NOT_NULL_FLAG,	"The offset of the BLOB in the repository file"},
+	{"Repository_id",		NOVAL, NULL, MYSQL_TYPE_LONG,		NULL,				NOT_NULL_FLAG,	"The repository file number"},
+	{"Repo_blob_offset",	NOVAL, NULL, MYSQL_TYPE_LONGLONG,	NULL,				NOT_NULL_FLAG,	"The offset of the BLOB in the repository file"},
 	{"Blob_alias",			BLOB_ALIAS_LENGTH, NULL, MYSQL_TYPE_VARCHAR,		&my_charset_utf8_bin,	NOT_NULL_FLAG,			"The BLOB alias"},
-	{NULL,NULL, NULL, MYSQL_TYPE_STRING,NULL, 0, NULL}
+	{NULL,NOVAL, NULL, MYSQL_TYPE_STRING,NULL, 0, NULL}
 };
 
 static DT_KEY_INFO pbms_alias_keys[]=
@@ -150,10 +150,10 @@ static DT_KEY_INFO pbms_alias_keys[]=
 
 static DT_FIELD_INFO pbms_blobs_info[]=
 {
-	{"Repository_id",		NULL, NULL, MYSQL_TYPE_LONG,		NULL,				NOT_NULL_FLAG,	"The repository file number"},
-	{"Repo_blob_offset",	NULL, NULL, MYSQL_TYPE_LONGLONG,	NULL,				NOT_NULL_FLAG,	"The offset of the BLOB in the repository file"},
-	{"Blob_data",			NULL, NULL, MYSQL_TYPE_LONG_BLOB,	&my_charset_bin,	NOT_NULL_FLAG,	"The data of this BLOB"},
-	{NULL,NULL, NULL, MYSQL_TYPE_STRING,NULL, 0, NULL}
+	{"Repository_id",		NOVAL, NULL, MYSQL_TYPE_LONG,		NULL,				NOT_NULL_FLAG,	"The repository file number"},
+	{"Repo_blob_offset",	NOVAL, NULL, MYSQL_TYPE_LONGLONG,	NULL,				NOT_NULL_FLAG,	"The offset of the BLOB in the repository file"},
+	{"Blob_data",			NOVAL, NULL, MYSQL_TYPE_LONG_BLOB,	&my_charset_bin,	NOT_NULL_FLAG,	"The data of this BLOB"},
+	{NULL,NOVAL, NULL, MYSQL_TYPE_STRING,NULL, 0, NULL}
 };
 
 #ifdef PBMS_HAS_KEYS
@@ -167,17 +167,17 @@ static DT_KEY_INFO pbms_blobs_keys[]=
 static DT_FIELD_INFO pbms_reference_info[]=
 {
 	{"Table_name",		MS_TABLE_NAME_SIZE,		NULL, MYSQL_TYPE_STRING,	system_charset_info,	0,	"The name of the referencing table"},
-	{"Column_ordinal",	NULL,					NULL, MYSQL_TYPE_LONG,		NULL,					0,	"The column ordinal of the referencing field"},
-	{"Blob_id",			NULL,					NULL, MYSQL_TYPE_LONGLONG,	NULL,					NOT_NULL_FLAG,	"The BLOB reference number - part of the BLOB URL"},
+	{"Column_ordinal",	NOVAL,					NULL, MYSQL_TYPE_LONG,		NULL,					0,	"The column ordinal of the referencing field"},
+	{"Blob_id",			NOVAL,					NULL, MYSQL_TYPE_LONGLONG,	NULL,					NOT_NULL_FLAG,	"The BLOB reference number - part of the BLOB URL"},
 	{"Blob_url",		PBMS_BLOB_URL_SIZE,		NULL, MYSQL_TYPE_VARCHAR,	system_charset_info,	0,	"The BLOB URL for HTTP GET access"},
-	{"Repository_id",	NULL,					NULL, MYSQL_TYPE_LONG,		NULL,					NOT_NULL_FLAG,	"The repository file number of the BLOB"},
-	{"Repo_blob_offset",NULL,					NULL, MYSQL_TYPE_LONGLONG,	NULL,					NOT_NULL_FLAG,	"The offset in the repository file"},
-	{"Blob_size",		NULL,					NULL, MYSQL_TYPE_LONGLONG,	NULL,					NOT_NULL_FLAG,	"The size of the BLOB in bytes"},
-	{"Deletion_time",	NULL,					NULL, MYSQL_TYPE_TIMESTAMP,	NULL,					0,				"The time the BLOB was deleted"},
-	{"Remove_in",		NULL,					NULL, MYSQL_TYPE_LONG,		NULL,					0,				"The number of seconds before the reference/BLOB is removed perminently"},
-	{"Temp_log_id",		NULL,					NULL, MYSQL_TYPE_LONG,		NULL,					0,				"Temporary log number of the referencing deletion entry"},
-	{"Temp_log_offset",	NULL,					NULL, MYSQL_TYPE_LONGLONG,	NULL,					0,				"Temporary log offset of the referencing deletion entry"},
-	{NULL,NULL, NULL, MYSQL_TYPE_STRING,NULL, 0, NULL}
+	{"Repository_id",	NOVAL,					NULL, MYSQL_TYPE_LONG,		NULL,					NOT_NULL_FLAG,	"The repository file number of the BLOB"},
+	{"Repo_blob_offset",NOVAL,					NULL, MYSQL_TYPE_LONGLONG,	NULL,					NOT_NULL_FLAG,	"The offset in the repository file"},
+	{"Blob_size",		NOVAL,					NULL, MYSQL_TYPE_LONGLONG,	NULL,					NOT_NULL_FLAG,	"The size of the BLOB in bytes"},
+	{"Deletion_time",	NOVAL,					NULL, MYSQL_TYPE_TIMESTAMP,	NULL,					0,				"The time the BLOB was deleted"},
+	{"Remove_in",		NOVAL,					NULL, MYSQL_TYPE_LONG,		NULL,					0,				"The number of seconds before the reference/BLOB is removed perminently"},
+	{"Temp_log_id",		NOVAL,					NULL, MYSQL_TYPE_LONG,		NULL,					0,				"Temporary log number of the referencing deletion entry"},
+	{"Temp_log_offset",	NOVAL,					NULL, MYSQL_TYPE_LONGLONG,	NULL,					0,				"Temporary log offset of the referencing deletion entry"},
+	{NULL,NOVAL, NULL, MYSQL_TYPE_STRING,NULL, 0, NULL}
 };
 
 #ifdef PBMS_HAS_KEYS
@@ -320,9 +320,7 @@ static int pbms_create_proto_table(const char *engine_name, const char *name, DT
 			
 		field_constraints= field->mutable_constraints();
 		if (info->field_flags & NOT_NULL_FLAG)
-			field_constraints->set_is_nullable(false);
-		else
-			field_constraints->set_is_nullable(true);
+			field_constraints->set_is_notnull(true);
 		
 		if (info->field_flags & UNSIGNED_FLAG)
 			field_constraints->set_is_unsigned(true);
@@ -354,7 +352,7 @@ static int pbms_create_proto_table(const char *engine_name, const char *name, DT
 				break;
 				
 			case DRIZZLE_TYPE_TIMESTAMP:
-				field->set_type(message::Table::Field::TIMESTAMP);
+				field->set_type(message::Table::Field::EPOCH);
 				break;
 				
 			case DRIZZLE_TYPE_BLOB:
@@ -488,41 +486,45 @@ void PBMSSystemTables::removeSystemTables(CSString *db_path)
 	exit_();
 }
 
+//----------------
+bool PBMSSystemTables::try_loadSystemTables(CSThread *self, int i, MSDatabase *db)
+{
+	volatile bool rtc = true;
+	try_(a) {
+		switch (i) {
+			case 0:
+				MSHTTPHeaderTable::loadTable(RETAIN(db));
+				break;
+			case 1:
+				MSCloudTable::loadTable(RETAIN(db));
+				break;
+			case 2:
+				MSBackupTable::loadTable(RETAIN(db));
+				break;
+			case 3:
+				// Variable must be loaded after cloud and backup info
+				// incase BLOB recovery is required.
+				MSVariableTable::loadTable(RETAIN(db)); 
+				break;
+				
+			default:
+				ASSERT(false);
+		}
+		rtc = false;
+	}
+	catch_(a);
+	cont_(a);
+	return rtc;
+}
 //----------------
 void PBMSSystemTables::loadSystemTables(MSDatabase *db)
 {
-	int i = 0;
-	
-	CLOBBER_PROTECT(i);
 	enter_();
 	push_(db);
 	
-	for ( i = 0; i < 4; i++) {
-		try_(a) {
-			switch (i) {
-				case 0:
-					MSHTTPHeaderTable::loadTable(RETAIN(db));
-					break;
-				case 1:
-					MSCloudTable::loadTable(RETAIN(db));
-					break;
-				case 2:
-					MSBackupTable::loadTable(RETAIN(db));
-					break;
-				case 3:
-					// Variable must be loaded after cloud and backup info
-					// incase BLOB recovery is required.
-					MSVariableTable::loadTable(RETAIN(db)); 
-					break;
-					
-				default:
-					ASSERT(false);
-			}
-		}
-		catch_(a) {
-			self->logException();
-		}
-		cont_(a);
+	for ( int i = 0; i < 4; i++) {
+		if (try_loadSystemTables(self, i, db))
+			self->logException();			
 	}
 	
 	release_(db);
@@ -633,25 +635,25 @@ void PBMSSystemTables::restoreSystemTables(MSDatabase *db, const char *data, siz
 				if (MSHTTPHeaderTable::tableVersion == tab_version)
 					MSHTTPHeaderTable::restoreTable(RETAIN(db), data, tab_size);
 				else
-					CSException::logException(CS_CONTEXT, MS_ERR_SYSTAB_VERSION, "Restore "METADATA_HEADER_NAME" failed, incompatable table version" );
+					CSException::logException(CS_CONTEXT, MS_ERR_SYSTAB_VERSION, "Restore "METADATA_HEADER_NAME" failed, incompatible table version" );
 				break;
 			case MSCloudTable::tableID:
 				if (MSCloudTable::tableVersion == tab_version)
 					MSCloudTable::restoreTable(RETAIN(db), data, tab_size);
 				else
-					CSException::logException(CS_CONTEXT, MS_ERR_SYSTAB_VERSION, "Restore "CLOUD_TABLE_NAME" failed, incompatable table version" );
+					CSException::logException(CS_CONTEXT, MS_ERR_SYSTAB_VERSION, "Restore "CLOUD_TABLE_NAME" failed, incompatible table version" );
 				break;
 			case MSBackupTable::tableID:
 				if (MSBackupTable::tableVersion == tab_version)
 					MSBackupTable::restoreTable(RETAIN(db), data, tab_size);
 				else
-					CSException::logException(CS_CONTEXT, MS_ERR_SYSTAB_VERSION, "Restore "BACKUP_TABLE_NAME" failed, incompatable table version" );
+					CSException::logException(CS_CONTEXT, MS_ERR_SYSTAB_VERSION, "Restore "BACKUP_TABLE_NAME" failed, incompatible table version" );
 				break;				
 			case MSVariableTable::tableID:
 				if (MSVariableTable::tableVersion == tab_version)
 					MSVariableTable::restoreTable(RETAIN(db), data, tab_size);
 				else
-					CSException::logException(CS_CONTEXT, MS_ERR_SYSTAB_VERSION, "Restore "VARIABLES_TABLE_NAME" failed, incompatable table version" );
+					CSException::logException(CS_CONTEXT, MS_ERR_SYSTAB_VERSION, "Restore "VARIABLES_TABLE_NAME" failed, incompatible table version" );
 				break;
 			default:
 				ASSERT(false);
@@ -675,8 +677,13 @@ void PBMSSystemTables::restoreSystemTables(MSDatabase *db, const char *data, siz
 
 void MSOpenSystemTable::setNotNullInRecord(Field *field, char *record)
 {
+#ifdef DRIZZLED
 	if (field->null_ptr)
 		record[(uint) (field->null_ptr - (uchar *) field->getTable()->getInsertRecord())] &= (uchar) ~field->null_bit;
+#else
+	if (field->null_ptr)
+		record[(uint) (field->null_ptr - (uchar *) field->table->record[0])] &= (uchar) ~field->null_bit;
+#endif
 }
 
 /*
@@ -722,6 +729,22 @@ MSRepositoryTable::~MSRepositoryTable()
 //-----------------------
 void MSRepositoryTable::use()
 {
+	MSDatabase *db;
+	enter_();
+
+	if (!iBlobBuffer)
+		new_(iBlobBuffer, CSStringBuffer(20));
+		
+	db = myShare->mySysDatabase;
+	if ((iCompactor = db->getCompactorThread())) {
+		if (iCompactor->isMe(self))
+			iCompactor = NULL;
+		else {
+			iCompactor->retain();
+			iCompactor->suspend();
+		}
+	}
+	exit_();
 }
 
 //-----------------------
@@ -744,8 +767,6 @@ void MSRepositoryTable::unuse()
 //-----------------------
 void MSRepositoryTable::seqScanInit()
 {
-	MSDatabase *db;
-
 	enter_();
 	
 	// Flush all committed transactions to the repository file.
@@ -753,17 +774,6 @@ void MSRepositoryTable::seqScanInit()
 
 	iRepoIndex = 0;
 	iRepoOffset = 0;
-	if (!iBlobBuffer)
-		new_(iBlobBuffer, CSStringBuffer(20));
-	db = myShare->mySysDatabase;
-	if ((iCompactor = db->getCompactorThread())) {
-		if (iCompactor->isMe(self))
-			iCompactor = NULL;
-		else {
-			iCompactor->retain();
-			iCompactor->suspend();
-		}
-	}
 		
 	exit_();
 }
@@ -845,7 +855,7 @@ int	MSRepositoryTable::getRefLen()
 
 
 //-----------------------
-void MSRepositoryTable::seqScanPos(uint8_t *pos)
+void MSRepositoryTable::seqScanPos(unsigned char *pos)
 {
 	mi_int4store(pos, iRepoIndex); pos +=4;
 	mi_int8store(pos, iRepoCurrentOffset);
@@ -863,7 +873,7 @@ void MSRepositoryTable::seqScanRead(uint32_t repo, uint64_t offset, char *buf)
 }
 
 //-----------------------
-void MSRepositoryTable::seqScanRead(uint8_t *pos, char *buf)
+void MSRepositoryTable::seqScanRead(unsigned char *pos, char *buf)
 {
 	seqScanRead(mi_uint4korr( pos), mi_uint8korr(pos +4), buf);
 }
@@ -959,15 +969,22 @@ bool MSRepositoryTable::returnRow(MSBlobHeadPtr	blob, char *buf)
 	save_write_set = table->write_set;
 	table->write_set = NULL;
 
+#ifdef DRIZZLED
+	memset(buf, 0xFF, table->getNullBytes());
+#else
 	memset(buf, 0xFF, table->s->null_bytes);
+#endif
  	for (Field **field=GET_TABLE_FIELDS(table) ; *field ; field++) {
  		curr_field = *field;
-
 		save = curr_field->ptr;
 #if MYSQL_VERSION_ID < 50114
 		curr_field->ptr = (byte *) buf + curr_field->offset();
 #else
+#ifdef DRIZZLED
 		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->getTable()->getInsertRecord());
+#else
+		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->table->record[0]);
+#endif
 #endif
 		switch (curr_field->field_name[0]) {
 			case 'A':
@@ -1037,10 +1054,10 @@ bool MSRepositoryTable::returnRow(MSBlobHeadPtr	blob, char *buf)
 				break;
 			case 'M': // MD5_Checksum
 				if (storage_type == MS_STANDARD_STORAGE) {
-					char checksum[sizeof(Md5Digest) *2];
+					char checksum[sizeof(Md5Digest) *2 +1];
 					
 					ASSERT(strcmp(curr_field->field_name, "MD5_Checksum") == 0);
-					cs_bin_to_hex(sizeof(Md5Digest) *2, checksum, sizeof(Md5Digest), &(blob->rb_blob_checksum_md5d));
+					cs_bin_to_hex(sizeof(Md5Digest) *2 +1, checksum, sizeof(Md5Digest), &(blob->rb_blob_checksum_md5d));
 					curr_field->store(checksum, sizeof(Md5Digest) *2, system_charset_info);
 					setNotNullInRecord(curr_field, buf);
 					
@@ -1121,15 +1138,22 @@ bool MSBlobDataTable::returnRow(MSBlobHeadPtr blob, char *buf)
 	save_write_set = table->write_set;
 	table->write_set = NULL;
 
+#ifdef DRIZZLED
+	memset(buf, 0xFF, table->getNullBytes());
+#else
 	memset(buf, 0xFF, table->s->null_bytes);
+#endif
  	for (Field **field=GET_TABLE_FIELDS(table) ; *field ; field++) {
  		curr_field = *field;
-
 		save = curr_field->ptr;
 #if MYSQL_VERSION_ID < 50114
 		curr_field->ptr = (byte *) buf + curr_field->offset();
 #else
+#ifdef DRIZZLED
 		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->getTable()->getInsertRecord());
+#else
+		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->table->record[0]);
+#endif
 #endif
 		switch (curr_field->field_name[0]) {
 			case 'R':
@@ -1211,15 +1235,22 @@ bool MSBlobAliasTable::returnRow(MSBlobHeadPtr blob, char *buf)
 	save_write_set = table->write_set;
 	table->write_set = NULL;
 
+#ifdef DRIZZLED
+	memset(buf, 0xFF, table->getNullBytes());
+#else
 	memset(buf, 0xFF, table->s->null_bytes);
+#endif
  	for (Field **field=GET_TABLE_FIELDS(table) ; *field ; field++) {
  		curr_field = *field;
-
 		save = curr_field->ptr;
 #if MYSQL_VERSION_ID < 50114
 		curr_field->ptr = (byte *) buf + curr_field->offset();
 #else
-		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->table->getInsertRecord());
+#ifdef DRIZZLED
+		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->getTable()->getInsertRecord());
+#else
+		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->table->record[0]);
+#endif
 #endif
 		switch (curr_field->field_name[0]) {
 			case 'R':
@@ -1312,7 +1343,7 @@ int	MSReferenceTable::getRefLen()
 	return sizeof(iRefDataUsed) + sizeof(iRefDataPos) + sizeof(iRefCurrentIndex) + sizeof(iRefCurrentOffset);
 }
 
-void MSReferenceTable::seqScanPos(uint8_t *pos)
+void MSReferenceTable::seqScanPos(unsigned char *pos)
 {
 	mi_int4store(pos, iRefCurrentDataPos); pos +=4;
 	mi_int4store(pos, iRefCurrentDataUsed);pos +=4;	
@@ -1320,7 +1351,7 @@ void MSReferenceTable::seqScanPos(uint8_t *pos)
 	mi_int8store(pos, iRefCurrentOffset);
 }
 
-void MSReferenceTable::seqScanRead(uint8_t *pos, char *buf)
+void MSReferenceTable::seqScanRead(unsigned char *pos, char *buf)
 {
 	iRefDataPos = mi_uint4korr( pos); pos +=4;
 	iRefDataUsed = mi_uint4korr(pos); pos +=4;
@@ -1564,15 +1595,22 @@ void MSReferenceTable::returnRow(MSRefDataPtr ref_data, char *buf)
 	table->write_set = NULL;
 	table->read_set = NULL;
 
+#ifdef DRIZZLED
+	memset(buf, 0xFF, table->getNullBytes());
+#else
 	memset(buf, 0xFF, table->s->null_bytes);
+#endif
  	for (Field **field=GET_TABLE_FIELDS(table) ; *field ; field++) {
  		curr_field = *field;
-
 		save = curr_field->ptr;
 #if MYSQL_VERSION_ID < 50114
 		curr_field->ptr = (byte *) buf + curr_field->offset();
 #else
+#ifdef DRIZZLED
 		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->getTable()->getInsertRecord());
+#else
+		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->table->record[0]);
+#endif
 #endif
 		switch (curr_field->field_name[0]) {
 			case 'B':
@@ -1730,6 +1768,13 @@ MSMetaDataTable *MSMetaDataTable::newMSMetaDataTable(MSDatabase *db)
 	return  (MSMetaDataTable*) MSSystemTableShare::openSystemTable(path, NULL);
 }
 
+void MSMetaDataTable::use()
+{
+	MSRepositoryTable::use();
+	new_(iMetData, CSStringBuffer(80));
+	iMetDataSize = 0;
+}
+
 void MSMetaDataTable::unuse()
 {
 	MSRepositoryTable::unuse();
@@ -1748,7 +1793,6 @@ void MSMetaDataTable::seqScanInit()
 	iMetDataPos = 0;
 	iMetBlobRepo = 0;
 	iMetBlobOffset = 0;
-	new_(iMetData, CSStringBuffer(80));
 	iMetStateSaved = false;
 }
 
@@ -1764,7 +1808,7 @@ int	MSMetaDataTable::getRefLen()
 	return sizeof(iMetCurrentDataPos) + sizeof(iMetCurrentDataSize) + sizeof(iMetCurrentBlobRepo) + sizeof(iMetCurrentBlobOffset);
 }
 
-void MSMetaDataTable::seqScanPos(uint8_t *pos)
+void MSMetaDataTable::seqScanPos(unsigned char *pos)
 {
 	mi_int4store(pos, iMetCurrentDataPos); pos +=4;
 	mi_int4store(pos, iMetCurrentDataSize);pos +=4;	
@@ -1772,7 +1816,7 @@ void MSMetaDataTable::seqScanPos(uint8_t *pos)
 	mi_int8store(pos, iMetCurrentBlobOffset);
 }
 
-void MSMetaDataTable::seqScanRead(uint8_t *pos, char *buf)
+void MSMetaDataTable::seqScanRead(unsigned char *pos, char *buf)
 {
 	iMetStateSaved = false;
 	iMetDataPos = mi_uint4korr( pos); pos +=4;
@@ -1921,15 +1965,22 @@ void MSMetaDataTable::returnRow(char *name, char *value, char *buf)
 	save_write_set = table->write_set;
 	table->write_set = NULL;
 
+#ifdef DRIZZLED
+	memset(buf, 0xFF, table->getNullBytes());
+#else
 	memset(buf, 0xFF, table->s->null_bytes);
+#endif
  	for (Field **field=GET_TABLE_FIELDS(table) ; *field ; field++) {
  		curr_field = *field;
-
 		save = curr_field->ptr;
 #if MYSQL_VERSION_ID < 50114
 		curr_field->ptr = (byte *) buf + curr_field->offset();
 #else
+#ifdef DRIZZLED
 		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->getTable()->getInsertRecord());
+#else
+		curr_field->ptr = (byte *) buf + curr_field->offset(curr_field->table->record[0]);
+#endif
 #endif
 		switch (curr_field->field_name[0]) {
 			case 'R':
@@ -2162,6 +2213,39 @@ void MSMetaDataTable::deleteRow(char *buf)
 	exit_();
 }
 
+class UpdateRowCleanUp : public CSRefObject {
+	bool do_cleanup;
+	MSMetaDataTable *tab;
+	char *row_data;
+	
+	uint32_t ref_id;
+
+	public:
+	
+	UpdateRowCleanUp(): CSRefObject(),
+		do_cleanup(false), tab(NULL), row_data(NULL){}
+		
+	~UpdateRowCleanUp() 
+	{
+		if (do_cleanup) {
+			tab->deleteRow(row_data);
+		}
+	}
+	
+	void setCleanUp(MSMetaDataTable *table, char *data)
+	{
+		row_data = data;
+		tab = table;
+		do_cleanup = true;
+	}
+	
+	void cancelCleanUp()
+	{
+		do_cleanup = false;
+	}
+	
+};
+
 void MSMetaDataTable::updateRow(char *old_data, char *new_data)
 {
 	uint32_t o_repo_index, n_repo_index;
@@ -2191,15 +2275,19 @@ void MSMetaDataTable::updateRow(char *old_data, char *new_data)
 	
 	// If the meta data is not for the same BLOB then we do an insert and delete.
 	if ((n_repo_index != o_repo_index) || (n_repo_offset != o_repo_offset)) {
+		UpdateRowCleanUp *cleanup;
+		new_(cleanup, UpdateRowCleanUp());
+		push_(cleanup);
+
 		insertRow(new_data);
-		try_(a) {
-			deleteRow(old_data);
-		}
-		catch_(a) {
-			deleteRow(new_data);
-			throw_();
-		}
-		cont_(a);
+		
+		cleanup->setCleanUp(this, new_data);
+		
+		deleteRow(old_data);
+		
+		cleanup->cancelCleanUp();
+		release_(cleanup);
+		
 		exit_();
 	}
 	
@@ -2300,7 +2388,11 @@ iOpenCount(0)
 
 MSSystemTableShare::~MSSystemTableShare()
 {
-	myThrLock.unlock();
+#ifdef DRIZZLED
+	myThrLock.deinit();
+#else
+	thr_lock_delete(&myThrLock);
+#endif
 	if (myTablePath) {
 		myTablePath->release();
 		myTablePath = NULL;
