@@ -1,4 +1,4 @@
-/* Copyright (c) 2009 PrimeBase Technologies GmbH, Germany
+/* Copyright (C) 2009 PrimeBase Technologies GmbH, Germany
  *
  * PrimeBase Media Stream for MySQL
  *
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * Barry Leslie
  *
@@ -205,16 +205,21 @@ try_again:
 	
 	
 	if (!path->exists()) { // Create the transaction log.	
-		CSFile *tr_file = path->createFile(CSFile::CREATE);
+		// Preallocate the log space and initialize it.
+		MSDiskTransRec *recs;
+		off64_t offset = sizeof(MSDiskTransHeadRec);
+		uint64_t num_records = DFLT_TRANS_LOG_LIST_SIZE;
+		size_t size;
+		CSFile *tr_file;
+		
+		recs = (MSDiskTransRec *) cs_calloc(1024 * sizeof(MSDiskTransRec));
+		push_ptr_(recs);
+		
+		tr_file = path->createFile(CSFile::CREATE);
 		push_(tr_file);
 		
 		log_size = DFLT_TRANS_LOG_LIST_SIZE * sizeof(MSDiskTransRec) + sizeof(MSDiskTransHeadRec);
 
-		// Preallocate the log space and initialize it.
-		MSDiskTransRec recs[1024] = {};
-		off64_t offset = sizeof(MSDiskTransHeadRec);
-		uint64_t num_records = DFLT_TRANS_LOG_LIST_SIZE;
-		size_t size;
 		
 		while (num_records) {
 			if (num_records < 1024)
@@ -258,6 +263,9 @@ try_again:
 		trans->txn_Checksum = CS_GET_DISK_1(trans->txn_DiskHeader.th_checksum_1);
 		
 		trans->txn_TransCache = MSTransCache::newMSTransCache(DFLT_TRANS_CACHE_SIZE);
+		
+		release_(recs);
+
 	} else { // The transaction log already exists
 		bool overflow = false, recovered = false;
 		
