@@ -18,9 +18,9 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
-#include "plugin/performance_dictionary/dictionary.h"
+#include <plugin/performance_dictionary/dictionary.h>
 
 #include <drizzled/session.h>
 
@@ -40,7 +40,7 @@ bool SessionUsageLogger::pre(Session *session)
 
 bool SessionUsageLogger::post(Session *session)
 {
-  QueryUsage *usage_cache= dynamic_cast<QueryUsage *>(session->getProperty("query_usage"));
+  QueryUsage *usage_cache= static_cast<QueryUsage *>(session->getProperty("query_usage"));
 
   if (not usage_cache)
   {
