@@ -22,41 +22,47 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
+
+#include <drizzled/gettext.h>
+
 #include "rabbitmq_handler.h"
 
 using namespace std;
 
-RabbitMQHandler::RabbitMQHandler(const char* rabbitMQHost, 
-				 const int rabbitMQPort, 
-				 const char* rabbitMQUsername, 
-				 const char* rabbitMQPassword, 
-				 const char* rabbitMQVirtualhost) 
-  throw(rabbitmq_handler_exception):
-  hostname(rabbitMQHost),
-  port(rabbitMQPort),
-  username(rabbitMQUsername),
-  password(rabbitMQPassword),
-  virtualhost(rabbitMQVirtualhost)
+namespace drizzle_plugin
+{
+
+RabbitMQHandler::RabbitMQHandler(const std::string &rabbitMQHost, 
+                                 const in_port_t rabbitMQPort, 
+                                 const std::string &rabbitMQUsername, 
+                                 const std::string &rabbitMQPassword, 
+                                 const std::string &rabbitMQVirtualhost) 
+  throw(rabbitmq_handler_exception) :
+    rabbitmqConnection(amqp_new_connection()),
+    sockfd(amqp_open_socket(rabbitMQHost.c_str(), rabbitMQPort)),
+    hostname(rabbitMQHost),
+    port(rabbitMQPort),
+    username(rabbitMQUsername),
+    password(rabbitMQPassword),
+    virtualhost(rabbitMQVirtualhost)
 {
-  rabbitmqConnection = amqp_new_connection();
   /* open the socket to the rabbitmq server */
-  sockfd = amqp_open_socket(hostname, port);
   if(sockfd < 0) 
   {
-    throw rabbitmq_handler_exception("Could not open socket, is rabbitmq running?");
+    throw rabbitmq_handler_exception(_("Could not open socket, is rabbitmq running?"));
   }
   amqp_set_sockfd(rabbitmqConnection, sockfd);
   /* login to rabbitmq, handleAMQPError throws exception if there is a problem */
   handleAMQPError(amqp_login(rabbitmqConnection, 
-			     virtualhost, 
-			     0, 
-			     131072, 
-			     0, 
-			     AMQP_SASL_METHOD_PLAIN, 
-			     username, 
-			     password), 
-		  "rabbitmq login");
+                             virtualhost.c_str(), 
+                             0, 
+                             131072, 
+                             0, 
+                             AMQP_SASL_METHOD_PLAIN, 
+                             username.c_str(), 
+                             password.c_str()), 
+                  "rabbitmq login");
   /* open the channel */
   amqp_channel_open(rabbitmqConnection, 1);
 }
@@ -79,23 +85,24 @@ RabbitMQHandler::~RabbitMQHandler()
   close(sockfd);
 }
 
-void RabbitMQHandler::publish(const uint8_t *message, 
-			      const int length, 
-			      const char* exchangeName, 
-			      const char* routingKey) throw(rabbitmq_handler_exception)
+void RabbitMQHandler::publish(void *message, 
+                              const int length, 
+                              const std::string &exchangeName, 
+                              const std::string &routingKey)
+throw(rabbitmq_handler_exception)
 {
   amqp_bytes_t b;
-  b.bytes= (void*)message;
+  b.bytes= message;
   b.len= length;
   
-  if(amqp_basic_publish(rabbitmqConnection,
-			1,
-			amqp_cstring_bytes(exchangeName),
-			amqp_cstring_bytes(routingKey),
-			0,
-			0,
-			NULL,
-			b) < 0)
+  if (amqp_basic_publish(rabbitmqConnection,
+                         1,
+                         amqp_cstring_bytes(exchangeName.c_str()),
+                         amqp_cstring_bytes(routingKey.c_str()),
+                         0,
+                         0,
+                         NULL,
+                         b) < 0)
   {
     throw rabbitmq_handler_exception("Could not publish message");
   }
@@ -130,3 +137,5 @@ void RabbitMQHandler::handleAMQPError(amqp_rpc_reply_t x, string context) throw(
     }
   }
 }
+
+} /* namespace drizzle_plugin */
