@@ -23,14 +23,15 @@
  */
 
 
-#ifndef PLUGIN_RABBITMQ_RABBITMQ_LOG_H
-#define PLUGIN_RABBITMQ_RABBITMQ_LOG_H
+#pragma once
 
 #include <drizzled/replication_services.h>
 #include <drizzled/plugin/transaction_applier.h>
 #include <string>
 #include "rabbitmq_handler.h"
 
+namespace drizzle_plugin
+{
 
 /**
  * @brief
@@ -41,10 +42,13 @@
  *   Connects to rabbitmq server in constructor, publishes messages
  *   in apply(...). If error occurs, the plugin disables itself.
  */
-class RabbitMQLog: public drizzled::plugin::TransactionApplier 
+class RabbitMQLog :
+  public drizzled::plugin::TransactionApplier 
 {
 private:
-  RabbitMQHandler* rabbitMQHandler;
+  RabbitMQHandler* _rabbitMQHandler;
+  const std::string _exchange;
+  const std::string _routingkey;
 public:
 
   /**
@@ -56,8 +60,10 @@ public:
    *
    * @param[in] mqHandler name of the plugin, typically rabbitmq_log.
    */
-  RabbitMQLog(const std::string name_arg, 
-	      RabbitMQHandler* mqHandler);
+  RabbitMQLog(const std::string &name,
+              const std::string &exchange,
+              const std::string &routingkey,
+              RabbitMQHandler* mqHandler);
   ~RabbitMQLog();
 
   /**
@@ -74,4 +80,5 @@ public:
 
 };
 
-#endif /* PLUGIN_RABBITMQ_RABBITMQ_LOG_H */
+} /* namespace drizzle_plugin */
+
