@@ -18,8 +18,8 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
-#include "plugin/registry_dictionary/dictionary.h"
+#include <config.h>
+#include <plugin/registry_dictionary/dictionary.h>
 
 using namespace drizzled;
 
@@ -46,7 +46,7 @@ DRIZZLE_DECLARE_PLUGIN
   "Provides dictionary for plugin registry system.",
   PLUGIN_LICENSE_GPL,
   init,     /* Plugin Init */
-  NULL,               /* system variables */
+  NULL,               /* depends */
   NULL                /* config options   */
 }
 DRIZZLE_DECLARE_PLUGIN_END;
