@@ -18,14 +18,16 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
-#include "plugin/show_dictionary/dictionary.h"
+#include <config.h>
+#include <plugin/show_dictionary/dictionary.h>
 
 using namespace drizzled;
 
 static int init(drizzled::module::Context &context)
 {
   context.add(new ShowColumns());
+  context.add(new ShowCreateSchema());
+  context.add(new ShowCreateTable());
   context.add(new ShowIndexes());
   context.add(new ShowSchemas());
   context.add(new ShowTableStatus());
