@@ -18,9 +18,9 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
-#include "plugin/show_dictionary/dictionary.h"
-#include "drizzled/identifier.h"
+#include <config.h>
+#include <plugin/show_dictionary/dictionary.h>
+#include <drizzled/identifier.h>
 #include <string>
 
 using namespace std;
@@ -41,7 +41,7 @@ static const string TIMESTAMP("TIMESTAMP");
 static const string DATETIME("DATETIME");
 
 ShowColumns::ShowColumns() :
-  plugin::TableFunction("DATA_DICTIONARY", "SHOW_COLUMNS")
+  show_dictionary::Show("SHOW_COLUMNS")
 {
   add_field("Field");
   add_field("Type");
@@ -52,21 +52,32 @@ ShowColumns::ShowColumns() :
 }
 
 ShowColumns::Generator::Generator(Field **arg) :
-  plugin::TableFunction::Generator(arg),
+  show_dictionary::Show::Generator(arg),
   is_tables_primed(false),
   is_columns_primed(false),
   column_iterator(0)
 {
-  statement::Select *select= static_cast<statement::Select *>(getSession().lex->statement);
+  if (not isShowQuery())
+   return;
 
-  if (not select->getShowTable().empty() && not select->getShowSchema().empty())
+  statement::Show& select= static_cast<statement::Show&>(statement());
+
+  if (not select.getShowTable().empty() && not select.getShowSchema().empty())
   {
-    table_name.append(select->getShowTable().c_str());
-    TableIdentifier identifier(select->getShowSchema().c_str(), select->getShowTable().c_str());
+    table_name.append(select.getShowTable().c_str());
+    identifier::Table identifier(select.getShowSchema().c_str(), select.getShowTable().c_str());
 
-    is_tables_primed= plugin::StorageEngine::getTableDefinition(getSession(),
-                                                                identifier,
-                                                                table_proto);
+    if (not plugin::Authorization::isAuthorized(*getSession().user(),
+                                            identifier, false))
+    {
+      drizzled::error::access(*getSession().user(), identifier);
+      return;
+    }
+
+    table_proto= plugin::StorageEngine::getTableMessage(getSession(), identifier);
+
+    if (table_proto)
+      is_tables_primed= true;
   }
 }
 
@@ -85,10 +96,10 @@ bool ShowColumns::Generator::nextColumnCore()
     is_columns_primed= true;
   }
 
-  if (column_iterator >= getTableProto().field_size())
+  if (column_iterator >= getTableProto()->field_size())
     return false;
 
-  column= getTableProto().field(column_iterator);
+  column= getTableProto()->field(column_iterator);
 
   return true;
 }
@@ -144,7 +155,7 @@ void ShowColumns::Generator::pushType(message::Table::Field::FieldType type, con
   case message::Table::Field::DATE:
     push(DATE);
     break;
-  case message::Table::Field::TIMESTAMP:
+  case message::Table::Field::EPOCH:
     push(TIMESTAMP);
     break;
   case message::Table::Field::DATETIME:
@@ -163,7 +174,7 @@ void ShowColumns::Generator::fill()
   pushType(column.type(), column.string_options().collation());
 
   /* Null */
-  push(column.constraints().is_nullable());
+  push(not column.constraints().is_notnull());
 
   /* Default */
   if (column.options().has_default_value())
