@@ -18,17 +18,16 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
-#include "plugin/show_dictionary/dictionary.h"
-#include "drizzled/pthread_globals.h"
-#include "drizzled/my_hash.h"
+#include <plugin/show_dictionary/dictionary.h>
+#include <drizzled/pthread_globals.h>
 
 using namespace drizzled;
 using namespace std;
 
 ShowTableStatus::ShowTableStatus() :
-  plugin::TableFunction("DATA_DICTIONARY", "SHOW_TABLE_STATUS")
+  show_dictionary::Show("SHOW_TABLE_STATUS")
 {
   add_field("Session", plugin::TableFunction::NUMBER, 0, false);
   add_field("Schema");
@@ -43,32 +42,35 @@ ShowTableStatus::ShowTableStatus() :
 }
 
 ShowTableStatus::Generator::Generator(drizzled::Field **arg) :
-  drizzled::plugin::TableFunction::Generator(arg),
-  is_primed(false)
+  show_dictionary::Show::Generator(arg),
+  is_primed(false),
+  scopedLock(table::Cache::singleton().mutex())
 {
-  statement::Select *select= static_cast<statement::Select *>(getSession().lex->statement);
+  if (not isShowQuery())
+   return;
 
-  schema_predicate.append(select->getShowSchema());
+  statement::Show& select= static_cast<statement::Show&>(statement());
 
-  if (schema_predicate.empty())
+  schema_predicate.append(select.getShowSchema());
+
+  util::string::const_shared_ptr schema(getSession().schema());
+  if (schema_predicate.empty() and schema)
   {
-    schema_predicate.append(getSession().db);
+    schema_predicate.append(*schema);
   }
 
   if (not schema_predicate.empty())
   {
-    LOCK_open.lock(); /* Optionally lock for remove tables from open_cahe if not in use */
+    table::CacheMap &open_cache(table::getCache());
 
-    TableOpenCache &open_cache(get_open_cache());
-
-    for (TableOpenCache::const_iterator iter= open_cache.begin();
+    for (table::CacheMap::const_iterator iter= open_cache.begin();
          iter != open_cache.end();
          iter++)
     {
-      table_list.push_back((*iter).second);
+      table_list.push_back(iter->second);
     }
 
-    for (drizzled::Table *tmp_table= getSession().temporary_tables; tmp_table; tmp_table= tmp_table->getNext())
+    for (drizzled::Table *tmp_table= getSession().getTemporaryTables(); tmp_table; tmp_table= tmp_table->getNext())
     {
       if (tmp_table->getShare())
       {
@@ -81,8 +83,6 @@ ShowTableStatus::Generator::Generator(drizzled::Field **arg) :
 
 ShowTableStatus::Generator::~Generator()
 {
-  if (not schema_predicate.empty())
-    LOCK_open.unlock(); /* Optionally lock for remove tables from open_cahe if not in use */
 }
 
 bool ShowTableStatus::Generator::nextCore()
@@ -138,7 +138,7 @@ bool ShowTableStatus::Generator::populate()
 {
   if (not next())
     return false;
-  
+
   fill();
 
   return true;
@@ -182,5 +182,16 @@ void ShowTableStatus::Generator::fill()
   push(table->getCursor().tableSize());
 
   /* Auto_increment 10 */
-  push(table->getCursor().getNextInsertId());
+  bool session_set= false;
+  if (table->in_use == NULL)
+  {
+    table->in_use= &getSession();
+    session_set= true;
+  }
+
+  table->getCursor().info(HA_STATUS_AUTO);
+  push(table->getCursor().getAutoIncrement());
+
+  if (session_set)
+    table->in_use= NULL;
 }
