@@ -19,28 +19,31 @@
  */
 
 
-#include "config.h"
-#include "plugin/show_dictionary/dictionary.h"
-#include "drizzled/identifier.h"
+#include <config.h>
+#include <plugin/show_dictionary/dictionary.h>
+#include <drizzled/identifier.h>
 
 using namespace std;
 using namespace drizzled;
 
 ShowTables::ShowTables() :
-  plugin::TableFunction("DATA_DICTIONARY", "SHOW_TABLES")
+  show_dictionary::Show("SHOW_TABLES")
 {
   add_field("TABLE_NAME");
 }
 
 ShowTables::Generator::Generator(drizzled::Field **arg) :
-  drizzled::plugin::TableFunction::Generator(arg),
+  show_dictionary::Show::Generator(arg),
   is_primed(false)
 {
-  statement::Select *select= static_cast<statement::Select *>(getSession().lex->statement);
+  if (not isShowQuery())
+   return;
 
-  if (not select->getShowSchema().empty())
+  statement::Show& select= static_cast<statement::Show&>(statement());
+
+  if (not select.getShowSchema().empty())
   {
-    schema_name.append(select->getShowSchema());
+    schema_name.append(select.getShowSchema());
     assert(not schema_name.empty());
   }
 }
@@ -59,7 +62,7 @@ bool ShowTables::Generator::nextCore()
       return false;
     }
 
-    SchemaIdentifier identifier(schema_name);
+    identifier::Schema identifier(schema_name);
     plugin::StorageEngine::getIdentifiers(getSession(), identifier, set_of_identifiers);
     table_iterator= set_of_identifiers.begin();
     is_primed= true;
@@ -91,7 +94,7 @@ bool ShowTables::Generator::populate()
 {
   if (not next())
     return false;
-  
+
   fill();
 
   return true;
