@@ -18,19 +18,18 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef PLUGIN_SHOW_DICTIONARY_SHOW_TABLES_H
-#define PLUGIN_SHOW_DICTIONARY_SHOW_TABLES_H
+#pragma once
 
-class ShowTables : public drizzled::plugin::TableFunction
+class ShowTables : public show_dictionary::Show
 {
 public:
   ShowTables();
 
-  class Generator : public drizzled::plugin::TableFunction::Generator
+  class Generator : public show_dictionary::Show::Generator
   {
     bool is_primed;
-    drizzled::TableIdentifiers set_of_identifiers;
-    drizzled::TableIdentifiers::iterator table_iterator;
+    drizzled::identifier::Table::vector set_of_identifiers;
+    drizzled::identifier::Table::vector::iterator table_iterator;
     std::string schema_name;
 
     void fill();
@@ -49,4 +48,3 @@ public:
   }
 };
 
-#endif /* PLUGIN_SHOW_DICTIONARY_SHOW_TABLES_H */
