@@ -18,15 +18,15 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
-#include "plugin/show_dictionary/dictionary.h"
+#include <plugin/show_dictionary/dictionary.h>
 
 using namespace std;
 using namespace drizzled;
 
 ShowTemporaryTables::ShowTemporaryTables() :
-  drizzled::plugin::TableFunction("DATA_DICTIONARY", "SHOW_TEMPORARY_TABLES")
+  show_dictionary::Show("SHOW_TEMPORARY_TABLES")
 {
   add_field("TABLE_SCHEMA");
   add_field("TABLE_NAME");
@@ -36,10 +36,10 @@ ShowTemporaryTables::ShowTemporaryTables() :
 }
 
 ShowTemporaryTables::Generator::Generator(Field **arg) :
-  plugin::TableFunction::Generator(arg),
+  show_dictionary::Show::Generator(arg),
   session(getSession())
 {
-  table= session.temporary_tables;
+  table= session.getTemporaryTables();
 }
 
 bool ShowTemporaryTables::Generator::populate()
