@@ -1,7 +1,7 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2010 Sun Microsystems
+ *  Copyright (C) 2010 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,14 +18,15 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
-#include "plugin/status_dictionary/dictionary.h"
+#include <plugin/status_dictionary/dictionary.h>
 
 #include <drizzled/pthread_globals.h>
 #include <drizzled/internal/m_string.h>
 #include <drizzled/definitions.h>
 #include <drizzled/status_helper.h>
+#include <drizzled/sql_lex.h>
 
 #include <vector>
 #include <string>
@@ -71,7 +72,7 @@ bool StateTool::Generator::populate()
       drizzle_show_var tmp;
 
       for (var= variables; var->type == SHOW_FUNC; var= &tmp)
-        ((mysql_show_var_func)((st_show_var_func_container *)var->value)->func)(&tmp, buff);
+        ((drizzle_show_var_func)((st_show_var_func_container *)var->value)->func)(&tmp, buff);
     }
 
     if (isWild(variables->name))
@@ -95,19 +96,20 @@ void StateTool::Generator::fill(const std::string &name, char *value, SHOW_TYPE
   std::ostringstream oss;
   std::string return_value;
 
-  LOCK_global_system_variables.lock();
-
-  if (show_type == SHOW_SYS)
   {
-    show_type= ((sys_var*) value)->show_type();
-    value= (char*) ((sys_var*) value)->value_ptr(&(getSession()), option_type,
-                                                 &null_lex_str);
+    boost::mutex::scoped_lock scopedLock(getSession().catalog().systemVariableLock());
+
+    if (show_type == SHOW_SYS)
+    {
+      show_type= ((sys_var*) value)->show_type();
+      value= (char*) ((sys_var*) value)->value_ptr(&(getSession()), option_type,
+                                                   &null_lex_str);
+    }
+
+    return_value= StatusHelper::fillHelper(NULL, value, show_type); 
   }
-
-  return_value= StatusHelper::fillHelper(NULL, value, show_type); 
-
-  LOCK_global_system_variables.unlock();
   push(name);
+
   if (return_value.length())
     push(return_value);
   else 
