@@ -19,12 +19,10 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
-#include "plugin/string_functions/functions.h"
+#include <config.h>
 
-#include "elt.h"
-#include "format.h"
-#include "quote.h"
+#include <drizzled/plugin.h>
+#include <plugin/string_functions/functions.h>
 
 using namespace drizzled;
 
@@ -33,6 +31,7 @@ static int init(drizzled::module::Context &context)
   context.add(new plugin::Create_function<Item_func_elt>("elt"));
   context.add(new plugin::Create_function<Item_func_format>("format"));
   context.add(new plugin::Create_function<Item_func_quote>("quote"));
+  context.add(new plugin::Create_function<drizzled::string_functions::Regex>("regex"));
 
   return 0;
 }
