@@ -18,9 +18,13 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef PLUGIN_STRING_FUNCTIONS_FUNCTIONS_H
-#define PLUGIN_STRING_FUNCTIONS_FUNCTIONS_H
+#pragma once
+
+#include <drizzled/plugin/function.h>
+
+#include <plugin/string_functions/elt.h>
+#include <plugin/string_functions/format.h>
+#include <plugin/string_functions/quote.h>
+#include <plugin/string_functions/regex.h>
 
-#include "drizzled/plugin/function.h"
 
-#endif /* PLUGIN_STRING_FUNCTIONS_FUNCTIONS_H */
