@@ -17,26 +17,33 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef PLUGIN_SYSLOG_ERRMSG_H
-#define PLUGIN_SYSLOG_ERRMSG_H
+#pragma once
 
-#include "module.h"
 #include <stdarg.h>
 #include <drizzled/plugin/error_message.h>
 
-class ErrorMessage_syslog : public drizzled::plugin::ErrorMessage
+namespace drizzle_plugin
+{
+namespace error_message
 {
- private:
-  int syslog_facility;
-  int syslog_priority;
 
-  ErrorMessage_syslog(const ErrorMessage_syslog&);
-  ErrorMessage_syslog& operator=(const ErrorMessage_syslog&);
+class Syslog : public drizzled::plugin::ErrorMessage
+{
+private:
+  int _facility;
+  int _priority;
 
- public:
-  ErrorMessage_syslog();
+  Syslog();
+  Syslog(const Syslog&);
+  Syslog& operator=(const Syslog&);
 
-  virtual bool errmsg(drizzled::Session *, int, const char *format, va_list ap);
+public:
+  explicit Syslog(const std::string& facility,
+                  const std::string& priority);
+
+  virtual bool errmsg(drizzled::error::level_t, const char *format, va_list ap);
 };
 
-#endif /* PLUGIN_SYSLOG_ERRMSG_H */
+} /* namespace error_message */
+} /* namespace drizzle_plugin */
+
