@@ -17,23 +17,25 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef PLUGIN_SYSLOG_FUNCTION_H
-#define PLUGIN_SYSLOG_FUNCTION_H
-
-#include "module.h"
+#pragma once
 
 #include <drizzled/plugin/function.h>
 #include <drizzled/item/func.h>
 #include <drizzled/function/str/strfunc.h>
 
-class Function_syslog : public drizzled::Item_str_func
+namespace drizzle_plugin
+{
+namespace udf
+{
+
+class Syslog : public drizzled::Item_str_func
 {
 private:
-  Function_syslog(const Function_syslog&);
-  Function_syslog& operator=(const Function_syslog&);
+  Syslog(const Syslog&);
+  Syslog& operator=(const Syslog&);
 
 public:
-  Function_syslog();
+  Syslog();
 
   const char *func_name() const { return "syslog"; }
 
@@ -42,4 +44,7 @@ public:
   bool check_argument_count(int n);
 };
 
-#endif /* PLUGIN_SYSLOG_FUNCTION_H */
+} /* namespace udf */
+} /* namepsace drizzle_plugin */
+
+
