@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef PLUGIN_TABLE_CACHE_DICTIONARY_TABLE_CACHE_H
-#define PLUGIN_TABLE_CACHE_DICTIONARY_TABLE_CACHE_H
+#pragma once
 
 namespace table_cache_dictionary {
 
@@ -34,6 +33,7 @@ public:
     drizzled::Table *table;
     std::vector<drizzled::Table *> table_list;
     std::vector<drizzled::Table *>::iterator table_list_iterator;
+    boost::mutex::scoped_lock scopedLock;
 
     void fill();
 
@@ -55,4 +55,3 @@ public:
 
 } /* namespace table_cache_dictionary */
 
-#endif /* PLUGIN_TABLE_CACHE_DICTIONARY_TABLE_CACHE_H */
