@@ -17,10 +17,9 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef PLUGIN_TABLE_CACHE_DICTIONARY_TABLE_DEFINITION_CACHE_H
-#define PLUGIN_TABLE_CACHE_DICTIONARY_TABLE_DEFINITION_CACHE_H
+#pragma once
 
-#include "drizzled/table_share.h"
+#include <drizzled/generator.h>
 
 namespace table_cache_dictionary {
 
@@ -31,14 +30,7 @@ public:
 
   class Generator : public drizzled::plugin::TableFunction::Generator 
   {
-    bool is_primed;
-    drizzled::TableShare *share;
-    drizzled::TableDefinitionCache::const_iterator table_share_iterator;
-
-    void fill();
-
-    bool nextCore();
-    bool next();
+    drizzled::generator::TableDefinitionCache table_definition_cache_generator;
 
   public:
     bool populate();
@@ -55,4 +47,3 @@ public:
 
 } /* namespace table_cache_dictionary */
 
-#endif /* PLUGIN_TABLE_CACHE_DICTIONARY_TABLE_DEFINITION_CACHE_H */
