@@ -1,7 +1,7 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  Authors:
  *
@@ -28,13 +28,15 @@
  * Implements the PRINT_TRANSACTION_MESSAGE(filename, offset) UDF.
  */
 
-#include "config.h"
+#include <config.h>
 #include <drizzled/plugin/function.h>
 #include <drizzled/item/func.h>
 #include <drizzled/function/str/strfunc.h>
 #include <drizzled/error.h>
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/charset.h"
+#include <drizzled/internal/my_sys.h>
+#include <drizzled/charset.h>
+#include <drizzled/gettext.h>
+#include <drizzled/errmsg_print.h>
 
 #include <fcntl.h>
 #include <errno.h>
@@ -101,12 +103,9 @@ String *PrintTransactionMessageFunction::val_str(String *str)
   int log_file= open(filename.c_str(), O_RDONLY);
   if (log_file == -1)
   {
-    char errmsg[STRERROR_MAX];
-    strerror_r(errno, errmsg, sizeof(errmsg));
-    errmsg_printf(ERRMSG_LVL_ERROR, _("Failed to open transaction log file %s.  Got error: %s\n"), 
-                  filename.c_str(), 
-                  errmsg);
+    sql_perror(_("Failed to open transaction log file"), filename);
     null_value= true;
+
     return NULL;
   }
 
@@ -164,11 +163,8 @@ String *PrintTransactionMessageFunction::val_str(String *str)
   bool result= coded_input->ReadRaw(buffer, message_size);
   if (result == false)
   {
-    char errmsg[STRERROR_MAX];
-    strerror_r(errno, errmsg, sizeof(errmsg));
-    fprintf(stderr, _("Could not read transaction message.\n"));
-    fprintf(stderr, _("GPB ERROR: %s.\n"), errmsg);
-    fprintf(stderr, _("Raw buffer read: %s.\n"), buffer);
+    // 120 was arbitrary
+    sql_perror(_("Could not read transaction message. Raw buffer read "), std::string((const char *)buffer, std::min(message_size, 120U)));
   }
 
   result= transaction_message.ParseFromArray(buffer, static_cast<int32_t>(message_size));
