@@ -1,8 +1,8 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008-2009 Sun Microsystems
- *  Copyright (c) 2010 Jay Pipes <jaypipes@gmail.com>
+ *  Copyright (C) 2008-2009 Sun Microsystems, Inc.
+ *  Copyright (C) 2010 Jay Pipes <jaypipes@gmail.com>
  *
  *  Authors:
  *
@@ -69,7 +69,7 @@
  * as a skeleton and a springboard.
  */
 
-#include "config.h"
+#include <config.h>
 #include "transaction_log.h"
 
 #include <sys/stat.h>
@@ -211,12 +211,12 @@ off_t TransactionLog::writeEntry(const uint8_t *data, size_t data_length)
   {
     char errmsg[STRERROR_MAX];
     strerror_r(errno, errmsg, sizeof(errmsg));
-    errmsg_printf(ERRMSG_LVL_ERROR, 
+    errmsg_printf(error::ERROR, 
                   _("Failed to write full size of log entry.  Tried to write %" PRId64
                     " bytes at offset %" PRId64 ", but only wrote %" PRId32 " bytes.  Error: %s\n"), 
                   static_cast<int64_t>(data_length),
                   static_cast<int64_t>(cur_offset),
-                  static_cast<int64_t>(written), 
+                  static_cast<int32_t>(written), 
                   errmsg);
     state= CRASHED;
     /* 
@@ -230,12 +230,9 @@ off_t TransactionLog::writeEntry(const uint8_t *data, size_t data_length)
 
   if (unlikely(error_code != 0))
   {
-    char errmsg[STRERROR_MAX];
-    strerror_r(errno, errmsg, sizeof(errmsg));
-    errmsg_printf(ERRMSG_LVL_ERROR, 
-                  _("Failed to sync log file. Got error: %s\n"), 
-                  errmsg);
+    sql_perror(_("Failed to sync log file."));
   }
+
   return cur_offset;
 }
 
@@ -285,7 +282,6 @@ void TransactionLog::truncate()
     result= ftruncate(log_file, log_offset);
   }
   while (result == -1 && errno == EINTR);
-  drizzled::TransactionServices::singleton().resetTransactionId();
 }
 
 bool TransactionLog::findLogFilenameContainingTransactionId(const ReplicationServices::GlobalTransactionId&,
