@@ -1,8 +1,8 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008-2009 Sun Microsystems
- *  Copyright (c) 2010 Jay Pipes <jaypipes@gmail.com>
+ *  Copyright (C) 2008-2009 Sun Microsystems, Inc.
+ *  Copyright (C) 2010 Jay Pipes <jaypipes@gmail.com>
  *
  *  Authors:
  *
@@ -42,7 +42,7 @@
  * the written transaction to the transaction log index.
  */
 
-#include "config.h"
+#include <config.h>
 #include "write_buffer.h"
 #include "transaction_log.h"
 #include "transaction_log_applier.h"
