@@ -1,8 +1,8 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2008-2009 Sun Microsystems
- *  Copyright (c) 2010 Jay Pipes <jaypipes@gmail.com>
+ *  Copyright (C) 2008-2009 Sun Microsystems, Inc.
+ *  Copyright (C) 2010 Jay Pipes <jaypipes@gmail.com>
  *
  *  Authors:
  *
@@ -32,8 +32,7 @@
  * @see drizzled/plugin/applier.h
  */
 
-#ifndef PLUGIN_TRANSACTION_LOG_TRANSACTION_LOG_APPLIER_H
-#define PLUGIN_TRANSACTION_LOG_TRANSACTION_LOG_APPLIER_H
+#pragma once
 
 #include <drizzled/replication_services.h>
 #include <drizzled/plugin/transaction_applier.h>
@@ -104,4 +103,3 @@ private:
   WriteBuffer *getWriteBuffer(const drizzled::Session &session);
 };
 
-#endif /* PLUGIN_TRANSACTION_LOG_TRANSACTION_LOG_APPLIER_H */
