@@ -1,7 +1,7 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2009 Sun Microsystems
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
  *
  *  Authors:
  *
@@ -28,7 +28,7 @@
  * Defines the implementation of a transaction log entry POD class
  */
 
-#include "config.h"
+#include <config.h>
 
 #include "transaction_log_entry.h"
 
