@@ -36,7 +36,7 @@ DRIZZLE_DECLARE_PLUGIN
   "trigger_dictionary",
   "1.0",
   "Brian Aker",
-  N_("Dictionary of triggers"),
+  "Table for describing what triggers have been loaded.",
   PLUGIN_LICENSE_GPL,
   init,
   NULL,
