@@ -28,11 +28,13 @@ namespace user_locks {
 
 int64_t ReleaseLocks::val_int()
 {
-  user_locks::Storable *list= getSession().getProperty<user_locks::Storable>("user_locks");
-  if (list) // To be compatible with MySQL, we will now release all other locks we might have.
-    return list->erase_all();
+  int64_t count= 0;
 
-  return 0;
+  user_locks::Storable *list= static_cast<user_locks::Storable *>(getSession().getProperty("user_locks"));
+  if (list) // To be compatible with MySQL, we will now release all other locks we might have.
+    count= list->erase_all();
+
+  return count;
 }
 
 } /* namespace user_locks */
