@@ -18,14 +18,15 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
-#include "plugin/utility_dictionary/dictionary.h"
+#include <config.h>
+#include <plugin/utility_dictionary/dictionary.h>
 
 using namespace drizzled;
 
 static int init(drizzled::module::Context &context)
 {
   context.add(new utility_dictionary::Counter);
+  context.add(new utility_dictionary::Environmental);
   context.add(new utility_dictionary::RandomNumber);
   context.add(new utility_dictionary::RandomString);
   
