@@ -20,8 +20,9 @@
 
 #pragma once
 
-#include <drizzled/charset.h>
+#include <drizzled/charset_info.h>
 #include <drizzled/function/str/strfunc.h>
+#include <drizzled/global_charset_info.h>
 
 namespace drizzled
 {
